@@ -12,6 +12,9 @@
 /*! \file */
 
 #include <config.h>
+
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <limits.h>
 
@@ -26,7 +29,6 @@
 #include <isc/string.h>
 #include <isc/util.h>
 #include <isc/task.h>
-#include <isc/stdlib.h>
 
 #include <dns/byaddr.h>
 #include <dns/fixedname.h>
@@ -40,14 +42,14 @@
 
 #include <dig/dig.h>
 
-static isc_boolean_t short_form = ISC_TRUE, listed_server = ISC_FALSE;
-static isc_boolean_t default_lookups = ISC_TRUE;
+static bool short_form = true, listed_server = false;
+static bool default_lookups = true;
 static int seen_error = -1;
-static isc_boolean_t list_addresses = ISC_TRUE;
-static isc_boolean_t list_almost_all = ISC_FALSE;
+static bool list_addresses = true;
+static bool list_almost_all = false;
 static dns_rdatatype_t list_type = dns_rdatatype_a;
-static isc_boolean_t printed_server = ISC_FALSE;
-static isc_boolean_t ipv4only = ISC_FALSE, ipv6only = ISC_FALSE;
+static bool printed_server = false;
+static bool ipv4only = false, ipv6only = false;
 
 static const char *opcodetext[] = {
 	"QUERY",
@@ -224,7 +226,7 @@ say_message(dns_name_t *name, const char *msg, dns_rdata_t *rdata,
 
 static isc_result_t
 printsection(dns_message_t *msg, dns_section_t sectionid,
-	     const char *section_name, isc_boolean_t headers,
+	     const char *section_name, bool headers,
 	     dig_query_t *query)
 {
 	dns_name_t *name, *print_name;
@@ -235,13 +237,13 @@ printsection(dns_message_t *msg, dns_section_t sectionid,
 	isc_region_t r;
 	dns_name_t empty_name;
 	char tbuf[4096];
-	isc_boolean_t first;
-	isc_boolean_t no_rdata;
+	bool first;
+	bool no_rdata;
 
 	if (sectionid == DNS_SECTION_QUESTION)
-		no_rdata = ISC_TRUE;
+		no_rdata = true;
 	else
-		no_rdata = ISC_FALSE;
+		no_rdata = false;
 
 	if (headers)
 		printf(";; %s SECTION:\n", section_name);
@@ -259,7 +261,7 @@ printsection(dns_message_t *msg, dns_section_t sectionid,
 		dns_message_currentname(msg, sectionid, &name);
 
 		isc_buffer_init(&target, tbuf, sizeof(tbuf));
-		first = ISC_TRUE;
+		first = true;
 		print_name = name;
 
 		for (rdataset = ISC_LIST_HEAD(name->list);
@@ -283,7 +285,7 @@ printsection(dns_message_t *msg, dns_section_t sectionid,
 			if (!short_form) {
 				result = dns_rdataset_totext(rdataset,
 							     print_name,
-							     ISC_FALSE,
+							     false,
 							     no_rdata,
 							     &target);
 				if (result != ISC_R_SUCCESS)
@@ -291,7 +293,7 @@ printsection(dns_message_t *msg, dns_section_t sectionid,
 #ifdef USEINITALWS
 				if (first) {
 					print_name = &empty_name;
-					first = ISC_FALSE;
+					first = false;
 				}
 #else
 				UNUSED(first); /* Shut up compiler. */
@@ -350,7 +352,7 @@ printsection(dns_message_t *msg, dns_section_t sectionid,
 static isc_result_t
 printrdata(dns_message_t *msg, dns_rdataset_t *rdataset,
 	   const dns_name_t *owner, const char *set_name,
-	   isc_boolean_t headers)
+	   bool headers)
 {
 	isc_buffer_t target;
 	isc_result_t result;
@@ -363,7 +365,7 @@ printrdata(dns_message_t *msg, dns_rdataset_t *rdataset,
 
 	isc_buffer_init(&target, tbuf, sizeof(tbuf));
 
-	result = dns_rdataset_totext(rdataset, owner, ISC_FALSE, ISC_FALSE,
+	result = dns_rdataset_totext(rdataset, owner, false, false,
 				     &target);
 	if (result != ISC_R_SUCCESS)
 		return (result);
@@ -400,8 +402,8 @@ chase_cnamechain(dns_message_t *msg, dns_name_t *qname) {
 }
 
 static isc_result_t
-printmessage(dig_query_t *query, dns_message_t *msg, isc_boolean_t headers) {
-	isc_boolean_t did_flag = ISC_FALSE;
+printmessage(dig_query_t *query, dns_message_t *msg, bool headers) {
+	bool did_flag = false;
 	dns_rdataset_t *opt, *tsig = NULL;
 	const dns_name_t *tsigname;
 	isc_result_t result = ISC_R_SUCCESS;
@@ -424,7 +426,7 @@ printmessage(dig_query_t *query, dns_message_t *msg, isc_boolean_t headers) {
 				    sizeof(sockstr));
 		printf("Address: %s\n", sockstr);
 		printf("Aliases: \n\n");
-		printed_server = ISC_TRUE;
+		printed_server = true;
 	}
 
 	if (msg->rcode != 0) {
@@ -456,22 +458,22 @@ printmessage(dig_query_t *query, dns_message_t *msg, isc_boolean_t headers) {
 		dns_name_copy(query->lookup->name, name, NULL);
 		chase_cnamechain(msg, name);
 		dns_name_format(name, namestr, sizeof(namestr));
-		lookup = clone_lookup(query->lookup, ISC_FALSE);
+		lookup = clone_lookup(query->lookup, false);
 		if (lookup != NULL) {
 			strlcpy(lookup->textname, namestr,
 				sizeof(lookup->textname));
 			lookup->rdtype = dns_rdatatype_aaaa;
-			lookup->rdtypeset = ISC_TRUE;
+			lookup->rdtypeset = true;
 			lookup->origin = NULL;
 			lookup->retries = tries;
 			ISC_LIST_APPEND(lookup_list, lookup, link);
 		}
-		lookup = clone_lookup(query->lookup, ISC_FALSE);
+		lookup = clone_lookup(query->lookup, false);
 		if (lookup != NULL) {
 			strlcpy(lookup->textname, namestr,
 				sizeof(lookup->textname));
 			lookup->rdtype = dns_rdatatype_mx;
-			lookup->rdtypeset = ISC_TRUE;
+			lookup->rdtypeset = true;
 			lookup->origin = NULL;
 			lookup->retries = tries;
 			ISC_LIST_APPEND(lookup_list, lookup, link);
@@ -485,31 +487,31 @@ printmessage(dig_query_t *query, dns_message_t *msg, isc_boolean_t headers) {
 		printf(";; flags: ");
 		if ((msg->flags & DNS_MESSAGEFLAG_QR) != 0) {
 			printf("qr");
-			did_flag = ISC_TRUE;
+			did_flag = true;
 		}
 		if ((msg->flags & DNS_MESSAGEFLAG_AA) != 0) {
 			printf("%saa", did_flag ? " " : "");
-			did_flag = ISC_TRUE;
+			did_flag = true;
 		}
 		if ((msg->flags & DNS_MESSAGEFLAG_TC) != 0) {
 			printf("%stc", did_flag ? " " : "");
-			did_flag = ISC_TRUE;
+			did_flag = true;
 		}
 		if ((msg->flags & DNS_MESSAGEFLAG_RD) != 0) {
 			printf("%srd", did_flag ? " " : "");
-			did_flag = ISC_TRUE;
+			did_flag = true;
 		}
 		if ((msg->flags & DNS_MESSAGEFLAG_RA) != 0) {
 			printf("%sra", did_flag ? " " : "");
-			did_flag = ISC_TRUE;
+			did_flag = true;
 		}
 		if ((msg->flags & DNS_MESSAGEFLAG_AD) != 0) {
 			printf("%sad", did_flag ? " " : "");
-			did_flag = ISC_TRUE;
+			did_flag = true;
 		}
 		if ((msg->flags & DNS_MESSAGEFLAG_CD) != 0) {
 			printf("%scd", did_flag ? " " : "");
-			did_flag = ISC_TRUE;
+			did_flag = true;
 			POST(did_flag);
 		}
 		printf("; QUERY: %u, ANSWER: %u, "
@@ -532,7 +534,7 @@ printmessage(dig_query_t *query, dns_message_t *msg, isc_boolean_t headers) {
 	    !short_form) {
 		printf("\n");
 		result = printsection(msg, DNS_SECTION_QUESTION, "QUESTION",
-				      ISC_TRUE, query);
+				      true, query);
 		if (result != ISC_R_SUCCESS)
 			return (result);
 	}
@@ -540,7 +542,7 @@ printmessage(dig_query_t *query, dns_message_t *msg, isc_boolean_t headers) {
 		if (!short_form)
 			printf("\n");
 		result = printsection(msg, DNS_SECTION_ANSWER, "ANSWER",
-				      ISC_TF(!short_form), query);
+				      !short_form, query);
 		if (result != ISC_R_SUCCESS)
 			return (result);
 	}
@@ -549,7 +551,7 @@ printmessage(dig_query_t *query, dns_message_t *msg, isc_boolean_t headers) {
 	    !short_form) {
 		printf("\n");
 		result = printsection(msg, DNS_SECTION_AUTHORITY, "AUTHORITY",
-				      ISC_TRUE, query);
+				      true, query);
 		if (result != ISC_R_SUCCESS)
 			return (result);
 	}
@@ -557,14 +559,14 @@ printmessage(dig_query_t *query, dns_message_t *msg, isc_boolean_t headers) {
 	    !short_form) {
 		printf("\n");
 		result = printsection(msg, DNS_SECTION_ADDITIONAL,
-				      "ADDITIONAL", ISC_TRUE, query);
+				      "ADDITIONAL", true, query);
 		if (result != ISC_R_SUCCESS)
 			return (result);
 	}
 	if ((tsig != NULL) && !short_form) {
 		printf("\n");
 		result = printrdata(msg, tsig, tsigname,
-				    "PSEUDOSECTION TSIG", ISC_TRUE);
+				    "PSEUDOSECTION TSIG", true);
 		if (result != ISC_R_SUCCESS)
 			return (result);
 	}
@@ -599,7 +601,7 @@ pre_parse_args(int argc, char **argv) {
 	while ((c = isc_commandline_parse(argc, argv, optstring)) != -1) {
 		switch (c) {
 		case 'm':
-			memdebugging = ISC_TRUE;
+			memdebugging = true;
 			if (strcasecmp("trace", isc_commandline_argument) == 0)
 				isc_mem_debugging |= ISC_MEM_DEBUGTRACE;
 			else if (strcasecmp("record",
@@ -613,12 +615,12 @@ pre_parse_args(int argc, char **argv) {
 		case '4':
 			if (ipv6only)
 				fatal("only one of -4 and -6 allowed");
-			ipv4only = ISC_TRUE;
+			ipv4only = true;
 			break;
 		case '6':
 			if (ipv4only)
 				fatal("only one of -4 and -6 allowed");
-			ipv6only = ISC_TRUE;
+			ipv6only = true;
 			break;
 		case 'a': break;
 		case 'A': break;
@@ -639,8 +641,8 @@ pre_parse_args(int argc, char **argv) {
 		case 'C': break;
 		case 'D':
 			if (debugging)
-				debugtiming = ISC_TRUE;
-			debugging = ISC_TRUE;
+				debugtiming = true;
+			debugging = true;
 			break;
 		case 'N': break;
 		case 'R': break;
@@ -650,12 +652,12 @@ pre_parse_args(int argc, char **argv) {
 			show_usage();
 		}
 	}
-	isc_commandline_reset = ISC_TRUE;
+	isc_commandline_reset = true;
 	isc_commandline_index = 1;
 }
 
 static void
-parse_args(isc_boolean_t is_batchfile, int argc, char **argv) {
+parse_args(bool is_batchfile, int argc, char **argv) {
 	char hostname[MXNAME];
 	dig_lookup_t *lookup;
 	int c;
@@ -664,30 +666,30 @@ parse_args(isc_boolean_t is_batchfile, int argc, char **argv) {
 	isc_result_t result = ISC_R_SUCCESS;
 	dns_rdatatype_t rdtype;
 	dns_rdataclass_t rdclass;
-	isc_uint32_t serial = 0;
+	uint32_t serial = 0;
 
 	UNUSED(is_batchfile);
 
 	lookup = make_empty_lookup();
 
-	lookup->servfail_stops = ISC_FALSE;
-	lookup->comments = ISC_FALSE;
+	lookup->servfail_stops = false;
+	lookup->comments = false;
 	short_form = !verbose;
 
 	while ((c = isc_commandline_parse(argc, argv, optstring)) != -1) {
 		switch (c) {
 		case 'l':
-			lookup->tcp_mode = ISC_TRUE;
+			lookup->tcp_mode = true;
 			lookup->rdtype = dns_rdatatype_axfr;
-			lookup->rdtypeset = ISC_TRUE;
+			lookup->rdtypeset = true;
 			fatalexit = 3;
 			break;
 		case 'v':
 		case 'd':
-			short_form = ISC_FALSE;
+			short_form = false;
 			break;
 		case 'r':
-			lookup->recurse = ISC_FALSE;
+			lookup->recurse = false;
 			break;
 		case 't':
 			if (strncasecmp(isc_commandline_argument,
@@ -712,23 +714,23 @@ parse_args(isc_boolean_t is_batchfile, int argc, char **argv) {
 			if (!lookup->rdtypeset ||
 			    lookup->rdtype != dns_rdatatype_axfr)
 				lookup->rdtype = rdtype;
-			lookup->rdtypeset = ISC_TRUE;
+			lookup->rdtypeset = true;
 			if (rdtype == dns_rdatatype_axfr) {
 				/* -l -t any -v */
 				list_type = dns_rdatatype_any;
-				short_form = ISC_FALSE;
-				lookup->tcp_mode = ISC_TRUE;
+				short_form = false;
+				lookup->tcp_mode = true;
 			} else if (rdtype == dns_rdatatype_ixfr) {
 				lookup->ixfr_serial = serial;
-				lookup->tcp_mode = ISC_TRUE;
+				lookup->tcp_mode = true;
 				list_type = rdtype;
 			} else if (rdtype == dns_rdatatype_any) {
 				if (!lookup->tcp_mode_set)
-					lookup->tcp_mode = ISC_TRUE;
+					lookup->tcp_mode = true;
 			} else
 				list_type = rdtype;
-			list_addresses = ISC_FALSE;
-			default_lookups = ISC_FALSE;
+			list_addresses = false;
+			default_lookups = false;
 			break;
 		case 'c':
 			tr.base = isc_commandline_argument;
@@ -742,25 +744,25 @@ parse_args(isc_boolean_t is_batchfile, int argc, char **argv) {
 				      isc_commandline_argument);
 			} else {
 				lookup->rdclass = rdclass;
-				lookup->rdclassset = ISC_TRUE;
+				lookup->rdclassset = true;
 			}
-			default_lookups = ISC_FALSE;
+			default_lookups = false;
 			break;
 		case 'A':
-			list_almost_all = ISC_TRUE;
+			list_almost_all = true;
 			/* FALL THROUGH */
 		case 'a':
 			if (!lookup->rdtypeset ||
 			    lookup->rdtype != dns_rdatatype_axfr)
 				lookup->rdtype = dns_rdatatype_any;
 			list_type = dns_rdatatype_any;
-			list_addresses = ISC_FALSE;
-			lookup->rdtypeset = ISC_TRUE;
-			short_form = ISC_FALSE;
-			default_lookups = ISC_FALSE;
+			list_addresses = false;
+			lookup->rdtypeset = true;
+			short_form = false;
+			default_lookups = false;
 			break;
 		case 'i':
-			lookup->ip6_int = ISC_TRUE;
+			lookup->ip6_int = true;
 			break;
 		case 'n':
 			/* deprecated */
@@ -786,23 +788,23 @@ parse_args(isc_boolean_t is_batchfile, int argc, char **argv) {
 				tries = 2;
 			break;
 		case 'T':
-			lookup->tcp_mode = ISC_TRUE;
-			lookup->tcp_mode_set = ISC_TRUE;
+			lookup->tcp_mode = true;
+			lookup->tcp_mode_set = true;
 			break;
 		case 'U':
-			lookup->tcp_mode = ISC_FALSE;
-			lookup->tcp_mode_set = ISC_TRUE;
+			lookup->tcp_mode = false;
+			lookup->tcp_mode_set = true;
 			break;
 		case 'C':
 			debug("showing all SOAs");
 			lookup->rdtype = dns_rdatatype_ns;
-			lookup->rdtypeset = ISC_TRUE;
+			lookup->rdtypeset = true;
 			lookup->rdclass = dns_rdataclass_in;
-			lookup->rdclassset = ISC_TRUE;
-			lookup->ns_search_only = ISC_TRUE;
-			lookup->trace_root = ISC_TRUE;
-			lookup->identify_previous_line = ISC_TRUE;
-			default_lookups = ISC_FALSE;
+			lookup->rdclassset = true;
+			lookup->ns_search_only = true;
+			lookup->trace_root = true;
+			lookup->identify_previous_line = true;
+			default_lookups = false;
 			break;
 		case 'N':
 			debug("setting NDOTS to %s",
@@ -819,7 +821,7 @@ parse_args(isc_boolean_t is_batchfile, int argc, char **argv) {
 			/* Handled by pre_parse_args(). */
 			break;
 		case 's':
-			lookup->servfail_stops = ISC_TRUE;
+			lookup->servfail_stops = true;
 			break;
 		}
 	}
@@ -834,22 +836,22 @@ parse_args(isc_boolean_t is_batchfile, int argc, char **argv) {
 	if (argc > isc_commandline_index + 1) {
 		set_nameserver(argv[isc_commandline_index+1]);
 		debug("server is %s", argv[isc_commandline_index+1]);
-		listed_server = ISC_TRUE;
+		listed_server = true;
 	} else
-		check_ra = ISC_TRUE;
+		check_ra = true;
 
-	lookup->pending = ISC_FALSE;
+	lookup->pending = false;
 	if (get_reverse(store, sizeof(store), hostname,
-			lookup->ip6_int, ISC_TRUE) == ISC_R_SUCCESS) {
+			lookup->ip6_int, true) == ISC_R_SUCCESS) {
 		strlcpy(lookup->textname, store, sizeof(lookup->textname));
 		lookup->rdtype = dns_rdatatype_ptr;
-		lookup->rdtypeset = ISC_TRUE;
-		default_lookups = ISC_FALSE;
+		lookup->rdtypeset = true;
+		default_lookups = false;
 	} else {
 		strlcpy(lookup->textname, hostname, sizeof(lookup->textname));
-		usesearch = ISC_TRUE;
+		usesearch = true;
 	}
-	lookup->new_search = ISC_TRUE;
+	lookup->new_search = true;
 	ISC_LIST_APPEND(lookup_list, lookup, link);
 }
 
@@ -878,7 +880,7 @@ main(int argc, char **argv) {
 	check_result(result, "isc_app_start");
 	setup_libs();
 	setup_system(ipv4only, ipv6only);
-	parse_args(ISC_FALSE, argc, argv);
+	parse_args(false, argc, argv);
 	if (keyfile[0] != 0)
 		setup_file_key();
 	else if (keysecret[0] != 0)
