@@ -19,6 +19,8 @@
 #include <config.h>
 
 #include <errno.h>
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 
 #include <isc/buffer.h>
@@ -53,14 +55,14 @@
 
 #include <dst/dst.h>
 
-#if HAVE_PKCS11
+#if USE_PKCS11
 #include <pk11/result.h>
 #endif
 
 #include "dnssectool.h"
 
 #ifndef PATH_MAX
-#define PATH_MAX 1024   /* AIX, WIN32, and others don't define this. */
+#define PATH_MAX 1024   /* WIN32, and others don't define this. */
 #endif
 
 const char *program = "dnssec-cds";
@@ -84,7 +86,7 @@ static dns_rdataclass_t rdclass = dns_rdataclass_in;
  * List of digest types used by ds_from_cdnskey(), filled in by add_dtype()
  * from -a arguments. The size of the array is an arbitrary limit.
  */
-static isc_uint8_t dtype[8];
+static uint8_t dtype[8];
 
 static const char *startstr  = NULL;	/* from which we derive notbefore */
 static isc_stdtime_t notbefore = 0;	/* restrict sig inception times */
@@ -127,7 +129,7 @@ static int nkey; /* number of child zone DNSKEY records */
 typedef struct keyinfo {
 	dns_rdata_t rdata;
 	dst_key_t *dst;
-	isc_uint8_t algo;
+	uint8_t algo;
 	dns_keytag_t tag;
 } keyinfo_t;
 
@@ -258,7 +260,7 @@ load_db(const char *filename, dns_db_t **dbp, dns_dbnode_t **nodep) {
 		      isc_result_totext(result));
 	}
 
-	result = dns_db_findnode(*dbp, name, ISC_FALSE, nodep);
+	result = dns_db_findnode(*dbp, name, false, nodep);
 	if (result != ISC_R_SUCCESS) {
 		fatal("can't find %s node in %s", namestr, filename);
 	}
@@ -312,7 +314,7 @@ get_dsset_name(char *filename, size_t size,
 		}
 		isc_buffer_putstr(&buf, prefix);
 
-		result = dns_name_tofilenametext(name, ISC_FALSE, &buf);
+		result = dns_name_tofilenametext(name, false, &buf);
 		check_result(result, "dns_name_tofilenametext()");
 		if (isc_buffer_availablelength(&buf) == 0) {
 			fatal("%s: pathname too long", path);
@@ -400,7 +402,7 @@ formatset(dns_rdataset_t *rdataset) {
 
 static void
 write_parent_set(const char *path, const char *inplace,
-		 isc_boolean_t nsupdate, dns_rdataset_t *rdataset)
+		 bool nsupdate, dns_rdataset_t *rdataset)
 {
 	isc_result_t result;
 	isc_buffer_t *buf = NULL;
@@ -467,7 +469,7 @@ typedef enum { LOOSE, TIGHT } strictness_t;
 /*
  * Find out if any (C)DS record matches a particular (C)DNSKEY.
  */
-static isc_boolean_t
+static bool
 match_key_dsset(keyinfo_t *ki, dns_rdataset_t *dsset, strictness_t strictness)
 {
 	isc_result_t result;
@@ -481,7 +483,7 @@ match_key_dsset(keyinfo_t *ki, dns_rdataset_t *dsset, strictness_t strictness)
 		dns_rdata_t dsrdata = DNS_RDATA_INIT;
 		dns_rdata_t newdsrdata = DNS_RDATA_INIT;
 		dns_rdatatype_t keytype;
-		isc_boolean_t c;
+		bool c;
 
 		dns_rdataset_current(dsset, &dsrdata);
 		result = dns_rdata_tostruct(&dsrdata, &ds, NULL);
@@ -511,13 +513,13 @@ match_key_dsset(keyinfo_t *ki, dns_rdataset_t *dsset, strictness_t strictness)
 			vbprintf(1, "found matching %s %d %d %d\n",
 				 c ? "CDS" : "DS",
 				 ds.key_tag, ds.algorithm, ds.digest_type);
-			return (ISC_TRUE);
+			return (true);
 		} else if (strictness == TIGHT) {
 			vbprintf(0, "key does not match %s %d %d %d "
 				"when it looks like it should\n",
 				 c ? "CDS" : "DS",
 				 ds.key_tag, ds.algorithm, ds.digest_type);
-			return (ISC_FALSE);
+			return (false);
 		}
 	}
 
@@ -528,7 +530,7 @@ match_key_dsset(keyinfo_t *ki, dns_rdataset_t *dsset, strictness_t strictness)
 		 ? "CDNSKEY" : "DNSKEY",
 		 ki->tag, ki->algo);
 
-	return (ISC_FALSE);
+	return (false);
 }
 
 /*
@@ -617,12 +619,12 @@ free_keytable(keyinfo_t **keytable_p) {
  * otherwise the key algorithm. This is used by the signature coverage
  * check functions below.
  */
-static isc_uint8_t *
+static uint8_t *
 matching_sigs(keyinfo_t *keytbl, dns_rdataset_t *rdataset,
 	      dns_rdataset_t *sigset)
 {
 	isc_result_t result;
-	isc_uint8_t *algo;
+	uint8_t *algo;
 	int i;
 
 	algo = isc_mem_get(mctx, nkey);
@@ -668,7 +670,7 @@ matching_sigs(keyinfo_t *keytbl, dns_rdataset_t *rdataset,
 			}
 
 			result = dns_dnssec_verify(name, rdataset, ki->dst,
-						   ISC_FALSE, 0, mctx,
+						   false, 0, mctx,
 						   &sigrdata, NULL);
 
 			if (result != ISC_R_SUCCESS &&
@@ -704,13 +706,13 @@ matching_sigs(keyinfo_t *keytbl, dns_rdataset_t *rdataset,
  * Consume the result of matching_sigs(). When checking records
  * fetched from the child zone, any working signature is enough.
  */
-static isc_boolean_t
-signed_loose(isc_uint8_t *algo) {
-	isc_boolean_t ok = ISC_FALSE;
+static bool
+signed_loose(uint8_t *algo) {
+	bool ok = false;
 	int i;
 	for (i = 0; i < nkey; i++) {
 		if (algo[i] != 0) {
-			ok = ISC_TRUE;
+			ok = true;
 		}
 	}
 	isc_mem_put(mctx, algo, nkey);
@@ -723,10 +725,10 @@ signed_loose(isc_uint8_t *algo) {
  * key algorithm in the DS RRset must have a signature in the DNSKEY
  * RRset.
  */
-static isc_boolean_t
-signed_strict(dns_rdataset_t *dsset, isc_uint8_t *algo) {
+static bool
+signed_strict(dns_rdataset_t *dsset, uint8_t *algo) {
 	isc_result_t result;
-	isc_boolean_t all_ok = ISC_TRUE;
+	bool all_ok = true;
 
 	for (result = dns_rdataset_first(dsset);
 	     result == ISC_R_SUCCESS;
@@ -734,23 +736,23 @@ signed_strict(dns_rdataset_t *dsset, isc_uint8_t *algo) {
 	{
 		dns_rdata_t dsrdata = DNS_RDATA_INIT;
 		dns_rdata_ds_t ds;
-		isc_boolean_t ds_ok;
+		bool ds_ok;
 		int i;
 
 		dns_rdataset_current(dsset, &dsrdata);
 		result = dns_rdata_tostruct(&dsrdata, &ds, NULL);
 		check_result(result, "dns_rdata_tostruct(DS)");
 
-		ds_ok = ISC_FALSE;
+		ds_ok = false;
 		for (i = 0; i < nkey; i++) {
 			if (algo[i] == ds.algorithm) {
-				ds_ok = ISC_TRUE;
+				ds_ok = true;
 			}
 		}
 		if (!ds_ok) {
 			vbprintf(0, "missing signature for algorithm %d "
 				 "(key %d)\n", ds.algorithm, ds.key_tag);
-			all_ok = ISC_FALSE;
+			all_ok = false;
 		}
 	}
 
@@ -848,14 +850,14 @@ ds_from_cdnskey(dns_rdatalist_t *dslist, isc_buffer_t *buf,
  */
 static int
 cmp_dtype(const void *ap, const void *bp) {
-	int a = *(const isc_uint8_t *)ap;
-	int b = *(const isc_uint8_t *)bp;
+	int a = *(const uint8_t *)ap;
+	int b = *(const uint8_t *)bp;
 	return (a - b);
 }
 
 static void
 add_dtype(const char *dn) {
-	isc_uint8_t dt;
+	uint8_t dt;
 	unsigned i, n;
 
 	dt = strtodsdigest(dn);
@@ -872,7 +874,7 @@ add_dtype(const char *dn) {
 
 static void
 make_new_ds_set(ds_maker_func_t *ds_from_rdata,
-		isc_uint32_t ttl, dns_rdataset_t *rdset)
+		uint32_t ttl, dns_rdataset_t *rdset)
 {
 	unsigned int size = 16;
 	for (;;) {
@@ -934,14 +936,14 @@ rdata_cmp(const void *rdata1, const void *rdata2) {
  * Ensure that every key identified by the DS RRset has the same set of
  * digest types.
  */
-static isc_boolean_t
+static bool
 consistent_digests(dns_rdataset_t *dsset) {
 	isc_result_t result;
 	dns_rdata_t *arrdata;
 	dns_rdata_ds_t *ds;
 	dns_keytag_t key_tag;
-	isc_uint8_t algorithm;
-	isc_boolean_t match;
+	uint8_t algorithm;
+	bool match;
 	int i, j, n, d;
 
 	/*
@@ -995,7 +997,7 @@ consistent_digests(dns_rdataset_t *dsset) {
 	/*
 	 * Check subsequent keys match the first one
 	 */
-	match = ISC_TRUE;
+	match = true;
 	while (i < n) {
 		key_tag = ds[i].key_tag;
 		algorithm = ds[i].algorithm;
@@ -1004,7 +1006,7 @@ consistent_digests(dns_rdataset_t *dsset) {
 			    ds[i+j].algorithm != algorithm ||
 			    ds[i+j].digest_type != ds[j].digest_type)
 			{
-				match = ISC_FALSE;
+				match = false;
 			}
 		}
 		i += d;
@@ -1039,7 +1041,7 @@ print_diff(const char *cmd, dns_rdataset_t *rdataset) {
 }
 
 static void
-update_diff(const char *cmd, isc_uint32_t ttl,
+update_diff(const char *cmd, uint32_t ttl,
 	    dns_rdataset_t *addset, dns_rdataset_t *delset)
 {
 	isc_result_t result;
@@ -1047,7 +1049,7 @@ update_diff(const char *cmd, isc_uint32_t ttl,
 	dns_dbnode_t *node;
 	dns_dbversion_t *ver;
 	dns_rdataset_t diffset;
-	isc_uint32_t save;
+	uint32_t save;
 
 	db = NULL;
 	result = dns_db_create(mctx, "rbt", name, dns_dbtype_zone,
@@ -1059,7 +1061,7 @@ update_diff(const char *cmd, isc_uint32_t ttl,
 	check_result(result, "dns_db_newversion()");
 
 	node = NULL;
-	result = dns_db_findnode(db, name, ISC_TRUE, &node);
+	result = dns_db_findnode(db, name, true, &node);
 	check_result(result, "dns_db_findnode()");
 
 	dns_rdataset_init(&diffset);
@@ -1083,12 +1085,12 @@ update_diff(const char *cmd, isc_uint32_t ttl,
 	}
 
 	dns_db_detachnode(db, &node);
-	dns_db_closeversion(db, &ver, ISC_FALSE);
+	dns_db_closeversion(db, &ver, false);
 	dns_db_detach(&db);
 }
 
 static void
-nsdiff(isc_uint32_t ttl, dns_rdataset_t *oldset, dns_rdataset_t *newset) {
+nsdiff(uint32_t ttl, dns_rdataset_t *oldset, dns_rdataset_t *newset) {
 	if (ttl == 0) {
 		vbprintf(1, "warning: no TTL in nsupdate script\n");
 	}
@@ -1136,9 +1138,9 @@ main(int argc, char *argv[]) {
 	const char *ds_path = NULL;
 	const char *inplace = NULL;
 	isc_result_t result;
-	isc_boolean_t prefer_cdnskey = ISC_FALSE;
-	isc_boolean_t nsupdate = ISC_FALSE;
-	isc_uint32_t ttl = 0;
+	bool prefer_cdnskey = false;
+	bool nsupdate = false;
+	uint32_t ttl = 0;
 	int ch;
 	char *endp;
 
@@ -1147,12 +1149,12 @@ main(int argc, char *argv[]) {
 		fatal("out of memory");
 	}
 
-#if HAVE_PKCS11
+#if USE_PKCS11
 	pk11_result_register();
 #endif
 	dns_result_register();
 
-	isc_commandline_errprint = ISC_FALSE;
+	isc_commandline_errprint = false;
 
 #define OPTIONS "a:c:Dd:f:i:ms:T:uv:V"
 	while ((ch = isc_commandline_parse(argc, argv, OPTIONS)) != -1) {
@@ -1164,7 +1166,7 @@ main(int argc, char *argv[]) {
 			rdclass = strtoclass(isc_commandline_argument);
 			break;
 		case 'D':
-			prefer_cdnskey = ISC_TRUE;
+			prefer_cdnskey = true;
 			break;
 		case 'd':
 			ds_path = isc_commandline_argument;
@@ -1197,7 +1199,7 @@ main(int argc, char *argv[]) {
 			ttl = strtottl(isc_commandline_argument);
 			break;
 		case 'u':
-			nsupdate = ISC_TRUE;
+			nsupdate = true;
 			break;
 		case 'V':
 			/* Does not return. */
