@@ -12,8 +12,7 @@ SYSTEMTESTTOP=..
 
 status=0
 n=0
-# using dig insecure mode as not testing dnssec here
-DIGOPTS="-i -p ${PORT}"
+DIGOPTS="-p ${PORT}"
 SENDCMD="$PERL $SYSTEMTESTTOP/send.pl 10.53.0.4 ${EXTRAPORT1}"
 
 if [ -x ${DIG} ] ; then
@@ -443,23 +442,6 @@ if [ -x ${DIG} ] ; then
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
-  n=`expr $n + 1`
-  if $FEATURETEST --with-idn
-  then
-    echo_i "checking dig +idnout ($n)"
-    ret=0
-    $DIG $DIGOPTS @10.53.0.3 +noidnout xn--caf-dma.example. > dig.out.1.test$n 2>&1 || ret=1
-    $DIG $DIGOPTS @10.53.0.3 +idnout xn--caf-dma.example. > dig.out.2.test$n 2>&1 || ret=1
-    grep "^xn--caf-dma.example" dig.out.1.test$n > /dev/null || ret=1
-    grep "^xn--caf-dma.example" dig.out.2.test$n > /dev/null && ret=1
-    grep 10.1.2.3 dig.out.1.test$n > /dev/null || ret=1
-    grep 10.1.2.3 dig.out.2.test$n > /dev/null || ret=1
-    if [ $ret != 0 ]; then echo_i "failed"; fi
-    status=`expr $status + $ret`
-  else
-    echo_i "skipping 'dig +idnout' as IDN support is not enabled ($n)"
-  fi
-
   n=`expr $n + 1`
   echo_i "checking that dig warns about .local queries ($n)"
   ret=0
@@ -493,6 +475,14 @@ if [ -x ${DIG} ] ; then
   if [ $ret != 0 ]; then echo_i "failed"; fi
   status=`expr $status + $ret`
 
+  n=`expr $n + 1`
+  echo_i "check that dig handles malformed option '+ednsopt=:' gracefully ($n)"
+  ret=0
+  $DIG $DIGOPTS @10.53.0.3 +ednsopt=: a.example > dig.out.test$n 2>&1 && ret=1
+  grep "ednsopt no code point specified" dig.out.test$n > /dev/null || ret=1
+  if [ $ret != 0 ]; then echo_i "failed"; fi
+  status=`expr $status + $ret`
+
   n=`expr $n + 1`
   echo_i "check that dig gracefully handles bad escape in domain name ($n)"
   ret=0
@@ -509,6 +499,19 @@ else
   echo_i "$DIG is needed, so skipping these dig tests"
 fi
 
+MDIGOPTS="-p ${PORT}"
+if [ -x ${MDIG} ] ; then
+  n=`expr $n + 1`
+  echo_i "check that mdig handles malformed option '+ednsopt=:' gracefully ($n)"
+  ret=0
+  $MDIG $MDIGOPTS @10.53.0.3 +ednsopt=: a.example > dig.out.test$n 2>&1 && ret=1
+  grep "ednsopt no code point specified" dig.out.test$n > /dev/null || ret=1
+  if [ $ret != 0 ]; then echo_i "failed"; fi
+  status=`expr $status + $ret`
+else
+  echo_i "$MDIG is needed, so skipping these mdig tests"
+fi
+
 # using delv insecure mode as not testing dnssec here
 DELVOPTS="-i -p ${PORT}"
 
