@@ -12,6 +12,9 @@
  */
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
+
 #include <isc/string.h>
 #include <isc/util.h>
 
@@ -69,7 +72,7 @@ attach(dns_db_t *source, dns_db_t **targetp) {
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
 
-	isc_refcount_increment(&sampledb->refs, NULL);
+	isc_refcount_increment(&sampledb->refs);
 	*targetp = source;
 }
 
@@ -84,15 +87,13 @@ free_sampledb(sampledb_t *sampledb) {
 
 static void
 detach(dns_db_t **dbp) {
+	REQUIRE(dbp != NULL && VALID_SAMPLEDB((sampledb_t *)(*dbp)));
 	sampledb_t *sampledb = (sampledb_t *)(*dbp);
-	unsigned int refs;
-
-	REQUIRE(VALID_SAMPLEDB(sampledb));
-
-	isc_refcount_decrement(&sampledb->refs, &refs);
-	if (refs == 0)
-		free_sampledb(sampledb);
 	*dbp = NULL;
+
+	if (isc_refcount_decrement(&sampledb->refs) == 1) {
+		free_sampledb(sampledb);
+	}
 }
 
 /*
@@ -182,7 +183,7 @@ attachversion(dns_db_t *db, dns_dbversion_t *source,
 }
 
 static void
-closeversion(dns_db_t *db, dns_dbversion_t **versionp, isc_boolean_t commit) {
+closeversion(dns_db_t *db, dns_dbversion_t **versionp, bool commit) {
 	sampledb_t *sampledb = (sampledb_t *)db;
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
@@ -191,7 +192,7 @@ closeversion(dns_db_t *db, dns_dbversion_t **versionp, isc_boolean_t commit) {
 }
 
 static isc_result_t
-findnode(dns_db_t *db, const dns_name_t *name, isc_boolean_t create,
+findnode(dns_db_t *db, const dns_name_t *name, bool create,
 	 dns_dbnode_t **nodep)
 {
 	sampledb_t *sampledb = (sampledb_t *) db;
@@ -372,7 +373,7 @@ deleterdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 				      type, covers));
 }
 
-static isc_boolean_t
+static bool
 issecure(dns_db_t *db) {
 	sampledb_t *sampledb = (sampledb_t *) db;
 
@@ -392,17 +393,17 @@ nodecount(dns_db_t *db) {
 
 /*
  * The database does not need to be loaded from disk or written to disk.
- * Always return ISC_TRUE.
+ * Always return true.
  */
-static isc_boolean_t
+static bool
 ispersistent(dns_db_t *db) {
 	UNUSED(db);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 static void
-overmem(dns_db_t *db, isc_boolean_t over) {
+overmem(dns_db_t *db, bool over) {
 	sampledb_t *sampledb = (sampledb_t *) db;
 
 	REQUIRE(VALID_SAMPLEDB(sampledb));
@@ -440,8 +441,8 @@ transfernode(dns_db_t *db, dns_dbnode_t **sourcep, dns_dbnode_t **targetp) {
 
 static isc_result_t
 getnsec3parameters(dns_db_t *db, dns_dbversion_t *version,
-		   dns_hash_t *hash, isc_uint8_t *flags,
-		   isc_uint16_t *iterations,
+		   dns_hash_t *hash, uint8_t *flags,
+		   uint16_t *iterations,
 		   unsigned char *salt, size_t *salt_length)
 {
 	sampledb_t *sampledb = (sampledb_t *) db;
@@ -455,7 +456,7 @@ getnsec3parameters(dns_db_t *db, dns_dbversion_t *version,
 }
 
 static isc_result_t
-findnsec3node(dns_db_t *db, const dns_name_t *name, isc_boolean_t create,
+findnsec3node(dns_db_t *db, const dns_name_t *name, bool create,
 	      dns_dbnode_t **nodep)
 {
 	sampledb_t *sampledb = (sampledb_t *) db;
@@ -492,7 +493,7 @@ resigned(dns_db_t *db, dns_rdataset_t *rdataset, dns_dbversion_t *version) {
 	dns_db_resigned(sampledb->rbtdb, rdataset, version);
 }
 
-static isc_boolean_t
+static bool
 isdnssec(dns_db_t *db) {
 	sampledb_t *sampledb = (sampledb_t *) db;
 
@@ -513,7 +514,7 @@ getrrsetstats(dns_db_t *db) {
 
 static isc_result_t
 findnodeext(dns_db_t *db, const dns_name_t *name,
-	    isc_boolean_t create, dns_clientinfomethods_t *methods,
+	    bool create, dns_clientinfomethods_t *methods,
 	    dns_clientinfo_t *clientinfo, dns_dbnode_t **nodep)
 {
 	sampledb_t *sampledb = (sampledb_t *) db;
@@ -645,7 +646,7 @@ add_soa(dns_db_t *db, dns_dbversion_t *version, const dns_name_t *name,
 	rdatalist.ttl = 86400;
 	ISC_LIST_APPEND(rdatalist.rdata, &rdata, link);
 	CHECK(dns_rdatalist_tordataset(&rdatalist, &rdataset));
-	CHECK(dns_db_findnode(db, name, ISC_TRUE, &node));
+	CHECK(dns_db_findnode(db, name, true, &node));
 	CHECK(dns_db_addrdataset(db, node, version, 0, &rdataset, 0, NULL));
  cleanup:
 	if (node != NULL)
@@ -684,7 +685,7 @@ add_ns(dns_db_t *db, dns_dbversion_t *version, const dns_name_t *name,
 	rdatalist.ttl = 86400;
 	ISC_LIST_APPEND(rdatalist.rdata, &rdata, link);
 	CHECK(dns_rdatalist_tordataset(&rdatalist, &rdataset));
-	CHECK(dns_db_findnode(db, name, ISC_TRUE, &node));
+	CHECK(dns_db_findnode(db, name, true, &node));
 	CHECK(dns_db_addrdataset(db, node, version, 0, &rdataset, 0, NULL));
  cleanup:
 	if (node != NULL)
@@ -720,7 +721,7 @@ add_a(dns_db_t *db, dns_dbversion_t *version, const dns_name_t *name,
 	rdatalist.ttl = 86400;
 	ISC_LIST_APPEND(rdatalist.rdata, &rdata, link);
 	CHECK(dns_rdatalist_tordataset(&rdatalist, &rdataset));
-	CHECK(dns_db_findnode(db, name, ISC_TRUE, &node));
+	CHECK(dns_db_findnode(db, name, true, &node));
 	CHECK(dns_db_addrdataset(db, node, version, 0, &rdataset, 0, NULL));
  cleanup:
 	if (node != NULL)
@@ -770,7 +771,7 @@ create_db(isc_mem_t *mctx, const dns_name_t *origin, dns_dbtype_t type,
 
 	CHECK(dns_name_dupwithoffsets(origin, mctx, &sampledb->common.origin));
 
-	CHECK(isc_refcount_init(&sampledb->refs, 1));
+	isc_refcount_init(&sampledb->refs, 1);
 
 	/* Translate instance name to instance pointer. */
 	sampledb->inst = driverarg;
@@ -784,7 +785,7 @@ create_db(isc_mem_t *mctx, const dns_name_t *origin, dns_dbtype_t type,
 	CHECK(add_soa(sampledb->rbtdb, version, origin, origin, origin));
 	CHECK(add_ns(sampledb->rbtdb, version, origin, origin));
 	CHECK(add_a(sampledb->rbtdb, version, origin, a_addr));
-	dns_db_closeversion(sampledb->rbtdb, &version, ISC_TRUE);
+	dns_db_closeversion(sampledb->rbtdb, &version, true);
 
 	*dbp = (dns_db_t *)sampledb;
 
