@@ -35,7 +35,7 @@
 
 /*
  * Copyright (C) 1999-2001, 2016  Internet Systems Consortium, Inc. ("ISC")
- * 
+ *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
@@ -44,9 +44,10 @@
 #ifdef DLZ_FILESYSTEM
 
 #include <config.h>
+#include <stdbool.h>
 #include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <sys/stat.h>
 
@@ -59,7 +60,6 @@
 #include <isc/platform.h>
 #include <isc/print.h>
 #include <isc/result.h>
-#include <isc/string.h>
 #include <isc/util.h>
 
 #include <named/globals.h>
@@ -84,7 +84,7 @@ typedef struct config_data {
 typedef struct dir_entry dir_entry_t;
 
 struct dir_entry {
-	char dirpath[ISC_DIR_PATHMAX];
+	char dirpath[PATH_MAX];
 	ISC_LINK(dir_entry_t)	link;
 };
 
@@ -361,7 +361,7 @@ process_dir(isc_dir_t *dir, void *passback, config_data_t *cd,
 	    dlist_t *dir_list, unsigned int basedirlen)
 {
 
-	char tmp[ISC_DIR_PATHMAX + ISC_DIR_NAMEMAX];
+	char tmp[PATH_MAX + NAME_MAX];
 	int astPos;
 	struct stat	sb;
 	isc_result_t result = ISC_R_FAILURE;
@@ -369,7 +369,7 @@ process_dir(isc_dir_t *dir, void *passback, config_data_t *cd,
 	char *type;
 	char *ttlStr;
 	char *data;
-	char host[ISC_DIR_NAMEMAX];
+	char host[NAME_MAX];
 	char *tmpString;
 	char *tmpPtr;
 	int ttl;
@@ -408,7 +408,7 @@ process_dir(isc_dir_t *dir, void *passback, config_data_t *cd,
 					{
 						if ((strlen(host) +
 						     strlen(tmpPtr + 1) + 2)
-						    > ISC_DIR_NAMEMAX)
+						    > NAME_MAX)
 							continue;
 						strcat(host, tmpPtr + 1);
 						strcat(host, ".");
@@ -416,7 +416,7 @@ process_dir(isc_dir_t *dir, void *passback, config_data_t *cd,
 					}
 					if ((strlen(host) +
 					     strlen(tmpString) + 1)
-					    <= ISC_DIR_NAMEMAX)
+					    <= NAME_MAX)
 						strcat(host, tmpString);
 				}
 
@@ -438,12 +438,12 @@ process_dir(isc_dir_t *dir, void *passback, config_data_t *cd,
 					 */
 					if (strcmp((char *) &dir->entry.name[6],
 						   "-") == 0)
-					{
-						strlcpy(host, "*", sizeof(host));
-					} else {
-						strlcpy(host,
+						strcpy(host, "*");
+					else {
+						strncpy(host,
 						   (char *) &dir->entry.name[6],
-						   sizeof(host));
+						   sizeof(host) - 1);
+						host[NAME_MAX-1] = '\0';
 					}
 					foundHost = true;
 					break;
@@ -655,8 +655,7 @@ fs_allnodes(const char *zone, void *driverarg, void *dbdata,
 	ISC_LIST_INIT(*dir_list);
 
 	if (create_path(zone, NULL, NULL, cd, &basepath) != ISC_R_SUCCESS) {
-		result = ISC_R_NOTFOUND;
-		goto complete_allnds;
+		return (ISC_R_NOTFOUND);
 	}
 
 	/* remove path separator at end of path so stat works properly */
