@@ -43,6 +43,8 @@
 
 #include <config.h>
 
+#include <stdbool.h>
+
 #include <dns/log.h>
 #include <dns/result.h>
 
@@ -83,7 +85,7 @@ destroy_querylist(isc_mem_t *mctx, query_list_t **querylist)
 		 * was really a query segment, and not a pointer to
 		 * %zone%, or %record%, or %client%
 		*/
-		if (tseg->sql != NULL && tseg->direct == isc_boolean_true)
+		if (tseg->sql != NULL && tseg->direct == true)
 			isc_mem_free(mctx, tseg->sql);
 		/* get the next query segment, before we destroy this one. */
 		nseg = ISC_LIST_NEXT(nseg, link);
@@ -101,9 +103,9 @@ build_querylist(isc_mem_t *mctx, const char *query_str, char **zone,
 		unsigned int flags)
 {
 	isc_result_t result;
-	isc_boolean_t foundzone = isc_boolean_false;
-	isc_boolean_t foundrecord = isc_boolean_false;
-	isc_boolean_t foundclient = isc_boolean_false;
+	bool foundzone = false;
+	bool foundrecord = false;
+	bool foundclient = false;
 	char *temp_str = NULL;
 	char *right_str = NULL;
 	query_list_t *tql;
@@ -149,7 +151,7 @@ build_querylist(isc_mem_t *mctx, const char *query_str, char **zone,
 			goto cleanup;
 		}
 		tseg->sql = NULL;
-		tseg->direct = isc_boolean_false;
+		tseg->direct = false;
 		/* initialize the query segment link */
 		ISC_LINK_INIT(tseg, link);
 		/* append the query segment to the list */
@@ -168,7 +170,7 @@ build_querylist(isc_mem_t *mctx, const char *query_str, char **zone,
 			goto cleanup;
 		}
 		/* tseg->sql points directly to a string. */
-		tseg->direct = isc_boolean_true;
+		tseg->direct = true;
 		tseg->strlen = strlen(tseg->sql);
 
 		/* check if we encountered "$zone$" token */
@@ -182,8 +184,8 @@ build_querylist(isc_mem_t *mctx, const char *query_str, char **zone,
 			tseg->sql = (char**) zone;
 			tseg->strlen = 0;
 			/* tseg->sql points in-directly to a string */
-			tseg->direct = isc_boolean_false;
-			foundzone = isc_boolean_true;
+			tseg->direct = false;
+			foundzone = true;
 			/* check if we encountered "$record$" token */
 		} else if (strcasecmp(tseg->sql, "record") == 0) {
 			/*
@@ -195,8 +197,8 @@ build_querylist(isc_mem_t *mctx, const char *query_str, char **zone,
 			tseg->sql = (char**) record;
 			tseg->strlen = 0;
 			/* tseg->sql points in-directly poinsts to a string */
-			tseg->direct = isc_boolean_false;
-			foundrecord = isc_boolean_true;
+			tseg->direct = false;
+			foundrecord = true;
 			/* check if we encountered "$client$" token */
 		} else if (strcasecmp(tseg->sql, "client") == 0) {
 			/*
@@ -208,8 +210,8 @@ build_querylist(isc_mem_t *mctx, const char *query_str, char **zone,
 			tseg->sql = (char**) client;
 			tseg->strlen = 0;
 			/* tseg->sql points in-directly poinsts to a string */
-			tseg->direct = isc_boolean_false;
-			foundclient = isc_boolean_true;
+			tseg->direct = false;
+			foundclient = true;
 		}
 	}
 
@@ -290,7 +292,7 @@ sdlzh_build_querystring(isc_mem_t *mctx, query_list_t *querylist)
 		 * if this is a query segment, use the
 		 * precalculated string length
 		 */
-		if (tseg->direct == isc_boolean_true)
+		if (tseg->direct == true)
 			length += tseg->strlen;
 		else	/* calculate string length for dynamic segments. */
 			length += strlen(* (char**) tseg->sql);
@@ -308,7 +310,7 @@ sdlzh_build_querystring(isc_mem_t *mctx, query_list_t *querylist)
 	/* start at the top of the list again */
 	tseg = ISC_LIST_HEAD(*querylist);
 	while (tseg != NULL) {
-		if (tseg->direct == isc_boolean_true)
+		if (tseg->direct == true)
 			/* query segments */
 			strcat(qs, tseg->sql);
 		else
