@@ -1,21 +1,29 @@
 /*
- * Copyright (C) 2016, 2017  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 /*! \file */
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
+
 #include <isc/hex.h>
 #include <isc/mem.h>
 #include <isc/parseint.h>
+#include <isc/print.h>
 #include <isc/result.h>
 #include <isc/sha2.h>
 #include <isc/task.h>
+#include <isc/util.h>
 
 #include <dns/catz.h>
 #include <dns/dbiterator.h>
@@ -50,8 +58,8 @@ struct dns_catz_zone {
 	dns_catz_options_t	defoptions;
 	dns_catz_options_t	zoneoptions;
 	isc_time_t		lastupdated;
-	isc_boolean_t		updatepending;
-	isc_uint32_t		version;
+	bool		updatepending;
+	uint32_t		version;
 
 	dns_db_t		*db;
 	dns_dbversion_t		*dbversion;
@@ -59,8 +67,8 @@ struct dns_catz_zone {
 	isc_timer_t		*updatetimer;
 	isc_event_t		updateevent;
 
-	isc_boolean_t		active;
-	isc_boolean_t		db_registered;
+	bool		active;
+	bool		db_registered;
 
 	isc_refcount_t		refs;
 };
@@ -97,7 +105,7 @@ dns_catz_options_init(dns_catz_options_t *options) {
 	options->allow_query = NULL;
 	options->allow_transfer = NULL;
 
-	options->in_memory = ISC_FALSE;
+	options->in_memory = false;
 	options->min_update_interval = 5;
 	options->zonedir = NULL;
 }
@@ -120,6 +128,7 @@ isc_result_t
 dns_catz_options_copy(isc_mem_t *mctx, const dns_catz_options_t *src,
 		      dns_catz_options_t *dst)
 {
+	REQUIRE(src != NULL);
 	REQUIRE(dst != NULL);
 	REQUIRE(dst->masters.count == 0);
 	REQUIRE(dst->allow_query == NULL);
@@ -224,80 +233,73 @@ dns_catz_entry_copy(dns_catz_zone_t *zone, const dns_catz_entry_t *entry,
 void
 dns_catz_entry_attach(dns_catz_entry_t *entry, dns_catz_entry_t **entryp) {
 	REQUIRE(entryp != NULL && *entryp == NULL);
-	isc_refcount_increment(&entry->refs, NULL);
+	isc_refcount_increment(&entry->refs);
 	*entryp = entry;
 }
 
 void
 dns_catz_entry_detach(dns_catz_zone_t *zone, dns_catz_entry_t **entryp) {
-	dns_catz_entry_t *entry;
-	isc_mem_t *mctx;
-	unsigned int refs;
-
 	REQUIRE(entryp != NULL && *entryp != NULL);
-
-	entry = *entryp;
+	dns_catz_entry_t *entry = *entryp;
 	*entryp = NULL;
 
-	mctx = zone->catzs->mctx;
-
-	isc_refcount_decrement(&entry->refs, &refs);
-	if (refs == 0) {
+	if (isc_refcount_decrement(&entry->refs) == 1) {
+		isc_refcount_destroy(&entry->refs);
+		isc_mem_t *mctx = zone->catzs->mctx;
 		dns_catz_options_free(&entry->opts, mctx);
 		if (dns_name_dynamic(&entry->name))
 			dns_name_free(&entry->name, mctx);
-		isc_refcount_destroy(&entry->refs);
 		isc_mem_put(mctx, entry, sizeof(dns_catz_entry_t));
 	}
 }
 
-isc_boolean_t
+bool
 dns_catz_entry_validate(const dns_catz_entry_t *entry) {
 	UNUSED(entry);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
-isc_boolean_t
+bool
 dns_catz_entry_cmp(const dns_catz_entry_t *ea, const dns_catz_entry_t *eb) {
 	isc_region_t ra, rb;
 
 	if (ea == eb)
-		return (ISC_TRUE);
+		return (true);
 
 	if (ea->opts.masters.count != eb->opts.masters.count)
-		return (ISC_FALSE);
+		return (false);
 
 	if (memcmp(ea->opts.masters.addrs, eb->opts.masters.addrs,
 		   ea->opts.masters.count * sizeof(isc_sockaddr_t)))
-		return (ISC_FALSE);
+		return (false);
 
 	/* If one is NULL and the other isn't, the entries don't match */
 	if ((ea->opts.allow_query == NULL) != (eb->opts.allow_query == NULL))
-		return (ISC_FALSE);
+		return (false);
 
 	/* If one is non-NULL, then they both are */
 	if (ea->opts.allow_query != NULL) {
 		isc_buffer_usedregion(ea->opts.allow_query, &ra);
 		isc_buffer_usedregion(eb->opts.allow_query, &rb);
 		if (isc_region_compare(&ra, &rb))
-			return (ISC_FALSE);
+			return (false);
 	}
 
 	/* Repeat the above checks with allow_transfer */
 	if ((ea->opts.allow_transfer == NULL) !=
 	    (eb->opts.allow_transfer == NULL))
-		return (ISC_FALSE);
+		return (false);
 
 	if (ea->opts.allow_transfer != NULL) {
 		isc_buffer_usedregion(ea->opts.allow_transfer, &ra);
 		isc_buffer_usedregion(eb->opts.allow_transfer, &rb);
 		if (isc_region_compare(&ra, &rb))
-			return (ISC_FALSE);
+			return (false);
 	}
 
 	/* xxxwpk TODO compare dscps/keys! */
-	return (ISC_TRUE);
+	return (true);
 }
 
 dns_name_t *
@@ -328,7 +330,7 @@ dns_catz_zones_merge(dns_catz_zone_t *target, dns_catz_zone_t *newzone) {
 	isc_ht_iter_t *iter1 = NULL, *iter2 = NULL;
 	isc_ht_iter_t *iteradd = NULL, *itermod = NULL;
 	isc_ht_t *toadd = NULL, *tomod = NULL;
-	isc_boolean_t delcur = ISC_FALSE;
+	bool delcur = false;
 	char czname[DNS_NAME_FORMATSIZE];
 	char zname[DNS_NAME_FORMATSIZE];
 	dns_catz_zoneop_fn_t addzone, modzone, delzone;
@@ -393,7 +395,7 @@ dns_catz_zones_merge(dns_catz_zone_t *target, dns_catz_zone_t *newzone) {
 		dns_catz_entry_t *oentry;
 		unsigned char * key;
 		size_t keysize;
-		delcur = ISC_FALSE;
+		delcur = false;
 
 		isc_ht_iter_current(iter1, (void **) &nentry);
 		isc_ht_iter_currentkey(iter1, &key, &keysize);
@@ -405,7 +407,7 @@ dns_catz_zones_merge(dns_catz_zone_t *target, dns_catz_zone_t *newzone) {
 		 */
 		if (dns_name_countlabels(&nentry->name) == 0) {
 			dns_catz_entry_detach(newzone, &nentry);
-			delcur = ISC_TRUE;
+			delcur = true;
 			continue;
 		}
 
@@ -420,9 +422,9 @@ dns_catz_zones_merge(dns_catz_zone_t *target, dns_catz_zone_t *newzone) {
 					    &nentry->opts);
 
 		result = isc_ht_find(target->entries, key,
-				     (isc_uint32_t)keysize, (void **) &oentry);
+				     (uint32_t)keysize, (void **) &oentry);
 		if (result != ISC_R_SUCCESS) {
-			result = isc_ht_add(toadd, key, (isc_uint32_t)keysize,
+			result = isc_ht_add(toadd, key, (uint32_t)keysize,
 					    nentry);
 			if (result != ISC_R_SUCCESS)
 				isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
@@ -435,8 +437,8 @@ dns_catz_zones_merge(dns_catz_zone_t *target, dns_catz_zone_t *newzone) {
 			continue;
 		}
 
-		if (dns_catz_entry_cmp(oentry, nentry) != ISC_TRUE) {
-			result = isc_ht_add(tomod, key, (isc_uint32_t)keysize,
+		if (dns_catz_entry_cmp(oentry, nentry) != true) {
+			result = isc_ht_add(tomod, key, (uint32_t)keysize,
 					    nentry);
 			if (result != ISC_R_SUCCESS)
 				isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
@@ -449,7 +451,7 @@ dns_catz_zones_merge(dns_catz_zone_t *target, dns_catz_zone_t *newzone) {
 		}
 		dns_catz_entry_detach(target, &oentry);
 		result = isc_ht_delete(target->entries, key,
-				       (isc_uint32_t)keysize);
+				       (uint32_t)keysize);
 		RUNTIME_CHECK(result == ISC_R_SUCCESS);
 	}
 	RUNTIME_CHECK(result == ISC_R_NOMORE);
@@ -559,9 +561,7 @@ dns_catz_new_zones(dns_catz_zones_t **catzsp, dns_catz_zonemodmethods_t *zmm,
 	if (result != ISC_R_SUCCESS)
 		goto cleanup_newzones;
 
-	result = isc_refcount_init(&new_zones->refs, 1);
-	if (result != ISC_R_SUCCESS)
-		goto cleanup_mutex;
+	isc_refcount_init(&new_zones->refs, 1);
 
 	result = isc_ht_init(&new_zones->zones, mctx, 4);
 	if (result != ISC_R_SUCCESS)
@@ -583,7 +583,6 @@ dns_catz_new_zones(dns_catz_zones_t **catzsp, dns_catz_zonemodmethods_t *zmm,
 	isc_ht_destroy(&new_zones->zones);
   cleanup_refcount:
 	isc_refcount_destroy(&new_zones->refs);
-  cleanup_mutex:
 	isc_mutex_destroy(&new_zones->lock);
   cleanup_newzones:
 	isc_mem_put(mctx, new_zones, sizeof(*new_zones));
@@ -635,15 +634,15 @@ dns_catz_new_zone(dns_catz_zones_t *catzs, dns_catz_zone_t **zonep,
 		goto cleanup_ht;
 
 	isc_time_settoepoch(&new_zone->lastupdated);
-	new_zone->updatepending = ISC_FALSE;
+	new_zone->updatepending = false;
 	new_zone->db = NULL;
 	new_zone->dbversion = NULL;
 	new_zone->catzs = catzs;
 	dns_catz_options_init(&new_zone->defoptions);
 	dns_catz_options_init(&new_zone->zoneoptions);
-	new_zone->active = ISC_TRUE;
-	new_zone->db_registered = ISC_FALSE;
-	new_zone->version = (isc_uint32_t)(-1);
+	new_zone->active = true;
+	new_zone->db_registered = false;
+	new_zone->version = (uint32_t)(-1);
 	isc_refcount_init(&new_zone->refs, 1);
 
 	*zonep = new_zone;
@@ -694,7 +693,7 @@ dns_catz_add_zone(dns_catz_zones_t *catzs, const dns_name_t *name,
 		tresult = isc_ht_find(catzs->zones, name->ndata,
 				     name->length, (void **) &new_zone);
 		INSIST(tresult == ISC_R_SUCCESS && !new_zone->active);
-		new_zone->active = ISC_TRUE;
+		new_zone->active = true;
 	}
 
 	*zonep = new_zone;
@@ -722,7 +721,7 @@ void
 dns_catz_catzs_attach(dns_catz_zones_t *catzs, dns_catz_zones_t **catzsp) {
 	REQUIRE(catzsp != NULL && *catzsp == NULL);
 
-	isc_refcount_increment(&catzs->refs, NULL);
+	isc_refcount_increment(&catzs->refs);
 	*catzsp = catzs;
 }
 
@@ -730,25 +729,21 @@ void
 dns_catz_zone_attach(dns_catz_zone_t *zone, dns_catz_zone_t **zonep) {
 	REQUIRE(zonep != NULL && *zonep == NULL);
 
-	isc_refcount_increment(&zone->refs, NULL);
+	isc_refcount_increment(&zone->refs);
 	*zonep = zone;
 }
 
 void
 dns_catz_zone_detach(dns_catz_zone_t **zonep) {
-	isc_result_t result;
-	dns_catz_zone_t *zone;
-	isc_ht_iter_t *iter = NULL;
-	isc_mem_t *mctx;
-	unsigned int refs;
-
 	REQUIRE(zonep != NULL && *zonep != NULL);
-
-	zone = *zonep;
+	dns_catz_zone_t *zone = *zonep;
 	*zonep = NULL;
-	isc_refcount_decrement(&zone->refs, &refs);
-	if (refs == 0) {
+
+	if (isc_refcount_decrement(&zone->refs) == 1) {
+		isc_refcount_destroy(&zone->refs);
 		if (zone->entries != NULL) {
+			isc_ht_iter_t *iter = NULL;
+			isc_result_t result;
 			result = isc_ht_iter_create(zone->entries, &iter);
 			INSIST(result == ISC_R_SUCCESS);
 			for (result = isc_ht_iter_first(iter);
@@ -767,18 +762,18 @@ dns_catz_zone_detach(dns_catz_zone_t **zonep) {
 			INSIST(isc_ht_count(zone->entries) == 0);
 			isc_ht_destroy(&zone->entries);
 		}
-		mctx = zone->catzs->mctx;
+		isc_mem_t *mctx = zone->catzs->mctx;
 		isc_timer_detach(&zone->updatetimer);
-		isc_refcount_destroy(&zone->refs);
-		if (zone->db_registered == ISC_TRUE) {
-			result = dns_db_updatenotify_unregister(zone->db,
-						    dns_catz_dbupdate_callback,
-						    zone->catzs);
-			INSIST(result == ISC_R_SUCCESS);
+		if (zone->db_registered == true) {
+			INSIST(dns_db_updatenotify_unregister(
+				       zone->db,
+				       dns_catz_dbupdate_callback,
+				       zone->catzs)
+			       == ISC_R_SUCCESS);
 		}
 		if (zone->dbversion)
 			dns_db_closeversion(zone->db, &zone->dbversion,
-					    ISC_FALSE);
+					    false);
 		if (zone->db != NULL)
 			dns_db_detach(&zone->db);
 
@@ -792,29 +787,25 @@ dns_catz_zone_detach(dns_catz_zone_t **zonep) {
 }
 
 void
-dns_catz_catzs_detach(dns_catz_zones_t ** catzsp) {
-	dns_catz_zones_t *catzs;
-	isc_ht_iter_t *iter = NULL;
-	isc_result_t result;
-	unsigned int refs;
-	dns_catz_zone_t *zone;
+dns_catz_catzs_detach(dns_catz_zones_t **catzsp) {
+	REQUIRE(catzsp != NULL && *catzsp != NULL);
+	dns_catz_zones_t *catzs = *catzsp;
 
-
-	REQUIRE(catzsp != NULL);
 	catzs = *catzsp;
-	REQUIRE(catzs != NULL);
-
 	*catzsp = NULL;
-	isc_refcount_decrement(&catzs->refs, &refs);
 
-	if (refs == 0) {
+	if (isc_refcount_decrement(&catzs->refs) == 1) {
+		isc_refcount_destroy(&catzs->refs);
 		DESTROYLOCK(&catzs->lock);
 		if (catzs->zones != NULL) {
+			isc_ht_iter_t *iter = NULL;
+			isc_result_t result;
 			result = isc_ht_iter_create(catzs->zones, &iter);
 			INSIST(result == ISC_R_SUCCESS);
 			for (result = isc_ht_iter_first(iter);
 			     result == ISC_R_SUCCESS;)
 			{
+				dns_catz_zone_t *zone;
 				isc_ht_iter_current(iter, (void **) &zone);
 				result = isc_ht_iter_delcurrent_next(iter);
 				dns_catz_zone_detach(&zone);
@@ -824,7 +815,6 @@ dns_catz_catzs_detach(dns_catz_zones_t ** catzsp) {
 			INSIST(isc_ht_count(catzs->zones) == 0);
 			isc_ht_destroy(&catzs->zones);
 		}
-		isc_refcount_destroy(&catzs->refs);
 		isc_task_destroy(&catzs->updater);
 		isc_mem_putanddetach(&catzs->mctx, catzs, sizeof(*catzs));
 	}
@@ -839,14 +829,14 @@ typedef enum {
 	CATZ_OPT_VERSION,
 } catz_opt_t;
 
-static isc_boolean_t
+static bool
 catz_opt_cmp(const dns_label_t *option, const char *opt) {
 	unsigned int l = strlen(opt);
 	if (option->length - 1 == l &&
 	    memcmp(opt, option->base + 1, l - 1) == 0)
-		return (ISC_TRUE);
+		return (true);
 	else
-		return (ISC_FALSE);
+		return (false);
 }
 
 static catz_opt_t
@@ -962,7 +952,7 @@ catz_process_version(dns_catz_zone_t *zone, dns_rdataset_t *value) {
 	dns_rdata_t rdata;
 	dns_rdata_txt_t rdatatxt;
 	dns_rdata_txt_string_t rdatastr;
-	isc_uint32_t tversion;
+	uint32_t tversion;
 	char t[16];
 
 	REQUIRE(zone != NULL);
@@ -999,7 +989,7 @@ catz_process_version(dns_catz_zone_t *zone, dns_rdataset_t *value) {
 		result = ISC_R_BADNUMBER;
 		goto cleanup;
 	}
-	memcpy(t, rdatastr.data, rdatastr.length);
+	memmove(t, rdatastr.data, rdatastr.length);
 	t[rdatastr.length] = 0;
 	result = isc_parse_uint32(&tversion, t, 10);
 	if (result != ISC_R_SUCCESS) {
@@ -1094,7 +1084,7 @@ catz_process_masters(dns_catz_zone_t *zone, dns_ipkeylist_t *ipkl,
 			if (keyname == NULL)
 				return (ISC_R_NOMEMORY);
 			dns_name_init(keyname, 0);
-			memcpy(keycbuf, rdatastr.data, rdatastr.length);
+			memmove(keycbuf, rdatastr.data, rdatastr.length);
 			keycbuf[rdatastr.length] = 0;
 			result = dns_name_fromstring(keyname, keycbuf, 0, mctx);
 			if (result != ISC_R_SUCCESS) {
@@ -1123,8 +1113,8 @@ catz_process_masters(dns_catz_zone_t *zone, dns_ipkeylist_t *ipkl,
 			if (value->type == dns_rdatatype_txt)
 				ipkl->keys[i] = keyname;
 			else /* A/AAAA */
-				memcpy(&ipkl->addrs[i], &sockaddr,
-				       sizeof(isc_sockaddr_t));
+				memmove(&ipkl->addrs[i], &sockaddr,
+					sizeof(isc_sockaddr_t));
 		} else {
 			result = dns_ipkeylist_resize(mctx, ipkl,
 						      i+1);
@@ -1155,8 +1145,8 @@ catz_process_masters(dns_catz_zone_t *zone, dns_ipkeylist_t *ipkl,
 			if (value->type == dns_rdatatype_txt)
 				ipkl->keys[i] = keyname;
 			else /* A/AAAA */
-				memcpy(&ipkl->addrs[i], &sockaddr,
-				       sizeof(isc_sockaddr_t));
+				memmove(&ipkl->addrs[i], &sockaddr,
+					sizeof(isc_sockaddr_t));
 			ipkl->count++;
 		}
 		return (ISC_R_SUCCESS);
@@ -1239,7 +1229,7 @@ catz_process_apl(dns_catz_zone_t *zone, isc_buffer_t **aclbp,
 	if (result != ISC_R_SUCCESS)
 		return (result);
 	result = isc_buffer_allocate(zone->catzs->mctx, &aclb, 16);
-	isc_buffer_setautorealloc(aclb, ISC_TRUE);
+	isc_buffer_setautorealloc(aclb, true);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
 	for (result = dns_rdata_apl_first(&rdata_apl);
@@ -1248,7 +1238,8 @@ catz_process_apl(dns_catz_zone_t *zone, isc_buffer_t **aclbp,
 		result = dns_rdata_apl_current(&rdata_apl, &apl_ent);
 		RUNTIME_CHECK(result == ISC_R_SUCCESS);
 		memset(buf, 0, sizeof(buf));
-		memcpy(buf, apl_ent.data, apl_ent.length);
+		if (apl_ent.data != NULL && apl_ent.length > 0)
+			memmove(buf, apl_ent.data, apl_ent.length);
 		if (apl_ent.family == 1)
 			isc_netaddr_fromin(&addr, (struct in_addr*) buf);
 		else if (apl_ent.family == 2)
@@ -1384,7 +1375,7 @@ catz_process_value(dns_catz_zone_t *zone, dns_name_t *name,
 
 isc_result_t
 dns_catz_update_process(dns_catz_zones_t *catzs, dns_catz_zone_t *zone,
-			dns_name_t *src_name, dns_rdataset_t *rdataset)
+			const dns_name_t *src_name, dns_rdataset_t *rdataset)
 {
 	isc_result_t result;
 	int order;
@@ -1452,12 +1443,12 @@ dns_catz_generate_masterfilename(dns_catz_zone_t *zone, dns_catz_entry_t *entry,
 
 	isc_buffer_putstr(tbuf, zone->catzs->view->name);
 	isc_buffer_putstr(tbuf, "_");
-	result = dns_name_totext(&zone->name, ISC_TRUE, tbuf);
+	result = dns_name_totext(&zone->name, true, tbuf);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
 
 	isc_buffer_putstr(tbuf, "_");
-	result = dns_name_totext(&entry->name, ISC_TRUE, tbuf);
+	result = dns_name_totext(&entry->name, true, tbuf);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
 
@@ -1505,14 +1496,16 @@ dns_catz_generate_zonecfg(dns_catz_zone_t *zone, dns_catz_entry_t *entry,
 	 * We have to generate a text buffer with regular zone config:
 	 * zone foo.bar {
 	 * 	type slave;
-	 * 	masters { ip1 port1; ip2 port2; };
+	 * 	masters [ dscp X ] { ip1 port port1; ip2 port port2; };
 	 * }
 	 */
 	isc_buffer_t *buffer = NULL;
 	isc_region_t region;
 	isc_result_t result;
-	isc_uint32_t i;
+	uint32_t i;
 	isc_netaddr_t netaddr;
+	char pbuf[sizeof("65535")]; /* used both for port number and DSCP */
+	char zname[DNS_NAME_FORMATSIZE];
 
 	REQUIRE(zone != NULL);
 	REQUIRE(entry != NULL);
@@ -1520,7 +1513,7 @@ dns_catz_generate_zonecfg(dns_catz_zone_t *zone, dns_catz_entry_t *entry,
 
 	/*
 	 * The buffer will be reallocated if something won't fit,
-	 * ISC_BUFFER_INC seems like a good start.
+	 * ISC_BUFFER_INCR seems like a good start.
 	 */
 	result = isc_buffer_allocate(zone->catzs->mctx, &buffer,
 				     ISC_BUFFER_INCR);
@@ -1528,47 +1521,84 @@ dns_catz_generate_zonecfg(dns_catz_zone_t *zone, dns_catz_entry_t *entry,
 		goto cleanup;
 	}
 
-	isc_buffer_setautorealloc(buffer, ISC_TRUE);
+	isc_buffer_setautorealloc(buffer, true);
 	isc_buffer_putstr(buffer, "zone ");
-	dns_name_totext(&entry->name, ISC_TRUE, buffer);
-	isc_buffer_putstr(buffer, " { type slave; masters { ");
+	dns_name_totext(&entry->name, true, buffer);
+	isc_buffer_putstr(buffer, " { type slave; masters");
+
+	/*
+	 * DSCP value has no default, but when it is specified, it is identical
+	 * for all masters and cannot be overriden for a specific master IP, so
+	 * use the DSCP value set for the first master
+	 */
+	if (entry->opts.masters.count > 0 &&
+	    entry->opts.masters.dscps[0] >= 0) {
+		isc_buffer_putstr(buffer, " dscp ");
+		snprintf(pbuf, sizeof(pbuf), "%hd",
+			 entry->opts.masters.dscps[0]);
+		isc_buffer_putstr(buffer, pbuf);
+	}
+
+	isc_buffer_putstr(buffer, " { ");
 	for (i = 0; i < entry->opts.masters.count; i++) {
-		/* TODO port and DSCP */
+		/*
+		 * Every master must have an IP address assigned.
+		 */
+		switch (entry->opts.masters.addrs[i].type.sa.sa_family) {
+		case AF_INET:
+		case AF_INET6:
+			break;
+		default:
+			dns_name_format(&entry->name, zname,
+					DNS_NAME_FORMATSIZE);
+			isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
+				      DNS_LOGMODULE_MASTER, ISC_LOG_ERROR,
+				      "catz: zone '%s' uses an invalid master "
+				      "(no IP address assigned)",
+				      zname);
+			result = ISC_R_FAILURE;
+			goto cleanup;
+		}
 		isc_netaddr_fromsockaddr(&netaddr,
 					 &entry->opts.masters.addrs[i]);
 		isc_buffer_reserve(&buffer, INET6_ADDRSTRLEN);
 		result = isc_netaddr_totext(&netaddr, buffer);
 		RUNTIME_CHECK(result == ISC_R_SUCCESS);
 
+		isc_buffer_putstr(buffer, " port ");
+		snprintf(pbuf, sizeof(pbuf), "%u",
+			 isc_sockaddr_getport(&entry->opts.masters.addrs[i]));
+		isc_buffer_putstr(buffer, pbuf);
+
 		if (entry->opts.masters.keys[i] != NULL) {
 			isc_buffer_putstr(buffer, " key ");
 			result = dns_name_totext(entry->opts.masters.keys[i],
-						 ISC_TRUE, buffer);
+						 true, buffer);
 			if (result != ISC_R_SUCCESS)
 				goto cleanup;
 		}
 		isc_buffer_putstr(buffer, "; ");
 	}
-	isc_buffer_putstr(buffer, "};");
-	if (entry->opts.in_memory == ISC_FALSE) {
+	isc_buffer_putstr(buffer, "}; ");
+	if (entry->opts.in_memory == false) {
 		isc_buffer_putstr(buffer, "file \"");
 		result = dns_catz_generate_masterfilename(zone, entry, &buffer);
 		if (result != ISC_R_SUCCESS)
 			goto cleanup;
-		isc_buffer_putstr(buffer, "\";");
+		isc_buffer_putstr(buffer, "\"; ");
 
 	}
 	if (entry->opts.allow_query != NULL) {
 		isc_buffer_putstr(buffer, "allow-query { ");
 		isc_buffer_usedregion(entry->opts.allow_query, &region);
 		isc_buffer_copyregion(buffer, &region);
-		isc_buffer_putstr(buffer, "};");
+		isc_buffer_putstr(buffer, "}; ");
 	}
 	if (entry->opts.allow_transfer != NULL) {
 		isc_buffer_putstr(buffer, "allow-transfer { ");
 		isc_buffer_usedregion(entry->opts.allow_transfer, &region);
 		isc_buffer_copyregion(buffer, &region);
-		isc_buffer_putstr(buffer, "};");
+		isc_buffer_putstr(buffer, "}; ");
 	}
 
 	isc_buffer_putstr(buffer, "};");
@@ -1576,12 +1606,11 @@ dns_catz_generate_zonecfg(dns_catz_zone_t *zone, dns_catz_entry_t *entry,
 	return (ISC_R_SUCCESS);
 
 cleanup:
-	if (buffer)
+	if (buffer != NULL)
 		isc_buffer_free(&buffer);
 	return (result);
 }
 
-
 void
 dns_catz_update_taskaction(isc_task_t *task, isc_event_t *event) {
 	isc_result_t result;
@@ -1593,10 +1622,10 @@ dns_catz_update_taskaction(isc_task_t *task, isc_event_t *event) {
 	REQUIRE(zone != NULL);
 
 	LOCK(&zone->catzs->lock);
-	zone->updatepending = ISC_FALSE;
+	zone->updatepending = false;
 	dns_catz_update_from_db(zone->db, zone->catzs);
 	result = isc_timer_reset(zone->updatetimer, isc_timertype_inactive,
-				 NULL, NULL, ISC_TRUE);
+				 NULL, NULL, true);
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
 	isc_event_free(&event);
 	result = isc_time_now(&zone->lastupdated);
@@ -1609,7 +1638,7 @@ dns_catz_dbupdate_callback(dns_db_t *db, void *fn_arg) {
 	dns_catz_zones_t *catzs;
 	dns_catz_zone_t *zone = NULL;
 	isc_time_t now;
-	isc_uint64_t tdiff;
+	uint64_t tdiff;
 	isc_result_t result = ISC_R_SUCCESS;
 	isc_region_t r;
 
@@ -1628,19 +1657,19 @@ dns_catz_dbupdate_callback(dns_db_t *db, void *fn_arg) {
 	if (zone->db != NULL && zone->db != db) {
 		if (zone->dbversion != NULL)
 			dns_db_closeversion(zone->db, &zone->dbversion,
-						    ISC_FALSE);
+						    false);
 		dns_db_detach(&zone->db);
 		/*
 		 * We're not registering db update callback, it will be
 		 * registered at the end of update_from_db
 		 */
-		zone->db_registered = ISC_FALSE;
+		zone->db_registered = false;
 	}
 	if (zone->db == NULL)
 		dns_db_attach(db, &zone->db);
 
-	if (zone->updatepending == ISC_FALSE) {
-		zone->updatepending = ISC_TRUE;
+	if (zone->updatepending == false) {
+		zone->updatepending = true;
 		isc_time_now(&now);
 		tdiff = isc_time_microdiff(&now, &zone->lastupdated)/1000000;
 		if (tdiff < zone->defoptions.min_update_interval) {
@@ -1655,7 +1684,7 @@ dns_catz_dbupdate_callback(dns_db_t *db, void *fn_arg) {
 			dns_db_currentversion(db, &zone->dbversion);
 			result = isc_timer_reset(zone->updatetimer,
 						 isc_timertype_once,
-						 NULL, &interval, ISC_TRUE);
+						 NULL, &interval, true);
 			if (result != ISC_R_SUCCESS)
 				goto cleanup;
 		} else {
@@ -1676,7 +1705,7 @@ dns_catz_dbupdate_callback(dns_db_t *db, void *fn_arg) {
 			      "catz: update already queued");
 		if (zone->dbversion != NULL)
 			dns_db_closeversion(zone->db, &zone->dbversion,
-					    ISC_FALSE);
+					    false);
 		dns_db_currentversion(zone->db, &zone->dbversion);
 	}
 
@@ -1699,7 +1728,7 @@ dns_catz_update_from_db(dns_db_t *db, dns_catz_zones_t *catzs) {
 	dns_rdataset_t rdataset;
 	char bname[DNS_NAME_FORMATSIZE];
 	isc_buffer_t ibname;
-	isc_uint32_t vers;
+	uint32_t vers;
 
 	REQUIRE(DNS_DB_VALID(db));
 	REQUIRE(catzs != NULL);
@@ -1719,7 +1748,7 @@ dns_catz_update_from_db(dns_db_t *db, dns_catz_zones_t *catzs) {
 	}
 
 	isc_buffer_init(&ibname, bname, DNS_NAME_FORMATSIZE);
-	result = dns_name_totext(&db->origin, ISC_TRUE, &ibname);
+	result = dns_name_totext(&db->origin, true, &ibname);
 	INSIST(result == ISC_R_SUCCESS);
 
 	result = dns_db_getsoaserial(db, oldzone->dbversion, &vers);
@@ -1739,7 +1768,7 @@ dns_catz_update_from_db(dns_db_t *db, dns_catz_zones_t *catzs) {
 
 	result = dns_catz_new_zone(catzs, &newzone, &db->origin);
 	if (result != ISC_R_SUCCESS) {
-		dns_db_closeversion(db, &oldzone->dbversion, ISC_FALSE);
+		dns_db_closeversion(db, &oldzone->dbversion, false);
 		isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
 			      DNS_LOGMODULE_MASTER, ISC_LOG_ERROR,
 			      "catz: failed to create new zone - %s",
@@ -1750,7 +1779,7 @@ dns_catz_update_from_db(dns_db_t *db, dns_catz_zones_t *catzs) {
 	result = dns_db_createiterator(db, DNS_DB_NONSEC3, &it);
 	if (result != ISC_R_SUCCESS) {
 		dns_catz_zone_detach(&newzone);
-		dns_db_closeversion(db, &oldzone->dbversion, ISC_FALSE);
+		dns_db_closeversion(db, &oldzone->dbversion, false);
 		isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
 			      DNS_LOGMODULE_MASTER, ISC_LOG_ERROR,
 			      "catz: failed to create DB iterator - %s",
@@ -1758,8 +1787,7 @@ dns_catz_update_from_db(dns_db_t *db, dns_catz_zones_t *catzs) {
 		return;
 	}
 
-	dns_fixedname_init(&fixname);
-	name = dns_fixedname_name(&fixname);
+	name = dns_fixedname_initname(&fixname);
 
 	/*
 	 * Iterate over database to fill the new zone.
@@ -1801,21 +1829,22 @@ dns_catz_update_from_db(dns_db_t *db, dns_catz_zones_t *catzs) {
 							 &rdataset);
 			if (result != ISC_R_SUCCESS) {
 				char cname[DNS_NAME_FORMATSIZE];
-				char type[DNS_RDATATYPE_FORMATSIZE];
-				char class[DNS_RDATACLASS_FORMATSIZE];
+				char typebuf[DNS_RDATATYPE_FORMATSIZE];
+				char classbuf[DNS_RDATACLASS_FORMATSIZE];
 
 				dns_name_format(name, cname,
 						DNS_NAME_FORMATSIZE);
-				dns_rdataclass_format(rdataset.rdclass, class,
-						      sizeof(class));
-				dns_rdatatype_format(rdataset.type, type,
-						     sizeof(type));
+				dns_rdataclass_format(rdataset.rdclass,
+						      classbuf,
+						      sizeof(classbuf));
+				dns_rdatatype_format(rdataset.type, typebuf,
+						     sizeof(typebuf));
 				isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
 					      DNS_LOGMODULE_MASTER,
 					      ISC_LOG_WARNING,
 					      "catz: unknown record in catalog "
 					      "zone - %s %s %s(%s) - ignoring",
-					      cname, class, type,
+					      cname, classbuf, typebuf,
 					      isc_result_totext(result));
 			}
 			dns_rdataset_disassociate(&rdataset);
@@ -1832,7 +1861,7 @@ dns_catz_update_from_db(dns_db_t *db, dns_catz_zones_t *catzs) {
 	}
 
 	dns_dbiterator_destroy(&it);
-	dns_db_closeversion(db, &oldzone->dbversion, ISC_FALSE);
+	dns_db_closeversion(db, &oldzone->dbversion, false);
 	isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
 		      DNS_LOGMODULE_MASTER, ISC_LOG_DEBUG(3),
 		      "catz: update_from_db: iteration finished");
@@ -1862,12 +1891,12 @@ dns_catz_update_from_db(dns_db_t *db, dns_catz_zones_t *catzs) {
 	 * update callback in zone_startload or axfr_makedb, but we will
 	 * call onupdate() artificially so we can register the callback here.
 	 */
-	if (oldzone->db_registered == ISC_FALSE) {
+	if (oldzone->db_registered == false) {
 		result = dns_db_updatenotify_register(db,
 						    dns_catz_dbupdate_callback,
 						    oldzone->catzs);
 		if (result == ISC_R_SUCCESS)
-			oldzone->db_registered = ISC_TRUE;
+			oldzone->db_registered = true;
 	}
 }
 
@@ -1886,7 +1915,7 @@ dns_catz_prereconfig(dns_catz_zones_t *catzs) {
 	     result = isc_ht_iter_next(iter))
 	{
 		isc_ht_iter_current(iter, (void **) &zone);
-		zone->active = ISC_FALSE;
+		zone->active = false;
 	}
 	INSIST(result == ISC_R_NOMORE);
 	isc_ht_iter_destroy(&iter);
@@ -1906,7 +1935,7 @@ dns_catz_postreconfig(dns_catz_zones_t *catzs) {
 	     result == ISC_R_SUCCESS;)
 	{
 		isc_ht_iter_current(iter, (void **) &zone);
-		if (zone->active == ISC_FALSE) {
+		if (zone->active == false) {
 			char cname[DNS_NAME_FORMATSIZE];
 			dns_name_format(&zone->name, cname,
 					DNS_NAME_FORMATSIZE);
