@@ -49,6 +49,8 @@
 #error DNSTAP not configured.
 #endif /* HAVE_DNSTAP */
 
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 
 #include <isc/buffer.h>
@@ -109,7 +111,7 @@ struct dns_dtenv {
 
 	isc_task_t *reopen_task;
 	isc_mutex_t reopen_lock;	/* locks 'reopen_queued' */
-	isc_boolean_t reopen_queued;
+	bool reopen_queued;
 
 	isc_region_t identity;
 	isc_region_t version;
@@ -128,7 +130,7 @@ struct dns_dtenv {
 	} while (0)
 
 static isc_mutex_t dt_mutex;
-static isc_boolean_t dt_initialized = ISC_FALSE;
+static bool dt_initialized = false;
 static isc_thread_key_t dt_key;
 static isc_once_t mutex_once = ISC_ONCE_INIT;
 static isc_mem_t *dt_mctx = NULL;
@@ -169,11 +171,11 @@ dt_init(void) {
 		if (result != ISC_R_SUCCESS)
 			goto unlock;
 		isc_mem_setname(dt_mctx, "dt", NULL);
-		isc_mem_setdestroycheck(dt_mctx, ISC_FALSE);
+		isc_mem_setdestroycheck(dt_mctx, false);
 
 		ret = isc_thread_key_create(&dt_key, dtfree);
 		if (ret == 0)
-			dt_initialized = ISC_TRUE;
+			dt_initialized = true;
 		else
 			result = ISC_R_FAILURE;
 	}
@@ -212,7 +214,7 @@ dns_dt_create(isc_mem_t *mctx, dns_dtmode_t mode, const char *path,
 
 	memset(env, 0, sizeof(dns_dtenv_t));
 
-	CHECK(isc_refcount_init(&env->refcount, 1));
+	isc_refcount_init(&env->refcount, 1);
 	CHECK(isc_stats_create(mctx, &env->stats, dns_dnstapcounter_max));
 	env->path = isc_mem_strdup(mctx, path);
 	if (env->path == NULL)
@@ -263,7 +265,7 @@ dns_dt_create(isc_mem_t *mctx, dns_dtmode_t mode, const char *path,
 
 	env->reopen_task = reopen_task;
 	isc_mutex_init(&env->reopen_lock);
-	env->reopen_queued = ISC_FALSE;
+	env->reopen_queued = false;
 
 	isc_mem_attach(mctx, &env->mctx);
 
@@ -297,7 +299,7 @@ dns_dt_create(isc_mem_t *mctx, dns_dtmode_t mode, const char *path,
 }
 
 isc_result_t
-dns_dt_setupfile(dns_dtenv_t *env, isc_uint64_t max_size, int rolls,
+dns_dt_setupfile(dns_dtenv_t *env, uint64_t max_size, int rolls,
 		 isc_log_rollsuffix_t suffix)
 {
 	REQUIRE(VALID_DTENV(env));
@@ -407,7 +409,7 @@ dns_dt_reopen(dns_dtenv_t *env, int roll) {
 		file.stream = NULL;
 		file.versions = roll != 0 ? roll : env->rolls;
 		file.maximum_size = 0;
-		file.maximum_reached = ISC_FALSE;
+		file.maximum_reached = false;
 		file.suffix = env->suffix;
 		result = isc_logfile_roll(&file);
 		isc_mem_free(env->mctx, filename);
@@ -529,7 +531,7 @@ dns_dt_attach(dns_dtenv_t *source, dns_dtenv_t **destp) {
 	REQUIRE(VALID_DTENV(source));
 	REQUIRE(destp != NULL && *destp == NULL);
 
-	isc_refcount_increment(&source->refcount, NULL);
+	isc_refcount_increment(&source->refcount);
 	*destp = source;
 }
 
@@ -577,17 +579,14 @@ destroy(dns_dtenv_t *env) {
 
 void
 dns_dt_detach(dns_dtenv_t **envp) {
-	unsigned int refs;
-	dns_dtenv_t *env;
-
 	REQUIRE(envp != NULL && VALID_DTENV(*envp));
-
-	env = *envp;
+	dns_dtenv_t *env = *envp;
 	*envp = NULL;
 
-	isc_refcount_decrement(&env->refcount, &refs);
-	if (refs == 0)
+	if (isc_refcount_decrement(&env->refcount) == 1) {
+		isc_refcount_destroy(&env->refcount);
 		destroy(env);
+	}
 }
 
 static isc_result_t
@@ -658,13 +657,13 @@ init_msg(dns_dtenv_t *env, dns_dtmsg_t *dm, Dnstap__Message__Type mtype) {
 	if (env->identity.length != 0) {
 		dm->d.identity.data = env->identity.base;
 		dm->d.identity.len = env->identity.length;
-		dm->d.has_identity = ISC_TRUE;
+		dm->d.has_identity = true;
 	}
 
 	if (env->version.length != 0) {
 		dm->d.version.data = env->version.base;
 		dm->d.version.len = env->version.length;
-		dm->d.has_version = ISC_TRUE;
+		dm->d.has_version = true;
 	}
 }
 
@@ -708,9 +707,9 @@ cpbuf(isc_buffer_t *buf, ProtobufCBinaryData *p, protobuf_c_boolean *has) {
 }
 
 static void
-setaddr(dns_dtmsg_t *dm, isc_sockaddr_t *sa, isc_boolean_t tcp,
+setaddr(dns_dtmsg_t *dm, isc_sockaddr_t *sa, bool tcp,
 	ProtobufCBinaryData *addr, protobuf_c_boolean *has_addr,
-	isc_uint32_t *port, protobuf_c_boolean *has_port)
+	uint32_t *port, protobuf_c_boolean *has_port)
 {
 	int family = isc_sockaddr_pf(sa);
 
@@ -724,7 +723,7 @@ setaddr(dns_dtmsg_t *dm, isc_sockaddr_t *sa, isc_boolean_t tcp,
 		*port = ntohs(sa->type.sin6.sin6_port);
 	} else {
 		dm->m.socket_family = DNSTAP__SOCKET_FAMILY__INET;
-		addr->data = (isc_uint8_t *) &sa->type.sin.sin_addr.s_addr;
+		addr->data = (uint8_t *) &sa->type.sin.sin_addr.s_addr;
 		addr->len = 4;
 		*port = ntohs(sa->type.sin.sin_port);
 	}
@@ -772,7 +771,7 @@ perform_reopen(isc_task_t *task, isc_event_t *event) {
 	 * Re-allow output file rolling.
 	 */
 	LOCK(&env->reopen_lock);
-	env->reopen_queued = ISC_FALSE;
+	env->reopen_queued = false;
 	UNLOCK(&env->reopen_lock);
 }
 
@@ -819,7 +818,7 @@ check_file_size_and_maybe_reopen(dns_dtenv_t *env) {
 	}
 	isc_task_attach(env->reopen_task, &reopen_task);
 	isc_task_send(reopen_task, &event);
-	env->reopen_queued = ISC_TRUE;
+	env->reopen_queued = true;
 
  unlock_and_return:
 	UNLOCK(&env->reopen_lock);
@@ -828,7 +827,7 @@ check_file_size_and_maybe_reopen(dns_dtenv_t *env) {
 void
 dns_dt_send(dns_view_t *view, dns_dtmsgtype_t msgtype,
 	    isc_sockaddr_t *qaddr, isc_sockaddr_t *raddr,
-	    isc_boolean_t tcp, isc_region_t *zone, isc_time_t *qtime,
+	    bool tcp, isc_region_t *zone, isc_time_t *qtime,
 	    isc_time_t *rtime, isc_buffer_t *buf)
 {
 	isc_time_t now, *t;
@@ -965,35 +964,35 @@ putaddr(isc_buffer_t **b, isc_region_t *ip) {
 	return (putstr(b, buf));
 }
 
-static isc_boolean_t
+static bool
 dnstap_file(struct fstrm_reader *r) {
 	fstrm_res res;
 	const struct fstrm_control *control = NULL;
-	const isc_uint8_t *rtype = NULL;
+	const uint8_t *rtype = NULL;
 	size_t dlen = strlen(DNSTAP_CONTENT_TYPE), rlen = 0;
 	size_t n = 0;
 
 	res = fstrm_reader_get_control(r, FSTRM_CONTROL_START, &control);
 	if (res != fstrm_res_success)
-		return (ISC_FALSE);
+		return (false);
 
 	res = fstrm_control_get_num_field_content_type(control, &n);
 	if (res != fstrm_res_success)
-		return (ISC_FALSE);
+		return (false);
 	if (n > 0) {
 		res = fstrm_control_get_field_content_type(control, 0,
 							   &rtype, &rlen);
 		if (res != fstrm_res_success)
-			return (ISC_FALSE);
+			return (false);
 
 		if (rlen != dlen)
-			return (ISC_FALSE);
+			return (false);
 
 		if (memcmp(DNSTAP_CONTENT_TYPE, rtype, dlen) == 0)
-			return (ISC_TRUE);
+			return (true);
 	}
 
-	return (ISC_FALSE);
+	return (false);
 }
 
 isc_result_t
@@ -1057,15 +1056,15 @@ dns_dt_open(const char *filename, dns_dtmode_t mode, isc_mem_t *mctx,
 }
 
 isc_result_t
-dns_dt_getframe(dns_dthandle_t *handle, isc_uint8_t **bufp, size_t *sizep) {
-	const isc_uint8_t *data;
+dns_dt_getframe(dns_dthandle_t *handle, uint8_t **bufp, size_t *sizep) {
+	const uint8_t *data;
 	fstrm_res res;
 
 	REQUIRE(handle != NULL);
 	REQUIRE(bufp != NULL);
 	REQUIRE(sizep != NULL);
 
-	data = (const isc_uint8_t *) *bufp;
+	data = (const uint8_t *) *bufp;
 
 	res = fstrm_reader_read(handle->reader, &data, sizep);
 	switch (res) {
@@ -1167,9 +1166,9 @@ dns_dt_parse(isc_mem_t *mctx, isc_region_t *src, dns_dtdata_t **destp) {
 
 	/* Query? */
 	if ((d->type & DNS_DTTYPE_QUERY) != 0)
-		d->query = ISC_TRUE;
+		d->query = true;
 	else
-		d->query = ISC_FALSE;
+		d->query = false;
 
 	/* Parse DNS message */
 	if (d->query && m->has_query_message) {
@@ -1226,9 +1225,9 @@ dns_dt_parse(isc_mem_t *mctx, isc_region_t *src, dns_dtdata_t **destp) {
 				m->socket_protocol);
 		if (type != NULL &&
 		    type->value == DNSTAP__SOCKET_PROTOCOL__TCP)
-			d->tcp = ISC_TRUE;
+			d->tcp = true;
 		else
-			d->tcp = ISC_FALSE;
+			d->tcp = false;
 	}
 
 	/* Query tuple */
