@@ -27,6 +27,8 @@
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <time.h>
 
@@ -67,7 +69,7 @@
 
 static dst_func_t *dst_t_func[DST_MAX_ALGS];
 
-static isc_boolean_t dst_initialized = ISC_FALSE;
+static bool dst_initialized = false;
 
 void gss_log(int level, const char *fmt, ...) ISC_FORMAT_PRINTF(2, 3);
 
@@ -123,7 +125,6 @@ static isc_result_t	addsuffix(char *filename, int len,
 			return (_r);		\
 	} while (0);				\
 
-#if HAVE_OPENSSL
 static void *
 default_memalloc(void *arg, size_t size) {
 	UNUSED(arg);
@@ -137,20 +138,18 @@ default_memfree(void *arg, void *ptr) {
 	UNUSED(arg);
 	free(ptr);
 }
-#endif
 
 isc_result_t
 dst_lib_init(isc_mem_t *mctx, const char *engine) {
 	isc_result_t result;
 
 	REQUIRE(mctx != NULL);
-	REQUIRE(dst_initialized == ISC_FALSE);
+	REQUIRE(dst_initialized == false);
 
 	UNUSED(engine);
 
 	dst__memory_pool = NULL;
 
-#if HAVE_OPENSSL
 	UNUSED(mctx);
 	/*
 	 * When using --with-openssl, there seems to be no good way of not
@@ -166,29 +165,23 @@ dst_lib_init(isc_mem_t *mctx, const char *engine) {
 		return (result);
 	isc_mem_setname(dst__memory_pool, "dst", NULL);
 #ifndef OPENSSL_LEAKS
-	isc_mem_setdestroycheck(dst__memory_pool, ISC_FALSE);
+	isc_mem_setdestroycheck(dst__memory_pool, false);
 #endif
-#else /* HAVE_OPENSSL */
-	isc_mem_attach(mctx, &dst__memory_pool);
-#endif /* HAVE_OPENSSL */
 
 	dst_result_register();
 
 	memset(dst_t_func, 0, sizeof(dst_t_func));
-#ifndef PK11_MD5_DISABLE
 	RETERR(dst__hmacmd5_init(&dst_t_func[DST_ALG_HMACMD5]));
-#endif
 	RETERR(dst__hmacsha1_init(&dst_t_func[DST_ALG_HMACSHA1]));
 	RETERR(dst__hmacsha224_init(&dst_t_func[DST_ALG_HMACSHA224]));
 	RETERR(dst__hmacsha256_init(&dst_t_func[DST_ALG_HMACSHA256]));
 	RETERR(dst__hmacsha384_init(&dst_t_func[DST_ALG_HMACSHA384]));
 	RETERR(dst__hmacsha512_init(&dst_t_func[DST_ALG_HMACSHA512]));
-#if HAVE_OPENSSL
 	RETERR(dst__openssl_init(engine));
-#ifndef PK11_MD5_DISABLE
+	RETERR(dst__openssldh_init(&dst_t_func[DST_ALG_DH]));
+#if USE_OPENSSL
 	RETERR(dst__opensslrsa_init(&dst_t_func[DST_ALG_RSAMD5],
 				    DST_ALG_RSAMD5));
-#endif
 	RETERR(dst__opensslrsa_init(&dst_t_func[DST_ALG_RSASHA1],
 				    DST_ALG_RSASHA1));
 	RETERR(dst__opensslrsa_init(&dst_t_func[DST_ALG_NSEC3RSASHA1],
@@ -197,60 +190,46 @@ dst_lib_init(isc_mem_t *mctx, const char *engine) {
 				    DST_ALG_RSASHA256));
 	RETERR(dst__opensslrsa_init(&dst_t_func[DST_ALG_RSASHA512],
 				    DST_ALG_RSASHA512));
-#if defined(HAVE_OPENSSL_DSA) && !defined(PK11_DSA_DISABLE)
 	RETERR(dst__openssldsa_init(&dst_t_func[DST_ALG_DSA]));
 	RETERR(dst__openssldsa_init(&dst_t_func[DST_ALG_NSEC3DSA]));
-#endif
-#ifndef PK11_DH_DISABLE
-	RETERR(dst__openssldh_init(&dst_t_func[DST_ALG_DH]));
-#endif
-#ifdef HAVE_OPENSSL_ECDSA
 	RETERR(dst__opensslecdsa_init(&dst_t_func[DST_ALG_ECDSA256]));
 	RETERR(dst__opensslecdsa_init(&dst_t_func[DST_ALG_ECDSA384]));
-#endif
 #ifdef HAVE_OPENSSL_ED25519
 	RETERR(dst__openssleddsa_init(&dst_t_func[DST_ALG_ED25519]));
 #endif
 #ifdef HAVE_OPENSSL_ED448
 	RETERR(dst__openssleddsa_init(&dst_t_func[DST_ALG_ED448]));
 #endif
-#elif HAVE_PKCS11
+#endif /* USE_OPENSSL */
+
+#if USE_PKCS11
 	RETERR(dst__pkcs11_init(mctx, engine));
-#ifndef PK11_MD5_DISABLE
 	RETERR(dst__pkcs11rsa_init(&dst_t_func[DST_ALG_RSAMD5]));
-#endif
 	RETERR(dst__pkcs11rsa_init(&dst_t_func[DST_ALG_RSASHA1]));
 	RETERR(dst__pkcs11rsa_init(&dst_t_func[DST_ALG_NSEC3RSASHA1]));
 	RETERR(dst__pkcs11rsa_init(&dst_t_func[DST_ALG_RSASHA256]));
 	RETERR(dst__pkcs11rsa_init(&dst_t_func[DST_ALG_RSASHA512]));
-#ifndef PK11_DSA_DISABLE
 	RETERR(dst__pkcs11dsa_init(&dst_t_func[DST_ALG_DSA]));
 	RETERR(dst__pkcs11dsa_init(&dst_t_func[DST_ALG_NSEC3DSA]));
-#endif
-#ifndef PK11_DH_DISABLE
-	RETERR(dst__pkcs11dh_init(&dst_t_func[DST_ALG_DH]));
-#endif
-#ifdef HAVE_PKCS11_ECDSA
 	RETERR(dst__pkcs11ecdsa_init(&dst_t_func[DST_ALG_ECDSA256]));
 	RETERR(dst__pkcs11ecdsa_init(&dst_t_func[DST_ALG_ECDSA384]));
-#endif
 #ifdef HAVE_PKCS11_ED25519
 	RETERR(dst__pkcs11eddsa_init(&dst_t_func[DST_ALG_ED25519]));
 #endif
 #ifdef HAVE_PKCS11_ED448
 	RETERR(dst__pkcs11eddsa_init(&dst_t_func[DST_ALG_ED448]));
 #endif
-#endif /* if HAVE_OPENSSL, elif HAVE_PKCS11 */
+#endif /* USE_PKCS11 */
 #ifdef GSSAPI
 	RETERR(dst__gssapi_init(&dst_t_func[DST_ALG_GSSAPI]));
 #endif
 
-	dst_initialized = ISC_TRUE;
+	dst_initialized = true;
 	return (ISC_R_SUCCESS);
 
  out:
 	/* avoid immediate crash! */
-	dst_initialized = ISC_TRUE;
+	dst_initialized = true;
 	dst_lib_destroy();
 	return (result);
 }
@@ -258,48 +237,45 @@ dst_lib_init(isc_mem_t *mctx, const char *engine) {
 void
 dst_lib_destroy(void) {
 	int i;
-	RUNTIME_CHECK(dst_initialized == ISC_TRUE);
-	dst_initialized = ISC_FALSE;
+	RUNTIME_CHECK(dst_initialized == true);
+	dst_initialized = false;
 
 	for (i = 0; i < DST_MAX_ALGS; i++)
 		if (dst_t_func[i] != NULL && dst_t_func[i]->cleanup != NULL)
 			dst_t_func[i]->cleanup();
-#if HAVE_OPENSSL
 	dst__openssl_destroy();
-#elif HAVE_PKCS11
+#if USE_PKCS11
 	(void) dst__pkcs11_destroy();
-#else
-#error Either OpenSSL or PKCS#11 cryptographic provider needed.
-#endif /* if HAVE_OPENSSL, elif HAVE_PKCS11 */
+#endif /* USE_PKCS11 */
 	if (dst__memory_pool != NULL)
 		isc_mem_detach(&dst__memory_pool);
 }
 
-isc_boolean_t
+bool
 dst_algorithm_supported(unsigned int alg) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 
 	if (alg >= DST_MAX_ALGS || dst_t_func[alg] == NULL)
-		return (ISC_FALSE);
-	return (ISC_TRUE);
+		return (false);
+	return (true);
 }
 
-isc_boolean_t
+bool
 dst_ds_digest_supported(unsigned int digest_type) {
-	return  (ISC_TF(digest_type == DNS_DSDIGEST_SHA1 ||
-			digest_type == DNS_DSDIGEST_SHA256 ||
-			digest_type == DNS_DSDIGEST_SHA384));
+	return  (digest_type == DNS_DSDIGEST_SHA1 ||
+		 digest_type == DNS_DSDIGEST_SHA256 ||
+		 digest_type == DNS_DSDIGEST_SHA384);
 }
 
 isc_result_t
 dst_context_create(dst_key_t *key, isc_mem_t *mctx,
-		   isc_logcategory_t *category, isc_boolean_t useforsigning,
+		   isc_logcategory_t *category, bool useforsigning,
 		   int maxbits, dst_context_t **dctxp)
 {
 	dst_context_t *dctx;
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(mctx != NULL);
 	REQUIRE(dctxp != NULL && *dctxp == NULL);
@@ -376,7 +352,7 @@ dst_context_sign(dst_context_t *dctx, isc_buffer_t *sig) {
 	if (key->func->sign == NULL)
 		return (DST_R_NOTPRIVATEKEY);
 	if (key->func->isprivate == NULL ||
-	    key->func->isprivate(key) == ISC_FALSE)
+	    key->func->isprivate(key) == false)
 		return (DST_R_NOTPRIVATEKEY);
 
 	return (key->func->sign(dctx, sig));
@@ -419,7 +395,7 @@ isc_result_t
 dst_key_computesecret(const dst_key_t *pub, const dst_key_t *priv,
 		      isc_buffer_t *secret)
 {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(pub) && VALID_KEY(priv));
 	REQUIRE(secret != NULL);
 
@@ -434,7 +410,7 @@ dst_key_computesecret(const dst_key_t *pub, const dst_key_t *priv,
 	    priv->func->computesecret == NULL)
 		return (DST_R_KEYCANNOTCOMPUTESECRET);
 
-	if (dst_key_isprivate(priv) == ISC_FALSE)
+	if (dst_key_isprivate(priv) == false)
 		return (DST_R_NOTPRIVATEKEY);
 
 	return (pub->func->computesecret(pub, priv, secret));
@@ -444,7 +420,7 @@ isc_result_t
 dst_key_tofile(const dst_key_t *key, int type, const char *directory) {
 	isc_result_t ret = ISC_R_SUCCESS;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 
@@ -467,11 +443,11 @@ dst_key_tofile(const dst_key_t *key, int type, const char *directory) {
 }
 
 void
-dst_key_setexternal(dst_key_t *key, isc_boolean_t value) {
+dst_key_setexternal(dst_key_t *key, bool value) {
 	key->external = value;
 }
 
-isc_boolean_t
+bool
 dst_key_isexternal(dst_key_t *key) {
 	return (key->external);
 }
@@ -483,7 +459,7 @@ dst_key_getfilename(dns_name_t *name, dns_keytag_t id,
 {
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 	REQUIRE(mctx != NULL);
@@ -508,11 +484,11 @@ dst_key_fromfile(dns_name_t *name, dns_keytag_t id,
 		 isc_mem_t *mctx, dst_key_t **keyp)
 {
 	isc_result_t result;
-	char filename[ISC_DIR_NAMEMAX];
+	char filename[NAME_MAX];
 	isc_buffer_t buf;
 	dst_key_t *key;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 	REQUIRE(mctx != NULL);
@@ -522,7 +498,7 @@ dst_key_fromfile(dns_name_t *name, dns_keytag_t id,
 
 	key = NULL;
 
-	isc_buffer_init(&buf, filename, ISC_DIR_NAMEMAX);
+	isc_buffer_init(&buf, filename, NAME_MAX);
 	result = dst_key_getfilename(name, id, alg, type, NULL, mctx, &buf);
 	if (result != ISC_R_SUCCESS)
 		goto out;
@@ -561,7 +537,7 @@ dst_key_fromnamedfile(const char *filename, const char *dirname,
 	int newfilenamelen = 0;
 	isc_lex_t *lex = NULL;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(filename != NULL);
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 	REQUIRE(mctx != NULL);
@@ -660,7 +636,7 @@ dst_key_fromnamedfile(const char *filename, const char *dirname,
 
 isc_result_t
 dst_key_todns(const dst_key_t *key, isc_buffer_t *target) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(target != NULL);
 
@@ -671,15 +647,15 @@ dst_key_todns(const dst_key_t *key, isc_buffer_t *target) {
 
 	if (isc_buffer_availablelength(target) < 4)
 		return (ISC_R_NOSPACE);
-	isc_buffer_putuint16(target, (isc_uint16_t)(key->key_flags & 0xffff));
-	isc_buffer_putuint8(target, (isc_uint8_t)key->key_proto);
-	isc_buffer_putuint8(target, (isc_uint8_t)key->key_alg);
+	isc_buffer_putuint16(target, (uint16_t)(key->key_flags & 0xffff));
+	isc_buffer_putuint8(target, (uint8_t)key->key_proto);
+	isc_buffer_putuint8(target, (uint8_t)key->key_alg);
 
 	if (key->key_flags & DNS_KEYFLAG_EXTENDED) {
 		if (isc_buffer_availablelength(target) < 2)
 			return (ISC_R_NOSPACE);
 		isc_buffer_putuint16(target,
-				     (isc_uint16_t)((key->key_flags >> 16)
+				     (uint16_t)((key->key_flags >> 16)
 						    & 0xffff));
 	}
 
@@ -693,8 +669,8 @@ isc_result_t
 dst_key_fromdns(const dns_name_t *name, dns_rdataclass_t rdclass,
 		isc_buffer_t *source, isc_mem_t *mctx, dst_key_t **keyp)
 {
-	isc_uint8_t alg, proto;
-	isc_uint32_t flags, extflags;
+	uint8_t alg, proto;
+	uint32_t flags, extflags;
 	dst_key_t *key = NULL;
 	dns_keytag_t id, rid;
 	isc_region_t r;
@@ -759,7 +735,7 @@ dst_key_frombuffer(const dns_name_t *name, unsigned int alg,
 
 isc_result_t
 dst_key_tobuffer(const dst_key_t *key, isc_buffer_t *target) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(target != NULL);
 
@@ -776,7 +752,7 @@ dst_key_privatefrombuffer(dst_key_t *key, isc_buffer_t *buffer) {
 	isc_lex_t *lex = NULL;
 	isc_result_t result = ISC_R_SUCCESS;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(!dst_key_isprivate(key));
 	REQUIRE(buffer != NULL);
@@ -842,7 +818,7 @@ dst_key_buildinternal(const dns_name_t *name, unsigned int alg,
 	dst_key_t *key;
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE(mctx != NULL);
 	REQUIRE(keyp != NULL && *keyp == NULL);
@@ -876,7 +852,7 @@ dst_key_fromlabel(const dns_name_t *name, int alg, unsigned int flags,
 	dst_key_t *key;
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE(mctx != NULL);
 	REQUIRE(keyp != NULL && *keyp == NULL);
@@ -920,7 +896,7 @@ dst_key_generate(const dns_name_t *name, unsigned int alg,
 	dst_key_t *key;
 	isc_result_t ret;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE(mctx != NULL);
 	REQUIRE(keyp != NULL && *keyp == NULL);
@@ -960,7 +936,7 @@ dst_key_generate(const dns_name_t *name, unsigned int alg,
 }
 
 isc_result_t
-dst_key_getnum(const dst_key_t *key, int type, isc_uint32_t *valuep)
+dst_key_getnum(const dst_key_t *key, int type, uint32_t *valuep)
 {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(valuep != NULL);
@@ -972,12 +948,12 @@ dst_key_getnum(const dst_key_t *key, int type, isc_uint32_t *valuep)
 }
 
 void
-dst_key_setnum(dst_key_t *key, int type, isc_uint32_t value)
+dst_key_setnum(dst_key_t *key, int type, uint32_t value)
 {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_NUMERIC);
 	key->nums[type] = value;
-	key->numset[type] = ISC_TRUE;
+	key->numset[type] = true;
 }
 
 void
@@ -985,7 +961,7 @@ dst_key_unsetnum(dst_key_t *key, int type)
 {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_NUMERIC);
-	key->numset[type] = ISC_FALSE;
+	key->numset[type] = false;
 }
 
 isc_result_t
@@ -1004,14 +980,14 @@ dst_key_settime(dst_key_t *key, int type, isc_stdtime_t when) {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_TIMES);
 	key->times[type] = when;
-	key->timeset[type] = ISC_TRUE;
+	key->timeset[type] = true;
 }
 
 void
 dst_key_unsettime(dst_key_t *key, int type) {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_TIMES);
-	key->timeset[type] = ISC_FALSE;
+	key->timeset[type] = false;
 }
 
 isc_result_t
@@ -1031,41 +1007,39 @@ dst_key_setprivateformat(dst_key_t *key, int major, int minor) {
 	key->fmt_minor = minor;
 }
 
-static isc_boolean_t
+static bool
 comparekeys(const dst_key_t *key1, const dst_key_t *key2,
-	    isc_boolean_t match_revoked_key,
-	    isc_boolean_t (*compare)(const dst_key_t *key1,
+	    bool match_revoked_key,
+	    bool (*compare)(const dst_key_t *key1,
 				     const dst_key_t *key2))
 {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key1));
 	REQUIRE(VALID_KEY(key2));
 
 	if (key1 == key2)
-		return (ISC_TRUE);
+		return (true);
 
 	if (key1->key_alg != key2->key_alg)
-		return (ISC_FALSE);
+		return (false);
 
 	if (key1->key_id != key2->key_id) {
 		if (!match_revoked_key)
-			return (ISC_FALSE);
-#ifndef PK11_MD5_DISABLE
+			return (false);
 		if (key1->key_alg == DST_ALG_RSAMD5)
-			return (ISC_FALSE);
-#endif
+			return (false);
 		if ((key1->key_flags & DNS_KEYFLAG_REVOKE) ==
 		    (key2->key_flags & DNS_KEYFLAG_REVOKE))
-			return (ISC_FALSE);
+			return (false);
 		if (key1->key_id != key2->key_rid &&
 		    key1->key_rid != key2->key_id)
-			return (ISC_FALSE);
+			return (false);
 	}
 
 	if (compare != NULL)
 		return (compare(key1, key2));
 	else
-		return (ISC_FALSE);
+		return (false);
 }
 
 
@@ -1073,7 +1047,7 @@ comparekeys(const dst_key_t *key1, const dst_key_t *key2,
  * Compares only the public portion of two keys, by converting them
  * both to wire format and comparing the results.
  */
-static isc_boolean_t
+static bool
 pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	isc_result_t result;
 	unsigned char buf1[DST_KEY_MAXSIZE], buf2[DST_KEY_MAXSIZE];
@@ -1083,7 +1057,7 @@ pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	isc_buffer_init(&b1, buf1, sizeof(buf1));
 	result = dst_key_todns(key1, &b1);
 	if (result != ISC_R_SUCCESS)
-		return (ISC_FALSE);
+		return (false);
 	/* Zero out flags. */
 	buf1[0] = buf1[1] = 0;
 	if ((key1->key_flags & DNS_KEYFLAG_EXTENDED) != 0)
@@ -1092,7 +1066,7 @@ pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	isc_buffer_init(&b2, buf2, sizeof(buf2));
 	result = dst_key_todns(key2, &b2);
 	if (result != ISC_R_SUCCESS)
-		return (ISC_FALSE);
+		return (false);
 	/* Zero out flags. */
 	buf2[0] = buf2[1] = 0;
 	if ((key2->key_flags & DNS_KEYFLAG_EXTENDED) != 0)
@@ -1111,85 +1085,78 @@ pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 		memmove(&buf2[4], &buf2[6], r2.length - 6);
 		r2.length -= 2;
 	}
-	return (ISC_TF(isc_region_compare(&r1, &r2) == 0));
+	return (isc_region_compare(&r1, &r2) == 0);
 }
 
-isc_boolean_t
+bool
 dst_key_compare(const dst_key_t *key1, const dst_key_t *key2) {
-	return (comparekeys(key1, key2, ISC_FALSE, key1->func->compare));
+	return (comparekeys(key1, key2, false, key1->func->compare));
 }
 
-isc_boolean_t
+bool
 dst_key_pubcompare(const dst_key_t *key1, const dst_key_t *key2,
-		   isc_boolean_t match_revoked_key)
+		   bool match_revoked_key)
 {
 	return (comparekeys(key1, key2, match_revoked_key, pub_compare));
 }
 
 
-isc_boolean_t
+bool
 dst_key_paramcompare(const dst_key_t *key1, const dst_key_t *key2) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key1));
 	REQUIRE(VALID_KEY(key2));
 
 	if (key1 == key2)
-		return (ISC_TRUE);
+		return (true);
 	if (key1->key_alg == key2->key_alg &&
 	    key1->func->paramcompare != NULL &&
-	    key1->func->paramcompare(key1, key2) == ISC_TRUE)
-		return (ISC_TRUE);
+	    key1->func->paramcompare(key1, key2) == true)
+		return (true);
 	else
-		return (ISC_FALSE);
+		return (false);
 }
 
 void
 dst_key_attach(dst_key_t *source, dst_key_t **target) {
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(target != NULL && *target == NULL);
 	REQUIRE(VALID_KEY(source));
 
-	isc_refcount_increment(&source->refs, NULL);
+	isc_refcount_increment(&source->refs);
 	*target = source;
 }
 
 void
 dst_key_free(dst_key_t **keyp) {
-	isc_mem_t *mctx;
-	dst_key_t *key;
-	unsigned int refs;
-
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(keyp != NULL && VALID_KEY(*keyp));
-
-	key = *keyp;
-	mctx = key->mctx;
-
-	isc_refcount_decrement(&key->refs, &refs);
-	if (refs != 0)
-		return;
-
-	isc_refcount_destroy(&key->refs);
-	if (key->keydata.generic != NULL) {
-		INSIST(key->func->destroy != NULL);
-		key->func->destroy(key);
-	}
-	if (key->engine != NULL)
-		isc_mem_free(mctx, key->engine);
-	if (key->label != NULL)
-		isc_mem_free(mctx, key->label);
-	dns_name_free(key->key_name, mctx);
-	isc_mem_put(mctx, key->key_name, sizeof(dns_name_t));
-	if (key->key_tkeytoken) {
-		isc_buffer_free(&key->key_tkeytoken);
-	}
-	isc_safe_memwipe(key, sizeof(*key));
-	isc_mem_putanddetach(&mctx, key, sizeof(*key));
+	dst_key_t *key = *keyp;
 	*keyp = NULL;
+
+	if (isc_refcount_decrement(&key->refs) == 1) {
+		isc_refcount_destroy(&key->refs);
+		isc_mem_t *mctx = key->mctx;
+		if (key->keydata.generic != NULL) {
+			INSIST(key->func->destroy != NULL);
+			key->func->destroy(key);
+		}
+		if (key->engine != NULL)
+			isc_mem_free(mctx, key->engine);
+		if (key->label != NULL)
+			isc_mem_free(mctx, key->label);
+		dns_name_free(key->key_name, mctx);
+		isc_mem_put(mctx, key->key_name, sizeof(dns_name_t));
+		if (key->key_tkeytoken) {
+			isc_buffer_free(&key->key_tkeytoken);
+		}
+		isc_safe_memwipe(key, sizeof(*key));
+		isc_mem_putanddetach(&mctx, key, sizeof(*key));
+	}
 }
 
-isc_boolean_t
+bool
 dst_key_isprivate(const dst_key_t *key) {
 	REQUIRE(VALID_KEY(key));
 	INSIST(key->func->isprivate != NULL);
@@ -1210,27 +1177,23 @@ dst_key_buildfilename(const dst_key_t *key, int type,
 
 isc_result_t
 dst_key_sigsize(const dst_key_t *key, unsigned int *n) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(n != NULL);
 
 	/* XXXVIX this switch statement is too sparse to gen a jump table. */
 	switch (key->key_alg) {
-#ifndef PK11_MD5_DISABLE
 	case DST_ALG_RSAMD5:
-#endif
 	case DST_ALG_RSASHA1:
 	case DST_ALG_NSEC3RSASHA1:
 	case DST_ALG_RSASHA256:
 	case DST_ALG_RSASHA512:
 		*n = (key->key_size + 7) / 8;
 		break;
-#ifndef PK11_DSA_DISABLE
 	case DST_ALG_DSA:
 	case DST_ALG_NSEC3DSA:
 		*n = DNS_SIG_DSASIGSIZE;
 		break;
-#endif
 	case DST_ALG_ECDSA256:
 		*n = DNS_SIG_ECDSA256SIZE;
 		break;
@@ -1243,11 +1206,9 @@ dst_key_sigsize(const dst_key_t *key, unsigned int *n) {
 	case DST_ALG_ED448:
 		*n = DNS_SIG_ED448SIZE;
 		break;
-#ifndef PK11_MD5_DISABLE
 	case DST_ALG_HMACMD5:
 		*n = 16;
 		break;
-#endif
 	case DST_ALG_HMACSHA1:
 		*n = ISC_SHA1_DIGESTLENGTH;
 		break;
@@ -1266,9 +1227,7 @@ dst_key_sigsize(const dst_key_t *key, unsigned int *n) {
 	case DST_ALG_GSSAPI:
 		*n = 128; /*%< XXX */
 		break;
-#ifndef PK11_DH_DISABLE
 	case DST_ALG_DH:
-#endif
 	default:
 		return (DST_R_UNSUPPORTEDALG);
 	}
@@ -1277,26 +1236,22 @@ dst_key_sigsize(const dst_key_t *key, unsigned int *n) {
 
 isc_result_t
 dst_key_secretsize(const dst_key_t *key, unsigned int *n) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(n != NULL);
 
-#ifndef PK11_DH_DISABLE
-	if (key->key_alg == DST_ALG_DH)
+	if (key->key_alg == DST_ALG_DH) {
 		*n = (key->key_size + 7) / 8;
-	else
-#endif
-		return (DST_R_UNSUPPORTEDALG);
-#ifndef PK11_DH_DISABLE
-	return (ISC_R_SUCCESS);
-#endif
+		return (ISC_R_SUCCESS);
+	}
+	return (DST_R_UNSUPPORTEDALG);
 }
 
 /*%
  * Set the flags on a key, then recompute the key ID
  */
 isc_result_t
-dst_key_setflags(dst_key_t *key, isc_uint32_t flags) {
+dst_key_setflags(dst_key_t *key, uint32_t flags) {
 	REQUIRE(VALID_KEY(key));
 	key->key_flags = flags;
 	return (computeid(key));
@@ -1333,7 +1288,7 @@ dst_key_restore(dns_name_t *name, unsigned int alg, unsigned int flags,
 	isc_result_t result;
 	dst_key_t *key;
 
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(keyp != NULL && *keyp == NULL);
 
 	if (alg >= DST_MAX_ALGS || dst_t_func[alg] == NULL)
@@ -1392,13 +1347,7 @@ get_key_struct(const dns_name_t *name, unsigned int alg,
 		return (NULL);
 	}
 
-	result = isc_refcount_init(&key->refs, 1);
-	if (result != ISC_R_SUCCESS) {
-		dns_name_free(key->key_name, mctx);
-		isc_mem_put(mctx, key->key_name, sizeof(dns_name_t));
-		isc_mem_put(mctx, key, sizeof(dst_key_t));
-		return (NULL);
-	}
+	isc_refcount_init(&key->refs, 1);
 	isc_mem_attach(mctx, &key->mctx);
 	key->key_alg = alg;
 	key->key_flags = flags;
@@ -1412,14 +1361,14 @@ get_key_struct(const dns_name_t *name, unsigned int alg,
 	key->fmt_minor = 0;
 	for (i = 0; i < (DST_MAX_TIMES + 1); i++) {
 		key->times[i] = 0;
-		key->timeset[i] = ISC_FALSE;
+		key->timeset[i] = false;
 	}
-	key->inactive = ISC_FALSE;
+	key->inactive = false;
 	key->magic = KEY_MAGIC;
 	return (key);
 }
 
-isc_boolean_t
+bool
 dst_key_inactive(const dst_key_t *key) {
 
 	REQUIRE(VALID_KEY(key));
@@ -1428,7 +1377,7 @@ dst_key_inactive(const dst_key_t *key) {
 }
 
 void
-dst_key_setinactive(dst_key_t *key, isc_boolean_t inactive) {
+dst_key_setinactive(dst_key_t *key, bool inactive) {
 
 	REQUIRE(VALID_KEY(key));
 
@@ -1452,7 +1401,7 @@ dst_key_read_public(const char *filename, int type,
 	unsigned int opt = ISC_LEXOPT_DNSMULTILINE;
 	dns_rdataclass_t rdclass = dns_rdataclass_in;
 	isc_lexspecials_t specials;
-	isc_uint32_t ttl = 0;
+	uint32_t ttl = 0;
 	isc_result_t result;
 	dns_rdatatype_t keytype;
 
@@ -1544,7 +1493,7 @@ dst_key_read_public(const char *filename, int type,
 
 	isc_buffer_init(&b, rdatabuf, sizeof(rdatabuf));
 	ret = dns_rdata_fromtext(&rdata, rdclass, keytype, lex, NULL,
-				 ISC_FALSE, mctx, &b, NULL);
+				 false, mctx, &b, NULL);
 	if (ret != ISC_R_SUCCESS)
 		goto cleanup;
 
@@ -1561,44 +1510,36 @@ dst_key_read_public(const char *filename, int type,
 	return (ret);
 }
 
-static isc_boolean_t
+static bool
 issymmetric(const dst_key_t *key) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 	REQUIRE(VALID_KEY(key));
 
 	/* XXXVIX this switch statement is too sparse to gen a jump table. */
 	switch (key->key_alg) {
-#ifndef PK11_MD5_DISABLE
 	case DST_ALG_RSAMD5:
-#endif
 	case DST_ALG_RSASHA1:
 	case DST_ALG_NSEC3RSASHA1:
 	case DST_ALG_RSASHA256:
 	case DST_ALG_RSASHA512:
-#ifndef PK11_DSA_DISABLE
 	case DST_ALG_DSA:
 	case DST_ALG_NSEC3DSA:
-#endif
-#ifndef PK11_DH_DISABLE
 	case DST_ALG_DH:
-#endif
 	case DST_ALG_ECDSA256:
 	case DST_ALG_ECDSA384:
 	case DST_ALG_ED25519:
 	case DST_ALG_ED448:
-		return (ISC_FALSE);
-#ifndef PK11_MD5_DISABLE
+		return (false);
 	case DST_ALG_HMACMD5:
-#endif
 	case DST_ALG_HMACSHA1:
 	case DST_ALG_HMACSHA224:
 	case DST_ALG_HMACSHA256:
 	case DST_ALG_HMACSHA384:
 	case DST_ALG_HMACSHA512:
 	case DST_ALG_GSSAPI:
-		return (ISC_TRUE);
+		return (true);
 	default:
-		return (ISC_FALSE);
+		return (false);
 	}
 }
 
@@ -1608,11 +1549,7 @@ issymmetric(const dst_key_t *key) {
 static void
 printtime(const dst_key_t *key, int type, const char *tag, FILE *stream) {
 	isc_result_t result;
-#ifdef ISC_PLATFORM_USETHREADS
 	char output[26]; /* Minimum buffer as per ctime_r() specification. */
-#else
-	const char *output;
-#endif
 	isc_stdtime_t when;
 	time_t t;
 	char utc[sizeof("YYYYMMDDHHSSMM")];
@@ -1625,7 +1562,6 @@ printtime(const dst_key_t *key, int type, const char *tag, FILE *stream) {
 
 	/* time_t and isc_stdtime_t might be different sizes */
 	t = when;
-#ifdef ISC_PLATFORM_USETHREADS
 #ifdef WIN32
 	if (ctime_s(output, sizeof(output), &t) != 0)
 		goto error;
@@ -1633,9 +1569,6 @@ printtime(const dst_key_t *key, int type, const char *tag, FILE *stream) {
 	if (ctime_r(&t, output) == NULL)
 		goto error;
 #endif
-#else
-	output = ctime(&t);
-#endif
 
 	isc_buffer_init(&b, utc, sizeof(utc));
 	result = dns_time32_totext(when, &b);
@@ -1659,7 +1592,7 @@ write_public_key(const dst_key_t *key, int type, const char *directory) {
 	FILE *fp;
 	isc_buffer_t keyb, textb, fileb, classb;
 	isc_region_t r;
-	char filename[ISC_DIR_NAMEMAX];
+	char filename[NAME_MAX];
 	unsigned char key_array[DST_KEY_MAXSIZE];
 	char text_array[DST_KEY_MAXTEXTSIZE];
 	char class_array[10];
@@ -1790,7 +1723,7 @@ buildfilename(dns_name_t *name, dns_keytag_t id,
 	if (isc_buffer_availablelength(out) < 1)
 		return (ISC_R_NOSPACE);
 	isc_buffer_putstr(out, "K");
-	result = dns_name_tofilenametext(name, ISC_FALSE, out);
+	result = dns_name_tofilenametext(name, false, out);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 
@@ -1856,7 +1789,7 @@ frombuffer(const dns_name_t *name, unsigned int alg, unsigned int flags,
 
 static isc_result_t
 algorithm_status(unsigned int alg) {
-	REQUIRE(dst_initialized == ISC_TRUE);
+	REQUIRE(dst_initialized == true);
 
 	if (dst_algorithm_supported(alg)) {
 		return (ISC_R_SUCCESS);
