@@ -25,6 +25,9 @@
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
+
 #include <isc/base64.h>
 #include <isc/dir.h>
 #include <isc/file.h>
@@ -88,20 +91,16 @@ static struct parse_map map[] = {
 	{TAG_RSA_ENGINE, "Engine:" },
 	{TAG_RSA_LABEL, "Label:" },
 
-#ifndef PK11_DH_DISABLE
 	{TAG_DH_PRIME, "Prime(p):"},
 	{TAG_DH_GENERATOR, "Generator(g):"},
 	{TAG_DH_PRIVATE, "Private_value(x):"},
 	{TAG_DH_PUBLIC, "Public_value(y):"},
-#endif
 
-#ifndef PK11_DSA_DISABLE
 	{TAG_DSA_PRIME, "Prime(p):"},
 	{TAG_DSA_SUBPRIME, "Subprime(q):"},
 	{TAG_DSA_BASE, "Base(g):"},
 	{TAG_DSA_PRIVATE, "Private_value(x):"},
 	{TAG_DSA_PUBLIC, "Public_value(y):"},
-#endif
 
 	{TAG_ECDSA_PRIVATEKEY, "PrivateKey:"},
 	{TAG_ECDSA_ENGINE, "Engine:" },
@@ -111,10 +110,8 @@ static struct parse_map map[] = {
 	{TAG_EDDSA_ENGINE, "Engine:" },
 	{TAG_EDDSA_LABEL, "Label:" },
 
-#ifndef PK11_MD5_DISABLE
 	{TAG_HMACMD5_KEY, "Key:"},
 	{TAG_HMACMD5_BITS, "Bits:"},
-#endif
 
 	{TAG_HMACSHA1_KEY, "Key:"},
 	{TAG_HMACSHA1_BITS, "Bits:"},
@@ -181,17 +178,17 @@ find_numericdata(const char *s) {
 }
 
 static int
-check_rsa(const dst_private_t *priv, isc_boolean_t external) {
+check_rsa(const dst_private_t *priv, bool external) {
 	int i, j;
-	isc_boolean_t have[RSA_NTAGS];
-	isc_boolean_t ok;
+	bool have[RSA_NTAGS];
+	bool ok;
 	unsigned int mask;
 
 	if (external)
 		return ((priv->nelements == 0) ? 0 : -1);
 
 	for (i = 0; i < RSA_NTAGS; i++)
-		have[i] = ISC_FALSE;
+		have[i] = false;
 
 	for (j = 0; j < priv->nelements; j++) {
 		for (i = 0; i < RSA_NTAGS; i++)
@@ -199,7 +196,7 @@ check_rsa(const dst_private_t *priv, isc_boolean_t external) {
 				break;
 		if (i == RSA_NTAGS)
 			return (-1);
-		have[i] = ISC_TRUE;
+		have[i] = true;
 	}
 
 	mask = (1ULL << TAG_SHIFT) - 1;
@@ -220,7 +217,6 @@ check_rsa(const dst_private_t *priv, isc_boolean_t external) {
 	return (ok ? 0 : -1 );
 }
 
-#ifndef PK11_DH_DISABLE
 static int
 check_dh(const dst_private_t *priv) {
 	int i, j;
@@ -235,11 +231,9 @@ check_dh(const dst_private_t *priv) {
 	}
 	return (0);
 }
-#endif
 
-#ifndef PK11_DSA_DISABLE
 static int
-check_dsa(const dst_private_t *priv, isc_boolean_t external) {
+check_dsa(const dst_private_t *priv, bool external) {
 	int i, j;
 
 	if (external)
@@ -257,27 +251,26 @@ check_dsa(const dst_private_t *priv, isc_boolean_t external) {
 	}
 	return (0);
 }
-#endif
 
 static int
-check_ecdsa(const dst_private_t *priv, isc_boolean_t external) {
+check_ecdsa(const dst_private_t *priv, bool external) {
 	int i, j;
-	isc_boolean_t have[ECDSA_NTAGS];
-	isc_boolean_t ok;
+	bool have[ECDSA_NTAGS];
+	bool ok;
 	unsigned int mask;
 
 	if (external)
 		return ((priv->nelements == 0) ? 0 : -1);
 
 	for (i = 0; i < ECDSA_NTAGS; i++)
-		have[i] = ISC_FALSE;
+		have[i] = false;
 	for (j = 0; j < priv->nelements; j++) {
 		for (i = 0; i < ECDSA_NTAGS; i++)
 			if (priv->elements[j].tag == TAG(DST_ALG_ECDSA256, i))
 				break;
 		if (i == ECDSA_NTAGS)
 			return (-1);
-		have[i] = ISC_TRUE;
+		have[i] = true;
 	}
 
 	mask = (1ULL << TAG_SHIFT) - 1;
@@ -290,24 +283,24 @@ check_ecdsa(const dst_private_t *priv, isc_boolean_t external) {
 }
 
 static int
-check_eddsa(const dst_private_t *priv, isc_boolean_t external) {
+check_eddsa(const dst_private_t *priv, bool external) {
 	int i, j;
-	isc_boolean_t have[EDDSA_NTAGS];
-	isc_boolean_t ok;
+	bool have[EDDSA_NTAGS];
+	bool ok;
 	unsigned int mask;
 
 	if (external)
 		return ((priv->nelements == 0) ? 0 : -1);
 
 	for (i = 0; i < EDDSA_NTAGS; i++)
-		have[i] = ISC_FALSE;
+		have[i] = false;
 	for (j = 0; j < priv->nelements; j++) {
 		for (i = 0; i < EDDSA_NTAGS; i++)
 			if (priv->elements[j].tag == TAG(DST_ALG_ED25519, i))
 				break;
 		if (i == EDDSA_NTAGS)
 			return (-1);
-		have[i] = ISC_TRUE;
+		have[i] = true;
 	}
 
 	mask = (1ULL << TAG_SHIFT) - 1;
@@ -319,9 +312,8 @@ check_eddsa(const dst_private_t *priv, isc_boolean_t external) {
 	return (ok ? 0 : -1 );
 }
 
-#ifndef PK11_MD5_DISABLE
 static int
-check_hmac_md5(const dst_private_t *priv, isc_boolean_t old) {
+check_hmac_md5(const dst_private_t *priv, bool old) {
 	int i, j;
 
 	if (priv->nelements != HMACMD5_NTAGS) {
@@ -346,7 +338,6 @@ check_hmac_md5(const dst_private_t *priv, isc_boolean_t old) {
 	}
 	return (0);
 }
-#endif
 
 static int
 check_hmac_sha(const dst_private_t *priv, unsigned int ntags,
@@ -367,40 +358,29 @@ check_hmac_sha(const dst_private_t *priv, unsigned int ntags,
 
 static int
 check_data(const dst_private_t *priv, const unsigned int alg,
-	   isc_boolean_t old, isc_boolean_t external)
+	   bool old, bool external)
 {
-#ifdef PK11_MD5_DISABLE
-	UNUSED(old);
-#endif
 	/* XXXVIX this switch statement is too sparse to gen a jump table. */
 	switch (alg) {
-#ifndef PK11_MD5_DISABLE
 	case DST_ALG_RSAMD5:
-#endif
 	case DST_ALG_RSASHA1:
 	case DST_ALG_NSEC3RSASHA1:
 	case DST_ALG_RSASHA256:
 	case DST_ALG_RSASHA512:
 		return (check_rsa(priv, external));
-#ifndef PK11_DH_DISABLE
 	case DST_ALG_DH:
 		return (check_dh(priv));
-#endif
-#ifndef PK11_DSA_DISABLE
 	case DST_ALG_DSA:
 	case DST_ALG_NSEC3DSA:
 		return (check_dsa(priv, external));
-#endif
 	case DST_ALG_ECDSA256:
 	case DST_ALG_ECDSA384:
 		return (check_ecdsa(priv, external));
 	case DST_ALG_ED25519:
 	case DST_ALG_ED448:
 		return (check_eddsa(priv, external));
-#ifndef PK11_MD5_DISABLE
 	case DST_ALG_HMACMD5:
 		return (check_hmac_md5(priv, old));
-#endif
 	case DST_ALG_HMACSHA1:
 		return (check_hmac_sha(priv, HMACSHA1_NTAGS, alg));
 	case DST_ALG_HMACSHA224:
@@ -442,7 +422,7 @@ dst__privstruct_parse(dst_key_t *key, unsigned int alg, isc_lex_t *lex,
 	unsigned int opt = ISC_LEXOPT_EOL;
 	isc_stdtime_t when;
 	isc_result_t ret;
-	isc_boolean_t external = ISC_FALSE;
+	bool external = false;
 
 	REQUIRE(priv != NULL);
 
@@ -542,7 +522,7 @@ dst__privstruct_parse(dst_key_t *key, unsigned int alg, isc_lex_t *lex,
 		}
 
 		if (strcmp(DST_AS_STR(token), "External:") == 0) {
-			external = ISC_TRUE;
+			external = true;
 			goto next;
 		}
 
@@ -617,12 +597,7 @@ dst__privstruct_parse(dst_key_t *key, unsigned int alg, isc_lex_t *lex,
 		goto fail;
 	}
 
-#ifdef PK11_MD5_DISABLE
-	check = check_data(priv, alg == DST_ALG_RSA ? DST_ALG_RSASHA1 : alg,
-			   ISC_TRUE, external);
-#else
-	check = check_data(priv, alg, ISC_TRUE, external);
-#endif
+	check = check_data(priv, alg, true, external);
 	if (check < 0) {
 		ret = DST_R_INVALIDPRIVATEKEY;
 		goto fail;
@@ -649,11 +624,11 @@ dst__privstruct_writefile(const dst_key_t *key, const dst_private_t *priv,
 {
 	FILE *fp;
 	isc_result_t result;
-	char filename[ISC_DIR_NAMEMAX];
+	char filename[NAME_MAX];
 	char buffer[MAXFIELDSIZE * 2];
 	isc_fsaccess_t access;
 	isc_stdtime_t when;
-	isc_uint32_t value;
+	uint32_t value;
 	isc_buffer_t b;
 	isc_region_t r;
 	int major, minor;
@@ -662,7 +637,7 @@ dst__privstruct_writefile(const dst_key_t *key, const dst_private_t *priv,
 
 	REQUIRE(priv != NULL);
 
-	ret = check_data(priv, dst_key_alg(key), ISC_FALSE, key->external);
+	ret = check_data(priv, dst_key_alg(key), false, key->external);
 	if (ret < 0)
 		return (DST_R_INVALIDPRIVATEKEY);
 	else if (ret != ISC_R_SUCCESS)
