@@ -9,7 +9,7 @@
  * information regarding copyright ownership.
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <stdbool.h>
 
@@ -725,7 +725,7 @@ rdataset_current(dns_rdataset_t *rdataset, dns_rdata_t *rdata) {
 	raw += 2;
 #endif
 	if (rdataset->type == dns_rdatatype_rrsig) {
-		if ((*raw & DNS_RDATASLAB_OFFLINE) != 0)
+		if (*raw & DNS_RDATASLAB_OFFLINE)
 			flags |= DNS_RDATA_OFFLINE;
 		length--;
 		raw++;
