@@ -27,28 +27,18 @@
 #include <sys/types.h>
 
 #include <ctype.h>
-#include <errno.h>
-#include <limits.h>
-#include <stdint.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
 
-#ifndef PATH_MAX
-#define PATH_MAX 1024
-#endif
-
 #ifdef WIN32
 #include "gen-win32.h"
 #else
 #include "gen-unix.h"
 #endif
 
-#ifndef ULLONG_MAX
-#define ULLONG_MAX (~0ULL)
-#endif
-
 #define INSIST(cond) \
 	if (!(cond)) { \
 		fprintf(stderr, "%s:%d: INSIST(%s)\n", \
@@ -143,28 +133,29 @@ static const char copyright[] =
 #define TYPECLASSBUF (TYPECLASSLEN + 1)
 #define TYPECLASSFMT "%" STR(TYPECLASSLEN) "[-0-9a-z]_%d"
 #define ATTRIBUTESIZE 256
+#define DIRNAMESIZE 256
 
 static struct cc {
 	struct cc *next;
 	int rdclass;
-	char classbuf[TYPECLASSBUF];
+	char classname[TYPECLASSBUF];
 } *classes;
 
 static struct tt {
 	struct tt *next;
-	uint16_t rdclass;
-	uint16_t type;
-	char classbuf[TYPECLASSBUF];
-	char typebuf[TYPECLASSBUF];
-	char dirbuf[PATH_MAX-30];
+	int rdclass;
+	int type;
+	char classname[TYPECLASSBUF];
+	char typename[TYPECLASSBUF];
+	char dirname[DIRNAMESIZE];	/* XXX Should be max path length */
 } *types;
 
 static struct ttnam {
-	char typebuf[TYPECLASSBUF];
+	char typename[TYPECLASSBUF];
 	char macroname[TYPECLASSBUF];
 	char attr[ATTRIBUTESIZE];
 	unsigned int sorted;
-	uint16_t type;
+	int type;
 } typenames[TYPENAMES];
 
 static int maxtype = -1;
@@ -258,13 +249,13 @@ doswitch(const char *name, const char *function, const char *args,
 			fprintf(stdout,
 				"\tcase %d:%s %s_%s(%s); break;",
 				tt->type, result, function,
-				funname(tt->typebuf, buf1), args);
+				funname(tt->typename, buf1), args);
 		else
 			fprintf(stdout,
 				"\t\tcase %d:%s %s_%s_%s(%s); break;",
 				tt->rdclass, result, function,
-				funname(tt->classbuf, buf1),
-				funname(tt->typebuf, buf2), args);
+				funname(tt->classname, buf1),
+				funname(tt->typename, buf2), args);
 		fputs(" \\\n", stdout);
 		lasttype = tt->type;
 	}
@@ -295,36 +286,32 @@ find_typename(int type) {
 	int i;
 
 	for (i = 0; i < TYPENAMES; i++) {
-		if (typenames[i].typebuf[0] != 0 &&
+		if (typenames[i].typename[0] != 0 &&
 		    typenames[i].type == type)
-		{
 			return (&typenames[i]);
-		}
 	}
 	return (NULL);
 }
 
 static void
-insert_into_typenames(int type, const char *typebuf, const char *attr) {
+insert_into_typenames(int type, const char *typename, const char *attr) {
 	struct ttnam *ttn = NULL;
 	size_t c;
 	int i, n;
 	char tmp[256];
 
-	INSIST(strlen(typebuf) < TYPECLASSBUF);
+	INSIST(strlen(typename) < TYPECLASSBUF);
 	for (i = 0; i < TYPENAMES; i++) {
-		if (typenames[i].typebuf[0] != 0 &&
+		if (typenames[i].typename[0] != 0 &&
 		    typenames[i].type == type &&
-		    strcmp(typebuf, typenames[i].typebuf) != 0)
-		{
+		    strcmp(typename, typenames[i].typename) != 0) {
 			fprintf(stderr,
 				"Error:  type %d has two names: %s, %s\n",
-				type, typenames[i].typebuf, typebuf);
+				type, typenames[i].typename, typename);
 			exit(1);
 		}
-		if (typenames[i].typebuf[0] == 0 && ttn == NULL) {
+		if (typenames[i].typename[0] == 0 && ttn == NULL)
 			ttn = &typenames[i];
-		}
 	}
 	if (ttn == NULL) {
 		fprintf(stderr, "Error: typenames array too small\n");
@@ -332,24 +319,23 @@ insert_into_typenames(int type, const char *typebuf, const char *attr) {
 	}
 
 	/* XXXMUKS: This is redundant due to the INSIST above. */
-	if (strlen(typebuf) > sizeof(ttn->typebuf) - 1) {
+	if (strlen(typename) > sizeof(ttn->typename) - 1) {
 		fprintf(stderr, "Error:  type name %s is too long\n",
-			typebuf);
+			typename);
 		exit(1);
 	}
 
-	strncpy(ttn->typebuf, typebuf, sizeof(ttn->typebuf));
-	ttn->typebuf[sizeof(ttn->typebuf) - 1] = '\0';
+	strncpy(ttn->typename, typename, sizeof(ttn->typename));
+	ttn->typename[sizeof(ttn->typename) - 1] = '\0';
 
-	strncpy(ttn->macroname, ttn->typebuf, sizeof(ttn->macroname));
+	strncpy(ttn->macroname, ttn->typename, sizeof(ttn->macroname));
 	ttn->macroname[sizeof(ttn->macroname) - 1] = '\0';
 
 	ttn->type = type;
 	c = strlen(ttn->macroname);
 	while (c > 0) {
-		if (ttn->macroname[c - 1] == '-') {
+		if (ttn->macroname[c - 1] == '-')
 			ttn->macroname[c - 1] = '_';
-		}
 		c--;
 	}
 
@@ -368,7 +354,7 @@ insert_into_typenames(int type, const char *typebuf, const char *attr) {
 
 	if (strlen(attr) > sizeof(ttn->attr) - 1) {
 		fprintf(stderr, "Error:  attr (%s) [name %s] is too long\n",
-			attr, typebuf);
+			attr, typename);
 		exit(1);
 	}
 
@@ -376,25 +362,24 @@ insert_into_typenames(int type, const char *typebuf, const char *attr) {
 	ttn->attr[sizeof(ttn->attr) - 1] = '\0';
 
 	ttn->sorted = 0;
-	if (maxtype < type) {
+	if (maxtype < type)
 		maxtype = type;
-	}
 }
 
 static void
-add(int rdclass, const char *classbuf, int type, const char *typebuf,
-    const char *dirbuf)
+add(int rdclass, const char *classname, int type, const char *typename,
+    const char *dirname)
 {
 	struct tt *newtt = (struct tt *)malloc(sizeof(*newtt));
 	struct tt *tt, *oldtt;
 	struct cc *newcc;
 	struct cc *cc, *oldcc;
 
-	INSIST(strlen(typebuf) < TYPECLASSBUF);
-	INSIST(strlen(classbuf) < TYPECLASSBUF);
-	INSIST(strlen(dirbuf) < PATH_MAX);
+	INSIST(strlen(typename) < TYPECLASSBUF);
+	INSIST(strlen(classname) < TYPECLASSBUF);
+	INSIST(strlen(dirname) < DIRNAMESIZE);
 
-	insert_into_typenames(type, typebuf, NULL);
+	insert_into_typenames(type, typename, NULL);
 
 	if (newtt == NULL) {
 		fprintf(stderr, "malloc() failed\n");
@@ -405,17 +390,16 @@ add(int rdclass, const char *classbuf, int type, const char *typebuf,
 	newtt->rdclass = rdclass;
 	newtt->type = type;
 
-	strncpy(newtt->classbuf, classbuf, sizeof(newtt->classbuf));
-	newtt->classbuf[sizeof(newtt->classbuf) - 1] = '\0';
+	strncpy(newtt->classname, classname, sizeof(newtt->classname));
+	newtt->classname[sizeof(newtt->classname) - 1] = '\0';
 
-	strncpy(newtt->typebuf, typebuf, sizeof(newtt->typebuf));
-	newtt->typebuf[sizeof(newtt->typebuf) - 1] = '\0';
+	strncpy(newtt->typename, typename, sizeof(newtt->typename));
+	newtt->typename[sizeof(newtt->typename) - 1] = '\0';
 
-	if (strncmp(dirbuf, "./", 2) == 0) {
-		dirbuf += 2;
-	}
-	strncpy(newtt->dirbuf, dirbuf, sizeof(newtt->dirbuf));
-	newtt->dirbuf[sizeof(newtt->dirbuf) - 1] = '\0';
+	if (strncmp(dirname, "./", 2) == 0)
+		dirname += 2;
+	strncpy(newtt->dirname, dirname, sizeof(newtt->dirname));
+	newtt->dirname[sizeof(newtt->dirname) - 1] = '\0';
 
 	tt = types;
 	oldtt = NULL;
@@ -426,30 +410,26 @@ add(int rdclass, const char *classbuf, int type, const char *typebuf,
 	}
 
 	while ((tt != NULL) && (tt->type == type) && (tt->rdclass < rdclass)) {
-		if (strcmp(tt->typebuf, typebuf) != 0) {
+		if (strcmp(tt->typename, typename) != 0)
 			exit(1);
-		}
 		oldtt = tt;
 		tt = tt->next;
 	}
 
-	if ((tt != NULL) && (tt->type == type) && (tt->rdclass == rdclass)) {
+	if ((tt != NULL) && (tt->type == type) && (tt->rdclass == rdclass))
 		exit(1);
-	}
 
 	newtt->next = tt;
-	if (oldtt != NULL) {
+	if (oldtt != NULL)
 		oldtt->next = newtt;
-	} else {
+	else
 		types = newtt;
-	}
 
 	/*
 	 * Do a class switch for this type.
 	 */
-	if (rdclass == 0) {
+	if (rdclass == 0)
 		return;
-	}
 
 	newcc = (struct cc *)malloc(sizeof(*newcc));
 	if (newcc == NULL) {
@@ -457,8 +437,8 @@ add(int rdclass, const char *classbuf, int type, const char *typebuf,
 		exit(1);
 	}
 	newcc->rdclass = rdclass;
-	strncpy(newcc->classbuf, classbuf, sizeof(newcc->classbuf));
-	newcc->classbuf[sizeof(newcc->classbuf) - 1] = '\0';
+	strncpy(newcc->classname, classname, sizeof(newcc->classname));
+	newcc->classname[sizeof(newcc->classname) - 1] = '\0';
 	cc = classes;
 	oldcc = NULL;
 
@@ -473,39 +453,34 @@ add(int rdclass, const char *classbuf, int type, const char *typebuf,
 	}
 
 	newcc->next = cc;
-	if (oldcc != NULL) {
+	if (oldcc != NULL)
 		oldcc->next = newcc;
-	} else {
+	else
 		classes = newcc;
-	}
 }
 
 static void
-sd(int rdclass, const char *classbuf, const char *dirbuf, char filetype) {
+sd(int rdclass, const char *classname, const char *dirname, char filetype) {
 	char buf[TYPECLASSLEN + sizeof("_65535.h")];
-	char typebuf[TYPECLASSBUF];
+	char typename[TYPECLASSBUF];
 	int type, n;
 	isc_dir_t dir;
 
-	if (!start_directory(dirbuf, &dir)) {
+	if (!start_directory(dirname, &dir))
 		return;
-	}
 
 	while (next_file(&dir)) {
-		if (sscanf(dir.filename, TYPECLASSFMT, typebuf, &type) != 2) {
+		if (sscanf(dir.filename, TYPECLASSFMT, typename, &type) != 2)
 			continue;
-		}
-		if ((type > 65535) || (type < 0)) {
+		if ((type > 65535) || (type < 0))
 			continue;
-		}
 
-		n = snprintf(buf, sizeof(buf), "%s_%d.%c", typebuf,
+		n = snprintf(buf, sizeof(buf), "%s_%d.%c", typename,
 			     type, filetype);
 		INSIST(n > 0 && (unsigned)n < sizeof(buf));
-		if (strcmp(buf, dir.filename) != 0) {
+		if (strcmp(buf, dir.filename) != 0)
 			continue;
-		}
-		add(rdclass, classbuf, type, typebuf, dirbuf);
+		add(rdclass, classname, type, typename, dirname);
 	}
 
 	end_directory(&dir);
@@ -529,14 +504,15 @@ HASH(char *string) {
 
 int
 main(int argc, char **argv) {
-	char buf[PATH_MAX];
-	char srcdir[PATH_MAX];
+	char buf[DIRNAMESIZE];		/* XXX Should be max path length */
+	char srcdir[DIRNAMESIZE];	/* XXX Should be max path length */
 	int rdclass;
-	char classbuf[TYPECLASSBUF];
+	char classname[TYPECLASSBUF];
 	struct tt *tt;
 	struct cc *cc;
 	struct ttnam *ttn, *ttn2;
 	unsigned int hash;
+	struct tm *tm;
 	time_t now;
 	char year[11];
 	int lasttype;
@@ -552,9 +528,6 @@ main(int argc, char **argv) {
 	char *prefix = NULL;
 	char *suffix = NULL;
 	char *file = NULL;
-	char *source_date_epoch;
-	unsigned long long epoch;
-	char *endptr;
 	isc_dir_t dir;
 
 	for (i = 0; i < TYPENAMES; i++)
@@ -597,9 +570,8 @@ main(int argc, char **argv) {
 			break;
 		case 's':
 			if (strlen(isc_commandline_argument) >
-			    PATH_MAX - 2 * TYPECLASSLEN  -
-			    sizeof("/rdata/_65535_65535"))
-			{
+			    DIRNAMESIZE - 2 * TYPECLASSLEN  -
+			    sizeof("/rdata/_65535_65535")) {
 				fprintf(stderr, "\"%s\" too long\n",
 					isc_commandline_argument);
 				exit(1);
@@ -624,74 +596,30 @@ main(int argc, char **argv) {
 	n = snprintf(buf, sizeof(buf), "%srdata", srcdir);
 	INSIST(n > 0 && (unsigned)n < sizeof(srcdir));
 
-	if (!start_directory(buf, &dir)) {
+	if (!start_directory(buf, &dir))
 		exit(1);
-	}
 
 	while (next_file(&dir)) {
-		if (sscanf(dir.filename, TYPECLASSFMT, classbuf,
+		if (sscanf(dir.filename, TYPECLASSFMT, classname,
 			   &rdclass) != 2)
-		{
 			continue;
-		}
-		if ((rdclass > 65535) || (rdclass < 0)) {
+		if ((rdclass > 65535) || (rdclass < 0))
 			continue;
-		}
 
 		n = snprintf(buf, sizeof(buf), "%srdata/%s_%d",
-			     srcdir, classbuf, rdclass);
+			     srcdir, classname, rdclass);
 		INSIST(n > 0 && (unsigned)n < sizeof(buf));
-		if (strcmp(buf + 6 + strlen(srcdir), dir.filename) != 0) {
+		if (strcmp(buf + 6 + strlen(srcdir), dir.filename) != 0)
 			continue;
-		}
-		sd(rdclass, classbuf, buf, filetype);
+		sd(rdclass, classname, buf, filetype);
 	}
 	end_directory(&dir);
 	n = snprintf(buf, sizeof(buf), "%srdata/generic", srcdir);
 	INSIST(n > 0 && (unsigned)n < sizeof(srcdir));
 	sd(0, "", buf, filetype);
 
-	source_date_epoch = getenv("SOURCE_DATE_EPOCH");
-	if (source_date_epoch) {
-		errno = 0;
-		epoch = strtoull(source_date_epoch, &endptr, 10);
-		if ((errno == ERANGE && (epoch == ULLONG_MAX || epoch == 0))
-				|| (errno != 0 && epoch == 0)) {
-			fprintf(stderr, "Environment variable "
-				"$SOURCE_DATE_EPOCH: strtoull: %s\n",
-				strerror(errno));
-			exit (EXIT_FAILURE);
-		}
-		if (endptr == source_date_epoch) {
-			fprintf(stderr, "Environment variable "
-				"$SOURCE_DATE_EPOCH: "
-				"No digits were found: %s\n",
-				endptr);
-			exit (EXIT_FAILURE);
-		}
-		if (*endptr != '\0') {
-			fprintf(stderr, "Environment variable "
-				"$SOURCE_DATE_EPOCH: Trailing garbage: %s\n",
-				endptr);
-			exit (EXIT_FAILURE);
-		}
-		if (epoch > ULONG_MAX) {
-			fprintf(stderr, "Environment variable "
-				"$SOURCE_DATE_EPOCH: value must be "
-				"smaller than or equal to: %lu but "
-				"was found to be: %llu \n",
-				ULONG_MAX, epoch);
-			exit (EXIT_FAILURE);
-		}
-		now = epoch;
-	} else {
-		time(&now);
-	}
-
-	if (now != -1) {
-		struct tm t, *tm = gmtime_r(&now, &t);
-
-		if (tm != NULL && tm->tm_year > 104) {
+	if (time(&now) != -1) {
+		if ((tm = localtime(&now)) != NULL && tm->tm_year > 104) {
 			n = snprintf(year, sizeof(year), "-%d",
 				     tm->tm_year + 1900);
 			INSIST(n > 0 && (unsigned)n < sizeof(year));
@@ -702,21 +630,20 @@ main(int argc, char **argv) {
 		snprintf(year, sizeof(year), "-2016");
 	}
 
-	if (!depend) {
+	if (!depend)
 		fprintf(stdout, copyright, year);
-	}
 
 	if (code) {
 		fputs("#ifndef DNS_CODE_H\n", stdout);
 		fputs("#define DNS_CODE_H 1\n\n", stdout);
 
+		fputs("#include <stdbool.h>\n", stdout);
 		fputs("#include <isc/result.h>\n\n", stdout);
 		fputs("#include <dns/name.h>\n\n", stdout);
 
-		for (tt = types; tt != NULL; tt = tt->next) {
+		for (tt = types; tt != NULL; tt = tt->next)
 			fprintf(stdout, "#include \"%s/%s_%d.c\"\n",
-				tt->dirbuf, tt->typebuf, tt->type);
-		}
+				tt->dirname, tt->typename, tt->type);
 
 		fputs("\n\n", stdout);
 
@@ -762,17 +689,19 @@ main(int argc, char **argv) {
 			 "DNS_RDATATYPEATTR_NOTQUESTION"
 #define METAQUESTIONONLY "DNS_RDATATYPEATTR_META | " \
 			 "DNS_RDATATYPEATTR_QUESTIONONLY"
-#define RESERVEDNAME	 "0"
-#define RESERVED	 "DNS_RDATATYPEATTR_RESERVED"
+#define RESERVED "DNS_RDATATYPEATTR_RESERVED"
 
 		/*
 		 * Add in reserved/special types.  This will let us
 		 * sort them without special cases.
 		 */
-		insert_into_typenames(100, "uinfo", RESERVEDNAME);
-		insert_into_typenames(101, "uid", RESERVEDNAME);
-		insert_into_typenames(102, "gid", RESERVEDNAME);
-		insert_into_typenames(103, "unspec", RESERVEDNAME);
+		insert_into_typenames(0, "reserved0", RESERVED);
+		insert_into_typenames(31, "eid", RESERVED);
+		insert_into_typenames(32, "nimloc", RESERVED);
+		insert_into_typenames(34, "atma", RESERVED);
+		insert_into_typenames(100, "uinfo", RESERVED);
+		insert_into_typenames(101, "uid", RESERVED);
+		insert_into_typenames(102, "gid", RESERVED);
 		insert_into_typenames(251, "ixfr", METAQUESTIONONLY);
 		insert_into_typenames(252, "axfr", METAQUESTIONONLY);
 		insert_into_typenames(253, "mailb", METAQUESTIONONLY);
@@ -807,18 +736,16 @@ main(int argc, char **argv) {
 		fprintf(stdout, "\tswitch (_hash) { \\\n");
 		for (i = 0; i <= maxtype; i++) {
 			ttn = find_typename(i);
-			if (ttn == NULL) {
+			if (ttn == NULL)
 				continue;
-			}
 
 			/*
 			 * Skip entries we already processed.
 			 */
-			if (ttn->sorted != 0) {
+			if (ttn->sorted != 0)
 				continue;
-			}
 
-			hash = HASH(ttn->typebuf);
+			hash = HASH(ttn->typename);
 			fprintf(stdout, "\t\tcase %u: \\\n", hash);
 
 			/*
@@ -827,15 +754,13 @@ main(int argc, char **argv) {
 			 */
 			for (j = 0; j <= maxtype; j++) {
 				ttn2 = find_typename(j);
-				if (ttn2 == NULL) {
+				if (ttn2 == NULL)
 					continue;
-				}
-				if (hash == HASH(ttn2->typebuf)) {
-					fprintf(stdout, "\t\t\t"
-						"RDATATYPE_COMPARE"
-						"(\"%s\", %d, _typename, "
-						" _length, _typep); \\\n",
-						ttn2->typebuf, ttn2->type);
+				if (hash == HASH(ttn2->typename)) {
+					fprintf(stdout, "\t\t\tRDATATYPE_COMPARE"
+					       "(\"%s\", %d, "
+					       "_typename, _length, _typep); \\\n",
+					       ttn2->typename, ttn2->type);
 					ttn2->sorted = 1;
 				}
 			}
@@ -847,9 +772,8 @@ main(int argc, char **argv) {
 		fprintf(stdout, "\tswitch (type) { \\\n");
 		for (i = 0; i <= maxtype; i++) {
 			ttn = find_typename(i);
-			if (ttn == NULL) {
+			if (ttn == NULL)
 				continue;
-			}
 			fprintf(stdout, "\tcase %d: return (%s); \\\n",
 				i, upper(ttn->attr));
 		}
@@ -859,21 +783,19 @@ main(int argc, char **argv) {
 		fprintf(stdout, "\tswitch (type) { \\\n");
 		for (i = 0; i <= maxtype; i++) {
 			ttn = find_typename(i);
-			if (ttn == NULL) {
+			if (ttn == NULL)
 				continue;
-			}
 			/*
 			 * Remove KEYDATA (65533) from the type to memonic
 			 * translation as it is internal use only.  This
 			 * stops the tools from displaying KEYDATA instead
 			 * of TYPE65533.
 			 */
-			if (i == 65533U) {
+			if (i == 65533U)
 				continue;
-			}
 			fprintf(stdout, "\tcase %d: return "
 				"(str_totext(\"%s\", target)); \\\n",
-				i, upper(ttn->typebuf));
+				i, upper(ttn->typename));
 		}
 		fprintf(stdout, "\t}\n");
 
@@ -888,14 +810,12 @@ main(int argc, char **argv) {
 		fprintf(stdout, "\tdns_rdatatype_none = 0,\n");
 
 		lasttype = 0;
-		for (tt = types; tt != NULL; tt = tt->next) {
-			if (tt->type != lasttype) {
+		for (tt = types; tt != NULL; tt = tt->next)
+			if (tt->type != lasttype)
 				fprintf(stdout,
 					"\tdns_rdatatype_%s = %d,\n",
-					funname(tt->typebuf, buf1),
+					funname(tt->typename, buf1),
 					lasttype = tt->type);
-			}
-		}
 
 		fprintf(stdout, "\tdns_rdatatype_ixfr = 251,\n");
 		fprintf(stdout, "\tdns_rdatatype_axfr = 252,\n");
@@ -908,9 +828,9 @@ main(int argc, char **argv) {
 		fprintf(stdout, "#define dns_rdatatype_none\t"
 			"((dns_rdatatype_t)dns_rdatatype_none)\n");
 
-		for (tt = types; tt != NULL; tt = tt->next) {
+		for (tt = types; tt != NULL; tt = tt->next)
 			if (tt->type != lasttype) {
-				s = funname(tt->typebuf, buf1);
+				s = funname(tt->typename, buf1);
 				fprintf(stdout,
 					"#define dns_rdatatype_%s\t%s"
 					"((dns_rdatatype_t)dns_rdatatype_%s)"
@@ -918,7 +838,6 @@ main(int argc, char **argv) {
 					s, strlen(s) < 2U ? "\t" : "", s);
 				lasttype = tt->type;
 			}
-		}
 
 		fprintf(stdout, "#define dns_rdatatype_ixfr\t"
 			"((dns_rdatatype_t)dns_rdatatype_ixfr)\n");
@@ -957,12 +876,11 @@ main(int argc, char **argv) {
 	} while (0)
 
 		for (cc = classes; cc != NULL; cc = cc->next) {
-			if (cc->rdclass == 3) {
+			if (cc->rdclass == 3)
 				PRINTCLASS("chaos", 3);
-			} else if (cc->rdclass == 255) {
+			else if (cc->rdclass == 255)
 				PRINTCLASS("none", 254);
-			}
-			PRINTCLASS(cc->classbuf, cc->rdclass);
+			PRINTCLASS(cc->classname, cc->rdclass);
 		}
 
 #undef PRINTCLASS
@@ -972,40 +890,35 @@ main(int argc, char **argv) {
 	} else if (structs) {
 		if (prefix != NULL) {
 			if ((fd = fopen(prefix,"r")) != NULL) {
-				while (fgets(buf, sizeof(buf), fd) != NULL) {
+				while (fgets(buf, sizeof(buf), fd) != NULL)
 					fputs(buf, stdout);
-				}
 				fclose(fd);
 			}
 		}
 		for (tt = types; tt != NULL; tt = tt->next) {
 			snprintf(buf, sizeof(buf), "%s/%s_%d.h",
-				tt->dirbuf, tt->typebuf, tt->type);
+				tt->dirname, tt->typename, tt->type);
 			if ((fd = fopen(buf,"r")) != NULL) {
-				while (fgets(buf, sizeof(buf), fd) != NULL) {
+				while (fgets(buf, sizeof(buf), fd) != NULL)
 					fputs(buf, stdout);
-				}
 				fclose(fd);
 			}
 		}
 		if (suffix != NULL) {
 			if ((fd = fopen(suffix,"r")) != NULL) {
-				while (fgets(buf, sizeof(buf), fd) != NULL) {
+				while (fgets(buf, sizeof(buf), fd) != NULL)
 					fputs(buf, stdout);
-				}
 				fclose(fd);
 			}
 		}
 	} else if (depend) {
-		for (tt = types; tt != NULL; tt = tt->next) {
+		for (tt = types; tt != NULL; tt = tt->next)
 			fprintf(stdout, "%s:\t%s/%s_%d.h\n", file,
-				tt->dirbuf, tt->typebuf, tt->type);
-		}
+				tt->dirname, tt->typename, tt->type);
 	}
 
-	if (ferror(stdout) != 0) {
+	if (ferror(stdout) != 0)
 		exit(1);
-	}
 
 	return (0);
 }
