@@ -13,6 +13,9 @@
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
+
 #include <isc/util.h>
 
 #include <isc/mem.h>
@@ -63,9 +66,9 @@
  * family and addr6 fields are to be used IPv6 is added.
  */
 typedef struct geoip_state {
-	isc_uint16_t subtype;
+	uint16_t subtype;
 	unsigned int family;
-	isc_uint32_t ipnum;
+	uint32_t ipnum;
 	geoipv6_t ipnum6;
 	GeoIPRecord *record;
 	GeoIPRegion *region;
@@ -75,9 +78,8 @@ typedef struct geoip_state {
 	isc_mem_t *mctx;
 } geoip_state_t;
 
-#ifdef ISC_PLATFORM_USETHREADS
 static isc_mutex_t key_mutex;
-static isc_boolean_t state_key_initialized = ISC_FALSE;
+static bool state_key_initialized = false;
 static isc_thread_key_t state_key;
 static isc_once_t mutex_once = ISC_ONCE_INIT;
 static isc_mem_t *state_mctx = NULL;
@@ -116,11 +118,11 @@ state_key_init(void) {
 			if (result != ISC_R_SUCCESS)
 				goto unlock;
 			isc_mem_setname(state_mctx, "geoip_state", NULL);
-			isc_mem_setdestroycheck(state_mctx, ISC_FALSE);
+			isc_mem_setdestroycheck(state_mctx, false);
 
 			ret = isc_thread_key_create(&state_key, free_state);
 			if (ret == 0)
-				state_key_initialized = ISC_TRUE;
+				state_key_initialized = true;
 			else
 				result = ISC_R_FAILURE;
 		}
@@ -130,9 +132,6 @@ state_key_init(void) {
 
 	return (result);
 }
-#else
-static geoip_state_t saved_state;
-#endif
 
 static void
 clean_state(geoip_state_t *state) {
@@ -157,12 +156,11 @@ clean_state(geoip_state_t *state) {
 }
 
 static isc_result_t
-set_state(unsigned int family, isc_uint32_t ipnum, const geoipv6_t *ipnum6,
+set_state(unsigned int family, uint32_t ipnum, const geoipv6_t *ipnum6,
 	  dns_geoip_subtype_t subtype, GeoIPRecord *record,
 	  GeoIPRegion *region, char *name, const char *text, int id)
 {
 	geoip_state_t *state = NULL;
-#ifdef ISC_PLATFORM_USETHREADS
 	isc_result_t result;
 
 	result = state_key_init();
@@ -186,10 +184,6 @@ set_state(unsigned int family, isc_uint32_t ipnum, const geoipv6_t *ipnum6,
 		isc_mem_attach(state_mctx, &state->mctx);
 	} else
 		clean_state(state);
-#else
-	state = &saved_state;
-	clean_state(state);
-#endif
 
 	if (family == AF_INET) {
 		state->ipnum = ipnum;
@@ -210,12 +204,11 @@ set_state(unsigned int family, isc_uint32_t ipnum, const geoipv6_t *ipnum6,
 }
 
 static geoip_state_t *
-get_state_for(unsigned int family, isc_uint32_t ipnum,
+get_state_for(unsigned int family, uint32_t ipnum,
 	      const geoipv6_t *ipnum6)
 {
 	geoip_state_t *state;
 
-#ifdef ISC_PLATFORM_USETHREADS
 	isc_result_t result;
 
 	result = state_key_init();
@@ -225,9 +218,6 @@ get_state_for(unsigned int family, isc_uint32_t ipnum,
 	state = (geoip_state_t *) isc_thread_key_getspecific(state_key);
 	if (state == NULL)
 		return (NULL);
-#else
-	state = &saved_state;
-#endif
 
 	if (state->family == family &&
 	    ((state->family == AF_INET && state->ipnum == ipnum) ||
@@ -246,7 +236,7 @@ get_state_for(unsigned int family, isc_uint32_t ipnum,
 static const char *
 country_lookup(GeoIP *db, dns_geoip_subtype_t subtype,
 	       unsigned int family,
-	       isc_uint32_t ipnum, const geoipv6_t *ipnum6)
+	       uint32_t ipnum, const geoipv6_t *ipnum6)
 {
 	geoip_state_t *prev_state = NULL;
 	const char *text = NULL;
@@ -362,7 +352,7 @@ city_string(GeoIPRecord *record, dns_geoip_subtype_t subtype, int *maxlen) {
 	}
 }
 
-static isc_boolean_t
+static bool
 is_city(dns_geoip_subtype_t subtype) {
 	switch (subtype) {
 	case dns_geoip_city_countrycode:
@@ -376,9 +366,9 @@ is_city(dns_geoip_subtype_t subtype) {
 	case dns_geoip_city_timezonecode:
 	case dns_geoip_city_metrocode:
 	case dns_geoip_city_areacode:
-		return (ISC_TRUE);
+		return (true);
 	default:
-		return (ISC_FALSE);
+		return (false);
 	}
 }
 
@@ -389,7 +379,7 @@ is_city(dns_geoip_subtype_t subtype) {
  */
 static GeoIPRecord *
 city_lookup(GeoIP *db, dns_geoip_subtype_t subtype,
-	    unsigned int family, isc_uint32_t ipnum,
+	    unsigned int family, uint32_t ipnum,
 	    const geoipv6_t *ipnum6)
 {
 	GeoIPRecord *record = NULL;
@@ -450,14 +440,14 @@ static char * region_string(GeoIPRegion *region, dns_geoip_subtype_t subtype, in
 	}
 }
 
-static isc_boolean_t
+static bool
 is_region(dns_geoip_subtype_t subtype) {
 	switch (subtype) {
 	case dns_geoip_region_countrycode:
 	case dns_geoip_region_code:
-		return (ISC_TRUE);
+		return (true);
 	default:
-		return (ISC_FALSE);
+		return (false);
 	}
 }
 
@@ -467,7 +457,7 @@ is_region(dns_geoip_subtype_t subtype) {
  * outside the Region database.
  */
 static GeoIPRegion *
-region_lookup(GeoIP *db, dns_geoip_subtype_t subtype, isc_uint32_t ipnum) {
+region_lookup(GeoIP *db, dns_geoip_subtype_t subtype, uint32_t ipnum) {
 	GeoIPRegion *region = NULL;
 	geoip_state_t *prev_state = NULL;
 
@@ -496,7 +486,7 @@ region_lookup(GeoIP *db, dns_geoip_subtype_t subtype, isc_uint32_t ipnum) {
  * or was for a search of a different subtype.
  */
 static char *
-name_lookup(GeoIP *db, dns_geoip_subtype_t subtype, isc_uint32_t ipnum) {
+name_lookup(GeoIP *db, dns_geoip_subtype_t subtype, uint32_t ipnum) {
 	char *name = NULL;
 	geoip_state_t *prev_state = NULL;
 
@@ -525,9 +515,9 @@ name_lookup(GeoIP *db, dns_geoip_subtype_t subtype, isc_uint32_t ipnum) {
  * different subtype.
  */
 static int
-netspeed_lookup(GeoIP *db, dns_geoip_subtype_t subtype, isc_uint32_t ipnum) {
+netspeed_lookup(GeoIP *db, dns_geoip_subtype_t subtype, uint32_t ipnum) {
 	geoip_state_t *prev_state = NULL;
-	isc_boolean_t found = ISC_FALSE;
+	bool found = false;
 	int id = -1;
 
 	REQUIRE(db != NULL);
@@ -535,7 +525,7 @@ netspeed_lookup(GeoIP *db, dns_geoip_subtype_t subtype, isc_uint32_t ipnum) {
 	prev_state = get_state_for(AF_INET, ipnum, NULL);
 	if (prev_state != NULL && prev_state->subtype == subtype) {
 		id = prev_state->id;
-		found = ISC_TRUE;
+		found = true;
 	}
 
 	if (!found) {
@@ -605,7 +595,7 @@ fix_subtype(const isc_netaddr_t *reqaddr, const dns_geoip_databases_t *geoip,
 }
 #endif /* HAVE_GEOIP */
 
-isc_boolean_t
+bool
 dns_geoip_match(const isc_netaddr_t *reqaddr,
 		const dns_geoip_databases_t *geoip,
 		const dns_geoip_elem_t *elt)
@@ -615,13 +605,13 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 	UNUSED(geoip);
 	UNUSED(elt);
 
-	return (ISC_FALSE);
+	return (false);
 #else
 	GeoIP *db;
 	GeoIPRecord *record;
 	GeoIPRegion *region;
 	dns_geoip_subtype_t subtype;
-	isc_uint32_t ipnum = 0;
+	uint32_t ipnum = 0;
 	int maxlen = 0, id, family;
 	const char *cs;
 	char *s;
@@ -643,10 +633,10 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 		ipnum6 = &reqaddr->type.in6;
 		break;
 #else
-		return (ISC_FALSE);
+		return (false);
 #endif
 	default:
-		return (ISC_FALSE);
+		return (false);
 	}
 
 	subtype = fix_subtype(reqaddr, geoip, elt->subtype);
@@ -665,13 +655,13 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
  getcountry:
 		db = DB46(reqaddr, geoip, country);
 		if (db == NULL)
-			return (ISC_FALSE);
+			return (false);
 
 		INSIST(elt->as_string != NULL);
 
 		cs = country_lookup(db, subtype, family, ipnum, ipnum6);
 		if (cs != NULL && strncasecmp(elt->as_string, cs, maxlen) == 0)
-			return (ISC_TRUE);
+			return (true);
 		break;
 
 	case dns_geoip_city_countrycode:
@@ -687,7 +677,7 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 
 		db = DB46(reqaddr, geoip, city);
 		if (db == NULL)
-			return (ISC_FALSE);
+			return (false);
 
 		record = city_lookup(db, subtype, family,
 				     ipnum, ipnum6);
@@ -697,13 +687,13 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 		s = city_string(record, subtype, &maxlen);
 		INSIST(maxlen != 0);
 		if (s != NULL && strncasecmp(elt->as_string, s, maxlen) == 0)
-			return (ISC_TRUE);
+			return (true);
 		break;
 
 	case dns_geoip_city_metrocode:
 		db = DB46(reqaddr, geoip, city);
 		if (db == NULL)
-			return (ISC_FALSE);
+			return (false);
 
 		record = city_lookup(db, subtype, family,
 				     ipnum, ipnum6);
@@ -711,13 +701,13 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 			break;
 
 		if (elt->as_int == record->metro_code)
-			return (ISC_TRUE);
+			return (true);
 		break;
 
 	case dns_geoip_city_areacode:
 		db = DB46(reqaddr, geoip, city);
 		if (db == NULL)
-			return (ISC_FALSE);
+			return (false);
 
 		record = city_lookup(db, subtype, family,
 				     ipnum, ipnum6);
@@ -725,7 +715,7 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 			break;
 
 		if (elt->as_int == record->area_code)
-			return (ISC_TRUE);
+			return (true);
 		break;
 
 	case dns_geoip_region_countrycode:
@@ -733,13 +723,13 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 	case dns_geoip_region_name:
 	case dns_geoip_region:
 		if (geoip->region == NULL)
-			return (ISC_FALSE);
+			return (false);
 
 		INSIST(elt->as_string != NULL);
 
 		/* Region DB is not supported for IPv6 */
 		if (family == AF_INET6)
-			return (ISC_FALSE);
+			return (false);
 
 		region = region_lookup(geoip->region, subtype, ipnum);
 		if (region == NULL)
@@ -748,7 +738,7 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 		s = region_string(region, subtype, &maxlen);
 		INSIST(maxlen != 0);
 		if (s != NULL && strncasecmp(elt->as_string, s, maxlen) == 0)
-			return (ISC_TRUE);
+			return (true);
 		break;
 
 	case dns_geoip_isp_name:
@@ -768,18 +758,18 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 
  getname:
 		if (db == NULL)
-			return (ISC_FALSE);
+			return (false);
 
 		INSIST(elt->as_string != NULL);
 		/* ISP, Org, AS, and Domain are not supported for IPv6 */
 		if (family == AF_INET6)
-			return (ISC_FALSE);
+			return (false);
 
 		s = name_lookup(db, subtype, ipnum);
 		if (s != NULL) {
 			size_t l;
 			if (strcasecmp(elt->as_string, s) == 0)
-				return (ISC_TRUE);
+				return (true);
 			if (subtype != dns_geoip_as_asnum)
 				break;
 			/*
@@ -789,7 +779,7 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 			if (l > 0U && strchr(elt->as_string, ' ') == NULL &&
 			    strncasecmp(elt->as_string, s, l) == 0 &&
 			    s[l] == ' ')
-				return (ISC_TRUE);
+				return (true);
 		}
 		break;
 
@@ -798,11 +788,11 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 
 		/* Netspeed DB is not supported for IPv6 */
 		if (family == AF_INET6)
-			return (ISC_FALSE);
+			return (false);
 
 		id = netspeed_lookup(geoip->netspeed, subtype, ipnum);
 		if (id == elt->as_int)
-			return (ISC_TRUE);
+			return (true);
 		break;
 
 	case dns_geoip_countrycode:
@@ -819,7 +809,7 @@ dns_geoip_match(const isc_netaddr_t *reqaddr,
 		INSIST(0);
 	}
 
-	return (ISC_FALSE);
+	return (false);
 #endif
 }
 
@@ -827,10 +817,8 @@ void
 dns_geoip_shutdown(void) {
 #ifdef HAVE_GEOIP
 	GeoIP_cleanup();
-#ifdef ISC_PLATFORM_USETHREADS
 	if (state_mctx != NULL)
 		isc_mem_detach(&state_mctx);
-#endif
 #else
 	return;
 #endif
