@@ -64,9 +64,9 @@
  *** Imports
  ***/
 
+#include <stdbool.h>
 #include <stdio.h>
 #include <inttypes.h>
-#include <stdbool.h>
 
 #include <isc/lang.h>
 #include <isc/magic.h>
@@ -193,8 +193,7 @@ LIBDNS_EXTERNAL_DATA extern const dns_name_t *dns_wildcardname;
  * is from 'buffer'->base + 'used_org' to the end of the used region.
  */
 typedef isc_result_t (*dns_name_totextfilter_t)(isc_buffer_t *target,
-						unsigned int used_org,
-						bool absolute);
+						unsigned int used_org);
 
 /***
  *** Initialization
@@ -372,26 +371,6 @@ dns_name_fullhash(const dns_name_t *name, bool case_sensitive);
  *\li	A hash value
  */
 
-unsigned int
-dns_name_hashbylabel(const dns_name_t *name, bool case_sensitive);
-/*%<
- * Provide a hash value for 'name', where the hash value is the sum
- * of the hash values of each label.  This function should only be used
- * when incremental hashing is necessary, for example, during RBT
- * traversal. It is not currently used in BIND. Generally,
- * dns_name_fullhash() is the correct function to use for name
- * hashing.
- *
- * Note: if 'case_sensitive' is false, then names which differ only in
- * case will have the same hash value.
- *
- * Requires:
- *\li	'name' is a valid name
- *
- * Returns:
- *\li	A hash value
- */
-
 /*
  *** Comparisons
  ***/
