@@ -1,21 +1,20 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * SPDX-License-Identifier: MPL-2.0
- *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
  */
 
-#pragma once
+#ifndef DNS_RDATASET_H
+#define DNS_RDATASET_H 1
 
 /*****
-***** Module Info
-*****/
+ ***** Module Info
+ *****/
 
 /*! \file dns/rdataset.h
  * \brief
@@ -51,20 +50,8 @@
 #include <isc/magic.h>
 #include <isc/stdtime.h>
 
-#include <dns/rdatastruct.h>
 #include <dns/types.h>
-
-/* Fixed RRSet helper macros */
-
-#define DNS_RDATASET_LENGTH 2;
-
-#if DNS_RDATASET_FIXED
-#define DNS_RDATASET_ORDER 2
-#define DNS_RDATASET_COUNT (count * 4)
-#else /* !DNS_RDATASET_FIXED */
-#define DNS_RDATASET_ORDER 0
-#define DNS_RDATASET_COUNT 0
-#endif /* DNS_RDATASET_FIXED */
+#include <dns/rdatastruct.h>
 
 ISC_LANG_BEGINDECLS
 
@@ -75,34 +62,42 @@ typedef enum {
 } dns_rdatasetadditional_t;
 
 typedef struct dns_rdatasetmethods {
-	void (*disassociate)(dns_rdataset_t *rdataset DNS__DB_FLARG);
-	isc_result_t (*first)(dns_rdataset_t *rdataset);
-	isc_result_t (*next)(dns_rdataset_t *rdataset);
-	void (*current)(dns_rdataset_t *rdataset, dns_rdata_t *rdata);
-	void (*clone)(dns_rdataset_t	    *source,
-		      dns_rdataset_t *target DNS__DB_FLARG);
-	unsigned int (*count)(dns_rdataset_t *rdataset);
-	isc_result_t (*addnoqname)(dns_rdataset_t   *rdataset,
-				   const dns_name_t *name);
-	isc_result_t (*getnoqname)(dns_rdataset_t *rdataset, dns_name_t *name,
-				   dns_rdataset_t	 *neg,
-				   dns_rdataset_t *negsig DNS__DB_FLARG);
-	isc_result_t (*addclosest)(dns_rdataset_t   *rdataset,
-				   const dns_name_t *name);
-	isc_result_t (*getclosest)(dns_rdataset_t *rdataset, dns_name_t *name,
-				   dns_rdataset_t	 *neg,
-				   dns_rdataset_t *negsig DNS__DB_FLARG);
-	void (*settrust)(dns_rdataset_t *rdataset, dns_trust_t trust);
-	void (*expire)(dns_rdataset_t *rdataset DNS__DB_FLARG);
-	void (*clearprefetch)(dns_rdataset_t *rdataset);
-	void (*setownercase)(dns_rdataset_t *rdataset, const dns_name_t *name);
-	void (*getownercase)(const dns_rdataset_t *rdataset, dns_name_t *name);
-	isc_result_t (*addglue)(dns_rdataset_t	*rdataset,
-				dns_dbversion_t *version, dns_message_t *msg);
+	void			(*disassociate)(dns_rdataset_t *rdataset);
+	isc_result_t		(*first)(dns_rdataset_t *rdataset);
+	isc_result_t		(*next)(dns_rdataset_t *rdataset);
+	void			(*current)(dns_rdataset_t *rdataset,
+					   dns_rdata_t *rdata);
+	void			(*clone)(dns_rdataset_t *source,
+					 dns_rdataset_t *target);
+	unsigned int		(*count)(dns_rdataset_t *rdataset);
+	isc_result_t		(*addnoqname)(dns_rdataset_t *rdataset,
+					      const dns_name_t *name);
+	isc_result_t		(*getnoqname)(dns_rdataset_t *rdataset,
+					      dns_name_t *name,
+					      dns_rdataset_t *neg,
+					      dns_rdataset_t *negsig);
+	isc_result_t		(*addclosest)(dns_rdataset_t *rdataset,
+					      const dns_name_t *name);
+	isc_result_t		(*getclosest)(dns_rdataset_t *rdataset,
+					      dns_name_t *name,
+					      dns_rdataset_t *neg,
+					      dns_rdataset_t *negsig);
+	void			(*settrust)(dns_rdataset_t *rdataset,
+					    dns_trust_t trust);
+	void			(*expire)(dns_rdataset_t *rdataset);
+	void			(*clearprefetch)(dns_rdataset_t *rdataset);
+	void			(*setownercase)(dns_rdataset_t *rdataset,
+						const dns_name_t *name);
+	void			(*getownercase)(const dns_rdataset_t *rdataset,
+						dns_name_t *name);
+	isc_result_t		(*addglue)(dns_rdataset_t *rdataset,
+					   dns_dbversion_t *version,
+					   unsigned int options,
+					   dns_message_t *msg);
 } dns_rdatasetmethods_t;
 
-#define DNS_RDATASET_MAGIC	ISC_MAGIC('D', 'N', 'S', 'R')
-#define DNS_RDATASET_VALID(set) ISC_MAGIC_VALID(set, DNS_RDATASET_MAGIC)
+#define DNS_RDATASET_MAGIC	       ISC_MAGIC('D','N','S','R')
+#define DNS_RDATASET_VALID(set)	       ISC_MAGIC_VALID(set, DNS_RDATASET_MAGIC)
 
 /*%
  * Direct use of this structure by clients is strongly discouraged, except
@@ -111,124 +106,51 @@ typedef struct dns_rdatasetmethods {
  * rdataset implementations may change any of the fields.
  */
 struct dns_rdataset {
-	unsigned int	       magic;
-	dns_rdatasetmethods_t *methods;
-	ISC_LINK(dns_rdataset_t) link;
-
+	unsigned int			magic;		/* XXX ? */
+	dns_rdatasetmethods_t *		methods;
+	ISC_LINK(dns_rdataset_t)	link;
 	/*
 	 * XXX do we need these, or should they be retrieved by methods?
 	 * Leaning towards the latter, since they are not frequently required
 	 * once you have the rdataset.
 	 */
-	dns_rdataclass_t rdclass;
-	dns_rdatatype_t	 type;
-	dns_ttl_t	 ttl;
-
-	dns_trust_t	trust;
-	dns_rdatatype_t covers;
-
+	dns_rdataclass_t		rdclass;
+	dns_rdatatype_t			type;
+	dns_ttl_t			ttl;
+	dns_trust_t			trust;
+	dns_rdatatype_t			covers;
 	/*
 	 * attributes
 	 */
-	unsigned int attributes;
-
+	unsigned int			attributes;
 	/*%
 	 * the counter provides the starting point in the "cyclic" order.
 	 * The value UINT32_MAX has a special meaning of "picking up a
 	 * random value." in order to take care of databases that do not
 	 * increment the counter.
 	 */
-	uint32_t count;
-
+	uint32_t			count;
 	/*
 	 * This RRSIG RRset should be re-generated around this time.
 	 * Only valid if DNS_RDATASETATTR_RESIGN is set in attributes.
 	 */
-	isc_stdtime_t resign;
-
+	isc_stdtime_t			resign;
+	/*@{*/
 	/*%
-	 * Extra fields used by various rdataset implementations, that is, by
-	 * the code referred to in the rdataset methods table. The names of
-	 * the structures roughly correspond to the file containing the
-	 * implementation, except that `rdlist` is used by `rdatalist.c`,
-	 * `sdb.c`, and `sdlz.c`.
-	 *
-	 * Pointers in these structs use incomplete structure types,
-	 * because the structure definitions and corresponding typedef
-	 * names might not be in scope in this header.
+	 * These are for use by the rdataset implementation, and MUST NOT
+	 * be changed by clients.
 	 */
+	void *				private1;
+	void *				private2;
+	void *				private3;
+	unsigned int			privateuint4;
+	void *				private5;
+	const void *			private6;
+	const void *			private7;
 	/*@}*/
-	union {
-		struct {
-			struct dns_keynode *node;
-			dns_rdata_t	   *iter;
-		} keytable;
 
-		/*
-		 * An ncache rdataset is a view of memory held elsewhere:
-		 * raw can point to either a buffer on the stack or to an
-		 * rdataslab, such as in an rbtdb database.
-		 */
-		struct {
-			unsigned char *raw;
-			unsigned char *iter_pos;
-			unsigned int   iter_count;
-		} ncache;
-
-		/*
-		 * A slab rdataset provides access to an rdataslab. In
-		 * an rbtdb database, 'raw' will generally point to the
-		 * memory immediately following a slabheader. (There
-		 * is an exception in the case of rdatasets returned by
-		 * the `getnoqname` and `getclosest` methods; see
-		 * comments in rbtdb.c for details.)
-		 */
-		struct {
-			struct dns_db *db;
-			dns_dbnode_t  *node;
-			unsigned char *raw;
-			unsigned char *iter_pos;
-			unsigned int   iter_count;
-			dns_proof_t   *noqname, *closest;
-		} slab;
-
-		/*
-		 * A simple rdatalist, plus an optional dbnode used by
-		 * builtin and sdlz.
-		 */
-		struct {
-			struct dns_rdatalist *list;
-			struct dns_rdata     *iter;
-
-			/*
-			 * These refer to names passed in by the caller of
-			 * dns_rdataset_addnoqname() and _addclosest()
-			 */
-			const struct dns_name *noqname, *closest;
-			dns_dbnode_t	      *node;
-		} rdlist;
-
-#ifdef USE_DNSRPS
-		/*
-		 * DNSRPS rdatasets. dns_rpsdb_t is defined in dnsrps.h.
-		 */
-		struct {
-			dns_rpsdb_t *db;
-			void	    *iter_pos;
-			unsigned int iter_count;
-		} rps;
-#endif /* USE_DNSRPS */
-	};
 };
 
-#define DNS_RDATASET_COUNT_UNDEFINED UINT32_MAX
-
-#define DNS_RDATASET_INIT                                                  \
-	{                                                                  \
-		.magic = DNS_RDATASET_MAGIC, .link = ISC_LINK_INITIALIZER, \
-		.count = DNS_RDATASET_COUNT_UNDEFINED                      \
-	}
-
 /*!
  * \def DNS_RDATASETATTR_RENDERED
  *	Used by message.c to indicate that the rdataset was rendered.
@@ -239,50 +161,48 @@ struct dns_rdataset {
  *
  * \def DNS_RDATASETATTR_LOADORDER
  *	Output the RRset in load order.
- *
- * \def DNS_RDATASETATTR_STALE_ADDED
- *	Set on rdatasets that were added during a stale-answer-client-timeout
- *	lookup. In other words, the RRset was added during a lookup of stale
- *	data and does not necessarily mean that the rdataset itself is stale.
  */
 
-#define DNS_RDATASETATTR_NONE	      0x00000000 /*%< No ordering. */
-#define DNS_RDATASETATTR_QUESTION     0x00000001
-#define DNS_RDATASETATTR_RENDERED     0x00000002 /*%< Used by message.c */
-#define DNS_RDATASETATTR_ANSWERED     0x00000004 /*%< Used by server. */
-#define DNS_RDATASETATTR_CACHE	      0x00000008 /*%< Used by resolver. */
-#define DNS_RDATASETATTR_ANSWER	      0x00000010 /*%< Used by resolver. */
-#define DNS_RDATASETATTR_ANSWERSIG    0x00000020 /*%< Used by resolver. */
-#define DNS_RDATASETATTR_EXTERNAL     0x00000040 /*%< Used by resolver. */
-#define DNS_RDATASETATTR_NCACHE	      0x00000080 /*%< Used by resolver. */
-#define DNS_RDATASETATTR_CHAINING     0x00000100 /*%< Used by resolver. */
-#define DNS_RDATASETATTR_TTLADJUSTED  0x00000200 /*%< Used by message.c */
-#define DNS_RDATASETATTR_FIXEDORDER   0x00000400 /*%< Fixed ordering. */
-#define DNS_RDATASETATTR_RANDOMIZE    0x00000800 /*%< Random ordering. */
-#define DNS_RDATASETATTR_CHASE	      0x00001000 /*%< Used by resolver. */
-#define DNS_RDATASETATTR_NXDOMAIN     0x00002000
-#define DNS_RDATASETATTR_NOQNAME      0x00004000
-#define DNS_RDATASETATTR_CHECKNAMES   0x00008000 /*%< Used by resolver. */
-#define DNS_RDATASETATTR_REQUIRED     0x00010000
-#define DNS_RDATASETATTR_REQUIREDGLUE DNS_RDATASETATTR_REQUIRED
-#define DNS_RDATASETATTR_LOADORDER    0x00020000
-#define DNS_RDATASETATTR_RESIGN	      0x00040000
-#define DNS_RDATASETATTR_CLOSEST      0x00080000
-#define DNS_RDATASETATTR_OPTOUT	      0x00100000 /*%< OPTOUT proof */
-#define DNS_RDATASETATTR_NEGATIVE     0x00200000
-#define DNS_RDATASETATTR_PREFETCH     0x00400000
-#define DNS_RDATASETATTR_CYCLIC	      0x00800000 /*%< Cyclic ordering. */
-#define DNS_RDATASETATTR_STALE	      0x01000000
-#define DNS_RDATASETATTR_ANCIENT      0x02000000
-#define DNS_RDATASETATTR_STALE_WINDOW 0x04000000
-#define DNS_RDATASETATTR_STALE_ADDED  0x08000000
-#define DNS_RDATASETATTR_KEEPCASE     0x10000000
+#define DNS_RDATASETATTR_NONE		0x00000000	/*%< No ordering. */
+#define DNS_RDATASETATTR_QUESTION	0x00000001
+#define DNS_RDATASETATTR_RENDERED	0x00000002	/*%< Used by message.c */
+#define DNS_RDATASETATTR_ANSWERED	0x00000004	/*%< Used by server. */
+#define DNS_RDATASETATTR_CACHE		0x00000008	/*%< Used by resolver. */
+#define DNS_RDATASETATTR_ANSWER		0x00000010	/*%< Used by resolver. */
+#define DNS_RDATASETATTR_ANSWERSIG	0x00000020	/*%< Used by resolver. */
+#define DNS_RDATASETATTR_EXTERNAL	0x00000040	/*%< Used by resolver. */
+#define DNS_RDATASETATTR_NCACHE		0x00000080	/*%< Used by resolver. */
+#define DNS_RDATASETATTR_CHAINING	0x00000100	/*%< Used by resolver. */
+#define DNS_RDATASETATTR_TTLADJUSTED	0x00000200	/*%< Used by message.c */
+#define DNS_RDATASETATTR_FIXEDORDER	0x00000400	/*%< Fixed ordering. */
+#define DNS_RDATASETATTR_RANDOMIZE	0x00000800	/*%< Random ordering. */
+#define DNS_RDATASETATTR_CHASE		0x00001000	/*%< Used by resolver. */
+#define DNS_RDATASETATTR_NXDOMAIN	0x00002000
+#define DNS_RDATASETATTR_NOQNAME	0x00004000
+#define DNS_RDATASETATTR_CHECKNAMES	0x00008000	/*%< Used by resolver. */
+#define DNS_RDATASETATTR_REQUIRED	0x00010000
+#define DNS_RDATASETATTR_REQUIREDGLUE	DNS_RDATASETATTR_REQUIRED
+#define DNS_RDATASETATTR_LOADORDER	0x00020000
+#define DNS_RDATASETATTR_RESIGN		0x00040000
+#define DNS_RDATASETATTR_CLOSEST	0x00080000
+#define DNS_RDATASETATTR_OPTOUT		0x00100000	/*%< OPTOUT proof */
+#define DNS_RDATASETATTR_NEGATIVE	0x00200000
+#define DNS_RDATASETATTR_PREFETCH	0x00400000
+#define DNS_RDATASETATTR_CYCLIC		0x00800000	/*%< Cyclic ordering. */
+#define DNS_RDATASETATTR_STALE		0x01000000
 
 /*%
  * _OMITDNSSEC:
  * 	Omit DNSSEC records when rendering ncache records.
  */
-#define DNS_RDATASETTOWIRE_OMITDNSSEC 0x0001
+#define DNS_RDATASETTOWIRE_OMITDNSSEC	0x0001
+
+/*%
+ * _FILTERAAAA
+ * 	If A records are present, omit AAAA records when adding
+ * 	glue
+ */
+#define DNS_RDATASETADDGLUE_FILTERAAAA 0x0001
 
 void
 dns_rdataset_init(dns_rdataset_t *rdataset);
@@ -309,10 +229,8 @@ dns_rdataset_invalidate(dns_rdataset_t *rdataset);
  *	without initializing it will cause an assertion failure.
  */
 
-#define dns_rdataset_disassociate(rdataset) \
-	dns__rdataset_disassociate(rdataset DNS__DB_FILELINE)
 void
-dns__rdataset_disassociate(dns_rdataset_t *rdataset DNS__DB_FLARG);
+dns_rdataset_disassociate(dns_rdataset_t *rdataset);
 /*%<
  * Disassociate 'rdataset' from its rdata, allowing it to be reused.
  *
@@ -357,11 +275,8 @@ dns_rdataset_makequestion(dns_rdataset_t *rdataset, dns_rdataclass_t rdclass,
  *\li	'rdataset' is a valid, associated, question rdataset.
  */
 
-#define dns_rdataset_clone(source, target) \
-	dns__rdataset_clone(source, target DNS__DB_FILELINE)
 void
-dns__rdataset_clone(dns_rdataset_t	  *source,
-		    dns_rdataset_t *target DNS__DB_FLARG);
+dns_rdataset_clone(dns_rdataset_t *source, dns_rdataset_t *target);
 /*%<
  * Make 'target' refer to the same rdataset as 'source'.
  *
@@ -435,8 +350,11 @@ dns_rdataset_current(dns_rdataset_t *rdataset, dns_rdata_t *rdata);
  */
 
 isc_result_t
-dns_rdataset_totext(dns_rdataset_t *rdataset, const dns_name_t *owner_name,
-		    bool omit_final_dot, bool question, isc_buffer_t *target);
+dns_rdataset_totext(dns_rdataset_t *rdataset,
+		    const dns_name_t *owner_name,
+		    bool omit_final_dot,
+		    bool question,
+		    isc_buffer_t *target);
 /*%<
  * Convert 'rdataset' to text format, storing the result in 'target'.
  *
@@ -457,9 +375,12 @@ dns_rdataset_totext(dns_rdataset_t *rdataset, const dns_name_t *owner_name,
  */
 
 isc_result_t
-dns_rdataset_towire(dns_rdataset_t *rdataset, const dns_name_t *owner_name,
-		    dns_compress_t *cctx, isc_buffer_t *target,
-		    unsigned int options, unsigned int *countp);
+dns_rdataset_towire(dns_rdataset_t *rdataset,
+		    const dns_name_t *owner_name,
+		    dns_compress_t *cctx,
+		    isc_buffer_t *target,
+		    unsigned int options,
+		    unsigned int *countp);
 /*%<
  * Convert 'rdataset' to wire format, compressing names as specified
  * in 'cctx', and storing the result in 'target'.
@@ -493,10 +414,13 @@ dns_rdataset_towire(dns_rdataset_t *rdataset, const dns_name_t *owner_name,
  */
 
 isc_result_t
-dns_rdataset_towiresorted(dns_rdataset_t   *rdataset,
-			  const dns_name_t *owner_name, dns_compress_t *cctx,
-			  isc_buffer_t *target, dns_rdatasetorderfunc_t order,
-			  const void *order_arg, unsigned int options,
+dns_rdataset_towiresorted(dns_rdataset_t *rdataset,
+			  const dns_name_t *owner_name,
+			  dns_compress_t *cctx,
+			  isc_buffer_t *target,
+			  dns_rdatasetorderfunc_t order,
+			  const void *order_arg,
+			  unsigned int options,
 			  unsigned int *countp);
 /*%<
  * Like dns_rdataset_towire(), but sorting the rdatasets according to
@@ -509,11 +433,15 @@ dns_rdataset_towiresorted(dns_rdataset_t   *rdataset,
  */
 
 isc_result_t
-dns_rdataset_towirepartial(dns_rdataset_t   *rdataset,
-			   const dns_name_t *owner_name, dns_compress_t *cctx,
-			   isc_buffer_t *target, dns_rdatasetorderfunc_t order,
-			   const void *order_arg, unsigned int options,
-			   unsigned int *countp, void **state);
+dns_rdataset_towirepartial(dns_rdataset_t *rdataset,
+			   const dns_name_t *owner_name,
+			   dns_compress_t *cctx,
+			   isc_buffer_t *target,
+			   dns_rdatasetorderfunc_t order,
+			   const void *order_arg,
+			   unsigned int options,
+			   unsigned int *countp,
+			   void **state);
 /*%<
  * Like dns_rdataset_towiresorted() except that a partial rdataset
  * may be written.
@@ -533,8 +461,7 @@ dns_rdataset_towirepartial(dns_rdataset_t   *rdataset,
  */
 
 isc_result_t
-dns_rdataset_additionaldata(dns_rdataset_t	    *rdataset,
-			    const dns_name_t	    *owner_name,
+dns_rdataset_additionaldata(dns_rdataset_t *rdataset,
 			    dns_additionaldatafunc_t add, void *arg);
 /*%<
  * For each rdata in rdataset, call 'add' for each name and type in the
@@ -561,12 +488,9 @@ dns_rdataset_additionaldata(dns_rdataset_t	    *rdataset,
  *\li	Any error that dns_rdata_additionaldata() can return.
  */
 
-#define dns_rdataset_getnoqname(rdataset, name, neg, negsig) \
-	dns__rdataset_getnoqname(rdataset, name, neg, negsig DNS__DB_FILELINE)
 isc_result_t
-dns__rdataset_getnoqname(dns_rdataset_t *rdataset, dns_name_t *name,
-			 dns_rdataset_t	       *neg,
-			 dns_rdataset_t *negsig DNS__DB_FLARG);
+dns_rdataset_getnoqname(dns_rdataset_t *rdataset, dns_name_t *name,
+			dns_rdataset_t *neg, dns_rdataset_t *negsig);
 /*%<
  * Return the noqname proof for this record.
  *
@@ -590,12 +514,9 @@ dns_rdataset_addnoqname(dns_rdataset_t *rdataset, dns_name_t *name);
  *	 rdatasets.
  */
 
-#define dns_rdataset_getclosest(rdataset, name, nsec, nsecsig) \
-	dns__rdataset_getclosest(rdataset, name, nsec, nsecsig DNS__DB_FILELINE)
 isc_result_t
-dns__rdataset_getclosest(dns_rdataset_t *rdataset, dns_name_t *name,
-			 dns_rdataset_t		*nsec,
-			 dns_rdataset_t *nsecsig DNS__DB_FLARG);
+dns_rdataset_getclosest(dns_rdataset_t *rdataset, dns_name_t *name,
+			dns_rdataset_t *nsec, dns_rdataset_t *nsecsig);
 /*%<
  * Return the closest encloser for this record.
  *
@@ -625,10 +546,8 @@ dns_rdataset_settrust(dns_rdataset_t *rdataset, dns_trust_t trust);
  * The local trust level of 'rdataset' is also set.
  */
 
-#define dns_rdataset_expire(rdataset) \
-	dns__rdataset_expire(rdataset DNS__DB_FILELINE)
 void
-dns__rdataset_expire(dns_rdataset_t *rdataset DNS__DB_FLARG);
+dns_rdataset_expire(dns_rdataset_t *rdataset);
 /*%<
  * Mark the rdataset to be expired in the backing database.
  */
@@ -660,6 +579,32 @@ dns_rdataset_getownercase(const dns_rdataset_t *rdataset, dns_name_t *name);
  * according to it. If CASESET is not set, do nothing.
  */
 
+isc_result_t
+dns_rdataset_addglue(dns_rdataset_t *rdataset,
+		     dns_dbversion_t *version,
+		     unsigned int options,
+		     dns_message_t *msg);
+/*%<
+ * Add glue records for rdataset to the additional section of message in
+ * 'msg'. 'rdataset' must be of type NS. If DNS_RDATASETADDGLUE_FILTERAAAA
+ * is set in 'options' there is type A glue, type AAAA glue is not added.
+ *
+ * In case a successful result is not returned, the caller should try to
+ * add glue directly to the message by iterating for additional data.
+ *
+ * Requires:
+ * \li	'rdataset' is a valid NS rdataset.
+ * \li	'version' is the DB version.
+ * \li  'options' is options; currently only _FILTERAAAA is defined.
+ * \li	'msg' is the DNS message to which the glue should be added.
+ *
+ * Returns:
+ *\li	#ISC_R_SUCCESS
+ *\li	#ISC_R_NOTIMPLEMENTED
+ *\li	#ISC_R_FAILURE
+ *\li	Any error that dns_rdata_additionaldata() can return.
+ */
+
 void
 dns_rdataset_trimttl(dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset,
 		     dns_rdata_rrsig_t *rrsig, isc_stdtime_t now,
@@ -686,3 +631,5 @@ dns_trust_totext(dns_trust_t trust);
  */
 
 ISC_LANG_ENDDECLS
+
+#endif /* DNS_RDATASET_H */
