@@ -14,6 +14,8 @@
 
 #include <config.h>
 
+#include <stdbool.h>
+
 #include <isc/mem.h>
 #include <isc/print.h>
 #include <isc/refcount.h>
@@ -47,8 +49,8 @@ struct dns_keynode {
 	unsigned int            magic;
 	isc_refcount_t          refcount;
 	dst_key_t *             key;
-	isc_boolean_t           managed;
-	isc_boolean_t		initial;
+	bool           managed;
+	bool		initial;
 	struct dns_keynode *    next;
 };
 
@@ -87,15 +89,8 @@ dns_keytable_create(isc_mem_t *mctx, dns_keytable_t **keytablep) {
 		goto cleanup_rbt;
 	}
 
-	result = isc_refcount_init(&keytable->active_nodes, 0);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup_rwlock;
-	}
-
-	result = isc_refcount_init(&keytable->references, 1);
-	if (result != ISC_R_SUCCESS) {
-		goto cleanup_active_nodes;
-	}
+	isc_refcount_init(&keytable->active_nodes, 0);
+	isc_refcount_init(&keytable->references, 1);
 
 	keytable->mctx = NULL;
 	isc_mem_attach(mctx, &keytable->mctx);
@@ -104,12 +99,6 @@ dns_keytable_create(isc_mem_t *mctx, dns_keytable_t **keytablep) {
 
 	return (ISC_R_SUCCESS);
 
- cleanup_active_nodes:
-	isc_refcount_destroy(&keytable->active_nodes);
-
- cleanup_rwlock:
-	isc_rwlock_destroy(&keytable->rwlock);
-
  cleanup_rbt:
 	dns_rbt_destroy(&keytable->table);
 
@@ -129,30 +118,20 @@ dns_keytable_attach(dns_keytable_t *source, dns_keytable_t **targetp) {
 	REQUIRE(VALID_KEYTABLE(source));
 	REQUIRE(targetp != NULL && *targetp == NULL);
 
-	isc_refcount_increment(&source->references, NULL);
+	isc_refcount_increment(&source->references);
 
 	*targetp = source;
 }
 
 void
 dns_keytable_detach(dns_keytable_t **keytablep) {
-	dns_keytable_t *keytable;
-	unsigned int refs;
-
-	/*
-	 * Detach *keytablep from its keytable.
-	 */
-
 	REQUIRE(keytablep != NULL && VALID_KEYTABLE(*keytablep));
-
-	keytable = *keytablep;
+	dns_keytable_t *keytable = *keytablep;
 	*keytablep = NULL;
 
-	isc_refcount_decrement(&keytable->references, &refs);
-	if (refs == 0) {
-		INSIST(isc_refcount_current(&keytable->active_nodes) == 0);
-		isc_refcount_destroy(&keytable->active_nodes);
+	if (isc_refcount_decrement(&keytable->references) == 1) {
 		isc_refcount_destroy(&keytable->references);
+		isc_refcount_destroy(&keytable->active_nodes);
 		dns_rbt_destroy(&keytable->table);
 		isc_rwlock_destroy(&keytable->rwlock);
 		keytable->magic = 0;
@@ -166,7 +145,7 @@ dns_keytable_detach(dns_keytable_t **keytablep) {
  * key as the one supplied in "keyp" and, if found, update it accordingly.
  */
 static isc_result_t
-update_keynode(dst_key_t **keyp, dns_rbtnode_t *node, isc_boolean_t initial) {
+update_keynode(dst_key_t **keyp, dns_rbtnode_t *node, bool initial) {
 	dns_keynode_t *knode;
 
 	REQUIRE(keyp != NULL && *keyp != NULL);
@@ -206,8 +185,8 @@ update_keynode(dst_key_t **keyp, dns_rbtnode_t *node, isc_boolean_t initial) {
  */
 static isc_result_t
 prepend_keynode(dst_key_t **keyp, dns_rbtnode_t *node,
-		dns_keytable_t *keytable, isc_boolean_t managed,
-		isc_boolean_t initial)
+		dns_keytable_t *keytable, bool managed,
+		bool initial)
 {
 	dns_keynode_t *knode = NULL;
 	isc_result_t result;
@@ -244,7 +223,7 @@ prepend_keynode(dst_key_t **keyp, dns_rbtnode_t *node,
  * supplying key data which would allow the domain to be validated.
  */
 static isc_result_t
-insert(dns_keytable_t *keytable, isc_boolean_t managed, isc_boolean_t initial,
+insert(dns_keytable_t *keytable, bool managed, bool initial,
        const dns_name_t *keyname, dst_key_t **keyp)
 {
 	dns_rbtnode_t *node = NULL;
@@ -306,8 +285,8 @@ insert(dns_keytable_t *keytable, isc_boolean_t managed, isc_boolean_t initial,
 }
 
 isc_result_t
-dns_keytable_add(dns_keytable_t *keytable, isc_boolean_t managed,
-		 isc_boolean_t initial, dst_key_t **keyp)
+dns_keytable_add(dns_keytable_t *keytable, bool managed,
+		 bool initial, dst_key_t **keyp)
 {
 	REQUIRE(keyp != NULL && *keyp != NULL);
 	REQUIRE(!initial || managed);
@@ -316,7 +295,7 @@ dns_keytable_add(dns_keytable_t *keytable, isc_boolean_t managed,
 
 isc_result_t
 dns_keytable_marksecure(dns_keytable_t *keytable, const dns_name_t *name) {
-	return (insert(keytable, ISC_TRUE, ISC_FALSE, name, NULL));
+	return (insert(keytable, true, false, name, NULL));
 }
 
 isc_result_t
@@ -333,7 +312,7 @@ dns_keytable_delete(dns_keytable_t *keytable, const dns_name_t *keyname) {
 	if (result == ISC_R_SUCCESS) {
 		if (node->data != NULL)
 			result = dns_rbt_deletenode(keytable->table,
-						    node, ISC_FALSE);
+						    node, false);
 		else
 			result = ISC_R_NOTFOUND;
 	} else if (result == DNS_R_PARTIALMATCH)
@@ -371,16 +350,16 @@ dns_keytable_deletekeynode(dns_keytable_t *keytable, dst_key_t *dstkey) {
 
 	knode = node->data;
 	if (knode->next == NULL && knode->key != NULL &&
-	    dst_key_compare(knode->key, dstkey) == ISC_TRUE)
+	    dst_key_compare(knode->key, dstkey) == true)
 	{
-		result = dns_rbt_deletenode(keytable->table, node, ISC_FALSE);
+		result = dns_rbt_deletenode(keytable->table, node, false);
 		goto finish;
 	}
 
 	kprev = (dns_keynode_t **) &node->data;
 	while (knode != NULL) {
 		if (knode->key != NULL &&
-		    dst_key_compare(knode->key, dstkey) == ISC_TRUE)
+		    dst_key_compare(knode->key, dstkey) == true)
 			break;
 		kprev = &knode->next;
 		knode = knode->next;
@@ -422,7 +401,7 @@ dns_keytable_find(dns_keytable_t *keytable, const dns_name_t *keyname,
 				  DNS_RBTFIND_NOOPTIONS, NULL, NULL);
 	if (result == ISC_R_SUCCESS) {
 		if (node->data != NULL) {
-			isc_refcount_increment0(&keytable->active_nodes, NULL);
+			isc_refcount_increment0(&keytable->active_nodes);
 			dns_keynode_attach(node->data, keynodep);
 		} else
 			result = ISC_R_NOTFOUND;
@@ -450,7 +429,7 @@ dns_keytable_nextkeynode(dns_keytable_t *keytable, dns_keynode_t *keynode,
 		return (ISC_R_NOTFOUND);
 
 	dns_keynode_attach(keynode->next, nextnodep);
-	isc_refcount_increment(&keytable->active_nodes, NULL);
+	isc_refcount_increment(&keytable->active_nodes);
 
 	return (ISC_R_SUCCESS);
 }
@@ -498,7 +477,7 @@ dns_keytable_findkeynode(dns_keytable_t *keytable, const dns_name_t *name,
 				break;
 		}
 		if (knode != NULL) {
-			isc_refcount_increment0(&keytable->active_nodes, NULL);
+			isc_refcount_increment0(&keytable->active_nodes);
 			dns_keynode_attach(knode, keynodep);
 		} else
 			result = DNS_R_PARTIALMATCH;
@@ -536,7 +515,7 @@ dns_keytable_findnextkeynode(dns_keytable_t *keytable, dns_keynode_t *keynode,
 			break;
 	}
 	if (knode != NULL) {
-		isc_refcount_increment(&keytable->active_nodes, NULL);
+		isc_refcount_increment(&keytable->active_nodes);
 		result = ISC_R_SUCCESS;
 		dns_keynode_attach(knode, nextnodep);
 	} else
@@ -585,7 +564,7 @@ dns_keytable_attachkeynode(dns_keytable_t *keytable, dns_keynode_t *source,
 	REQUIRE(VALID_KEYNODE(source));
 	REQUIRE(target != NULL && *target == NULL);
 
-	isc_refcount_increment(&keytable->active_nodes, NULL);
+	isc_refcount_increment(&keytable->active_nodes);
 
 	dns_keynode_attach(source, target);
 }
@@ -600,13 +579,13 @@ dns_keytable_detachkeynode(dns_keytable_t *keytable, dns_keynode_t **keynodep)
 	REQUIRE(VALID_KEYTABLE(keytable));
 	REQUIRE(keynodep != NULL && VALID_KEYNODE(*keynodep));
 
-	isc_refcount_decrement(&keytable->active_nodes, NULL);
+	INSIST(isc_refcount_decrement(&keytable->active_nodes) > 0);
 	dns_keynode_detach(keytable->mctx, keynodep);
 }
 
 isc_result_t
 dns_keytable_issecuredomain(dns_keytable_t *keytable, const dns_name_t *name,
-			    dns_name_t *foundname, isc_boolean_t *wantdnssecp)
+			    dns_name_t *foundname, bool *wantdnssecp)
 {
 	isc_result_t result;
 	dns_rbtnode_t *node = NULL;
@@ -625,10 +604,10 @@ dns_keytable_issecuredomain(dns_keytable_t *keytable, const dns_name_t *name,
 				  NULL, DNS_RBTFIND_NOOPTIONS, NULL, NULL);
 	if (result == ISC_R_SUCCESS || result == DNS_R_PARTIALMATCH) {
 		INSIST(node->data != NULL);
-		*wantdnssecp = ISC_TRUE;
+		*wantdnssecp = true;
 		result = ISC_R_SUCCESS;
 	} else if (result == ISC_R_NOTFOUND) {
-		*wantdnssecp = ISC_FALSE;
+		*wantdnssecp = false;
 		result = ISC_R_SUCCESS;
 	}
 
@@ -746,7 +725,7 @@ dns_keytable_forall(dns_keytable_t *keytable,
 			result = ISC_R_SUCCESS;
 		goto cleanup;
 	}
-	isc_refcount_increment0(&keytable->active_nodes, NULL);
+	isc_refcount_increment0(&keytable->active_nodes);
 	for (;;) {
 		dns_rbtnodechain_current(&chain, NULL, NULL, &node);
 		if (node->data != NULL)
@@ -758,7 +737,7 @@ dns_keytable_forall(dns_keytable_t *keytable,
 			break;
 		}
 	}
-	isc_refcount_decrement(&keytable->active_nodes, NULL);
+	INSIST(isc_refcount_decrement(&keytable->active_nodes) > 0);
 
    cleanup:
 	dns_rbtnodechain_invalidate(&chain);
@@ -773,14 +752,14 @@ dns_keynode_key(dns_keynode_t *keynode) {
 	return (keynode->key);
 }
 
-isc_boolean_t
+bool
 dns_keynode_managed(dns_keynode_t *keynode) {
 	REQUIRE(VALID_KEYNODE(keynode));
 
 	return (keynode->managed);
 }
 
-isc_boolean_t
+bool
 dns_keynode_initial(dns_keynode_t *keynode) {
 	REQUIRE(VALID_KEYNODE(keynode));
 
@@ -791,12 +770,11 @@ void
 dns_keynode_trust(dns_keynode_t *keynode) {
 	REQUIRE(VALID_KEYNODE(keynode));
 
-	keynode->initial = ISC_FALSE;
+	keynode->initial = false;
 }
 
 isc_result_t
 dns_keynode_create(isc_mem_t *mctx, dns_keynode_t **target) {
-	isc_result_t result;
 	dns_keynode_t *knode;
 
 	REQUIRE(target != NULL && *target == NULL);
@@ -806,14 +784,12 @@ dns_keynode_create(isc_mem_t *mctx, dns_keynode_t **target) {
 		return (ISC_R_NOMEMORY);
 
 	knode->magic = KEYNODE_MAGIC;
-	knode->managed = ISC_FALSE;
-	knode->initial = ISC_FALSE;
+	knode->managed = false;
+	knode->initial = false;
 	knode->key = NULL;
 	knode->next = NULL;
 
-	result = isc_refcount_init(&knode->refcount, 1);
-	if (result != ISC_R_SUCCESS)
-		return (result);
+	isc_refcount_init(&knode->refcount, 1);
 
 	*target = knode;
 	return (ISC_R_SUCCESS);
@@ -822,23 +798,23 @@ dns_keynode_create(isc_mem_t *mctx, dns_keynode_t **target) {
 void
 dns_keynode_attach(dns_keynode_t *source, dns_keynode_t **target) {
 	REQUIRE(VALID_KEYNODE(source));
-	isc_refcount_increment(&source->refcount, NULL);
+	isc_refcount_increment(&source->refcount);
 	*target = source;
 }
 
 void
 dns_keynode_detach(isc_mem_t *mctx, dns_keynode_t **keynode) {
-	unsigned int refs;
+	REQUIRE(keynode != NULL && VALID_KEYNODE(*keynode));
 	dns_keynode_t *node = *keynode;
-	REQUIRE(VALID_KEYNODE(node));
-	isc_refcount_decrement(&node->refcount, &refs);
-	if (refs == 0) {
-		if (node->key != NULL)
-			dst_key_free(&node->key);
+	*keynode = NULL;
+
+	if (isc_refcount_decrement(&node->refcount) == 1) {
 		isc_refcount_destroy(&node->refcount);
+		if (node->key != NULL) {
+			dst_key_free(&node->key);
+		}
 		isc_mem_put(mctx, node, sizeof(dns_keynode_t));
 	}
-	*keynode = NULL;
 }
 
 void
