@@ -15,6 +15,8 @@
 #include <config.h>
 
 #include <ctype.h>
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 
 #include <isc/buffer.h>
@@ -163,15 +165,11 @@ LIBDNS_EXTERNAL_DATA const dns_name_t *dns_wildcardname = &wild;
 /*
  * dns_name_t to text post-conversion procedure.
  */
-#ifdef ISC_PLATFORM_USETHREADS
 static int thread_key_initialized = 0;
 static isc_mutex_t thread_key_mutex;
 static isc_mem_t *thread_key_mctx = NULL;
 static isc_thread_key_t totext_filter_proc_key;
 static isc_once_t once = ISC_ONCE_INIT;
-#else
-static dns_name_totextfilter_t totext_filter_proc = NULL;
-#endif
 
 static void
 set_offsets(const dns_name_t *name, unsigned char *offsets,
@@ -211,16 +209,16 @@ dns_name_invalidate(dns_name_t *name) {
 	ISC_LINK_INIT(name, link);
 }
 
-isc_boolean_t
+bool
 dns_name_isvalid(const dns_name_t *name) {
 	unsigned char *ndata, *offsets;
 	unsigned int offset, count, length, nlabels;
 
 	if (!VALID_NAME(name))
-		return (ISC_FALSE);
+		return (false);
 
 	if (name->length > 255U || name->labels > 127U)
-		return (ISC_FALSE);
+		return (false);
 
 	ndata = name->ndata;
 	length = name->length;
@@ -231,24 +229,24 @@ dns_name_isvalid(const dns_name_t *name) {
 	while (offset != length) {
 		count = *ndata;
 		if (count > 63U)
-			return (ISC_FALSE);
+			return (false);
 		if (offsets != NULL && offsets[nlabels] != offset)
-			return (ISC_FALSE);
+			return (false);
 
 		nlabels++;
 		offset += count + 1;
 		ndata += count + 1;
 		if (offset > length)
-			return (ISC_FALSE);
+			return (false);
 
 		if (count == 0)
 			break;
 	}
 
 	if (nlabels != name->labels || offset != name->length)
-		return (ISC_FALSE);
+		return (false);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 void
@@ -264,7 +262,7 @@ dns_name_setbuffer(dns_name_t *name, isc_buffer_t *buffer) {
 	name->buffer = buffer;
 }
 
-isc_boolean_t
+bool
 dns_name_hasbuffer(const dns_name_t *name) {
 	/*
 	 * Does 'name' have a dedicated buffer?
@@ -273,12 +271,12 @@ dns_name_hasbuffer(const dns_name_t *name) {
 	REQUIRE(VALID_NAME(name));
 
 	if (name->buffer != NULL)
-		return (ISC_TRUE);
+		return (true);
 
-	return (ISC_FALSE);
+	return (false);
 }
 
-isc_boolean_t
+bool
 dns_name_isabsolute(const dns_name_t *name) {
 
 	/*
@@ -288,8 +286,8 @@ dns_name_isabsolute(const dns_name_t *name) {
 	REQUIRE(VALID_NAME(name));
 
 	if ((name->attributes & DNS_NAMEATTR_ABSOLUTE) != 0)
-		return (ISC_TRUE);
-	return (ISC_FALSE);
+		return (true);
+	return (false);
 }
 
 #define hyphenchar(c) ((c) == 0x2d)
@@ -301,11 +299,11 @@ dns_name_isabsolute(const dns_name_t *name) {
 #define middlechar(c) (borderchar(c) || hyphenchar(c))
 #define domainchar(c) ((c) > 0x20 && (c) < 0x7f)
 
-isc_boolean_t
+bool
 dns_name_ismailbox(const dns_name_t *name) {
 	unsigned char *ndata, ch;
 	unsigned int n;
-	isc_boolean_t first;
+	bool first;
 
 	REQUIRE(VALID_NAME(name));
 	REQUIRE(name->labels > 0);
@@ -315,7 +313,7 @@ dns_name_ismailbox(const dns_name_t *name) {
 	 * Root label.
 	 */
 	if (name->length == 1)
-		return (ISC_TRUE);
+		return (true);
 
 	ndata = name->ndata;
 	n = *ndata++;
@@ -323,11 +321,11 @@ dns_name_ismailbox(const dns_name_t *name) {
 	while (n--) {
 		ch = *ndata++;
 		if (!domainchar(ch))
-			return (ISC_FALSE);
+			return (false);
 	}
 
 	if (ndata == name->ndata + name->length)
-		return (ISC_FALSE);
+		return (false);
 
 	/*
 	 * RFC292/RFC1123 hostname.
@@ -335,27 +333,27 @@ dns_name_ismailbox(const dns_name_t *name) {
 	while (ndata < (name->ndata + name->length)) {
 		n = *ndata++;
 		INSIST(n <= 63);
-		first = ISC_TRUE;
+		first = true;
 		while (n--) {
 			ch = *ndata++;
 			if (first || n == 0) {
 				if (!borderchar(ch))
-					return (ISC_FALSE);
+					return (false);
 			} else {
 				if (!middlechar(ch))
-					return (ISC_FALSE);
+					return (false);
 			}
-			first = ISC_FALSE;
+			first = false;
 		}
 	}
-	return (ISC_TRUE);
+	return (true);
 }
 
-isc_boolean_t
-dns_name_ishostname(const dns_name_t *name, isc_boolean_t wildcard) {
+bool
+dns_name_ishostname(const dns_name_t *name, bool wildcard) {
 	unsigned char *ndata, ch;
 	unsigned int n;
-	isc_boolean_t first;
+	bool first;
 
 	REQUIRE(VALID_NAME(name));
 	REQUIRE(name->labels > 0);
@@ -365,7 +363,7 @@ dns_name_ishostname(const dns_name_t *name, isc_boolean_t wildcard) {
 	 * Root label.
 	 */
 	if (name->length == 1)
-		return (ISC_TRUE);
+		return (true);
 
 	/*
 	 * Skip wildcard if this is a ownername.
@@ -380,23 +378,23 @@ dns_name_ishostname(const dns_name_t *name, isc_boolean_t wildcard) {
 	while (ndata < (name->ndata + name->length)) {
 		n = *ndata++;
 		INSIST(n <= 63);
-		first = ISC_TRUE;
+		first = true;
 		while (n--) {
 			ch = *ndata++;
 			if (first || n == 0) {
 				if (!borderchar(ch))
-					return (ISC_FALSE);
+					return (false);
 			} else {
 				if (!middlechar(ch))
-					return (ISC_FALSE);
+					return (false);
 			}
-			first = ISC_FALSE;
+			first = false;
 		}
 	}
-	return (ISC_TRUE);
+	return (true);
 }
 
-isc_boolean_t
+bool
 dns_name_iswildcard(const dns_name_t *name) {
 	unsigned char *ndata;
 
@@ -410,13 +408,13 @@ dns_name_iswildcard(const dns_name_t *name) {
 	if (name->length >= 2) {
 		ndata = name->ndata;
 		if (ndata[0] == 1 && ndata[1] == '*')
-			return (ISC_TRUE);
+			return (true);
 	}
 
-	return (ISC_FALSE);
+	return (false);
 }
 
-isc_boolean_t
+bool
 dns_name_internalwildcard(const dns_name_t *name) {
 	unsigned char *ndata;
 	unsigned int count;
@@ -444,15 +442,15 @@ dns_name_internalwildcard(const dns_name_t *name) {
 		count = *ndata++;
 		INSIST(count <= 63);
 		if (count == 1 && *ndata == '*')
-			return (ISC_TRUE);
+			return (true);
 		ndata += count;
 		label++;
 	}
-	return (ISC_FALSE);
+	return (false);
 }
 
 unsigned int
-dns_name_hash(const dns_name_t *name, isc_boolean_t case_sensitive) {
+dns_name_hash(const dns_name_t *name, bool case_sensitive) {
 	unsigned int length;
 
 	/*
@@ -472,7 +470,7 @@ dns_name_hash(const dns_name_t *name, isc_boolean_t case_sensitive) {
 }
 
 unsigned int
-dns_name_fullhash(const dns_name_t *name, isc_boolean_t case_sensitive) {
+dns_name_fullhash(const dns_name_t *name, bool case_sensitive) {
 	/*
 	 * Provide a hash value for 'name'.
 	 */
@@ -644,7 +642,7 @@ dns_name_compare(const dns_name_t *name1, const dns_name_t *name2) {
 	return (order);
 }
 
-isc_boolean_t
+bool
 dns_name_equal(const dns_name_t *name1, const dns_name_t *name2) {
 	unsigned int l, count;
 	unsigned char c;
@@ -668,22 +666,22 @@ dns_name_equal(const dns_name_t *name1, const dns_name_t *name2) {
 		(name2->attributes & DNS_NAMEATTR_ABSOLUTE));
 
 	if (ISC_UNLIKELY(name1 == name2))
-		return (ISC_TRUE);
+		return (true);
 
 	if (name1->length != name2->length)
-		return (ISC_FALSE);
+		return (false);
 
 	l = name1->labels;
 
 	if (l != name2->labels)
-		return (ISC_FALSE);
+		return (false);
 
 	label1 = name1->ndata;
 	label2 = name2->ndata;
 	while (ISC_LIKELY(l-- > 0)) {
 		count = *label1++;
 		if (count != *label2++)
-			return (ISC_FALSE);
+			return (false);
 
 		INSIST(count <= 63); /* no bitstring support */
 
@@ -691,16 +689,16 @@ dns_name_equal(const dns_name_t *name1, const dns_name_t *name2) {
 		while (ISC_LIKELY(count > 3)) {
 			c = maptolower[label1[0]];
 			if (c != maptolower[label2[0]])
-				return (ISC_FALSE);
+				return (false);
 			c = maptolower[label1[1]];
 			if (c != maptolower[label2[1]])
-				return (ISC_FALSE);
+				return (false);
 			c = maptolower[label1[2]];
 			if (c != maptolower[label2[2]])
-				return (ISC_FALSE);
+				return (false);
 			c = maptolower[label1[3]];
 			if (c != maptolower[label2[3]])
-				return (ISC_FALSE);
+				return (false);
 			count -= 4;
 			label1 += 4;
 			label2 += 4;
@@ -708,14 +706,14 @@ dns_name_equal(const dns_name_t *name1, const dns_name_t *name2) {
 		while (ISC_LIKELY(count-- > 0)) {
 			c = maptolower[*label1++];
 			if (c != maptolower[*label2++])
-				return (ISC_FALSE);
+				return (false);
 		}
 	}
 
-	return (ISC_TRUE);
+	return (true);
 }
 
-isc_boolean_t
+bool
 dns_name_caseequal(const dns_name_t *name1, const dns_name_t *name2) {
 
 	/*
@@ -736,12 +734,12 @@ dns_name_caseequal(const dns_name_t *name1, const dns_name_t *name2) {
 		(name2->attributes & DNS_NAMEATTR_ABSOLUTE));
 
 	if (name1->length != name2->length)
-		return (ISC_FALSE);
+		return (false);
 
 	if (memcmp(name1->ndata, name2->ndata, name1->length) != 0)
-		return (ISC_FALSE);
+		return (false);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 int
@@ -802,7 +800,7 @@ dns_name_rdatacompare(const dns_name_t *name1, const dns_name_t *name2) {
 	return (0);
 }
 
-isc_boolean_t
+bool
 dns_name_issubdomain(const dns_name_t *name1, const dns_name_t *name2) {
 	int order;
 	unsigned int nlabels;
@@ -820,12 +818,12 @@ dns_name_issubdomain(const dns_name_t *name1, const dns_name_t *name2) {
 	namereln = dns_name_fullcompare(name1, name2, &order, &nlabels);
 	if (namereln == dns_namereln_subdomain ||
 	    namereln == dns_namereln_equal)
-		return (ISC_TRUE);
+		return (true);
 
-	return (ISC_FALSE);
+	return (false);
 }
 
-isc_boolean_t
+bool
 dns_name_matcheswildcard(const dns_name_t *name, const dns_name_t *wname) {
 	int order;
 	unsigned int nlabels, labels;
@@ -846,8 +844,8 @@ dns_name_matcheswildcard(const dns_name_t *name, const dns_name_t *wname) {
 	dns_name_getlabelsequence(wname, 1, labels - 1, &tname);
 	if (dns_name_fullcompare(name, &tname, &order, &nlabels) ==
 	    dns_namereln_subdomain)
-		return (ISC_TRUE);
-	return (ISC_FALSE);
+		return (true);
+	return (false);
 }
 
 unsigned int
@@ -1042,10 +1040,10 @@ dns_name_fromtext(dns_name_t *name, isc_buffer_t *source,
 	unsigned int value = 0, count = 0;
 	unsigned int n1 = 0, n2 = 0;
 	unsigned int tlen, nrem, nused, digits = 0, labels, tused;
-	isc_boolean_t done;
+	bool done;
 	unsigned char *offsets;
 	dns_offsets_t odata;
-	isc_boolean_t downcase;
+	bool downcase;
 
 	/*
 	 * Convert the textual representation of a DNS name at source
@@ -1062,7 +1060,7 @@ dns_name_fromtext(dns_name_t *name, isc_buffer_t *source,
 	REQUIRE((target != NULL && ISC_BUFFER_VALID(target)) ||
 		(target == NULL && ISC_BUFFER_VALID(name->buffer)));
 
-	downcase = ISC_TF((options & DNS_NAME_DOWNCASE) != 0);
+	downcase = (options & DNS_NAME_DOWNCASE);
 
 	if (target == NULL && name->buffer != NULL) {
 		target = name->buffer;
@@ -1091,7 +1089,7 @@ dns_name_fromtext(dns_name_t *name, isc_buffer_t *source,
 		nrem = 255;
 	nused = 0;
 	labels = 0;
-	done = ISC_FALSE;
+	done = false;
 	state = ft_init;
 
 	while (nrem > 0 && tlen > 0 && !done) {
@@ -1111,7 +1109,7 @@ dns_name_fromtext(dns_name_t *name, isc_buffer_t *source,
 				*ndata++ = 0;
 				nrem--;
 				nused++;
-				done = ISC_TRUE;
+				done = true;
 				break;
 			}
 			if (c == '@' && tlen == 0) {
@@ -1147,7 +1145,7 @@ dns_name_fromtext(dns_name_t *name, isc_buffer_t *source,
 					*ndata++ = 0;
 					nrem--;
 					nused++;
-					done = ISC_TRUE;
+					done = true;
 				}
 				state = ft_start;
 			} else if (c == '\\') {
@@ -1275,7 +1273,6 @@ dns_name_fromtext(dns_name_t *name, isc_buffer_t *source,
 	return (ISC_R_SUCCESS);
 }
 
-#ifdef ISC_PLATFORM_USETHREADS
 static void
 free_specific(void *arg) {
 	dns_name_totextfilter_t *mem = arg;
@@ -1308,7 +1305,7 @@ totext_filter_proc_key_init(void) {
 		if (result != ISC_R_SUCCESS)
 			goto unlock;
 		isc_mem_setname(thread_key_mctx, "threadkey", NULL);
-		isc_mem_setdestroycheck(thread_key_mctx, ISC_FALSE);
+		isc_mem_setdestroycheck(thread_key_mctx, false);
 
 		if (!thread_key_initialized &&
 		     isc_thread_key_create(&totext_filter_proc_key,
@@ -1322,10 +1319,9 @@ totext_filter_proc_key_init(void) {
 	}
 	return (result);
 }
-#endif
 
 isc_result_t
-dns_name_totext(const dns_name_t *name, isc_boolean_t omit_final_dot,
+dns_name_totext(const dns_name_t *name, bool omit_final_dot,
 		isc_buffer_t *target)
 {
 	unsigned int options = DNS_NAME_MASTERFILE;
@@ -1350,15 +1346,12 @@ dns_name_totext2(const dns_name_t *name, unsigned int options,
 	unsigned char c;
 	unsigned int trem, count;
 	unsigned int labels;
-	isc_boolean_t saw_root = ISC_FALSE;
+	bool saw_root = false;
 	unsigned int oused = target->used;
-#ifdef ISC_PLATFORM_USETHREADS
 	dns_name_totextfilter_t *mem;
 	dns_name_totextfilter_t totext_filter_proc = NULL;
 	isc_result_t result;
-#endif
-	isc_boolean_t omit_final_dot =
-		ISC_TF(options & DNS_NAME_OMITFINALDOT);
+	bool omit_final_dot = (options & DNS_NAME_OMITFINALDOT);
 
 	/*
 	 * This function assumes the name is in proper uncompressed
@@ -1367,11 +1360,9 @@ dns_name_totext2(const dns_name_t *name, unsigned int options,
 	REQUIRE(VALID_NAME(name));
 	REQUIRE(ISC_BUFFER_VALID(target));
 
-#ifdef ISC_PLATFORM_USETHREADS
 	result = totext_filter_proc_key_init();
 	if (result != ISC_R_SUCCESS)
 		return (result);
-#endif
 	ndata = name->ndata;
 	nlen = name->length;
 	labels = name->labels;
@@ -1394,8 +1385,8 @@ dns_name_totext2(const dns_name_t *name, unsigned int options,
 		 * They need to be set this way, though, to keep the "@"
 		 * from being trounced.
 		 */
-		saw_root = ISC_TRUE;
-		omit_final_dot = ISC_FALSE;
+		saw_root = true;
+		omit_final_dot = false;
 		*tdata++ = '@';
 		trem--;
 
@@ -1410,8 +1401,8 @@ dns_name_totext2(const dns_name_t *name, unsigned int options,
 		if (trem == 0)
 			return (ISC_R_NOSPACE);
 
-		saw_root = ISC_TRUE;
-		omit_final_dot = ISC_FALSE;
+		saw_root = true;
+		omit_final_dot = false;
 		*tdata++ = '.';
 		trem--;
 
@@ -1426,7 +1417,7 @@ dns_name_totext2(const dns_name_t *name, unsigned int options,
 		count = *ndata++;
 		nlen--;
 		if (count == 0) {
-			saw_root = ISC_TRUE;
+			saw_root = true;
 			break;
 		}
 		if (count < 64) {
@@ -1511,19 +1502,17 @@ dns_name_totext2(const dns_name_t *name, unsigned int options,
 	}
 	isc_buffer_add(target, tlen - trem);
 
-#ifdef ISC_PLATFORM_USETHREADS
 	mem = isc_thread_key_getspecific(totext_filter_proc_key);
 	if (mem != NULL)
 		totext_filter_proc = *mem;
-#endif
 	if (totext_filter_proc != NULL)
-		return ((*totext_filter_proc)(target, oused, saw_root));
+		return ((*totext_filter_proc)(target, oused));
 
 	return (ISC_R_SUCCESS);
 }
 
 isc_result_t
-dns_name_tofilenametext(const dns_name_t *name, isc_boolean_t omit_final_dot,
+dns_name_tofilenametext(const dns_name_t *name, bool omit_final_dot,
 			isc_buffer_t *target)
 {
 	unsigned char *ndata;
@@ -1556,7 +1545,7 @@ dns_name_tofilenametext(const dns_name_t *name, isc_boolean_t omit_final_dot,
 		if (trem == 0)
 			return (ISC_R_NOSPACE);
 
-		omit_final_dot = ISC_FALSE;
+		omit_final_dot = false;
 		*tdata++ = '.';
 		trem--;
 
@@ -1713,13 +1702,13 @@ set_offsets(const dns_name_t *name, unsigned char *offsets,
 {
 	unsigned int offset, count, length, nlabels;
 	unsigned char *ndata;
-	isc_boolean_t absolute;
+	bool absolute;
 
 	ndata = name->ndata;
 	length = name->length;
 	offset = 0;
 	nlabels = 0;
-	absolute = ISC_FALSE;
+	absolute = false;
 	while (ISC_LIKELY(offset != length)) {
 		INSIST(nlabels < 128);
 		offsets[nlabels++] = offset;
@@ -1729,7 +1718,7 @@ set_offsets(const dns_name_t *name, unsigned char *offsets,
 		ndata += count + 1;
 		INSIST(offset <= length);
 		if (ISC_UNLIKELY(count == 0)) {
-			absolute = ISC_TRUE;
+			absolute = true;
 			break;
 		}
 	}
@@ -1756,13 +1745,13 @@ dns_name_fromwire(dns_name_t *name, isc_buffer_t *source,
 	unsigned int cused; /* Bytes of compressed name data used */
 	unsigned int nused, labels, n, nmax;
 	unsigned int current, new_current, biggest_pointer;
-	isc_boolean_t done;
+	bool done;
 	fw_state state = fw_start;
 	unsigned int c;
 	unsigned char *offsets;
 	dns_offsets_t odata;
-	isc_boolean_t downcase;
-	isc_boolean_t seen_pointer;
+	bool downcase;
+	bool seen_pointer;
 
 	/*
 	 * Copy the possibly-compressed name at source into target,
@@ -1774,7 +1763,7 @@ dns_name_fromwire(dns_name_t *name, isc_buffer_t *source,
 	REQUIRE((target != NULL && ISC_BUFFER_VALID(target)) ||
 		(target == NULL && ISC_BUFFER_VALID(name->buffer)));
 
-	downcase = ISC_TF((options & DNS_NAME_DOWNCASE) != 0);
+	downcase = (options & DNS_NAME_DOWNCASE);
 
 	if (target == NULL && name->buffer != NULL) {
 		target = name->buffer;
@@ -1801,11 +1790,11 @@ dns_name_fromwire(dns_name_t *name, isc_buffer_t *source,
 	 * Set up.
 	 */
 	labels = 0;
-	done = ISC_FALSE;
+	done = false;
 
 	ndata = isc_buffer_used(target);
 	nused = 0;
-	seen_pointer = ISC_FALSE;
+	seen_pointer = false;
 
 	/*
 	 * Find the maximum number of uncompressed target name
@@ -1844,7 +1833,7 @@ dns_name_fromwire(dns_name_t *name, isc_buffer_t *source,
 				nused += c + 1;
 				*ndata++ = c;
 				if (c == 0)
-					done = ISC_TRUE;
+					done = true;
 				n = c;
 				state = fw_ordinary;
 			} else if (c >= 128 && c < 192) {
@@ -1882,7 +1871,7 @@ dns_name_fromwire(dns_name_t *name, isc_buffer_t *source,
 			biggest_pointer = new_current;
 			current = new_current;
 			cdata = (unsigned char *)source->base + current;
-			seen_pointer = ISC_TRUE;
+			seen_pointer = true;
 			state = fw_start;
 			break;
 		default:
@@ -1929,13 +1918,13 @@ dns_name_towire(const dns_name_t *name, dns_compress_t *cctx,
 
 isc_result_t
 dns_name_towire2(const dns_name_t *name, dns_compress_t *cctx,
-		 isc_buffer_t *target, isc_uint16_t *comp_offsetp)
+		 isc_buffer_t *target, uint16_t *comp_offsetp)
 {
 	unsigned int methods;
-	isc_uint16_t offset;
+	uint16_t offset;
 	dns_name_t gp;	/* Global compression prefix */
-	isc_boolean_t gf;	/* Global compression target found */
-	isc_uint16_t go;	/* Global compression offset */
+	bool gf;	/* Global compression target found */
+	uint16_t go;	/* Global compression offset */
 	dns_offsets_t clo;
 	dns_name_t clname;
 
@@ -1986,20 +1975,20 @@ dns_name_towire2(const dns_name_t *name, dns_compress_t *cctx,
 	    (methods & DNS_COMPRESS_GLOBAL14) != 0)
 		gf = dns_compress_findglobal(cctx, name, &gp, &go);
 	else
-		gf = ISC_FALSE;
+		gf = false;
 
 	/*
 	 * If the offset is too high for 14 bit global compression, we're
 	 * out of luck.
 	 */
 	if (gf && ISC_UNLIKELY(go >= 0x4000))
-		gf = ISC_FALSE;
+		gf = false;
 
 	/*
 	 * Will the compression pointer reduce the message size?
 	 */
 	if (gf && (gp.length + 2) >= name->length)
-		gf = ISC_FALSE;
+		gf = false;
 
 	if (gf) {
 		if (ISC_UNLIKELY(target->length - target->used < gp.length))
@@ -2043,9 +2032,9 @@ dns_name_concatenate(const dns_name_t *prefix, const dns_name_t *suffix,
 {
 	unsigned char *ndata, *offsets;
 	unsigned int nrem, labels, prefix_length, length;
-	isc_boolean_t copy_prefix = ISC_TRUE;
-	isc_boolean_t copy_suffix = ISC_TRUE;
-	isc_boolean_t absolute = ISC_FALSE;
+	bool copy_prefix = true;
+	bool copy_suffix = true;
+	bool absolute = false;
 	dns_name_t tmp_name;
 	dns_offsets_t odata;
 
@@ -2059,12 +2048,12 @@ dns_name_concatenate(const dns_name_t *prefix, const dns_name_t *suffix,
 	REQUIRE((target != NULL && ISC_BUFFER_VALID(target)) ||
 		(target == NULL && name != NULL && ISC_BUFFER_VALID(name->buffer)));
 	if (prefix == NULL || prefix->labels == 0)
-		copy_prefix = ISC_FALSE;
+		copy_prefix = false;
 	if (suffix == NULL || suffix->labels == 0)
-		copy_suffix = ISC_FALSE;
+		copy_suffix = false;
 	if (copy_prefix &&
 	    (prefix->attributes & DNS_NAMEATTR_ABSOLUTE) != 0) {
-		absolute = ISC_TRUE;
+		absolute = true;
 		REQUIRE(!copy_suffix);
 	}
 	if (name == NULL) {
@@ -2109,7 +2098,7 @@ dns_name_concatenate(const dns_name_t *prefix, const dns_name_t *suffix,
 
 	if (copy_suffix) {
 		if ((suffix->attributes & DNS_NAMEATTR_ABSOLUTE) != 0)
-			absolute = ISC_TRUE;
+			absolute = true;
 		memmove(ndata + prefix_length, suffix->ndata, suffix->length);
 	}
 
@@ -2300,7 +2289,7 @@ dns_name_digest(const dns_name_t *name, dns_digestfunc_t digest, void *arg) {
 	return ((digest)(arg, &r));
 }
 
-isc_boolean_t
+bool
 dns_name_dynamic(const dns_name_t *name) {
 	REQUIRE(VALID_NAME(name));
 
@@ -2309,7 +2298,7 @@ dns_name_dynamic(const dns_name_t *name) {
 	 */
 
 	return ((name->attributes & DNS_NAMEATTR_DYNAMIC) != 0 ?
-		ISC_TRUE : ISC_FALSE);
+		true : false);
 }
 
 isc_result_t
@@ -2326,7 +2315,7 @@ dns_name_print(const dns_name_t *name, FILE *stream) {
 	REQUIRE(VALID_NAME(name));
 
 	isc_buffer_init(&b, t, sizeof(t));
-	result = dns_name_totext(name, ISC_FALSE, &b);
+	result = dns_name_totext(name, false, &b);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 	isc_buffer_usedregion(&b, &r);
@@ -2337,7 +2326,6 @@ dns_name_print(const dns_name_t *name, FILE *stream) {
 
 isc_result_t
 dns_name_settotextfilter(dns_name_totextfilter_t proc) {
-#ifdef ISC_PLATFORM_USETHREADS
 	isc_result_t result;
 	dns_name_totextfilter_t *mem;
 	int res;
@@ -2373,10 +2361,6 @@ dns_name_settotextfilter(dns_name_totextfilter_t proc) {
 		result = ISC_R_UNEXPECTED;
 	}
 	return (result);
-#else
-	totext_filter_proc = proc;
-	return (ISC_R_SUCCESS);
-#endif
 }
 
 void
@@ -2390,7 +2374,7 @@ dns_name_format(const dns_name_t *name, char *cp, unsigned int size) {
 	 * Leave room for null termination after buffer.
 	 */
 	isc_buffer_init(&buf, cp, size - 1);
-	result = dns_name_totext(name, ISC_TRUE, &buf);
+	result = dns_name_totext(name, true, &buf);
 	if (result == ISC_R_SUCCESS) {
 		/*
 		 * Null terminate.
@@ -2418,7 +2402,7 @@ dns_name_tostring(const dns_name_t *name, char **target, isc_mem_t *mctx) {
 	REQUIRE(target != NULL && *target == NULL);
 
 	isc_buffer_init(&buf, txt, sizeof(txt));
-	result = dns_name_totext(name, ISC_FALSE, &buf);
+	result = dns_name_totext(name, false, &buf);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 
@@ -2526,7 +2510,6 @@ dns_name_copy(const dns_name_t *source, dns_name_t *dest, isc_buffer_t *target)
 
 void
 dns_name_destroy(void) {
-#ifdef ISC_PLATFORM_USETHREADS
 	RUNTIME_CHECK(isc_once_do(&once, thread_key_mutex_init)
 				  == ISC_R_SUCCESS);
 
@@ -2538,7 +2521,6 @@ dns_name_destroy(void) {
 	}
 	UNLOCK(&thread_key_mutex);
 
-#endif
 }
 
 /*
@@ -2563,7 +2545,7 @@ static dns_name_t const dns_sd[] = {
 	DNS_NAME_INITNONABSOLUTE(lb_dns_sd_udp_data, lb_dns_sd_udp_offsets)
 };
 
-isc_boolean_t
+bool
 dns_name_isdnssd(const dns_name_t *name) {
 	size_t i;
 	dns_name_t prefix;
@@ -2573,10 +2555,10 @@ dns_name_isdnssd(const dns_name_t *name) {
 		dns_name_getlabelsequence(name, 0, 3, &prefix);
 		for (i = 0; i < (sizeof(dns_sd)/sizeof(dns_sd[0])); i++)
 			if (dns_name_equal(&prefix, &dns_sd[i]))
-				return (ISC_TRUE);
+				return (true);
 	}
 
-	return (ISC_FALSE);
+	return (false);
 }
 
 static unsigned char inaddr10_offsets[] = { 0, 3, 11, 16 };
@@ -2625,14 +2607,14 @@ static dns_name_t const rfc1918names[] = {
 	DNS_NAME_INITABSOLUTE(inaddr168192, inaddr192_offsets)
 };
 
-isc_boolean_t
+bool
 dns_name_isrfc1918(const dns_name_t *name) {
 	size_t i;
 
 	for (i = 0; i < (sizeof(rfc1918names)/sizeof(*rfc1918names)); i++)
 		if (dns_name_issubdomain(name, &rfc1918names[i]))
-			return (ISC_TRUE);
-	return (ISC_FALSE);
+			return (true);
+	return (false);
 }
 
 static unsigned char ulaoffsets[] = { 0, 2, 4, 8, 13 };
@@ -2644,14 +2626,14 @@ static dns_name_t const ulanames[] = {
 	DNS_NAME_INITABSOLUTE(ip6fd, ulaoffsets)
 };
 
-isc_boolean_t
+bool
 dns_name_isula(const dns_name_t *name) {
 	size_t i;
 
 	for (i = 0; i < (sizeof(ulanames)/sizeof(*ulanames)); i++)
 		if (dns_name_issubdomain(name, &ulanames[i]))
-			return (ISC_TRUE);
-	return (ISC_FALSE);
+			return (true);
+	return (false);
 }
 
 /*
@@ -2670,7 +2652,7 @@ ishex[256] = {
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
 };
 
-isc_boolean_t
+bool
 dns_name_istat(const dns_name_t *name) {
 	unsigned char len;
 	const unsigned char *ndata;
@@ -2678,7 +2660,7 @@ dns_name_istat(const dns_name_t *name) {
 	REQUIRE(VALID_NAME(name));
 
 	if (name->labels < 1)
-		return (ISC_FALSE);
+		return (false);
 
 	ndata = name->ndata;
 	len = ndata[0];
@@ -2687,16 +2669,16 @@ dns_name_istat(const dns_name_t *name) {
 
 	/*
 	 * Is there at least one trust anchor reported and is the
-	 * label length consistent with a trust-anchor-telementry label.
+	 * label length consistent with a trust-anchor-telemetry label.
 	 */
 	if ((len < 8) || (len - 3) % 5 != 0) {
-		return (ISC_FALSE);
+		return (false);
 	}
 
 	if (ndata[0] != '_' ||
 	    maptolower[ndata[1]] != 't' ||
 	    maptolower[ndata[2]] != 'a') {
-		return (ISC_FALSE);
+		return (false);
 	}
 	ndata += 3;
 	len -= 3;
@@ -2705,10 +2687,10 @@ dns_name_istat(const dns_name_t *name) {
 		INSIST(len >= 5);
 		if (ndata[0] != '-' || !ishex[ndata[1]] || !ishex[ndata[2]] ||
 		    !ishex[ndata[3]] || !ishex[ndata[4]]) {
-			return (ISC_FALSE);
+			return (false);
 		}
 		ndata += 5;
 		len -= 5;
 	}
-	return (ISC_TRUE);
+	return (true);
 }
