@@ -208,9 +208,10 @@ dns_nsec3_typepresent(dns_rdata_t *rdata, dns_rdatatype_t type) {
 			break;
 		if ((window + 1) * 256 <= type)
 			continue;
-		if (type < (window * 256) + len * 8)
+		if (type < (window * 256) + len * 8) {
 			present = dns_nsec_isset(&nsec3.typebits[i],
 						 type % 256);
+		}
 		break;
 	}
 	dns_rdata_freestruct(&nsec3);
@@ -1809,18 +1810,8 @@ dns_nsec3_maxiterations(dns_db_t *db, dns_dbversion_t *version,
 	     result == ISC_R_SUCCESS;
 	     result = dns_rdataset_next(&rdataset)) {
 		dns_rdata_t rdata = DNS_RDATA_INIT;
+
 		dns_rdataset_current(&rdataset, &rdata);
-
-		REQUIRE(rdata.type == dns_rdatatype_key ||
-			rdata.type == dns_rdatatype_dnskey);
-		REQUIRE(rdata.length > 3);
-
-		/* Skip unsupported algorithms when
-		 * calculating the maximum iterations.
-		 */
-		if (!dst_algorithm_supported(rdata.data[3]))
-			continue;
-
 		isc_buffer_init(&buffer, rdata.data, rdata.length);
 		isc_buffer_add(&buffer, rdata.length);
 		CHECK(dst_key_fromdns(dns_db_origin(db), rdataset.rdclass,
@@ -1968,7 +1959,7 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, const dns_name_t *name,
 	 * Work out what this NSEC3 covers.
 	 * Inside (<0) or outside (>=0).
 	 */
-	scope = isc_safe_memcompare(owner, nsec3.next, nsec3.next_length);
+	scope = memcmp(owner, nsec3.next, nsec3.next_length);
 
 	/*
 	 * Prepare to compute all the hashes.
@@ -1992,7 +1983,7 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, const dns_name_t *name,
 			return (ISC_R_IGNORE);
 		}
 
-		order = isc_safe_memcompare(hash, owner, length);
+		order = memcmp(hash, owner, length);
 		if (first && order == 0) {
 			/*
 			 * The hashes are the same.
@@ -2108,12 +2099,13 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, const dns_name_t *name,
 			*exists = false;
 			*data = false;
 			if (optout != NULL) {
-				*optout = ((nsec3.flags & DNS_NSEC3FLAG_OPTOUT)
-					   != 0);
-				(*logit)(arg, ISC_LOG_DEBUG(3),
-					 (*optout
-					  ? "NSEC3 indicates optout"
-					  : "NSEC3 indicates secure range"));
+				if ((nsec3.flags & DNS_NSEC3FLAG_OPTOUT) != 0)
+					(*logit)(arg, ISC_LOG_DEBUG(3),
+						 "NSEC3 indicates optout");
+				else
+					(*logit)(arg, ISC_LOG_DEBUG(3),
+						 "NSEC3 indicates secure range");
+				*optout = (nsec3.flags & DNS_NSEC3FLAG_OPTOUT);
 			}
 			answer = ISC_R_SUCCESS;
 		}
