@@ -23,15 +23,15 @@
  * IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include <config.h>
+/*! \file */
 
-#if HAVE_OPENSSL
+#include <config.h>
 
 #include <pk11/site.h>
 
-#ifndef PK11_DH_DISABLE
-
 #include <ctype.h>
+#include <inttypes.h>
+#include <stdbool.h>
 
 #include <isc/mem.h>
 #include <isc/safe.h>
@@ -71,7 +71,7 @@ static isc_result_t openssldh_todns(const dst_key_t *key, isc_buffer_t *data);
 
 static BIGNUM *bn2 = NULL, *bn768 = NULL, *bn1024 = NULL, *bn1536 = NULL;
 
-#if !defined(HAVE_DH_GET0_KEY)
+#if !HAVE_DH_GET0_KEY
 /*
  * DH_get0_key, DH_set0_key, DH_get0_pqg and DH_set0_pqg
  * are from OpenSSL 1.1.0.
@@ -150,7 +150,7 @@ DH_set0_pqg(DH *dh, BIGNUM *p, BIGNUM *q, BIGNUM *g)
 
 #define DH_clear_flags(d, f) (d)->flags &= ~(f)
 
-#endif
+#endif /* !HAVE_DH_GET0_KEY */
 
 static isc_result_t
 openssldh_computesecret(const dst_key_t *pub, const dst_key_t *priv,
@@ -182,7 +182,7 @@ openssldh_computesecret(const dst_key_t *pub, const dst_key_t *priv,
 	return (ISC_R_SUCCESS);
 }
 
-static isc_boolean_t
+static bool
 openssldh_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	DH *dh1, *dh2;
 	const BIGNUM *pub_key1 = NULL, *pub_key2 = NULL;
@@ -193,9 +193,9 @@ openssldh_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	dh2 = key2->keydata.dh;
 
 	if (dh1 == NULL && dh2 == NULL)
-		return (ISC_TRUE);
+		return (true);
 	else if (dh1 == NULL || dh2 == NULL)
-		return (ISC_FALSE);
+		return (false);
 
 	DH_get0_key(dh1, &pub_key1, &priv_key1);
 	DH_get0_key(dh2, &pub_key2, &priv_key2);
@@ -204,18 +204,18 @@ openssldh_compare(const dst_key_t *key1, const dst_key_t *key2) {
 
 	if (BN_cmp(p1, p2) != 0 || BN_cmp(g1, g2) != 0 ||
 	    BN_cmp(pub_key1, pub_key2) != 0)
-		return (ISC_FALSE);
+		return (false);
 
 	if (priv_key1 != NULL || priv_key2 != NULL) {
 		if (priv_key1 == NULL || priv_key2 == NULL)
-			return (ISC_FALSE);
+			return (false);
 		if (BN_cmp(priv_key1, priv_key2) != 0)
-			return (ISC_FALSE);
+			return (false);
 	}
-	return (ISC_TRUE);
+	return (true);
 }
 
-static isc_boolean_t
+static bool
 openssldh_paramcompare(const dst_key_t *key1, const dst_key_t *key2) {
 	DH *dh1, *dh2;
 	const BIGNUM *p1 = NULL, *g1 = NULL, *p2 = NULL, *g2 = NULL;
@@ -224,16 +224,16 @@ openssldh_paramcompare(const dst_key_t *key1, const dst_key_t *key2) {
 	dh2 = key2->keydata.dh;
 
 	if (dh1 == NULL && dh2 == NULL)
-		return (ISC_TRUE);
+		return (true);
 	else if (dh1 == NULL || dh2 == NULL)
-		return (ISC_FALSE);
+		return (false);
 
 	DH_get0_pqg(dh1, &p1, NULL, &g1);
 	DH_get0_pqg(dh2, &p2, NULL, &g2);
 
 	if (BN_cmp(p1, p2) != 0 || BN_cmp(g1, g2) != 0)
-		return (ISC_FALSE);
-	return (ISC_TRUE);
+		return (false);
+	return (true);
 }
 
 static int
@@ -332,13 +332,13 @@ openssldh_generate(dst_key_t *key, int generator, void (*callback)(int)) {
 	return (ISC_R_SUCCESS);
 }
 
-static isc_boolean_t
+static bool
 openssldh_isprivate(const dst_key_t *key) {
 	DH *dh = key->keydata.dh;
 	const BIGNUM *priv_key = NULL;
 
 	DH_get0_key(dh, NULL, &priv_key);
-	return (ISC_TF(dh != NULL && priv_key != NULL));
+	return (dh != NULL && priv_key != NULL);
 }
 
 static void
@@ -353,16 +353,16 @@ openssldh_destroy(dst_key_t *key) {
 }
 
 static void
-uint16_toregion(isc_uint16_t val, isc_region_t *region) {
+uint16_toregion(uint16_t val, isc_region_t *region) {
 	*region->base = (val & 0xff00) >> 8;
 	isc_region_consume(region, 1);
 	*region->base = (val & 0x00ff);
 	isc_region_consume(region, 1);
 }
 
-static isc_uint16_t
+static uint16_t
 uint16_fromregion(isc_region_t *region) {
-	isc_uint16_t val;
+	uint16_t val;
 	unsigned char *cp = region->base;
 
 	val = ((unsigned int)(cp[0])) << 8;
@@ -378,7 +378,7 @@ openssldh_todns(const dst_key_t *key, isc_buffer_t *data) {
 	DH *dh;
 	const BIGNUM *pub_key = NULL, *p = NULL, *g = NULL;
 	isc_region_t r;
-	isc_uint16_t dnslen, plen, glen, publen;
+	uint16_t dnslen, plen, glen, publen;
 
 	REQUIRE(key->keydata.dh != NULL);
 
@@ -435,7 +435,7 @@ openssldh_fromdns(dst_key_t *key, isc_buffer_t *data) {
 	DH *dh;
 	BIGNUM *pub_key = NULL, *p = NULL, *g = NULL;
 	isc_region_t r;
-	isc_uint16_t plen, glen, publen;
+	uint16_t plen, glen, publen;
 	int special = 0;
 
 	isc_buffer_remainingregion(data, &r);
@@ -763,13 +763,3 @@ dst__openssldh_init(dst_func_t **funcp) {
 	if (bn1536 != NULL) BN_free(bn1536);
 	return (ISC_R_NOMEMORY);
 }
-#endif /* !PK11_DH_DISABLE */
-
-#else /* HAVE_OPENSSL */
-
-#include <isc/util.h>
-
-EMPTY_TRANSLATION_UNIT
-
-#endif /* HAVE_OPENSSL */
-/*! \file */
