@@ -13,6 +13,8 @@
 
 #include <config.h>
 
+#include <stdbool.h>
+
 #include <isc/magic.h>
 #include <isc/mem.h>
 #include <isc/netaddr.h>
@@ -37,7 +39,7 @@
 
 struct dns_ssurule {
 	unsigned int magic;
-	isc_boolean_t grant;		/*%< is this a grant or a deny? */
+	bool grant;		/*%< is this a grant or a deny? */
 	dns_ssumatchtype_t matchtype;	/*%< which type of pattern match? */
 	dns_name_t *identity;		/*%< the identity to match */
 	dns_name_t *name;		/*%< the name being updated */
@@ -130,7 +132,7 @@ dns_ssutable_attach(dns_ssutable_t *source, dns_ssutable_t **targetp) {
 void
 dns_ssutable_detach(dns_ssutable_t **tablep) {
 	dns_ssutable_t *table;
-	isc_boolean_t done = ISC_FALSE;
+	bool done = false;
 
 	REQUIRE(tablep != NULL);
 	table = *tablep;
@@ -140,7 +142,7 @@ dns_ssutable_detach(dns_ssutable_t **tablep) {
 
 	INSIST(table->references > 0);
 	if (--table->references == 0)
-		done = ISC_TRUE;
+		done = true;
 	UNLOCK(&table->lock);
 
 	*tablep = NULL;
@@ -150,7 +152,7 @@ dns_ssutable_detach(dns_ssutable_t **tablep) {
 }
 
 isc_result_t
-dns_ssutable_addrule(dns_ssutable_t *table, isc_boolean_t grant,
+dns_ssutable_addrule(dns_ssutable_t *table, bool grant,
 		     const dns_name_t *identity, dns_ssumatchtype_t matchtype,
 		     const dns_name_t *name, unsigned int ntypes,
 		     dns_rdatatype_t *types)
@@ -237,11 +239,11 @@ dns_ssutable_addrule(dns_ssutable_t *table, isc_boolean_t grant,
 	return (result);
 }
 
-static inline isc_boolean_t
+static inline bool
 isusertype(dns_rdatatype_t type) {
-	return (ISC_TF(type != dns_rdatatype_ns &&
-		       type != dns_rdatatype_soa &&
-		       type != dns_rdatatype_rrsig));
+	return (type != dns_rdatatype_ns &&
+		type != dns_rdatatype_soa &&
+		type != dns_rdatatype_rrsig);
 }
 
 static void
@@ -338,10 +340,10 @@ stf_from_address(dns_name_t *stfself, const isc_netaddr_t *tcpaddr) {
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
 }
 
-isc_boolean_t
+bool
 dns_ssutable_checkrules(dns_ssutable_t *table, const dns_name_t *signer,
 			const dns_name_t *name, const isc_netaddr_t *addr,
-			isc_boolean_t tcp, const dns_aclenv_t *env,
+			bool tcp, const dns_aclenv_t *env,
 			dns_rdatatype_t type, const dst_key_t *key)
 {
 	dns_ssurule_t *rule;
@@ -359,7 +361,7 @@ dns_ssutable_checkrules(dns_ssutable_t *table, const dns_name_t *signer,
 	REQUIRE(addr == NULL || env != NULL);
 
 	if (signer == NULL && addr == NULL)
-		return (ISC_FALSE);
+		return (false);
 
 	for (rule = ISC_LIST_HEAD(table->rules);
 	     rule != NULL;
@@ -540,10 +542,10 @@ dns_ssutable_checkrules(dns_ssutable_t *table, const dns_name_t *signer,
 		return (rule->grant);
 	}
 
-	return (ISC_FALSE);
+	return (false);
 }
 
-isc_boolean_t
+bool
 dns_ssurule_isgrant(const dns_ssurule_t *rule) {
 	REQUIRE(VALID_SSURULE(rule));
 	return (rule->grant);
@@ -619,7 +621,7 @@ dns_ssutable_createdlz(isc_mem_t *mctx, dns_ssutable_t **tablep,
 	rule->identity = NULL;
 	rule->name = NULL;
 	rule->types = NULL;
-	rule->grant = ISC_TRUE;
+	rule->grant = true;
 	rule->matchtype = dns_ssumatchtype_dlz;
 	rule->ntypes = 0;
 	rule->types = NULL;
