@@ -15,6 +15,7 @@
 
 #include <atf-c.h>
 
+#include <stdbool.h>
 #include <unistd.h>
 
 #include <isc/print.h>
@@ -130,7 +131,7 @@ load_geoip(const char *dir) {
 		      method, "NetSpeed");
 }
 
-static isc_boolean_t
+static bool
 do_lookup_string(const char *addr, dns_geoip_subtype_t subtype,
 		 const char *string)
 {
@@ -147,7 +148,7 @@ do_lookup_string(const char *addr, dns_geoip_subtype_t subtype,
 	return (dns_geoip_match(&na, &geoip, &elt));
 }
 
-static isc_boolean_t
+static bool
 do_lookup_string_v6(const char *addr, dns_geoip_subtype_t subtype,
 		    const char *string)
 {
@@ -164,7 +165,7 @@ do_lookup_string_v6(const char *addr, dns_geoip_subtype_t subtype,
 	return (dns_geoip_match(&na, &geoip, &elt));
 }
 
-static isc_boolean_t
+static bool
 do_lookup_int(const char *addr, dns_geoip_subtype_t subtype, int id) {
 	dns_geoip_elem_t elt;
 	struct in_addr in4;
@@ -190,11 +191,11 @@ ATF_TC_HEAD(country, tc) {
 }
 ATF_TC_BODY(country, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
@@ -235,11 +236,11 @@ ATF_TC_HEAD(country_v6, tc) {
 }
 ATF_TC_BODY(country_v6, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
@@ -272,11 +273,11 @@ ATF_TC_HEAD(city, tc) {
 }
 ATF_TC_BODY(city, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
@@ -335,11 +336,11 @@ ATF_TC_HEAD(city_v6, tc) {
 }
 ATF_TC_BODY(city_v6, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
@@ -394,11 +395,11 @@ ATF_TC_HEAD(region, tc) {
 }
 ATF_TC_BODY(region, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
@@ -436,11 +437,11 @@ ATF_TC_HEAD(best, tc) {
 }
 ATF_TC_BODY(best, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
@@ -516,11 +517,11 @@ ATF_TC_HEAD(asnum, tc) {
 }
 ATF_TC_BODY(asnum, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
@@ -546,11 +547,11 @@ ATF_TC_HEAD(isp, tc) {
 }
 ATF_TC_BODY(isp, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
@@ -575,11 +576,11 @@ ATF_TC_HEAD(org, tc) {
 }
 ATF_TC_BODY(org, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
@@ -604,11 +605,11 @@ ATF_TC_HEAD(domain, tc) {
 }
 ATF_TC_BODY(domain, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
@@ -633,11 +634,11 @@ ATF_TC_HEAD(netspeed, tc) {
 }
 ATF_TC_BODY(netspeed, tc) {
 	isc_result_t result;
-	isc_boolean_t match;
+	bool match;
 
 	UNUSED(tc);
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE(result == ISC_R_SUCCESS);
 
 	/* Use databases from the geoip system test */
