@@ -9,23 +9,17 @@
  * information regarding copyright ownership.
  */
 
+/*! \file */
+
 #include <config.h>
 
-#if HAVE_CMOCKA
-
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-
 #include <inttypes.h>
-#include <sched.h> /* IWYU pragma: keep */
 #include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
-#define UNIT_TESTING
-#include <cmocka.h>
+#include <atf-c.h>
 
 #include <isc/buffer.h>
 #include <isc/commandline.h>
@@ -41,33 +35,15 @@
 
 #include "dnstest.h"
 
-/* Set to true (or use -v option) for verbose output */
-static bool verbose = false;
+/*
+ * Individual unit tests
+ */
 
-static int
-_setup(void **state) {
-	isc_result_t result;
-
-	UNUSED(state);
-
-	result = dns_test_begin(NULL, false);
-	assert_int_equal(result, ISC_R_SUCCESS);
-
-	return (0);
+ATF_TC(fullcompare);
+ATF_TC_HEAD(fullcompare, tc) {
+	atf_tc_set_md_var(tc, "descr", "dns_name_fullcompare test");
 }
-
-static int
-_teardown(void **state) {
-	UNUSED(state);
-
-	dns_test_end();
-
-	return (0);
-}
-
-/* dns_name_fullcompare test */
-static void
-fullcompare_test(void **state) {
+ATF_TC_BODY(fullcompare, tc) {
 	dns_fixedname_t fixed1;
 	dns_fixedname_t fixed2;
 	dns_name_t *name1;
@@ -108,7 +84,7 @@ fullcompare_test(void **state) {
 		{ NULL, NULL, dns_namereln_none, 0, 0 }
 	};
 
-	UNUSED(state);
+	UNUSED(tc);
 
 	name1 = dns_fixedname_initname(&fixed1);
 	name2 = dns_fixedname_initname(&fixed2);
@@ -121,28 +97,28 @@ fullcompare_test(void **state) {
 		} else {
 			result = dns_name_fromstring2(name1, data[i].name1,
 						      NULL, 0, NULL);
-			assert_int_equal(result, ISC_R_SUCCESS);
+			ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 		}
 		if (data[i].name2[0] == 0) {
 			dns_fixedname_init(&fixed2);
 		} else {
 			result = dns_name_fromstring2(name2, data[i].name2,
 						      NULL, 0, NULL);
-			assert_int_equal(result, ISC_R_SUCCESS);
+			ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 		}
 		relation = dns_name_fullcompare(name1, name1, &order, &nlabels);
-		assert_int_equal(relation, dns_namereln_equal);
-		assert_int_equal(order, 0);
-		assert_int_equal(nlabels, name1->labels);
+		ATF_REQUIRE_EQ(relation, dns_namereln_equal);
+		ATF_REQUIRE_EQ(order, 0);
+		ATF_REQUIRE_EQ(nlabels, name1->labels);
 
 		/* Some random initializer */
 		order = 3001;
 		nlabels = 3001;
 
 		relation = dns_name_fullcompare(name1, name2, &order, &nlabels);
-		assert_int_equal(relation, data[i].relation);
-		assert_int_equal(order, data[i].order);
-		assert_int_equal(nlabels, data[i].nlabels);
+		ATF_REQUIRE_EQ(relation, data[i].relation);
+		ATF_REQUIRE_EQ(order, data[i].order);
+		ATF_REQUIRE_EQ(nlabels, data[i].nlabels);
 	}
 }
 
@@ -160,32 +136,34 @@ compress_test(dns_name_t *name1, dns_name_t *name2, dns_name_t *name3,
 	isc_buffer_init(&source, buf1, sizeof(buf1));
 	isc_buffer_init(&target, buf2, sizeof(buf2));
 
-	assert_int_equal(dns_name_towire(name1, cctx, &source), ISC_R_SUCCESS);
+	ATF_REQUIRE_EQ(dns_name_towire(name1, cctx, &source), ISC_R_SUCCESS);
 
-	assert_int_equal(dns_name_towire(name2, cctx, &source), ISC_R_SUCCESS);
-	assert_int_equal(dns_name_towire(name2, cctx, &source), ISC_R_SUCCESS);
-	assert_int_equal(dns_name_towire(name3, cctx, &source), ISC_R_SUCCESS);
+	ATF_CHECK_EQ(dns_name_towire(name2, cctx, &source), ISC_R_SUCCESS);
+	ATF_CHECK_EQ(dns_name_towire(name2, cctx, &source), ISC_R_SUCCESS);
+	ATF_CHECK_EQ(dns_name_towire(name3, cctx, &source), ISC_R_SUCCESS);
 
 	isc_buffer_setactive(&source, source.used);
 
 	dns_name_init(&name, NULL);
-	RUNTIME_CHECK(dns_name_fromwire(&name, &source, dctx, 0,
+	RUNTIME_CHECK(dns_name_fromwire(&name, &source, dctx, false,
 					&target) == ISC_R_SUCCESS);
-	RUNTIME_CHECK(dns_name_fromwire(&name, &source, dctx, 0,
+	RUNTIME_CHECK(dns_name_fromwire(&name, &source, dctx, false,
 					&target) == ISC_R_SUCCESS);
-	RUNTIME_CHECK(dns_name_fromwire(&name, &source, dctx, 0,
+	RUNTIME_CHECK(dns_name_fromwire(&name, &source, dctx, false,
 					&target) == ISC_R_SUCCESS);
-	RUNTIME_CHECK(dns_name_fromwire(&name, &source, dctx, 0,
+	RUNTIME_CHECK(dns_name_fromwire(&name, &source, dctx, false,
 					&target) == ISC_R_SUCCESS);
 	dns_decompress_invalidate(dctx);
 
-	assert_int_equal(target.used, length);
-	assert_true(memcmp(target.base, expected, target.used) == 0);
+	ATF_CHECK_EQ(target.used, length);
+	ATF_CHECK(memcmp(target.base, expected, target.used) == 0);
 }
 
-/* name compression test */
-static void
-compression_test(void **state) {
+ATF_TC(compression);
+ATF_TC_HEAD(compression, tc) {
+	atf_tc_set_md_var(tc, "descr", "name compression test");
+}
+ATF_TC_BODY(compression, tc) {
 	unsigned int allowed;
 	dns_compress_t cctx;
 	dns_decompress_t dctx;
@@ -199,7 +177,7 @@ compression_test(void **state) {
 	unsigned char plain[] = "\003yyy\003foo\0\003bar\003yyy\003foo\0\003"
 				"bar\003yyy\003foo\0\003xxx\003bar\003foo";
 
-	UNUSED(state);
+	ATF_REQUIRE_EQ(dns_test_begin(NULL, false), ISC_R_SUCCESS);;
 
 	dns_name_init(&name1, NULL);
 	r.base = plain1;
@@ -218,7 +196,7 @@ compression_test(void **state) {
 
 	/* Test 1: NONE */
 	allowed = DNS_COMPRESS_NONE;
-	assert_int_equal(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
+	ATF_REQUIRE_EQ(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
 	dns_compress_setmethods(&cctx, allowed);
 	dns_decompress_init(&dctx, -1, DNS_DECOMPRESS_STRICT);
 	dns_decompress_setmethods(&dctx, allowed);
@@ -231,7 +209,7 @@ compression_test(void **state) {
 
 	/* Test2: GLOBAL14 */
 	allowed = DNS_COMPRESS_GLOBAL14;
-	assert_int_equal(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
+	ATF_REQUIRE_EQ(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
 	dns_compress_setmethods(&cctx, allowed);
 	dns_decompress_init(&dctx, -1, DNS_DECOMPRESS_STRICT);
 	dns_decompress_setmethods(&dctx, allowed);
@@ -244,7 +222,7 @@ compression_test(void **state) {
 
 	/* Test3: ALL */
 	allowed = DNS_COMPRESS_ALL;
-	assert_int_equal(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
+	ATF_REQUIRE_EQ(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
 	dns_compress_setmethods(&cctx, allowed);
 	dns_decompress_init(&dctx, -1, DNS_DECOMPRESS_STRICT);
 	dns_decompress_setmethods(&dctx, allowed);
@@ -257,7 +235,7 @@ compression_test(void **state) {
 
 	/* Test4: NONE disabled */
 	allowed = DNS_COMPRESS_NONE;
-	assert_int_equal(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
+	ATF_REQUIRE_EQ(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
 	dns_compress_setmethods(&cctx, allowed);
 	dns_compress_disable(&cctx);
 	dns_decompress_init(&dctx, -1, DNS_DECOMPRESS_STRICT);
@@ -271,7 +249,7 @@ compression_test(void **state) {
 
 	/* Test5: GLOBAL14 disabled */
 	allowed = DNS_COMPRESS_GLOBAL14;
-	assert_int_equal(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
+	ATF_REQUIRE_EQ(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
 	dns_compress_setmethods(&cctx, allowed);
 	dns_compress_disable(&cctx);
 	dns_decompress_init(&dctx, -1, DNS_DECOMPRESS_STRICT);
@@ -285,7 +263,7 @@ compression_test(void **state) {
 
 	/* Test6: ALL disabled */
 	allowed = DNS_COMPRESS_ALL;
-	assert_int_equal(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
+	ATF_REQUIRE_EQ(dns_compress_init(&cctx, -1, mctx), ISC_R_SUCCESS);
 	dns_compress_setmethods(&cctx, allowed);
 	dns_compress_disable(&cctx);
 	dns_decompress_init(&dctx, -1, DNS_DECOMPRESS_STRICT);
@@ -296,11 +274,15 @@ compression_test(void **state) {
 
 	dns_compress_rollback(&cctx, 0);
 	dns_compress_invalidate(&cctx);
+
+	dns_test_end();
 }
 
-/* is trust-anchor-telemetry test */
-static void
-istat_test(void **state) {
+ATF_TC(istat);
+ATF_TC_HEAD(istat, tc) {
+	atf_tc_set_md_var(tc, "descr", "is trust-anchor-telemetry test");
+}
+ATF_TC_BODY(istat, tc) {
 	dns_fixedname_t fixed;
 	dns_name_t *name;
 	isc_result_t result;
@@ -333,73 +315,74 @@ istat_test(void **state) {
 		{ "_ta-1234-abcf-EcD89.example", false }
 	};
 
-	UNUSED(state);
-
 	name = dns_fixedname_initname(&fixed);
 
-	for (i = 0; i < (sizeof(data) / sizeof(data[0])); i++) {
+	for (i = 0; i < sizeof(data)/sizeof(data[0]); i++) {
 		result = dns_name_fromstring(name, data[i].name, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
-		assert_int_equal(dns_name_istat(name), data[i].istat);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
+		ATF_CHECK_EQ_MSG(dns_name_istat(name), data[i].istat,
+				 "testing %s - expected %u", data[i].name, data[i].istat);
 	}
 }
 
-/* dns_nane_init */
-static void
-init_test(void **state) {
+ATF_TC(init);
+ATF_TC_HEAD(init, tc) {
+	atf_tc_set_md_var(tc, "descr", "dns_nane_init");
+}
+ATF_TC_BODY(init, tc) {
 	dns_name_t name;
 	unsigned char offsets[1];
 
-	UNUSED(state);
-
 	dns_name_init(&name, offsets);
 
-	assert_null(name.ndata);
-	assert_int_equal(name.length, 0);
-	assert_int_equal(name.labels, 0);
-	assert_int_equal(name.attributes, 0);
-	assert_int_equal(name.offsets, offsets);
-	assert_null(name.buffer);
+	ATF_CHECK_EQ(name.ndata, NULL);
+	ATF_CHECK_EQ(name.length, 0);
+	ATF_CHECK_EQ(name.labels, 0);
+	ATF_CHECK_EQ(name.attributes, 0);
+	ATF_CHECK_EQ(name.offsets, offsets);
+	ATF_CHECK_EQ(name.buffer, NULL);
 }
 
-/* dns_nane_invalidate */
-static void
-invalidate_test(void **state) {
+ATF_TC(invalidate);
+ATF_TC_HEAD(invalidate, tc) {
+	atf_tc_set_md_var(tc, "descr", "dns_nane_invalidate");
+}
+ATF_TC_BODY(invalidate, tc) {
 	dns_name_t name;
 	unsigned char offsets[1];
 
-	UNUSED(state);
-
 	dns_name_init(&name, offsets);
 	dns_name_invalidate(&name);
 
-	assert_null(name.ndata);
-	assert_int_equal(name.length, 0);
-	assert_int_equal(name.labels, 0);
-	assert_int_equal(name.attributes, 0);
-	assert_null(name.offsets);
-	assert_null(name.buffer);
+	ATF_CHECK_EQ(name.ndata, NULL);
+	ATF_CHECK_EQ(name.length, 0);
+	ATF_CHECK_EQ(name.labels, 0);
+	ATF_CHECK_EQ(name.attributes, 0);
+	ATF_CHECK_EQ(name.offsets, NULL);
+	ATF_CHECK_EQ(name.buffer, NULL);
 }
 
-/* dns_nane_setbuffer/hasbuffer */
-static void
-buffer_test(void **state) {
+ATF_TC(buffer);
+ATF_TC_HEAD(buffer, tc) {
+	atf_tc_set_md_var(tc, "descr", "dns_nane_setbuffer/hasbuffer");
+}
+ATF_TC_BODY(buffer, tc) {
 	dns_name_t name;
 	unsigned char buf[BUFSIZ];
 	isc_buffer_t b;
 
-	UNUSED(state);
-
 	isc_buffer_init(&b, buf, BUFSIZ);
 	dns_name_init(&name, NULL);
 	dns_name_setbuffer(&name, &b);
-	assert_int_equal(name.buffer, &b);
-	assert_true(dns_name_hasbuffer(&name));
+	ATF_CHECK_EQ(name.buffer, &b);
+	ATF_CHECK(dns_name_hasbuffer(&name));
 }
 
-/* dns_nane_isabsolute */
-static void
-isabsolute_test(void **state) {
+ATF_TC(isabsolute);
+ATF_TC_HEAD(isabsolute, tc) {
+	atf_tc_set_md_var(tc, "descr", "dns_nane_isabsolute");
+}
+ATF_TC_BODY(isabsolute, tc) {
 	struct {
 		const char *namestr;
 		bool expect;
@@ -410,9 +393,7 @@ isabsolute_test(void **state) {
 	};
 	unsigned int i;
 
-	UNUSED(state);
-
-	for (i = 0; i < (sizeof(testcases) / sizeof(testcases[0])); i++) {
+	for (i = 0; i < (sizeof(testcases)/sizeof(testcases[0])); i++) {
 		isc_result_t result;
 		dns_name_t name;
 		unsigned char data[BUFSIZ];
@@ -427,16 +408,17 @@ isabsolute_test(void **state) {
 		isc_buffer_init(&nb, data, BUFSIZ);
 		dns_name_setbuffer(&name, &nb);
 		result = dns_name_fromtext(&name, &b, NULL, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
-		assert_int_equal(dns_name_isabsolute(&name),
-				 testcases[i].expect);
+		ATF_CHECK_EQ(dns_name_isabsolute(&name), testcases[i].expect);
 	}
 }
 
-/* dns_nane_hash */
-static void
-hash_test(void **state) {
+ATF_TC(hash);
+ATF_TC_HEAD(hash, tc) {
+	atf_tc_set_md_var(tc, "descr", "dns_nane_hash");
+}
+ATF_TC_BODY(hash, tc) {
 	struct {
 		const char *name1;
 		const char *name2;
@@ -452,9 +434,7 @@ hash_test(void **state) {
 	};
 	unsigned int i;
 
-	UNUSED(state);
-
-	for (i = 0; i < (sizeof(testcases) / sizeof(testcases[0])); i++) {
+	for (i = 0; i < (sizeof(testcases)/sizeof(testcases[0])); i++) {
 		isc_result_t result;
 		dns_fixedname_t f1, f2;
 		dns_name_t *n1, *n2;
@@ -465,42 +445,36 @@ hash_test(void **state) {
 
 		result = dns_name_fromstring2(n1, testcases[i].name1,
 					      NULL, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 		result = dns_name_fromstring2(n2, testcases[i].name2,
 					      NULL, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
 		/* Check case-insensitive hashing first */
 		h1 = dns_name_hash(n1, false);
 		h2 = dns_name_hash(n2, false);
 
-		if (verbose) {
-			print_message("# %s hashes to %u, "
-				      "%s to %u, case insensitive\n",
-				      testcases[i].name1, h1,
-				      testcases[i].name2, h2);
-		}
+		printf("%s hashes to %u, %s to %u, case insensitive\n",
+		       testcases[i].name1, h1, testcases[i].name2, h2);
 
-		assert_int_equal((h1 == h2), testcases[i].expect);
+		ATF_REQUIRE_EQ((h1 == h2), testcases[i].expect);
 
 		/* Now case-sensitive */
 		h1 = dns_name_hash(n1, false);
 		h2 = dns_name_hash(n2, false);
 
-		if (verbose) {
-			print_message("# %s hashes to %u, "
-				      "%s to %u, case sensitive\n",
-				      testcases[i].name1, h1,
-				      testcases[i].name2, h2);
-		}
+		printf("%s hashes to %u, %s to %u, case sensitive\n",
+		       testcases[i].name1, h1, testcases[i].name2, h2);
 
-		assert_int_equal((h1 == h2), testcases[i].expect);
+		ATF_REQUIRE_EQ((h1 == h2), testcases[i].expect);
 	}
 }
 
-/* dns_nane_issubdomain */
-static void
-issubdomain_test(void **state) {
+ATF_TC(issubdomain);
+ATF_TC_HEAD(issubdomain, tc) {
+	atf_tc_set_md_var(tc, "descr", "dns_nane_issubdomain");
+}
+ATF_TC_BODY(issubdomain, tc) {
 	struct {
 		const char *name1;
 		const char *name2;
@@ -516,9 +490,7 @@ issubdomain_test(void **state) {
 	};
 	unsigned int i;
 
-	UNUSED(state);
-
-	for (i = 0; i < (sizeof(testcases) / sizeof(testcases[0])); i++) {
+	for (i = 0; i < (sizeof(testcases)/sizeof(testcases[0])); i++) {
 		isc_result_t result;
 		dns_fixedname_t f1, f2;
 		dns_name_t *n1, *n2;
@@ -528,26 +500,26 @@ issubdomain_test(void **state) {
 
 		result = dns_name_fromstring2(n1, testcases[i].name1,
 					      NULL, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 		result = dns_name_fromstring2(n2, testcases[i].name2,
 					      NULL, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
-		if (verbose) {
-			print_message("# check: %s %s a subdomain of %s\n",
-				      testcases[i].name1,
-				      testcases[i].expect ? "is" : "is not",
-				      testcases[i].name2);
-		}
+		printf("check: %s %s a subdomain of %s\n",
+		       testcases[i].name1,
+		       testcases[i].expect ? "is" : "is not",
+		       testcases[i].name2);
 
-		assert_int_equal(dns_name_issubdomain(n1, n2),
+		ATF_CHECK_EQ(dns_name_issubdomain(n1, n2),
 			     testcases[i].expect);
 	}
 }
 
-/* dns_nane_countlabels */
-static void
-countlabels_test(void **state) {
+ATF_TC(countlabels);
+ATF_TC_HEAD(countlabels, tc) {
+	atf_tc_set_md_var(tc, "descr", "dns_nane_countlabels");
+}
+ATF_TC_BODY(countlabels, tc) {
 	struct {
 		const char *namestr;
 		unsigned int expect;
@@ -561,9 +533,7 @@ countlabels_test(void **state) {
 	};
 	unsigned int i;
 
-	UNUSED(state);
-
-	for (i = 0; i < (sizeof(testcases) / sizeof(testcases[0])); i++) {
+	for (i = 0; i < (sizeof(testcases)/sizeof(testcases[0])); i++) {
 		isc_result_t result;
 		dns_fixedname_t fname;
 		dns_name_t *name;
@@ -572,22 +542,21 @@ countlabels_test(void **state) {
 
 		result = dns_name_fromstring2(name, testcases[i].namestr,
 					      NULL, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
-		if (verbose) {
-			print_message("# %s: expect %u labels\n",
-				      testcases[i].namestr,
-				      testcases[i].expect);
-		}
+		printf("%s: expect %u labels\n",
+		       testcases[i].namestr, testcases[i].expect);
 
-		assert_int_equal(dns_name_countlabels(name),
+		ATF_REQUIRE_EQ(dns_name_countlabels(name),
 			       testcases[i].expect);
 	}
 }
 
-/* dns_nane_getlabel */
-static void
-getlabel_test(void **state) {
+ATF_TC(getlabel);
+ATF_TC_HEAD(getlabel, tc) {
+	atf_tc_set_md_var(tc, "descr", "dns_nane_getlabel");
+}
+ATF_TC_BODY(getlabel, tc) {
 	struct {
 		const char *name1;
 		unsigned int pos1;
@@ -600,13 +569,12 @@ getlabel_test(void **state) {
 	};
 	unsigned int i;
 
-	UNUSED(state);
-
-	for (i = 0; i < (sizeof(testcases) / sizeof(testcases[0])); i++) {
+	for (i = 0; i < (sizeof(testcases)/sizeof(testcases[0])); i++) {
 		isc_result_t result;
 		dns_fixedname_t f1, f2;
 		dns_name_t *n1, *n2;
 		dns_label_t l1, l2;
+		unsigned char *p1, *p2;
 		unsigned int j;
 
 		n1 = dns_fixedname_initname(&f1);
@@ -614,24 +582,28 @@ getlabel_test(void **state) {
 
 		result = dns_name_fromstring2(n1, testcases[i].name1,
 					      NULL, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 		result = dns_name_fromstring2(n2, testcases[i].name2,
 					      NULL, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
 		dns_name_getlabel(n1, testcases[i].pos1, &l1);
 		dns_name_getlabel(n2, testcases[i].pos2, &l2);
-		assert_int_equal(l1.length, l2.length);
+		ATF_CHECK_EQ(l1.length, l2.length);
 
+		p1 = l1.base;
+		p2 = l2.base;
 		for (j = 0; j < l1.length; j++) {
-			assert_int_equal(l1.base[j], l2.base[j]);
+			ATF_REQUIRE_EQ(*p1++, *p2++);
 		}
 	}
 }
 
-/* dns_nane_getlabelsequence */
-static void
-getlabelsequence_test(void **state) {
+ATF_TC(getlabelsequence);
+ATF_TC_HEAD(getlabelsequence, tc) {
+	atf_tc_set_md_var(tc, "descr", "dns_nane_getlabelsequence");
+}
+ATF_TC_BODY(getlabelsequence, tc) {
 	struct {
 		const char *name1;
 		unsigned int pos1;
@@ -646,9 +618,7 @@ getlabelsequence_test(void **state) {
 	};
 	unsigned int i;
 
-	UNUSED(state);
-
-	for (i = 0; i < (sizeof(testcases) / sizeof(testcases[0])); i++) {
+	for (i = 0; i < (sizeof(testcases)/sizeof(testcases[0])); i++) {
 		isc_result_t result;
 		dns_name_t t1, t2;
 		dns_fixedname_t f1, f2;
@@ -664,21 +634,20 @@ getlabelsequence_test(void **state) {
 
 		result = dns_name_fromstring2(n1, testcases[i].name1,
 					      NULL, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 		result = dns_name_fromstring2(n2, testcases[i].name2,
 					      NULL, 0, NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
 		dns_name_getlabelsequence(n1, testcases[i].pos1,
 					  testcases[i].range, &t1);
 		dns_name_getlabelsequence(n2, testcases[i].pos2,
 					  testcases[i].range, &t2);
 
-		assert_true(dns_name_equal(&t1, &t2));
+		ATF_REQUIRE(dns_name_equal(&t1, &t2));
 	}
 }
 
-#ifdef ISC_PLATFORM_USETHREADS
 #ifdef DNS_BENCHMARK_TESTS
 
 /*
@@ -686,7 +655,11 @@ getlabelsequence_test(void **state) {
  * name parser, but we don't require it as part of the unit test runs.
  */
 
-/* Benchmark dns_name_fromwire() implementation */
+ATF_TC(benchmark);
+ATF_TC_HEAD(benchmark, tc) {
+	atf_tc_set_md_var(tc, "descr",
+			  "Benchmark dns_name_fromwire() implementation");
+}
 
 static void *
 fromwire_thread(void *arg) {
@@ -727,8 +700,7 @@ fromwire_thread(void *arg) {
 	return (NULL);
 }
 
-static void
-benchmark_test(void **state) {
+ATF_TC_BODY(benchmark, tc) {
 	isc_result_t result;
 	unsigned int i;
 	isc_time_t ts1, ts2;
@@ -736,85 +708,61 @@ benchmark_test(void **state) {
 	unsigned int nthreads;
 	isc_thread_t threads[32];
 
-	UNUSED(state);
+	UNUSED(tc);
 
 	debug_mem_record = false;
 
+	result = dns_test_begin(NULL, true);
+	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
+
 	result = isc_time_now(&ts1);
-	assert_int_equal(result, ISC_R_SUCCESS);
+	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
 	nthreads = ISC_MIN(isc_os_ncpus(), 32);
 	nthreads = ISC_MAX(nthreads, 1);
 	for (i = 0; i < nthreads; i++) {
 		result = isc_thread_create(fromwire_thread, NULL, &threads[i]);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 	}
 
 	for (i = 0; i < nthreads; i++) {
 		result = isc_thread_join(threads[i], NULL);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 	}
 
 	result = isc_time_now(&ts2);
-	assert_int_equal(result, ISC_R_SUCCESS);
+	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
 	t = isc_time_microdiff(&ts2, &ts1);
 
 	printf("%u dns_name_fromwire() calls, %f seconds, %f calls/second\n",
 	       nthreads * 32000000, t / 1000000.0,
 	       (nthreads * 32000000) / (t / 1000000.0));
+
+	dns_test_end();
 }
 
 #endif /* DNS_BENCHMARK_TESTS */
-#endif /* ISC_PLATFORM_USETHREADS */
 
-int
-main(int argc, char **argv) {
-	const struct CMUnitTest tests[] = {
-		cmocka_unit_test(fullcompare_test),
-		cmocka_unit_test_setup_teardown(compression_test,
-						_setup, _teardown),
-		cmocka_unit_test(istat_test),
-		cmocka_unit_test(init_test),
-		cmocka_unit_test(invalidate_test),
-		cmocka_unit_test(buffer_test),
-		cmocka_unit_test(isabsolute_test),
-		cmocka_unit_test(hash_test),
-		cmocka_unit_test(issubdomain_test),
-		cmocka_unit_test(countlabels_test),
-		cmocka_unit_test(getlabel_test),
-		cmocka_unit_test(getlabelsequence_test),
-#ifdef ISC_PLATFORM_USETHREADS
+/*
+ * Main
+ */
+ATF_TP_ADD_TCS(tp) {
+	ATF_TP_ADD_TC(tp, fullcompare);
+	ATF_TP_ADD_TC(tp, compression);
+	ATF_TP_ADD_TC(tp, istat);
+	ATF_TP_ADD_TC(tp, init);
+	ATF_TP_ADD_TC(tp, invalidate);
+	ATF_TP_ADD_TC(tp, buffer);
+	ATF_TP_ADD_TC(tp, isabsolute);
+	ATF_TP_ADD_TC(tp, hash);
+	ATF_TP_ADD_TC(tp, issubdomain);
+	ATF_TP_ADD_TC(tp, countlabels);
+	ATF_TP_ADD_TC(tp, getlabel);
+	ATF_TP_ADD_TC(tp, getlabelsequence);
 #ifdef DNS_BENCHMARK_TESTS
-		cmocka_unit_test_setup_teardown(benchmark_test,
-						_setup, _teardown),
+	ATF_TP_ADD_TC(tp, benchmark);
 #endif /* DNS_BENCHMARK_TESTS */
-#endif /* ISC_PLATFORM_USETHREADS */
-	};
-	int c;
 
-	while ((c = isc_commandline_parse(argc, argv, "v")) != -1) {
-		switch (c) {
-		case 'v':
-			verbose = true;
-			break;
-		default:
-			break;
-		}
-	}
-
-
-	return (cmocka_run_group_tests(tests, dns_test_init, dns_test_final));
+	return (atf_no_error());
 }
-
-#else /* HAVE_CMOCKA */
-
-#include <stdio.h>
-
-int
-main(void) {
-	printf("1..0 # Skipped: cmocka not available\n");
-	return (0);
-}
-
-#endif
