@@ -12,16 +12,17 @@
 /* ! \file */
 
 #include <config.h>
+
 #include <atf-c.h>
+
+#include <fcntl.h>
+#include <inttypes.h>
+#include <stdbool.h>
+#include <unistd.h>
+
 #include <isc/mem.h>
 #include <isc/random.h>
 #include <isc/string.h>
-#include <fcntl.h>
-#include <unistd.h>
-
-#ifdef HAVE_INTTYPES_H
-#include <inttypes.h> /* uintptr_t */
-#endif
 
 #include <dns/rbt.h>
 #include <dns/fixedname.h>
@@ -219,13 +220,13 @@ ATF_TC_HEAD(rbt_create, tc) {
 ATF_TC_BODY(rbt_create, tc) {
 	isc_result_t result;
 	test_context_t *ctx;
-	isc_boolean_t tree_ok;
+	bool tree_ok;
 
 	UNUSED(tc);
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	ctx = test_context_setup();
@@ -233,7 +234,7 @@ ATF_TC_BODY(rbt_create, tc) {
 	check_test_data(ctx->rbt);
 
 	tree_ok = dns__rbt_checkproperties(ctx->rbt);
-	ATF_CHECK_EQ(tree_ok, ISC_TRUE);
+	ATF_CHECK_EQ(tree_ok, true);
 
 	test_context_teardown(ctx);
 
@@ -252,7 +253,7 @@ ATF_TC_BODY(rbt_nodecount, tc) {
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	ctx = test_context_setup();
@@ -282,7 +283,7 @@ ATF_TC_BODY(rbtnode_get_distance, tc) {
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	ctx = test_context_setup();
@@ -332,13 +333,13 @@ ATF_TC_BODY(rbt_check_distance_random, tc) {
 
 	int i;
 	isc_result_t result;
-	isc_boolean_t tree_ok;
+	bool tree_ok;
 
 	UNUSED(tc);
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	result = dns_rbt_create(mctx, delete_data, NULL, &mytree);
@@ -368,7 +369,7 @@ ATF_TC_BODY(rbt_check_distance_random, tc) {
 			dns_name_t *name;
 
 			for (j = 0; j < 32; j++) {
-				isc_uint32_t v = isc_random_uniform(26);
+				uint32_t v = isc_random_uniform(26);
 				namebuf[j] = 'a' + v;
 			}
 			namebuf[32] = '.';
@@ -393,7 +394,7 @@ ATF_TC_BODY(rbt_check_distance_random, tc) {
 
 	/* Also check RB tree properties */
 	tree_ok = dns__rbt_checkproperties(mytree);
-	ATF_CHECK_EQ(tree_ok, ISC_TRUE);
+	ATF_CHECK_EQ(tree_ok, true);
 
 	dns_rbt_destroy(&mytree);
 
@@ -416,13 +417,13 @@ ATF_TC_BODY(rbt_check_distance_ordered, tc) {
 
 	int i;
 	isc_result_t result;
-	isc_boolean_t tree_ok;
+	bool tree_ok;
 
 	UNUSED(tc);
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	result = dns_rbt_create(mctx, delete_data, NULL, &mytree);
@@ -466,7 +467,7 @@ ATF_TC_BODY(rbt_check_distance_ordered, tc) {
 
 	/* Also check RB tree properties */
 	tree_ok = dns__rbt_checkproperties(mytree);
-	ATF_CHECK_EQ(tree_ok, ISC_TRUE);
+	ATF_CHECK_EQ(tree_ok, true);
 
 	dns_rbt_destroy(&mytree);
 
@@ -484,12 +485,12 @@ insert_helper(dns_rbt_t *rbt, const char *namestr, dns_rbtnode_t **node) {
 	return (dns_rbt_addnode(rbt, name, node));
 }
 
-static isc_boolean_t
+static bool
 compare_labelsequences(dns_rbtnode_t *node, const char *labelstr) {
 	dns_name_t name;
 	isc_result_t result;
 	char *nodestr = NULL;
-	isc_boolean_t is_equal;
+	bool is_equal;
 
 	dns_name_init(&name, NULL);
 	dns_rbt_namefromnode(node, &name);
@@ -497,7 +498,7 @@ compare_labelsequences(dns_rbtnode_t *node, const char *labelstr) {
 	result = dns_name_tostring(&name, &nodestr, mctx);
 	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
-	is_equal = strcmp(labelstr, nodestr) == 0 ? ISC_TRUE : ISC_FALSE;
+	is_equal = strcmp(labelstr, nodestr) == 0 ? true : false;
 
 	isc_mem_free(mctx, nodestr);
 
@@ -517,7 +518,7 @@ ATF_TC_BODY(rbt_insert, tc) {
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	ctx = test_context_setup();
@@ -537,7 +538,7 @@ ATF_TC_BODY(rbt_insert, tc) {
 	node = NULL;
 	result = insert_helper(ctx->rbt, "0", &node);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
-	ATF_CHECK_EQ(compare_labelsequences(node, "0"), ISC_TRUE);
+	ATF_CHECK_EQ(compare_labelsequences(node, "0"), true);
 
 	/* Node count must have increased. */
 	ATF_CHECK_EQ(16, dns_rbt_nodecount(ctx->rbt));
@@ -564,7 +565,7 @@ ATF_TC_BODY(rbt_insert, tc) {
 	node = NULL;
 	result = insert_helper(ctx->rbt, "k.e.f", &node);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
-	ATF_CHECK_EQ(compare_labelsequences(node, "k"), ISC_TRUE);
+	ATF_CHECK_EQ(compare_labelsequences(node, "k"), true);
 
 	/* Node count must have incremented twice ("d.e.f" fissioned to
 	 * "d" and "e.f", and the newly added "k").
@@ -575,7 +576,7 @@ ATF_TC_BODY(rbt_insert, tc) {
 	node = NULL;
 	result = insert_helper(ctx->rbt, "h", &node);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
-	ATF_CHECK_EQ(compare_labelsequences(node, "h"), ISC_TRUE);
+	ATF_CHECK_EQ(compare_labelsequences(node, "h"), true);
 
 	/* Node count must have incremented ("g.h" fissioned to "g" and
 	 * "h").
@@ -587,19 +588,19 @@ ATF_TC_BODY(rbt_insert, tc) {
 	node = NULL;
 	result = insert_helper(ctx->rbt, "m.p.w.y.d.e.f", &node);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
-	ATF_CHECK_EQ(compare_labelsequences(node, "m"), ISC_TRUE);
+	ATF_CHECK_EQ(compare_labelsequences(node, "m"), true);
 	ATF_CHECK_EQ(21, dns_rbt_nodecount(ctx->rbt));
 
 	node = NULL;
 	result = insert_helper(ctx->rbt, "n.p.w.y.d.e.f", &node);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
-	ATF_CHECK_EQ(compare_labelsequences(node, "n"), ISC_TRUE);
+	ATF_CHECK_EQ(compare_labelsequences(node, "n"), true);
 	ATF_CHECK_EQ(22, dns_rbt_nodecount(ctx->rbt));
 
 	node = NULL;
 	result = insert_helper(ctx->rbt, "l.a", &node);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
-	ATF_CHECK_EQ(compare_labelsequences(node, "l"), ISC_TRUE);
+	ATF_CHECK_EQ(compare_labelsequences(node, "l"), true);
 	ATF_CHECK_EQ(23, dns_rbt_nodecount(ctx->rbt));
 
 	node = NULL;
@@ -686,7 +687,7 @@ ATF_TC_BODY(rbt_remove, tc) {
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
 	/*
@@ -697,7 +698,7 @@ ATF_TC_BODY(rbt_remove, tc) {
 		dns_rbtnode_t *node;
 		size_t i;
 		size_t *n;
-		isc_boolean_t tree_ok;
+		bool tree_ok;
 		dns_rbtnodechain_t chain;
 		size_t start_node;
 
@@ -747,13 +748,13 @@ ATF_TC_BODY(rbt_remove, tc) {
 
 			name = dns_fixedname_name(&fname);
 
-			result = dns_rbt_deletename(mytree, name, ISC_FALSE);
+			result = dns_rbt_deletename(mytree, name, false);
 			ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 		}
 
 		/* Check RB tree properties. */
 		tree_ok = dns__rbt_checkproperties(mytree);
-		ATF_CHECK_EQ(tree_ok, ISC_TRUE);
+		ATF_CHECK_EQ(tree_ok, true);
 
 		dns_rbtnodechain_init(&chain, mctx);
 
@@ -873,9 +874,9 @@ ATF_TC_BODY(rbt_remove, tc) {
 
 static void
 insert_nodes(dns_rbt_t *mytree, char **names,
-	     size_t *names_count, isc_uint32_t num_names)
+	     size_t *names_count, uint32_t num_names)
 {
-	isc_uint32_t i;
+	uint32_t i;
 	dns_rbtnode_t *node;
 
 	for (i = 0; i < num_names; i++) {
@@ -894,7 +895,7 @@ insert_nodes(dns_rbt_t *mytree, char **names,
 			isc_result_t result;
 
 			for (j = 0; j < 32; j++) {
-				isc_uint32_t v = isc_random_uniform(26);
+				uint32_t v = isc_random_uniform(26);
 				namebuf[j] = 'a' + v;
 			}
 			namebuf[32] = '.';
@@ -909,6 +910,7 @@ insert_nodes(dns_rbt_t *mytree, char **names,
 				node->data = n;
 				names[*names_count] = isc_mem_strdup(mctx,
 								     namebuf);
+				ATF_REQUIRE(names[*names_count] != NULL);
 				*names_count += 1;
 				break;
 			}
@@ -918,14 +920,14 @@ insert_nodes(dns_rbt_t *mytree, char **names,
 
 static void
 remove_nodes(dns_rbt_t *mytree, char **names,
-	     size_t *names_count, isc_uint32_t num_names)
+	     size_t *names_count, uint32_t num_names)
 {
-	isc_uint32_t i;
+	uint32_t i;
 
 	UNUSED(mytree);
 
 	for (i = 0; i < num_names; i++) {
-		isc_uint32_t node;
+		uint32_t node;
 		dns_fixedname_t fname;
 		dns_name_t *name;
 		isc_result_t result;
@@ -935,7 +937,7 @@ remove_nodes(dns_rbt_t *mytree, char **names,
 		dns_test_namefromstring(names[node], &fname);
 		name = dns_fixedname_name(&fname);
 
-		result = dns_rbt_deletename(mytree, name, ISC_FALSE);
+		result = dns_rbt_deletename(mytree, name, false);
 		ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 		isc_mem_free(mctx, names[node]);
@@ -951,7 +953,7 @@ static void
 check_tree(dns_rbt_t *mytree, char **names, size_t names_count,
 	   unsigned int line)
 {
-	isc_boolean_t tree_ok;
+	bool tree_ok;
 
 	UNUSED(names);
 
@@ -968,7 +970,7 @@ check_tree(dns_rbt_t *mytree, char **names, size_t names_count,
 
 	/* Also check RB tree properties */
 	tree_ok = dns__rbt_checkproperties(mytree);
-	ATF_CHECK_EQ(tree_ok, ISC_TRUE);
+	ATF_CHECK_EQ(tree_ok, true);
 }
 
 ATF_TC(rbt_insert_and_remove);
@@ -994,6 +996,7 @@ ATF_TC_BODY(rbt_insert_and_remove, tc) {
 	 */
 	isc_result_t result;
 	dns_rbt_t *mytree = NULL;
+	size_t *n;
 	/*
 	 * We use an array for storing names instead of a set
 	 * structure. It's slow, but works and is good enough for tests.
@@ -1006,18 +1009,23 @@ ATF_TC_BODY(rbt_insert_and_remove, tc) {
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	result = dns_rbt_create(mctx, delete_data, NULL, &mytree);
 	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
+	n = isc_mem_get(mctx, sizeof(size_t));
+	ATF_REQUIRE(n != NULL);
+	result = dns_rbt_addname(mytree, dns_rootname, n);
+	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
+
 	memset(names, 0, sizeof(names));
 	names_count = 0;
 
 	/* Repeat the insert/remove test some 4096 times */
 	for (i = 0; i < 4096; i++) {
-		isc_uint32_t num_names;
+		uint32_t num_names;
 
 		if (names_count < 1024) {
 			num_names = isc_random_uniform(1024 - names_count);
@@ -1050,6 +1058,12 @@ ATF_TC_BODY(rbt_insert_and_remove, tc) {
 		}
 	}
 
+	result = dns_rbt_deletename(mytree, dns_rootname, false);
+	ATF_CHECK_EQ_MSG(result, ISC_R_SUCCESS,
+			 "result: %s", isc_result_totext(result));
+	ATF_CHECK_EQ_MSG(dns_rbt_nodecount(mytree), 0,
+			 "%u != 0", dns_rbt_nodecount(mytree));
+
 	dns_rbt_destroy(&mytree);
 
 	dns_test_end();
@@ -1070,7 +1084,7 @@ ATF_TC_BODY(rbt_findname, tc) {
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	ctx = test_context_setup();
@@ -1129,7 +1143,7 @@ ATF_TC_BODY(rbt_addname, tc) {
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	ctx = test_context_setup();
@@ -1172,7 +1186,7 @@ ATF_TC_BODY(rbt_deletename, tc) {
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	ctx = test_context_setup();
@@ -1180,13 +1194,13 @@ ATF_TC_BODY(rbt_deletename, tc) {
 	/* Delete a name that doesn't exist */
 	dns_test_namefromstring("z.x.y.w", &fname);
 	name = dns_fixedname_name(&fname);
-	result = dns_rbt_deletename(ctx->rbt, name, ISC_FALSE);
+	result = dns_rbt_deletename(ctx->rbt, name, false);
 	ATF_REQUIRE_EQ(result, ISC_R_NOTFOUND);
 
 	/* Now one that does */
 	dns_test_namefromstring("d.e.f", &fname);
 	name = dns_fixedname_name(&fname);
-	result = dns_rbt_deletename(ctx->rbt, name, ISC_FALSE);
+	result = dns_rbt_deletename(ctx->rbt, name, false);
 	ATF_REQUIRE_EQ(result, ISC_R_NOTFOUND);
 
 	test_context_teardown(ctx);
@@ -1210,7 +1224,7 @@ ATF_TC_BODY(rbt_nodechain, tc) {
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	ctx = test_context_setup();
@@ -1262,7 +1276,6 @@ ATF_TC_BODY(rbt_nodechain, tc) {
 	dns_test_end();
 }
 
-#ifdef ISC_PLATFORM_USETHREADS
 #ifdef DNS_BENCHMARK_TESTS
 
 /*
@@ -1325,9 +1338,9 @@ ATF_TC_BODY(benchmark, tc) {
 
 	srandom(time(NULL));
 
-	debug_mem_record = ISC_FALSE;
+	debug_mem_record = false;
 
-	result = dns_test_begin(NULL, ISC_TRUE);
+	result = dns_test_begin(NULL, true);
 	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
 
 	fnames = (dns_fixedname_t *) malloc(4000000 * sizeof(dns_fixedname_t));
@@ -1390,7 +1403,6 @@ ATF_TC_BODY(benchmark, tc) {
 }
 
 #endif /* DNS_BENCHMARK_TESTS */
-#endif /* ISC_PLATFORM_USETHREADS */
 
 /*
  * Main
@@ -1408,11 +1420,9 @@ ATF_TP_ADD_TCS(tp) {
 	ATF_TP_ADD_TC(tp, rbt_addname);
 	ATF_TP_ADD_TC(tp, rbt_deletename);
 	ATF_TP_ADD_TC(tp, rbt_nodechain);
-#ifdef ISC_PLATFORM_USETHREADS
 #ifdef DNS_BENCHMARK_TESTS
 	ATF_TP_ADD_TC(tp, benchmark);
 #endif /* DNS_BENCHMARK_TESTS */
-#endif /* ISC_PLATFORM_USETHREADS */
 
 	return (atf_no_error());
 }
