@@ -12,6 +12,9 @@
 /*! \file */
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
+
 #include <isc/buffer.h>
 #include <isc/md5.h>
 #include <isc/mem.h>
@@ -45,7 +48,7 @@
 #define TEMP_BUFFER_SZ 8192
 #define TKEY_RANDOM_AMOUNT 16
 
-#if HAVE_PKCS11
+#if USE_PKCS11
 #include <pk11/pk11.h>
 #endif
 
@@ -154,7 +157,7 @@ dns_tkeyctx_destroy(dns_tkeyctx_t **tctxp) {
 
 static isc_result_t
 add_rdata_to_list(dns_message_t *msg, dns_name_t *name, dns_rdata_t *rdata,
-		isc_uint32_t ttl, dns_namelist_t *namelist)
+		uint32_t ttl, dns_namelist_t *namelist)
 {
 	isc_result_t result;
 	isc_region_t r, newr;
@@ -233,7 +236,6 @@ static isc_result_t
 compute_secret(isc_buffer_t *shared, isc_region_t *queryrandomness,
 	       isc_region_t *serverrandomness, isc_buffer_t *secret)
 {
-#ifndef PK11_MD5_DISABLE
 	isc_md5_t md5ctx;
 	isc_region_t r, r2;
 	unsigned char digests[32];
@@ -278,14 +280,6 @@ compute_secret(isc_buffer_t *shared, isc_region_t *queryrandomness,
 		isc_buffer_add(secret, sizeof(digests));
 	}
 	return (ISC_R_SUCCESS);
-#else
-	UNUSED(shared);
-	UNUSED(queryrandomness);
-	UNUSED(serverrandomness);
-	UNUSED(secret);
-
-	return (ISC_R_NOTIMPLEMENTED);
-#endif
 }
 
 static isc_result_t
@@ -298,7 +292,7 @@ process_dhtkey(dns_message_t *msg, dns_name_t *signer, dns_name_t *name,
 	dns_name_t *keyname, ourname;
 	dns_rdataset_t *keyset = NULL;
 	dns_rdata_t keyrdata = DNS_RDATA_INIT, ourkeyrdata = DNS_RDATA_INIT;
-	isc_boolean_t found_key = ISC_FALSE, found_incompatible = ISC_FALSE;
+	bool found_key = false, found_incompatible = false;
 	dst_key_t *pubkey = NULL;
 	isc_buffer_t ourkeybuf, *shared = NULL;
 	isc_region_t r, r2, ourkeyr;
@@ -314,18 +308,12 @@ process_dhtkey(dns_message_t *msg, dns_name_t *signer, dns_name_t *name,
 		return (DNS_R_REFUSED);
 	}
 
-#ifndef PK11_MD5_DISABLE
 	if (!dns_name_equal(&tkeyin->algorithm, DNS_TSIG_HMACMD5_NAME)) {
 		tkey_log("process_dhtkey: algorithms other than "
 			 "hmac-md5 are not supported");
 		tkeyout->error = dns_tsigerror_badalg;
 		return (ISC_R_SUCCESS);
 	}
-#else
-	tkey_log("process_dhtkey: MD5 was disabled");
-	tkeyout->error = dns_tsigerror_badalg;
-	return (ISC_R_SUCCESS);
-#endif
 
 	/*
 	 * Look for a DH KEY record that will work with ours.
@@ -352,17 +340,15 @@ process_dhtkey(dns_message_t *msg, dns_name_t *signer, dns_name_t *name,
 				dns_rdata_reset(&keyrdata);
 				continue;
 			}
-#ifndef PK11_DH_DISABLE
 			if (dst_key_alg(pubkey) == DNS_KEYALG_DH) {
 				if (dst_key_paramcompare(pubkey, tctx->dhkey))
 				{
-					found_key = ISC_TRUE;
+					found_key = true;
 					ttl = keyset->ttl;
 					break;
 				} else
-					found_incompatible = ISC_TRUE;
+					found_incompatible = true;
 			}
-#endif
 			dst_key_free(&pubkey);
 			dns_rdata_reset(&keyrdata);
 		}
@@ -424,7 +410,7 @@ process_dhtkey(dns_message_t *msg, dns_name_t *signer, dns_name_t *name,
 	RETERR(dns_tsigkey_create(name, &tkeyin->algorithm,
 				  isc_buffer_base(&secret),
 				  isc_buffer_usedlength(&secret),
-				  ISC_TRUE, signer, tkeyin->inception,
+				  true, signer, tkeyin->inception,
 				  tkeyin->expire, ring->mctx, ring, NULL));
 
 	/* This key is good for a long time */
@@ -524,7 +510,7 @@ process_gsstkey(dns_name_t *name, dns_rdata_tkey_t *tkeyin,
 #ifdef GSSAPI
 		OM_uint32 gret, minor, lifetime;
 #endif
-		isc_uint32_t expire;
+		uint32_t expire;
 
 		RETERR(dst_key_fromgssapi(name, gss_ctx, ring->mctx,
 					  &dstkey, &intoken));
@@ -539,7 +525,7 @@ process_gsstkey(dns_name_t *name, dns_rdata_tkey_t *tkeyin,
 			expire = now + lifetime;
 #endif
 		RETERR(dns_tsigkey_createfromkey(name, &tkeyin->algorithm,
-						 dstkey, ISC_TRUE, principal,
+						 dstkey, true, principal,
 						 now, expire, ring->mctx, ring,
 						 NULL));
 		dst_key_free(&dstkey);
@@ -638,7 +624,7 @@ dns_tkey_processquery(dns_message_t *msg, dns_tkeyctx_t *tctx,
 {
 	isc_result_t result = ISC_R_SUCCESS;
 	dns_rdata_tkey_t tkeyin, tkeyout;
-	isc_boolean_t freetkeyin = ISC_FALSE;
+	bool freetkeyin = false;
 	dns_name_t *qname, *name, *keyname, *signer, tsigner;
 	dns_fixedname_t fkeyname;
 	dns_rdataset_t *tkeyset;
@@ -694,7 +680,7 @@ dns_tkey_processquery(dns_message_t *msg, dns_tkeyctx_t *tctx,
 	dns_rdataset_current(tkeyset, &rdata);
 
 	RETERR(dns_rdata_tostruct(&rdata, &tkeyin, NULL));
-	freetkeyin = ISC_TRUE;
+	freetkeyin = true;
 
 	if (tkeyin.error != dns_rcode_noerror) {
 		result = DNS_R_FORMERR;
@@ -839,7 +825,7 @@ dns_tkey_processquery(dns_message_t *msg, dns_tkeyctx_t *tctx,
 
 	if (freetkeyin) {
 		dns_rdata_freestruct(&tkeyin);
-		freetkeyin = ISC_FALSE;
+		freetkeyin = false;
 	}
 
 	if (tkeyout.key != NULL)
@@ -851,7 +837,7 @@ dns_tkey_processquery(dns_message_t *msg, dns_tkeyctx_t *tctx,
 
 	RETERR(add_rdata_to_list(msg, keyname, &rdata, 0, &namelist));
 
-	RETERR(dns_message_reply(msg, ISC_TRUE));
+	RETERR(dns_message_reply(msg, true));
 
 	name = ISC_LIST_HEAD(namelist);
 	while (name != NULL) {
@@ -873,7 +859,7 @@ dns_tkey_processquery(dns_message_t *msg, dns_tkeyctx_t *tctx,
 
 static isc_result_t
 buildquery(dns_message_t *msg, const dns_name_t *name,
-	   dns_rdata_tkey_t *tkey, isc_boolean_t win2k)
+	   dns_rdata_tkey_t *tkey, bool win2k)
 {
 	dns_name_t *qname = NULL, *aname = NULL;
 	dns_rdataset_t *question = NULL, *tkeyset = NULL;
@@ -957,7 +943,7 @@ buildquery(dns_message_t *msg, const dns_name_t *name,
 isc_result_t
 dns_tkey_builddhquery(dns_message_t *msg, dst_key_t *key,
 		      const dns_name_t *name, const dns_name_t *algorithm,
-		      isc_buffer_t *nonce, isc_uint32_t lifetime)
+		      isc_buffer_t *nonce, uint32_t lifetime)
 {
 	dns_rdata_tkey_t tkey;
 	dns_rdata_t *rdata = NULL;
@@ -998,7 +984,7 @@ dns_tkey_builddhquery(dns_message_t *msg, dst_key_t *key,
 	tkey.other = NULL;
 	tkey.otherlen = 0;
 
-	RETERR(buildquery(msg, name, &tkey, ISC_FALSE));
+	RETERR(buildquery(msg, name, &tkey, false));
 
 	RETERR(dns_message_gettemprdata(msg, &rdata));
 	RETERR(isc_buffer_allocate(msg->mctx, &dynbuf, 1024));
@@ -1033,8 +1019,8 @@ dns_tkey_builddhquery(dns_message_t *msg, dst_key_t *key,
 isc_result_t
 dns_tkey_buildgssquery(dns_message_t *msg, const dns_name_t *name,
 		       const dns_name_t *gname,
-		       isc_buffer_t *intoken, isc_uint32_t lifetime,
-		       gss_ctx_id_t *context, isc_boolean_t win2k,
+		       isc_buffer_t *intoken, uint32_t lifetime,
+		       gss_ctx_id_t *context, bool win2k,
 		       isc_mem_t *mctx, char **err_message)
 {
 	dns_rdata_tkey_t tkey;
@@ -1100,7 +1086,7 @@ dns_tkey_builddeletequery(dns_message_t *msg, dns_tsigkey_t *key) {
 	tkey.keylen = tkey.otherlen = 0;
 	tkey.key = tkey.other = NULL;
 
-	return (buildquery(msg, &key->name, &tkey, ISC_FALSE));
+	return (buildquery(msg, &key->name, &tkey, false));
 }
 
 static isc_result_t
@@ -1147,7 +1133,7 @@ dns_tkey_processdhresponse(dns_message_t *qmsg, dns_message_t *rmsg,
 	isc_buffer_t *shared = NULL, secret;
 	isc_region_t r, r2;
 	isc_result_t result;
-	isc_boolean_t freertkey = ISC_FALSE;
+	bool freertkey = false;
 
 	REQUIRE(qmsg != NULL);
 	REQUIRE(rmsg != NULL);
@@ -1161,7 +1147,7 @@ dns_tkey_processdhresponse(dns_message_t *qmsg, dns_message_t *rmsg,
 		return (ISC_RESULTCLASS_DNSRCODE + rmsg->rcode);
 	RETERR(find_tkey(rmsg, &tkeyname, &rtkeyrdata, DNS_SECTION_ANSWER));
 	RETERR(dns_rdata_tostruct(&rtkeyrdata, &rtkey, NULL));
-	freertkey = ISC_TRUE;
+	freertkey = true;
 
 	RETERR(find_tkey(qmsg, &tempname, &qtkeyrdata,
 			 DNS_SECTION_ADDITIONAL));
@@ -1238,7 +1224,7 @@ dns_tkey_processdhresponse(dns_message_t *qmsg, dns_message_t *rmsg,
 
 	isc_buffer_usedregion(&secret, &r);
 	result = dns_tsigkey_create(tkeyname, &rtkey.algorithm,
-				    r.base, r.length, ISC_TRUE,
+				    r.base, r.length, true,
 				    NULL, rtkey.inception, rtkey.expire,
 				    rmsg->mctx, ring, outkey);
 	isc_buffer_free(&shared);
@@ -1321,7 +1307,7 @@ dns_tkey_processgssresponse(dns_message_t *qmsg, dns_message_t *rmsg,
 				  &dstkey, NULL));
 
 	RETERR(dns_tsigkey_createfromkey(tkeyname, DNS_TSIG_GSSAPI_NAME,
-					 dstkey, ISC_FALSE, NULL,
+					 dstkey, false, NULL,
 					 rtkey.inception, rtkey.expire,
 					 ring->mctx, ring, outkey));
 	dst_key_free(&dstkey);
@@ -1396,7 +1382,7 @@ isc_result_t
 dns_tkey_gssnegotiate(dns_message_t *qmsg, dns_message_t *rmsg,
 		      const dns_name_t *server, gss_ctx_id_t *context,
 		      dns_tsigkey_t **outkey, dns_tsig_keyring_t *ring,
-		      isc_boolean_t win2k, char **err_message)
+		      bool win2k, char **err_message)
 {
 	dns_rdata_t rtkeyrdata = DNS_RDATA_INIT, qtkeyrdata = DNS_RDATA_INIT;
 	dns_name_t *tkeyname;
@@ -1405,7 +1391,7 @@ dns_tkey_gssnegotiate(dns_message_t *qmsg, dns_message_t *rmsg,
 	dst_key_t *dstkey = NULL;
 	isc_result_t result;
 	unsigned char array[TEMP_BUFFER_SZ];
-	isc_boolean_t freertkey = ISC_FALSE;
+	bool freertkey = false;
 
 	REQUIRE(qmsg != NULL);
 	REQUIRE(rmsg != NULL);
@@ -1418,9 +1404,9 @@ dns_tkey_gssnegotiate(dns_message_t *qmsg, dns_message_t *rmsg,
 
 	RETERR(find_tkey(rmsg, &tkeyname, &rtkeyrdata, DNS_SECTION_ANSWER));
 	RETERR(dns_rdata_tostruct(&rtkeyrdata, &rtkey, NULL));
-	freertkey = ISC_TRUE;
+	freertkey = true;
 
-	if (win2k == ISC_TRUE)
+	if (win2k == true)
 		RETERR(find_tkey(qmsg, &tkeyname, &qtkeyrdata,
 				 DNS_SECTION_ANSWER));
 	else
@@ -1492,7 +1478,7 @@ dns_tkey_gssnegotiate(dns_message_t *qmsg, dns_message_t *rmsg,
 					 (win2k
 					  ? DNS_TSIG_GSSAPIMS_NAME
 					  : DNS_TSIG_GSSAPI_NAME),
-					 dstkey, ISC_TRUE, NULL,
+					 dstkey, true, NULL,
 					 rtkey.inception, rtkey.expire,
 					 ring->mctx, ring, outkey));
 	dst_key_free(&dstkey);
