@@ -14,6 +14,7 @@
 
 /*! \file isc/mem.h */
 
+#include <stdbool.h>
 #include <stdio.h>
 
 #include <isc/json.h>
@@ -194,14 +195,14 @@ typedef struct isc_memmethods {
 			       size_t size _ISC_MEM_FLARG);
 	char *(*memstrdup)(isc_mem_t *mctx, const char *s _ISC_MEM_FLARG);
 	void (*memfree)(isc_mem_t *mctx, void *ptr _ISC_MEM_FLARG);
-	void (*setdestroycheck)(isc_mem_t *mctx, isc_boolean_t flag);
+	void (*setdestroycheck)(isc_mem_t *mctx, bool flag);
 	void (*setwater)(isc_mem_t *ctx, isc_mem_water_t water,
 			 void *water_arg, size_t hiwater, size_t lowater);
 	void (*waterack)(isc_mem_t *ctx, int flag);
 	size_t (*inuse)(isc_mem_t *mctx);
 	size_t (*maxinuse)(isc_mem_t *mctx);
 	size_t (*total)(isc_mem_t *mctx);
-	isc_boolean_t (*isovermem)(isc_mem_t *mctx);
+	bool (*isovermem)(isc_mem_t *mctx);
 	isc_result_t (*mpcreate)(isc_mem_t *mctx, size_t size,
 				 isc_mempool_t **mpctxp);
 } isc_memmethods_t;
@@ -347,15 +348,6 @@ isc_mem_destroy(isc_mem_t **);
  * Destroy a memory context.
  */
 
-isc_result_t
-isc_mem_ondestroy(isc_mem_t *ctx,
-		  isc_task_t *task,
-		  isc_event_t **event);
-/*%<
- * Request to be notified with an event when a memory context has
- * been successfully destroyed.
- */
-
 void
 isc_mem_stats(isc_mem_t *mctx, FILE *out);
 /*%<
@@ -364,9 +356,9 @@ isc_mem_stats(isc_mem_t *mctx, FILE *out);
 
 void
 isc_mem_setdestroycheck(isc_mem_t *mctx,
-			isc_boolean_t on);
+			bool on);
 /*%<
- * If 'on' is ISC_TRUE, 'mctx' will check for memory leaks when
+ * If 'on' is true, 'mctx' will check for memory leaks when
  * destroyed and abort the program if any are present.
  */
 
@@ -404,7 +396,7 @@ isc_mem_total(isc_mem_t *mctx);
  * not yet used.
  */
 
-isc_boolean_t
+bool
 isc_mem_isovermem(isc_mem_t *mctx);
 /*%<
  * Return true iff the memory context is in "over memory" state, i.e.,
