@@ -9,15 +9,10 @@
  * information regarding copyright ownership.
  */
 
-#ifndef ISC_SHA1_H
-#define ISC_SHA1_H 1
-
-/*	$NetBSD: sha1.h,v 1.2 1998/05/29 22:55:44 thorpej Exp $	*/
+#pragma once
 
 /*! \file isc/sha1.h
  * \brief SHA-1 in C
- * \author By Steve Reid <steve@edmweb.com>
- * \note 100% Public Domain
  */
 
 #include <stdbool.h>
@@ -29,7 +24,6 @@
 #define ISC_SHA1_DIGESTLENGTH 20U
 #define ISC_SHA1_BLOCK_LENGTH 64U
 
-#ifdef ISC_PLATFORM_OPENSSLHASH
 #include <openssl/opensslv.h>
 #include <openssl/evp.h>
 
@@ -40,20 +34,6 @@ typedef struct {
 #endif
 } isc_sha1_t;
 
-#elif PKCS11CRYPTO
-#include <pk11/pk11.h>
-
-typedef pk11_context_t isc_sha1_t;
-
-#else
-
-typedef struct {
-	uint32_t state[5];
-	uint32_t count[2];
-	unsigned char buffer[ISC_SHA1_BLOCK_LENGTH];
-} isc_sha1_t;
-#endif
-
 ISC_LANG_BEGINDECLS
 
 void
@@ -72,5 +52,3 @@ bool
 isc_sha1_check(bool testing);
 
 ISC_LANG_ENDDECLS
-
-#endif /* ISC_SHA1_H */
