@@ -3,14 +3,14 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
  */
 
 
-#include "config.h"
+#include <config.h>
 
 #include <stdio.h>
 
@@ -18,7 +18,7 @@
 #include <isc/iterated_hash.h>
 
 int
-isc_iterated_hash(unsigned char out[NSEC3_MAX_HASH_LENGTH],
+isc_iterated_hash(unsigned char out[ISC_SHA1_DIGESTLENGTH],
 		  unsigned int hashalg, int iterations,
 		  const unsigned char *salt, int saltlength,
 		  const unsigned char *in, int inlength)
