@@ -11,7 +11,9 @@
 
 #include <config.h>
 
+#include <stdbool.h>
 #include <stdio.h>
+#include <inttypes.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -45,12 +47,12 @@
 #define PK11_NO_LOGERR 1
 #endif
 
-LIBISC_EXTERNAL_DATA isc_boolean_t pk11_verbose_init = ISC_FALSE;
+LIBISC_EXTERNAL_DATA bool pk11_verbose_init = false;
 
 static isc_once_t once = ISC_ONCE_INIT;
 static isc_mem_t *pk11_mctx = NULL;
-static isc_int32_t allocsize = 0;
-static isc_boolean_t initialized = ISC_FALSE;
+static int32_t allocsize = 0;
+static bool initialized = false;
 
 typedef struct pk11_session pk11_session_t;
 typedef struct pk11_token pk11_token_t;
@@ -69,7 +71,7 @@ struct pk11_token {
 	ISC_LINK(pk11_token_t)	link;
 	CK_SLOT_ID		slotid;
 	pk11_sessionlist_t	sessions;
-	isc_boolean_t		logged;
+	bool		logged;
 	char			name[32];
 	char			manuf[32];
 	char			model[16];
@@ -78,23 +80,21 @@ struct pk11_token {
 };
 static ISC_LIST(pk11_token_t) tokens;
 
-static pk11_token_t *rand_token;
 static pk11_token_t *best_rsa_token;
 static pk11_token_t *best_dsa_token;
 static pk11_token_t *best_dh_token;
-static pk11_token_t *digest_token;
-static pk11_token_t *best_ec_token;
-static pk11_token_t *aes_token;
+static pk11_token_t *best_ecdsa_token;
+static pk11_token_t *best_eddsa_token;
 
 static isc_result_t free_all_sessions(void);
 static isc_result_t free_session_list(pk11_sessionlist_t *slist);
 static isc_result_t setup_session(pk11_session_t *sp,
 				  pk11_token_t *token,
-				  isc_boolean_t rw);
+				  bool rw);
 static void scan_slots(void);
 static isc_result_t token_login(pk11_session_t *sp);
 static char *percent_decode(char *x, size_t *len);
-static isc_boolean_t pk11strcmp(const char *x, size_t lenx,
+static bool pk11strcmp(const char *x, size_t lenx,
 				const char *y, size_t leny);
 static CK_ATTRIBUTE *push_attribute(pk11_object_t *obj,
 				    isc_mem_t *mctx,
@@ -182,21 +182,20 @@ pk11_mem_put(void *ptr, size_t size) {
 
 isc_result_t
 pk11_initialize(isc_mem_t *mctx, const char *engine) {
-	isc_result_t result;
+	isc_result_t result = ISC_R_SUCCESS;
 	CK_RV rv;
 
 	RUNTIME_CHECK(isc_once_do(&once, initialize) == ISC_R_SUCCESS);
 
+	LOCK(&sessionlock);
 	LOCK(&alloclock);
 	if ((mctx != NULL) && (pk11_mctx == NULL) && (allocsize == 0))
 		isc_mem_attach(mctx, &pk11_mctx);
+	UNLOCK(&alloclock);
 	if (initialized) {
-		UNLOCK(&alloclock);
-		return (ISC_R_SUCCESS);
+		goto unlock;
 	} else {
-		LOCK(&sessionlock);
-		initialized = ISC_TRUE;
-		UNLOCK(&alloclock);
+		initialized = true;
 	}
 
 	ISC_LIST_INIT(tokens);
@@ -220,23 +219,6 @@ pk11_initialize(isc_mem_t *mctx, const char *engine) {
 	}
 
 	scan_slots();
-#if HAVE_PKCS11
-	if (rand_token == NULL) {
-		result = PK11_R_NORANDOMSERVICE;
-		goto unlock;
-	}
-	if (digest_token == NULL) {
-		result = PK11_R_NODIGESTSERVICE;
-		goto unlock;
-	}
-#if defined(AES_CC)
-	if (aes_token == NULL) {
-		result = PK11_R_NOAESSERVICE;
-		goto unlock;
-	}
-#endif
-#endif /* HAVE_PKCS11 */
-	result = ISC_R_SUCCESS;
  unlock:
 	UNLOCK(&sessionlock);
 	return (result);
@@ -253,119 +235,46 @@ pk11_finalize(void) {
 	while (token != NULL) {
 		next = ISC_LIST_NEXT(token, link);
 		ISC_LIST_UNLINK(tokens, token, link);
-		if (token == rand_token)
-			rand_token = NULL;
-		if (token == best_rsa_token)
+		if (token == best_rsa_token) {
 			best_rsa_token = NULL;
-		if (token == best_dsa_token)
+		}
+		if (token == best_dsa_token) {
 			best_dsa_token = NULL;
-		if (token == best_dh_token)
+		}
+		if (token == best_dh_token) {
 			best_dh_token = NULL;
-		if (token == digest_token)
-			digest_token = NULL;
-		if (token == best_ec_token)
-			best_ec_token = NULL;
-		if (token == aes_token)
-			aes_token = NULL;
+		}
+		if (token == best_ecdsa_token) {
+			best_ecdsa_token = NULL;
+		}
+		if (token == best_eddsa_token) {
+			best_eddsa_token = NULL;
+		}
 		pk11_mem_put(token, sizeof(*token));
 		token = next;
 	}
 	if (pk11_mctx != NULL)
 		isc_mem_detach(&pk11_mctx);
-	initialized = ISC_FALSE;
+	initialized = false;
 	return (ret);
 }
 
-isc_result_t
-pk11_rand_bytes(unsigned char *buf, int num) {
-	isc_result_t ret;
-	CK_RV rv;
-	pk11_context_t ctx;
-
-	ret = pk11_get_session(&ctx, OP_RAND, ISC_FALSE, ISC_FALSE,
-			       ISC_FALSE, NULL, 0);
-	if ((ret != ISC_R_SUCCESS) &&
-	    (ret != PK11_R_NODIGESTSERVICE) &&
-	    (ret != PK11_R_NOAESSERVICE))
-		return (ret);
-	RUNTIME_CHECK(ctx.session != CK_INVALID_HANDLE);
-	rv = pkcs_C_GenerateRandom(ctx.session,
-				   (CK_BYTE_PTR) buf, (CK_ULONG) num);
-	pk11_return_session(&ctx);
-	if (rv == CKR_OK)
-		return (ISC_R_SUCCESS);
-	else
-		return (DST_R_CRYPTOFAILURE);
-}
-
-#define SEEDSIZE	1024
-
-static CK_BYTE seed[SEEDSIZE];
-
-void
-pk11_rand_seed_fromfile(const char *randomfile) {
-	pk11_context_t ctx;
-	FILE *stream = NULL;
-	size_t cc = 0;
-	isc_result_t ret;
-
-	ret = pk11_get_session(&ctx, OP_RAND, ISC_FALSE, ISC_FALSE,
-			       ISC_FALSE, NULL, 0);
-	if ((ret != ISC_R_SUCCESS) &&
-	    (ret != PK11_R_NODIGESTSERVICE) &&
-	    (ret != PK11_R_NOAESSERVICE))
-		return;
-	RUNTIME_CHECK(ctx.session != CK_INVALID_HANDLE);
-	ret = isc_stdio_open(randomfile, "r", &stream);
-	if (ret != ISC_R_SUCCESS)
-		goto cleanup;
-	while (ret == ISC_R_SUCCESS) {
-		ret = isc_stdio_read(seed, 1, SEEDSIZE, stream, &cc);
-		if ((ret != ISC_R_SUCCESS) && (ret != ISC_R_EOF))
-			goto cleanup;
-		(void) pkcs_C_SeedRandom(ctx.session, seed, (CK_ULONG) cc);
-	}
-	ret = isc_stdio_close(stream);
-	stream = NULL;
-	if (ret != ISC_R_SUCCESS)
-		goto cleanup;
-
-    cleanup:
-	if (stream != NULL)
-		(void) isc_stdio_close(stream);
-	pk11_return_session(&ctx);
-}
-
 isc_result_t
 pk11_get_session(pk11_context_t *ctx, pk11_optype_t optype,
-		 isc_boolean_t need_services, isc_boolean_t rw,
-		 isc_boolean_t logon, const char *pin, CK_SLOT_ID slot)
+		 bool need_services, bool rw,
+		 bool logon, const char *pin, CK_SLOT_ID slot)
 {
 	pk11_token_t *token = NULL;
 	pk11_sessionlist_t *freelist;
 	pk11_session_t *sp;
 	isc_result_t ret;
-#if HAVE_PKCS11
-	isc_result_t service_ret = ISC_R_SUCCESS;
-#else
 	UNUSED(need_services);
-#endif
 
 	memset(ctx, 0, sizeof(pk11_context_t));
 	ctx->handle = NULL;
 	ctx->session = CK_INVALID_HANDLE;
 
 	ret = pk11_initialize(NULL, NULL);
-#if HAVE_PKCS11
-	if (ret == PK11_R_NORANDOMSERVICE ||
-	    ret == PK11_R_NODIGESTSERVICE ||
-	    ret == PK11_R_NOAESSERVICE) {
-		if (need_services)
-			return (ret);
-		service_ret = ret;
-	}
-	else
-#endif /* HAVE_PKCS11 */
 	if (ret != ISC_R_SUCCESS)
 		return (ret);
 
@@ -374,16 +283,6 @@ pk11_get_session(pk11_context_t *ctx, pk11_optype_t optype,
 	UNLOCK(&sessionlock);
 
 	switch(optype) {
-#if HAVE_PKCS11
-	case OP_RAND:
-		token = rand_token;
-		break;
-	case OP_DIGEST:
-		token = digest_token;
-		break;
-	case OP_AES:
-		token = aes_token;
-		break;
 	case OP_ANY:
 		for (token = ISC_LIST_HEAD(tokens);
 		     token != NULL;
@@ -391,18 +290,12 @@ pk11_get_session(pk11_context_t *ctx, pk11_optype_t optype,
 			if (token->slotid == slot)
 				break;
 		break;
-#endif
 	default:
 		for (token = ISC_LIST_HEAD(tokens);
 		     token != NULL;
 		     token = ISC_LIST_NEXT(token, link))
 			if (token->slotid == slot)
 				break;
-#if HAVE_PKCS11
-		if ((token == NULL) ||
-		    ((token->operations & (1 << optype)) == 0))
-			return (ISC_R_NOTFOUND);
-#endif
 		break;
 	}
 	if (token == NULL)
@@ -451,10 +344,6 @@ pk11_get_session(pk11_context_t *ctx, pk11_optype_t optype,
 	UNLOCK(&sessionlock);
 	ctx->handle = sp;
 	ctx->session = sp->session;
-#if HAVE_PKCS11
-	if (ret == ISC_R_SUCCESS)
-		ret = service_ret;
-#endif
 	return (ret);
 }
 
@@ -512,6 +401,7 @@ free_session_list(pk11_sessionlist_t *slist) {
 	LOCK(&sessionlock);
 	while (!ISC_LIST_EMPTY(*slist)) {
 		sp = ISC_LIST_HEAD(*slist);
+		ISC_LIST_UNLINK(*slist, sp, link);
 		UNLOCK(&sessionlock);
 		if (sp->session != CK_INVALID_HANDLE) {
 			rv = pkcs_C_CloseSession(sp->session);
@@ -519,7 +409,6 @@ free_session_list(pk11_sessionlist_t *slist) {
 				ret = DST_R_CRYPTOFAILURE;
 		}
 		LOCK(&sessionlock);
-		ISC_LIST_UNLINK(*slist, sp, link);
 		pk11_mem_put(sp, sizeof(*sp));
 	}
 	UNLOCK(&sessionlock);
@@ -529,7 +418,7 @@ free_session_list(pk11_sessionlist_t *slist) {
 
 static isc_result_t
 setup_session(pk11_session_t *sp, pk11_token_t *token,
-	      isc_boolean_t rw)
+	      bool rw)
 {
 	CK_RV rv;
 	CK_FLAGS flags = CKF_SERIAL_SESSION;
@@ -556,13 +445,14 @@ token_login(pk11_session_t *sp) {
 				  (CK_UTF8CHAR_PTR) token->pin,
 				  (CK_ULONG) strlen(token->pin));
 		if (rv != CKR_OK) {
-			ret = ISC_R_NOPERM;
 #if PK11_NO_LOGERR
 			pk11_error_fatalcheck(__FILE__, __LINE__,
 					      "pkcs_C_Login", rv);
+#else
+			ret = ISC_R_NOPERM;
 #endif
 		} else
-			token->logged = ISC_TRUE;
+			token->logged = true;
 	}
 	UNLOCK(&sessionlock);
 	return (ret);
@@ -587,7 +477,7 @@ scan_slots(void) {
 	CK_ULONG slotCount;
 	pk11_token_t *token;
 	unsigned int i;
-	isc_boolean_t bad;
+	bool bad;
 
 	slotCount = 0;
 	PK11_FATALCHECK(pkcs_C_GetSlotList, (CK_FALSE, NULL_PTR, &slotCount));
@@ -595,7 +485,7 @@ scan_slots(void) {
 	/* it's not an error if we didn't find any providers */
 	if (slotCount == 0)
 		return;
-	slotList = pk11_mem_get(sizeof(CK_SLOT_ID_PTR) * slotCount);
+	slotList = pk11_mem_get(sizeof(CK_SLOT_ID) * slotCount);
 	RUNTIME_CHECK(slotList != NULL);
 	PK11_FATALCHECK(pkcs_C_GetSlotList, (CK_FALSE, slotList, &slotCount));
 
@@ -617,21 +507,14 @@ scan_slots(void) {
 		memmove(token->model, tokenInfo.model, 16);
 		memmove(token->serial, tokenInfo.serialNumber, 16);
 		ISC_LIST_APPEND(tokens, token, link);
-		if ((tokenInfo.flags & CKF_RNG) == 0) {
-			PK11_TRACE("no CKF_RNG\n");
-			goto try_rsa;
-		}
-		token->operations |= 1 << OP_RAND;
-		if (rand_token == NULL)
-			rand_token = token;
 
-	try_rsa:
-		bad = ISC_FALSE;
+		/* Check for RSA support */
+		bad = false;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_RSA_PKCS_KEY_PAIR_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
-			bad = ISC_TRUE;
+			bad = true;
 			PK11_TRACEM(CKM_RSA_PKCS_KEY_PAIR_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_MD5_RSA_PKCS,
@@ -639,9 +522,7 @@ scan_slots(void) {
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-#if !defined(PK11_MD5_DISABLE) && !defined(PK11_RSA_PKCS_REPLACE)
-			bad = ISC_TRUE;
-#endif
+			bad = true;
 			PK11_TRACEM(CKM_MD5_RSA_PKCS);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA1_RSA_PKCS,
@@ -649,9 +530,7 @@ scan_slots(void) {
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-#ifndef PK11_RSA_PKCS_REPLACE
-			bad = ISC_TRUE;
-#endif
+			bad = true;
 			PK11_TRACEM(CKM_SHA1_RSA_PKCS);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA256_RSA_PKCS,
@@ -659,9 +538,7 @@ scan_slots(void) {
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-#ifndef PK11_RSA_PKCS_REPLACE
-			bad = ISC_TRUE;
-#endif
+			bad = true;
 			PK11_TRACEM(CKM_SHA256_RSA_PKCS);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA512_RSA_PKCS,
@@ -669,60 +546,54 @@ scan_slots(void) {
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-#ifndef PK11_RSA_PKCS_REPLACE
-			bad = ISC_TRUE;
-#endif
+			bad = true;
 			PK11_TRACEM(CKM_SHA512_RSA_PKCS);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_RSA_PKCS, &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-#ifdef PK11_RSA_PKCS_REPLACE
-			bad = ISC_TRUE;
-#endif
+			bad = true;
 			PK11_TRACEM(CKM_RSA_PKCS);
 		}
-		if (bad)
-			goto try_dsa;
-		token->operations |= 1 << OP_RSA;
-		if (best_rsa_token == NULL)
-			best_rsa_token = token;
+		if (!bad) {
+			token->operations |= 1 << OP_RSA;
+			if (best_rsa_token == NULL) {
+				best_rsa_token = token;
+			}
+		}
 
-	try_dsa:
-		bad = ISC_FALSE;
+		/* Check for DSA support */
+		bad = false;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_DSA_PARAMETER_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_GENERATE) == 0)) {
-#ifndef PK11_DSA_PARAMETER_GEN_SKIP
-			bad = ISC_TRUE;
-#endif
+			bad = true;
 			PK11_TRACEM(CKM_DSA_PARAMETER_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_DSA_KEY_PAIR_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
-			bad = ISC_TRUE;
+			bad = true;
 			PK11_TRACEM(CKM_DSA_PARAMETER_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_DSA_SHA1, &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-			bad = ISC_TRUE;
+			bad = true;
 			PK11_TRACEM(CKM_DSA_SHA1);
 		}
-		if (bad)
-			goto try_dh;
-#ifndef PK11_DSA_DISABLE
-		token->operations |= 1 << OP_DSA;
-		if (best_dsa_token == NULL)
-			best_dsa_token = token;
-#endif
+		if (!bad) {
+			token->operations |= 1 << OP_DSA;
+			if (best_dsa_token == NULL) {
+				best_dsa_token = token;
+			}
+		}
 
-	try_dh:
-		bad = ISC_FALSE;
+		/* Check for DH support */
+		bad = false;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_DH_PKCS_PARAMETER_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_GENERATE) == 0)) {
@@ -733,164 +604,76 @@ scan_slots(void) {
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
 #ifndef PK11_DH_PKCS_PARAMETER_GEN_SKIP
-			bad = ISC_TRUE;
+			bad = true;
 #endif
 			PK11_TRACEM(CKM_DH_PKCS_KEY_PAIR_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_DH_PKCS_DERIVE,
 					     &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DERIVE) == 0)) {
-			bad = ISC_TRUE;
+			bad = true;
 			PK11_TRACEM(CKM_DH_PKCS_DERIVE);
 		}
-		if (bad)
-			goto try_digest;
-#ifndef PK11_DH_DISABLE
-		token->operations |= 1 << OP_DH;
-		if (best_dh_token == NULL)
-			best_dh_token = token;
-#endif
-
-	try_digest:
-		bad = ISC_FALSE;
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_MD5, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-#ifndef PK11_MD5_DISABLE
-			bad = ISC_TRUE;
-#endif
-			PK11_TRACEM(CKM_MD5);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA_1, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = ISC_TRUE;
-			PK11_TRACEM(CKM_SHA_1);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA224, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = ISC_TRUE;
-			PK11_TRACEM(CKM_SHA224);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA256, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = ISC_TRUE;
-			PK11_TRACEM(CKM_SHA256);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA384, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = ISC_TRUE;
-			PK11_TRACEM(CKM_SHA384);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA512, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = ISC_TRUE;
-			PK11_TRACEM(CKM_SHA512);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_MD5_HMAC, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
-#if !defined(PK11_MD5_DISABLE) && !defined(PK11_MD5_HMAC_REPLACE)
-			bad = ISC_TRUE;
-#endif
-			PK11_TRACEM(CKM_MD5_HMAC);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA_1_HMAC, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
-#ifndef PK11_SHA_1_HMAC_REPLACE
-			bad = ISC_TRUE;
-#endif
-			PK11_TRACEM(CKM_SHA_1_HMAC);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA224_HMAC, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
-#ifndef PK11_SHA224_HMAC_REPLACE
-			bad = ISC_TRUE;
-#endif
-			PK11_TRACEM(CKM_SHA224_HMAC);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA256_HMAC, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
-#ifndef PK11_SHA256_HMAC_REPLACE
-			bad = ISC_TRUE;
-#endif
-			PK11_TRACEM(CKM_SHA256_HMAC);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA384_HMAC, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
-#ifndef PK11_SHA384_HMAC_REPLACE
-			bad = ISC_TRUE;
-#endif
-			PK11_TRACEM(CKM_SHA384_HMAC);
-		}
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA512_HMAC, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
-#ifndef PK11_SHA512_HMAC_REPLACE
-			bad = ISC_TRUE;
-#endif
-			PK11_TRACEM(CKM_SHA512_HMAC);
-		}
 		if (!bad) {
-			token->operations |= 1 << OP_DIGEST;
-			if (digest_token == NULL)
-				digest_token = token;
+			token->operations |= 1 << OP_DH;
+			if (best_dh_token == NULL) {
+				best_dh_token = token;
+			}
 		}
 
-		/* ECDSA requires digest */
+		/* Check for ECDSA support */
+		bad = false;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_EC_KEY_PAIR_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
-			bad = ISC_TRUE;
+			bad = true;
 			PK11_TRACEM(CKM_EC_KEY_PAIR_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_ECDSA, &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-			bad = ISC_TRUE;
+			bad = true;
 			PK11_TRACEM(CKM_ECDSA);
 		}
-		if (bad)
-			goto try_eddsa;
-		token->operations |= 1 << OP_EC;
-		if (best_ec_token == NULL)
-			best_ec_token = token;
+		if (!bad) {
+			token->operations |= 1 << OP_ECDSA;
+			if (best_ecdsa_token == NULL) {
+				best_ecdsa_token = token;
+			}
+		}
 
-	try_eddsa:
 #if defined(CKM_EDDSA_KEY_PAIR_GEN) && defined(CKM_EDDSA) && defined(CKK_EDDSA)
-		bad = ISC_FALSE;
+		/* Check for EDDSA support */
+		/* XXXOND: This was already broken */
+		bad = false;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_EDDSA_KEY_PAIR_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
-			bad = ISC_TRUE;
+			bad = true;
 			PK11_TRACEM(CKM_EDDSA_KEY_PAIR_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_EDDSA, &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-			bad = ISC_TRUE;
+			bad = true;
 			PK11_TRACEM(CKM_EDDSA);
 		}
-		if (bad)
-			goto try_aes;
-
-	try_aes:
-#endif
-		bad = ISC_FALSE;
-		rv = pkcs_C_GetMechanismInfo(slot, CKM_AES_ECB, &mechInfo);
-		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_ENCRYPT) == 0)) {
-			bad = ISC_TRUE;
-			PK11_TRACEM(CKM_AES_ECB);
+		if (!bad) {
+			token->operations |= 1 << OP_EDDSA;
+			if (best_eddsa_token == NULL) {
+				best_eddsa_token = token;
+			}
 		}
-		if (bad)
-			continue;
-		token->operations |= 1 << OP_AES;
-		if (aes_token == NULL)
-			aes_token = token;
+#endif
 	}
 
-	if (slotList != NULL)
-		pk11_mem_put(slotList, sizeof(CK_SLOT_ID_PTR) * slotCount);
+	if (slotList != NULL) {
+		pk11_mem_put(slotList, sizeof(CK_SLOT_ID) * slotCount);
+	}
 }
 
 CK_SLOT_ID
@@ -898,9 +681,6 @@ pk11_get_best_token(pk11_optype_t optype) {
 	pk11_token_t *token = NULL;
 
 	switch (optype) {
-	case OP_RAND:
-		token = rand_token;
-		break;
 	case OP_RSA:
 		token = best_rsa_token;
 		break;
@@ -910,20 +690,15 @@ pk11_get_best_token(pk11_optype_t optype) {
 	case OP_DH:
 		token = best_dh_token;
 		break;
-	case OP_DIGEST:
-		token = digest_token;
+	case OP_ECDSA:
+		token = best_ecdsa_token;
 		break;
-	case OP_EC:
-		token = best_ec_token;
-		break;
-	case OP_AES:
-		token = aes_token;
+	case OP_EDDSA:
+		token = best_eddsa_token;
 		break;
 	default:
-		break;
-	}
-	if (token == NULL)
 		return (0);
+	}
 	return (token->slotid);
 }
 
@@ -992,14 +767,13 @@ pk11_attribute_bytype(const pk11_object_t *obj, CK_ATTRIBUTE_TYPE type) {
 static char *
 percent_decode(char *x, size_t *len) {
 	char *p, *c;
-	unsigned char v;
+	unsigned char v = 0;
 
 	INSIST(len != NULL);
 
 	for (p = c = x; p[0] != '\0'; p++, c++) {
 		switch (p[0]) {
 		case '%':
-			v = 0;
 			switch (p[1]) {
 			case '0':
 			case '1':
@@ -1076,7 +850,7 @@ percent_decode(char *x, size_t *len) {
 	return (x);
 }
 
-static isc_boolean_t
+static bool
 pk11strcmp(const char *x, size_t lenx, const char *y, size_t leny) {
 	char buf[32];
 
@@ -1086,7 +860,7 @@ pk11strcmp(const char *x, size_t lenx, const char *y, size_t leny) {
 	if (lenx > leny)
 		lenx = leny;
 	memmove(buf, x, lenx);
-	return (ISC_TF(memcmp(buf, y, leny) == 0));
+	return (memcmp(buf, y, leny) == 0);
 }
 
 static CK_ATTRIBUTE *
@@ -1132,7 +906,7 @@ pk11_parse_uri(pk11_object_t *obj, const char *label,
 	size_t len, l;
 	FILE *stream = NULL;
 	char pin[PINLEN + 1];
-	isc_boolean_t gotpin = ISC_FALSE;
+	bool gotpin = false;
 	isc_result_t ret;
 
 	/* get values to work on */
@@ -1249,7 +1023,7 @@ pk11_parse_uri(pk11_object_t *obj, const char *label,
 			stream = NULL;
 			if (ret != ISC_R_SUCCESS)
 				goto err;
-			gotpin = ISC_TRUE;
+			gotpin = true;
 		} else
 			DST_RET(PK11_R_NOPROVIDER);
 	}
@@ -1259,21 +1033,24 @@ pk11_parse_uri(pk11_object_t *obj, const char *label,
 		DST_RET(ISC_R_NOTFOUND);
 
 	if (token == NULL) {
-		if (optype == OP_RSA)
+		if (optype == OP_RSA) {
 			token = best_rsa_token;
-		else if (optype == OP_DSA)
+		} else if (optype == OP_DSA) {
 			token = best_dsa_token;
-		else if (optype == OP_DH)
+		} else if (optype == OP_DH) {
 			token = best_dh_token;
-		else if (optype == OP_EC)
-			token = best_ec_token;
+		} else if (optype == OP_ECDSA) {
+			token = best_ecdsa_token;
+		} else if (optype == OP_EDDSA) {
+			token = best_eddsa_token;
+		}
 	}
 	if (token == NULL)
 		DST_RET(ISC_R_NOTFOUND);
 	obj->slot = token->slotid;
 	if (gotpin) {
 		memmove(token->pin, pin, PINLEN + 1);
-		obj->reqlogon = ISC_TRUE;
+		obj->reqlogon = true;
 	}
 
 	ret = ISC_R_SUCCESS;
@@ -1295,16 +1072,14 @@ pk11_error_fatalcheck(const char *file, int line,
 void
 pk11_dump_tokens(void) {
 	pk11_token_t *token;
-	isc_boolean_t first;
+	bool first;
 
 	printf("DEFAULTS\n");
-	printf("\trand_token=%p\n", rand_token);
 	printf("\tbest_rsa_token=%p\n", best_rsa_token);
 	printf("\tbest_dsa_token=%p\n", best_dsa_token);
 	printf("\tbest_dh_token=%p\n", best_dh_token);
-	printf("\tdigest_token=%p\n", digest_token);
-	printf("\tbest_ec_token=%p\n", best_ec_token);
-	printf("\taes_token=%p\n", aes_token);
+	printf("\tbest_ecdsa_token=%p\n", best_ecdsa_token);
+	printf("\tbest_eddsa_token=%p\n", best_eddsa_token);
 
 	for (token = ISC_LIST_HEAD(tokens);
 	     token != NULL;
@@ -1317,49 +1092,28 @@ pk11_dump_tokens(void) {
 		printf("\tmodel=%.16s\n", token->model);
 		printf("\tserialNumber=%.16s\n", token->serial);
 		printf("\tsupported operations=0x%x (", token->operations);
-		first = ISC_TRUE;
-		if (token->operations & (1 << OP_RAND)) {
-			if (!first)
-				printf(",");
-			first = ISC_FALSE;
-			printf("RAND");
-		}
+		first = true;
 		if (token->operations & (1 << OP_RSA)) {
-			if (!first)
-				printf(",");
-			first = ISC_FALSE;
+			first = false;
 			printf("RSA");
 		}
 		if (token->operations & (1 << OP_DSA)) {
 			if (!first)
 				printf(",");
-			first = ISC_FALSE;
+			first = false;
 			printf("DSA");
 		}
 		if (token->operations & (1 << OP_DH)) {
 			if (!first)
 				printf(",");
-			first = ISC_FALSE;
+			first = false;
 			printf("DH");
 		}
-		if (token->operations & (1 << OP_DIGEST)) {
+		if (token->operations & (1 << OP_ECDSA)) {
 			if (!first)
 				printf(",");
-			first = ISC_FALSE;
-			printf("DIGEST");
-		}
-		if (token->operations & (1 << OP_EC)) {
-			if (!first)
-				printf(",");
-			first = ISC_FALSE;
 			printf("EC");
 		}
-		if (token->operations & (1 << OP_AES)) {
-			if (!first)
-				printf(",");
-			first = ISC_FALSE;
-			printf("AES");
-		}
 		printf(")\n");
 	}
 }
