@@ -1,12 +1,14 @@
 /*
- * Copyright (C) 2000, 2001, 2003-2005, 2007, 2013, 2016-2018  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id: thread.c,v 1.17 2007/06/19 23:47:18 tbox Exp $ */
 
 /*! \file */
 
@@ -75,7 +77,7 @@ isc_thread_setconcurrency(unsigned int level) {
 
 void
 isc_thread_setname(isc_thread_t thread, const char *name) {
-#if defined(HAVE_PTHREAD_SETNAME_NP) && defined(_GNU_SOURCE)
+#if defined(HAVE_PTHREAD_SETNAME_NP) && !defined(__APPLE__)
 	/*
 	 * macOS has pthread_setname_np but only works on the
 	 * current thread so it's not used here
