@@ -18,6 +18,8 @@
 
 #include <config.h>
 
+#include <stdbool.h>
+
 #include <isc/app.h>
 #include <isc/condition.h>
 #include <isc/event.h>
@@ -51,12 +53,6 @@
  * is expected to have a separate manager; no "worker threads" are shared by
  * the application threads.
  */
-#ifdef ISC_PLATFORM_USETHREADS
-#define USE_WORKER_THREADS
-#else
-#define USE_SHARED_MANAGER
-#endif	/* ISC_PLATFORM_USETHREADS */
-
 #ifdef ISC_TASK_TRACE
 #define XTRACE(m)		fprintf(stderr, "task %p thread %lu: %s\n", \
 				       task, isc_thread_self(), (m))
@@ -130,26 +126,22 @@ struct isc__taskmgr {
 	isc_taskmgr_t			common;
 	isc_mem_t *			mctx;
 	isc_mutex_t			lock;
-#ifdef ISC_PLATFORM_USETHREADS
 	unsigned int			workers;
 	isc_thread_t *			threads;
-#endif /* ISC_PLATFORM_USETHREADS */
 	/* Locked by task manager lock. */
 	unsigned int			default_quantum;
 	LIST(isc__task_t)		tasks;
 	isc__tasklist_t			ready_tasks;
 	isc__tasklist_t			ready_priority_tasks;
 	isc_taskmgrmode_t		mode;
-#ifdef ISC_PLATFORM_USETHREADS
 	isc_condition_t			work_available;
 	isc_condition_t			exclusive_granted;
 	isc_condition_t			paused;
-#endif /* ISC_PLATFORM_USETHREADS */
 	unsigned int			tasks_running;
 	unsigned int			tasks_ready;
-	isc_boolean_t			pause_requested;
-	isc_boolean_t			exclusive_requested;
-	isc_boolean_t			exiting;
+	bool			pause_requested;
+	bool			exclusive_requested;
+	bool			exiting;
 
 	/*
 	 * Multiple threads can read/write 'excl' at the same time, so we need
@@ -158,19 +150,12 @@ struct isc__taskmgr {
 	 */
 	isc_mutex_t			excl_lock;
 	isc__task_t			*excl;
-#ifdef USE_SHARED_MANAGER
-	unsigned int			refs;
-#endif /* ISC_PLATFORM_USETHREADS */
 };
 
 #define DEFAULT_TASKMGR_QUANTUM		10
 #define DEFAULT_DEFAULT_QUANTUM		5
 #define FINISHED(m)			((m)->exiting && EMPTY((m)->tasks))
 
-#ifdef USE_SHARED_MANAGER
-static isc__taskmgr_t *taskmgr = NULL;
-#endif /* USE_SHARED_MANAGER */
-
 /*%
  * The following are intended for internal use (indicated by "isc__"
  * prefix) but are not declared as static, allowing direct access from
@@ -194,7 +179,7 @@ isc__task_purgerange(isc_task_t *task0, void *sender, isc_eventtype_t first,
 unsigned int
 isc__task_purge(isc_task_t *task, void *sender, isc_eventtype_t type,
 		void *tag);
-isc_boolean_t
+bool
 isc_task_purgeevent(isc_task_t *task0, isc_event_t *event);
 unsigned int
 isc__task_unsendrange(isc_task_t *task, void *sender, isc_eventtype_t first,
@@ -234,15 +219,15 @@ isc__task_beginexclusive(isc_task_t *task);
 void
 isc__task_endexclusive(isc_task_t *task0);
 void
-isc__task_setprivilege(isc_task_t *task0, isc_boolean_t priv);
-isc_boolean_t
+isc__task_setprivilege(isc_task_t *task0, bool priv);
+bool
 isc__task_privilege(isc_task_t *task0);
 void
 isc__taskmgr_setmode(isc_taskmgr_t *manager0, isc_taskmgrmode_t mode);
 isc_taskmgrmode_t
 isc__taskmgr_mode(isc_taskmgr_t *manager0);
 
-static inline isc_boolean_t
+static inline bool
 empty_readyq(isc__taskmgr_t *manager);
 
 static inline isc__task_t *
@@ -312,7 +297,6 @@ task_finished(isc__task_t *task) {
 
 	LOCK(&manager->lock);
 	UNLINK(manager->tasks, task, link);
-#ifdef USE_WORKER_THREADS
 	if (FINISHED(manager)) {
 		/*
 		 * All tasks have completed and the
@@ -322,7 +306,6 @@ task_finished(isc__task_t *task) {
 		 */
 		BROADCAST(&manager->work_available);
 	}
-#endif /* USE_WORKER_THREADS */
 	UNLOCK(&manager->lock);
 
 	DESTROYLOCK(&task->lock);
@@ -337,7 +320,7 @@ isc__task_create(isc_taskmgr_t *manager0, unsigned int quantum,
 {
 	isc__taskmgr_t *manager = (isc__taskmgr_t *)manager0;
 	isc__task_t *task;
-	isc_boolean_t exiting;
+	bool exiting;
 	isc_result_t result;
 
 	REQUIRE(VALID_MANAGER(manager));
@@ -368,14 +351,14 @@ isc__task_create(isc_taskmgr_t *manager0, unsigned int quantum,
 	INIT_LINK(task, ready_link);
 	INIT_LINK(task, ready_priority_link);
 
-	exiting = ISC_FALSE;
+	exiting = false;
 	LOCK(&manager->lock);
 	if (!manager->exiting) {
 		if (task->quantum == 0)
 			task->quantum = manager->default_quantum;
 		APPEND(manager->tasks, task, link);
 	} else
-		exiting = ISC_TRUE;
+		exiting = true;
 	UNLOCK(&manager->lock);
 
 	if (exiting) {
@@ -412,9 +395,9 @@ isc__task_attach(isc_task_t *source0, isc_task_t **targetp) {
 	*targetp = (isc_task_t *)source;
 }
 
-static inline isc_boolean_t
+static inline bool
 task_shutdown(isc__task_t *task) {
-	isc_boolean_t was_idle = ISC_FALSE;
+	bool was_idle = false;
 	isc_event_t *event, *prev;
 
 	/*
@@ -430,7 +413,7 @@ task_shutdown(isc__task_t *task) {
 		if (task->state == task_state_idle) {
 			INSIST(EMPTY(task->events));
 			task->state = task_state_ready;
-			was_idle = ISC_TRUE;
+			was_idle = true;
 		}
 		INSIST(task->state == task_state_ready ||
 		       task->state == task_state_running);
@@ -459,9 +442,7 @@ task_shutdown(isc__task_t *task) {
 static inline void
 task_ready(isc__task_t *task) {
 	isc__taskmgr_t *manager = task->manager;
-#ifdef USE_WORKER_THREADS
-	isc_boolean_t has_privilege = isc__task_privilege((isc_task_t *) task);
-#endif /* USE_WORKER_THREADS */
+	bool has_privilege = isc__task_privilege((isc_task_t *) task);
 
 	REQUIRE(VALID_MANAGER(manager));
 	REQUIRE(task->state == task_state_ready);
@@ -470,14 +451,12 @@ task_ready(isc__task_t *task) {
 
 	LOCK(&manager->lock);
 	push_readyq(manager, task);
-#ifdef USE_WORKER_THREADS
 	if (manager->mode == isc_taskmgrmode_normal || has_privilege)
 		SIGNAL(&manager->work_available);
-#endif /* USE_WORKER_THREADS */
 	UNLOCK(&manager->lock);
 }
 
-static inline isc_boolean_t
+static inline bool
 task_detach(isc__task_t *task) {
 
 	/*
@@ -500,16 +479,16 @@ task_detach(isc__task_t *task) {
 		 * loop to deal with shutting down and termination.
 		 */
 		task->state = task_state_ready;
-		return (ISC_TRUE);
+		return (true);
 	}
 
-	return (ISC_FALSE);
+	return (false);
 }
 
 void
 isc__task_detach(isc_task_t **taskp) {
 	isc__task_t *task;
-	isc_boolean_t was_idle;
+	bool was_idle;
 
 	/*
 	 * Detach *taskp from its task.
@@ -531,9 +510,9 @@ isc__task_detach(isc_task_t **taskp) {
 	*taskp = NULL;
 }
 
-static inline isc_boolean_t
+static inline bool
 task_send(isc__task_t *task, isc_event_t **eventp) {
-	isc_boolean_t was_idle = ISC_FALSE;
+	bool was_idle = false;
 	isc_event_t *event;
 
 	/*
@@ -550,7 +529,7 @@ task_send(isc__task_t *task, isc_event_t **eventp) {
 	XTRACE("task_send");
 
 	if (task->state == task_state_idle) {
-		was_idle = ISC_TRUE;
+		was_idle = true;
 		INSIST(EMPTY(task->events));
 		task->state = task_state_ready;
 	}
@@ -566,7 +545,7 @@ task_send(isc__task_t *task, isc_event_t **eventp) {
 void
 isc__task_send(isc_task_t *task0, isc_event_t **eventp) {
 	isc__task_t *task = (isc__task_t *)task0;
-	isc_boolean_t was_idle;
+	bool was_idle;
 
 	/*
 	 * Send '*event' to 'task'.
@@ -607,7 +586,7 @@ isc__task_send(isc_task_t *task0, isc_event_t **eventp) {
 
 void
 isc__task_sendanddetach(isc_task_t **taskp, isc_event_t **eventp) {
-	isc_boolean_t idle1, idle2;
+	bool idle1, idle2;
 	isc__task_t *task;
 
 	/*
@@ -644,7 +623,7 @@ isc__task_sendanddetach(isc_task_t **taskp, isc_event_t **eventp) {
 static unsigned int
 dequeue_events(isc__task_t *task, void *sender, isc_eventtype_t first,
 	       isc_eventtype_t last, void *tag,
-	       isc_eventlist_t *events, isc_boolean_t purging)
+	       isc_eventlist_t *events, bool purging)
 {
 	isc_event_t *event, *next_event;
 	unsigned int count = 0;
@@ -700,7 +679,7 @@ isc__task_purgerange(isc_task_t *task0, void *sender, isc_eventtype_t first,
 	ISC_LIST_INIT(events);
 
 	count = dequeue_events(task, sender, first, last, tag, &events,
-			       ISC_TRUE);
+			       true);
 
 	for (event = HEAD(events); event != NULL; event = next_event) {
 		next_event = NEXT(event, ev_link);
@@ -728,7 +707,7 @@ isc__task_purge(isc_task_t *task, void *sender, isc_eventtype_t type,
 	return (isc__task_purgerange(task, sender, type, type, tag));
 }
 
-isc_boolean_t
+bool
 isc_task_purgeevent(isc_task_t *task0, isc_event_t *event) {
 	isc__task_t *task = (isc__task_t *)task0;
 	isc_event_t *curr_event, *next_event;
@@ -765,11 +744,11 @@ isc_task_purgeevent(isc_task_t *task0, isc_event_t *event) {
 	UNLOCK(&task->lock);
 
 	if (curr_event == NULL)
-		return (ISC_FALSE);
+		return (false);
 
 	isc_event_free(&curr_event);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 unsigned int
@@ -784,7 +763,7 @@ isc__task_unsendrange(isc_task_t *task, void *sender, isc_eventtype_t first,
 	XTRACE("isc_task_unsendrange");
 
 	return (dequeue_events((isc__task_t *)task, sender, first,
-			       last, tag, events, ISC_FALSE));
+			       last, tag, events, false));
 }
 
 unsigned int
@@ -798,7 +777,7 @@ isc__task_unsend(isc_task_t *task, void *sender, isc_eventtype_t type,
 	XTRACE("isc_task_unsend");
 
 	return (dequeue_events((isc__task_t *)task, sender, type,
-			       type, tag, events, ISC_FALSE));
+			       type, tag, events, false));
 }
 
 isc_result_t
@@ -806,7 +785,7 @@ isc__task_onshutdown(isc_task_t *task0, isc_taskaction_t action,
 		     void *arg)
 {
 	isc__task_t *task = (isc__task_t *)task0;
-	isc_boolean_t disallowed = ISC_FALSE;
+	bool disallowed = false;
 	isc_result_t result = ISC_R_SUCCESS;
 	isc_event_t *event;
 
@@ -829,7 +808,7 @@ isc__task_onshutdown(isc_task_t *task0, isc_taskaction_t action,
 
 	LOCK(&task->lock);
 	if (TASK_SHUTTINGDOWN(task)) {
-		disallowed = ISC_TRUE;
+		disallowed = true;
 		result = ISC_R_SHUTTINGDOWN;
 	} else
 		ENQUEUE(task->on_shutdown, event, ev_link);
@@ -844,7 +823,7 @@ isc__task_onshutdown(isc_task_t *task0, isc_taskaction_t action,
 void
 isc__task_shutdown(isc_task_t *task0) {
 	isc__task_t *task = (isc__task_t *)task0;
-	isc_boolean_t was_idle;
+	bool was_idle;
 
 	/*
 	 * Shutdown 'task'.
@@ -936,13 +915,13 @@ isc__task_getcurrenttimex(isc_task_t *task0, isc_time_t *t) {
  ***/
 
 /*
- * Return ISC_TRUE if the current ready list for the manager, which is
+ * Return true if the current ready list for the manager, which is
  * either ready_tasks or the ready_priority_tasks, depending on whether
  * the manager is currently in normal or privileged execution mode.
  *
  * Caller must hold the task manager lock.
  */
-static inline isc_boolean_t
+static inline bool
 empty_readyq(isc__taskmgr_t *manager) {
 	isc__tasklist_t queue;
 
@@ -951,7 +930,7 @@ empty_readyq(isc__taskmgr_t *manager) {
 	else
 		queue = manager->ready_priority_tasks;
 
-	return (ISC_TF(EMPTY(queue)));
+	return (EMPTY(queue));
 }
 
 /*
@@ -999,12 +978,6 @@ push_readyq(isc__taskmgr_t *manager, isc__task_t *task) {
 static void
 dispatch(isc__taskmgr_t *manager) {
 	isc__task_t *task;
-#ifndef USE_WORKER_THREADS
-	unsigned int total_dispatch_count = 0;
-	isc__tasklist_t new_ready_tasks;
-	isc__tasklist_t new_priority_tasks;
-	unsigned int tasks_ready = 0;
-#endif /* USE_WORKER_THREADS */
 
 	REQUIRE(VALID_MANAGER(manager));
 
@@ -1058,14 +1031,9 @@ dispatch(isc__taskmgr_t *manager) {
 	 * unlocks.  The while expression is always protected by the lock.
 	 */
 
-#ifndef USE_WORKER_THREADS
-	ISC_LIST_INIT(new_ready_tasks);
-	ISC_LIST_INIT(new_priority_tasks);
-#endif
 	LOCK(&manager->lock);
 
 	while (!FINISHED(manager)) {
-#ifdef USE_WORKER_THREADS
 		/*
 		 * For reasons similar to those given in the comment in
 		 * isc_task_send() above, it is safe for us to dequeue
@@ -1087,20 +1055,15 @@ dispatch(isc__taskmgr_t *manager) {
 						    ISC_MSGSET_TASK,
 						    ISC_MSG_AWAKE, "awake"));
 		}
-#else /* USE_WORKER_THREADS */
-		if (total_dispatch_count >= DEFAULT_TASKMGR_QUANTUM ||
-		    empty_readyq(manager))
-			break;
-#endif /* USE_WORKER_THREADS */
 		XTHREADTRACE(isc_msgcat_get(isc_msgcat, ISC_MSGSET_TASK,
 					    ISC_MSG_WORKING, "working"));
 
 		task = pop_readyq(manager);
 		if (task != NULL) {
 			unsigned int dispatch_count = 0;
-			isc_boolean_t done = ISC_FALSE;
-			isc_boolean_t requeue = ISC_FALSE;
-			isc_boolean_t finished = ISC_FALSE;
+			bool done = false;
+			bool requeue = false;
+			bool finished = false;
 			isc_event_t *event;
 
 			INSIST(VALID_TASK(task));
@@ -1142,15 +1105,12 @@ dispatch(isc__taskmgr_t *manager) {
 						LOCK(&task->lock);
 					}
 					dispatch_count++;
-#ifndef USE_WORKER_THREADS
-					total_dispatch_count++;
-#endif /* USE_WORKER_THREADS */
 				}
 
 				if (task->references == 0 &&
 				    EMPTY(task->events) &&
 				    !TASK_SHUTTINGDOWN(task)) {
-					isc_boolean_t was_idle;
+					bool was_idle;
 
 					/*
 					 * There are no references and no
@@ -1197,11 +1157,11 @@ dispatch(isc__taskmgr_t *manager) {
 							       ISC_MSGSET_TASK,
 							       ISC_MSG_DONE,
 							       "done"));
-						finished = ISC_TRUE;
+						finished = true;
 						task->state = task_state_done;
 					} else
 						task->state = task_state_idle;
-					done = ISC_TRUE;
+					done = true;
 				} else if (dispatch_count >= task->quantum) {
 					/*
 					 * Our quantum has expired, but
@@ -1218,8 +1178,8 @@ dispatch(isc__taskmgr_t *manager) {
 							      ISC_MSG_QUANTUM,
 							      "quantum"));
 					task->state = task_state_ready;
-					requeue = ISC_TRUE;
-					done = ISC_TRUE;
+					requeue = true;
+					done = true;
 				}
 			} while (!done);
 			UNLOCK(&task->lock);
@@ -1229,7 +1189,6 @@ dispatch(isc__taskmgr_t *manager) {
 
 			LOCK(&manager->lock);
 			manager->tasks_running--;
-#ifdef USE_WORKER_THREADS
 			if (manager->exclusive_requested &&
 			    manager->tasks_running == 1) {
 				SIGNAL(&manager->exclusive_granted);
@@ -1237,7 +1196,6 @@ dispatch(isc__taskmgr_t *manager) {
 				   manager->tasks_running == 0) {
 				SIGNAL(&manager->paused);
 			}
-#endif /* USE_WORKER_THREADS */
 			if (requeue) {
 				/*
 				 * We know we're awake, so we don't have
@@ -1258,19 +1216,10 @@ dispatch(isc__taskmgr_t *manager) {
 				 * were usually nonempty, the 'optimization'
 				 * might even hurt rather than help.
 				 */
-#ifdef USE_WORKER_THREADS
 				push_readyq(manager, task);
-#else
-				ENQUEUE(new_ready_tasks, task, ready_link);
-				if ((task->flags & TASK_F_PRIVILEGED) != 0)
-					ENQUEUE(new_priority_tasks, task,
-						ready_priority_link);
-				tasks_ready++;
-#endif
 			}
 		}
 
-#ifdef USE_WORKER_THREADS
 		/*
 		 * If we are in privileged execution mode and there are no
 		 * tasks remaining on the current ready queue, then
@@ -1282,22 +1231,11 @@ dispatch(isc__taskmgr_t *manager) {
 			if (!empty_readyq(manager))
 				BROADCAST(&manager->work_available);
 		}
-#endif
 	}
 
-#ifndef USE_WORKER_THREADS
-	ISC_LIST_APPENDLIST(manager->ready_tasks, new_ready_tasks, ready_link);
-	ISC_LIST_APPENDLIST(manager->ready_priority_tasks, new_priority_tasks,
-			    ready_priority_link);
-	manager->tasks_ready += tasks_ready;
-	if (empty_readyq(manager))
-		manager->mode = isc_taskmgrmode_normal;
-#endif
-
 	UNLOCK(&manager->lock);
 }
 
-#ifdef USE_WORKER_THREADS
 static isc_threadresult_t
 #ifdef _WIN32
 WINAPI
@@ -1319,18 +1257,15 @@ run(void *uap) {
 
 	return ((isc_threadresult_t)0);
 }
-#endif /* USE_WORKER_THREADS */
 
 static void
 manager_free(isc__taskmgr_t *manager) {
 	isc_mem_t *mctx;
 
-#ifdef USE_WORKER_THREADS
 	(void)isc_condition_destroy(&manager->exclusive_granted);
 	(void)isc_condition_destroy(&manager->work_available);
 	(void)isc_condition_destroy(&manager->paused);
 	isc_mem_free(manager->mctx, manager->threads);
-#endif /* USE_WORKER_THREADS */
 	DESTROYLOCK(&manager->lock);
 	DESTROYLOCK(&manager->excl_lock);
 	manager->common.impmagic = 0;
@@ -1338,10 +1273,6 @@ manager_free(isc__taskmgr_t *manager) {
 	mctx = manager->mctx;
 	isc_mem_put(mctx, manager, sizeof(*manager));
 	isc_mem_detach(&mctx);
-
-#ifdef USE_SHARED_MANAGER
-	taskmgr = NULL;
-#endif	/* USE_SHARED_MANAGER */
 }
 
 isc_result_t
@@ -1359,21 +1290,6 @@ isc__taskmgr_create(isc_mem_t *mctx, unsigned int workers,
 	REQUIRE(workers > 0);
 	REQUIRE(managerp != NULL && *managerp == NULL);
 
-#ifndef USE_WORKER_THREADS
-	UNUSED(i);
-	UNUSED(started);
-#endif
-
-#ifdef USE_SHARED_MANAGER
-	if (taskmgr != NULL) {
-		if (taskmgr->refs == 0)
-			return (ISC_R_SHUTTINGDOWN);
-		taskmgr->refs++;
-		*managerp = (isc_taskmgr_t *)taskmgr;
-		return (ISC_R_SUCCESS);
-	}
-#endif /* USE_SHARED_MANAGER */
-
 	manager = isc_mem_get(mctx, sizeof(*manager));
 	if (manager == NULL)
 		return (ISC_R_NOMEMORY);
@@ -1391,7 +1307,6 @@ isc__taskmgr_create(isc_mem_t *mctx, unsigned int workers,
 		goto cleanup_mgr;
 	}
 
-#ifdef USE_WORKER_THREADS
 	manager->workers = 0;
 	manager->threads = isc_mem_allocate(mctx,
 					    workers * sizeof(isc_thread_t));
@@ -1423,7 +1338,6 @@ isc__taskmgr_create(isc_mem_t *mctx, unsigned int workers,
 		result = ISC_R_UNEXPECTED;
 		goto cleanup_exclusivegranted;
 	}
-#endif /* USE_WORKER_THREADS */
 	if (default_quantum == 0)
 		default_quantum = DEFAULT_DEFAULT_QUANTUM;
 	manager->default_quantum = default_quantum;
@@ -1432,14 +1346,13 @@ isc__taskmgr_create(isc_mem_t *mctx, unsigned int workers,
 	INIT_LIST(manager->ready_priority_tasks);
 	manager->tasks_running = 0;
 	manager->tasks_ready = 0;
-	manager->exclusive_requested = ISC_FALSE;
-	manager->pause_requested = ISC_FALSE;
-	manager->exiting = ISC_FALSE;
+	manager->exclusive_requested = false;
+	manager->pause_requested = false;
+	manager->exiting = false;
 	manager->excl = NULL;
 
 	isc_mem_attach(mctx, &manager->mctx);
 
-#ifdef USE_WORKER_THREADS
 	LOCK(&manager->lock);
 	/*
 	 * Start workers.
@@ -1463,17 +1376,11 @@ isc__taskmgr_create(isc_mem_t *mctx, unsigned int workers,
 		return (ISC_R_NOTHREADS);
 	}
 	isc_thread_setconcurrency(workers);
-#endif /* USE_WORKER_THREADS */
-#ifdef USE_SHARED_MANAGER
-	manager->refs = 1;
-	taskmgr = manager;
-#endif /* USE_SHARED_MANAGER */
 
 	*managerp = (isc_taskmgr_t *)manager;
 
 	return (ISC_R_SUCCESS);
 
-#ifdef USE_WORKER_THREADS
  cleanup_exclusivegranted:
 	(void)isc_condition_destroy(&manager->exclusive_granted);
  cleanup_workavailable:
@@ -1482,7 +1389,6 @@ isc__taskmgr_create(isc_mem_t *mctx, unsigned int workers,
 	isc_mem_free(mctx, manager->threads);
  cleanup_lock:
 	DESTROYLOCK(&manager->lock);
-#endif
  cleanup_mgr:
 	isc_mem_put(mctx, manager, sizeof(*manager));
 	return (result);
@@ -1502,18 +1408,6 @@ isc__taskmgr_destroy(isc_taskmgr_t **managerp) {
 	manager = (isc__taskmgr_t *)*managerp;
 	REQUIRE(VALID_MANAGER(manager));
 
-#ifndef USE_WORKER_THREADS
-	UNUSED(i);
-#endif /* USE_WORKER_THREADS */
-
-#ifdef USE_SHARED_MANAGER
-	manager->refs--;
-	if (manager->refs > 0) {
-		*managerp = NULL;
-		return;
-	}
-#endif
-
 	XTHREADTRACE("isc_taskmgr_destroy");
 	/*
 	 * Only one non-worker thread may ever call this routine.
@@ -1546,7 +1440,7 @@ isc__taskmgr_destroy(isc_taskmgr_t **managerp) {
 	 * Make sure we only get called once.
 	 */
 	INSIST(!manager->exiting);
-	manager->exiting = ISC_TRUE;
+	manager->exiting = true;
 
 	/*
 	 * If privileged mode was on, turn it off.
@@ -1565,7 +1459,6 @@ isc__taskmgr_destroy(isc_taskmgr_t **managerp) {
 			push_readyq(manager, task);
 		UNLOCK(&task->lock);
 	}
-#ifdef USE_WORKER_THREADS
 	/*
 	 * Wake up any sleeping workers.  This ensures we get work done if
 	 * there's work left to do, and if there are already no tasks left
@@ -1579,28 +1472,6 @@ isc__taskmgr_destroy(isc_taskmgr_t **managerp) {
 	 */
 	for (i = 0; i < manager->workers; i++)
 		(void)isc_thread_join(manager->threads[i], NULL);
-#else /* USE_WORKER_THREADS */
-	/*
-	 * Dispatch the shutdown events.
-	 */
-	UNLOCK(&manager->lock);
-	while (isc__taskmgr_ready((isc_taskmgr_t *)manager))
-		(void)isc__taskmgr_dispatch((isc_taskmgr_t *)manager);
-	if (!ISC_LIST_EMPTY(manager->tasks)) {
-		isc__task_t *t;
-		isc_mem_printallactive(stderr);
-		for (t = ISC_LIST_HEAD(manager->tasks);
-		     t != NULL;
-		     t = ISC_LIST_NEXT(t, link))
-		{
-			fprintf(stderr, "task: %p (%s)\n", t, t->name);
-		}
-	}
-	INSIST(ISC_LIST_EMPTY(manager->tasks));
-#ifdef USE_SHARED_MANAGER
-	taskmgr = NULL;
-#endif
-#endif /* USE_WORKER_THREADS */
 
 	manager_free(manager);
 
@@ -1626,47 +1497,10 @@ isc__taskmgr_mode(isc_taskmgr_t *manager0) {
 	return (mode);
 }
 
-#ifndef USE_WORKER_THREADS
-isc_boolean_t
-isc__taskmgr_ready(isc_taskmgr_t *manager0) {
-	isc__taskmgr_t *manager = (isc__taskmgr_t *)manager0;
-	isc_boolean_t is_ready;
-
-#ifdef USE_SHARED_MANAGER
-	if (manager == NULL)
-		manager = taskmgr;
-#endif
-	if (manager == NULL)
-		return (ISC_FALSE);
-
-	LOCK(&manager->lock);
-	is_ready = !empty_readyq(manager);
-	UNLOCK(&manager->lock);
-
-	return (is_ready);
-}
-
-isc_result_t
-isc__taskmgr_dispatch(isc_taskmgr_t *manager0) {
-	isc__taskmgr_t *manager = (isc__taskmgr_t *)manager0;
-
-#ifdef USE_SHARED_MANAGER
-	if (manager == NULL)
-		manager = taskmgr;
-#endif
-	if (manager == NULL)
-		return (ISC_R_NOTFOUND);
-
-	dispatch(manager);
-
-	return (ISC_R_SUCCESS);
-}
-
-#else
 void
 isc__taskmgr_pause(isc_taskmgr_t *manager0) {
 	isc__taskmgr_t *manager = (isc__taskmgr_t *)manager0;
-	manager->pause_requested = ISC_TRUE;
+	manager->pause_requested = true;
 	LOCK(&manager->lock);
 	while (manager->tasks_running > 0) {
 		WAIT(&manager->paused, &manager->lock);
@@ -1680,12 +1514,11 @@ isc__taskmgr_resume(isc_taskmgr_t *manager0) {
 
 	LOCK(&manager->lock);
 	if (manager->pause_requested) {
-		manager->pause_requested = ISC_FALSE;
+		manager->pause_requested = false;
 		BROADCAST(&manager->work_available);
 	}
 	UNLOCK(&manager->lock);
 }
-#endif /* USE_WORKER_THREADS */
 
 void
 isc_taskmgr_setexcltask(isc_taskmgr_t *mgr0, isc_task_t *task0) {
@@ -1721,7 +1554,6 @@ isc_taskmgr_excltask(isc_taskmgr_t *mgr0, isc_task_t **taskp) {
 
 isc_result_t
 isc__task_beginexclusive(isc_task_t *task0) {
-#ifdef USE_WORKER_THREADS
 	isc__task_t *task = (isc__task_t *)task0;
 	isc__taskmgr_t *manager = task->manager;
 
@@ -1736,42 +1568,35 @@ isc__task_beginexclusive(isc_task_t *task0) {
 		UNLOCK(&manager->lock);
 		return (ISC_R_LOCKBUSY);
 	}
-	manager->exclusive_requested = ISC_TRUE;
+	manager->exclusive_requested = true;
 	while (manager->tasks_running > 1) {
 		WAIT(&manager->exclusive_granted, &manager->lock);
 	}
 	UNLOCK(&manager->lock);
-#else
-	UNUSED(task0);
-#endif
 	return (ISC_R_SUCCESS);
 }
 
 void
 isc__task_endexclusive(isc_task_t *task0) {
-#ifdef USE_WORKER_THREADS
 	isc__task_t *task = (isc__task_t *)task0;
 	isc__taskmgr_t *manager = task->manager;
 
 	REQUIRE(task->state == task_state_running);
 	LOCK(&manager->lock);
 	REQUIRE(manager->exclusive_requested);
-	manager->exclusive_requested = ISC_FALSE;
+	manager->exclusive_requested = false;
 	BROADCAST(&manager->work_available);
 	UNLOCK(&manager->lock);
-#else
-	UNUSED(task0);
-#endif
 }
 
 void
-isc__task_setprivilege(isc_task_t *task0, isc_boolean_t priv) {
+isc__task_setprivilege(isc_task_t *task0, bool priv) {
 	isc__task_t *task = (isc__task_t *)task0;
 	isc__taskmgr_t *manager = task->manager;
-	isc_boolean_t oldpriv;
+	bool oldpriv;
 
 	LOCK(&task->lock);
-	oldpriv = ISC_TF((task->flags & TASK_F_PRIVILEGED) != 0);
+	oldpriv = (task->flags & TASK_F_PRIVILEGED);
 	if (priv)
 		task->flags |= TASK_F_PRIVILEGED;
 	else
@@ -1791,13 +1616,13 @@ isc__task_setprivilege(isc_task_t *task0, isc_boolean_t priv) {
 	UNLOCK(&manager->lock);
 }
 
-isc_boolean_t
+bool
 isc__task_privilege(isc_task_t *task0) {
 	isc__task_t *task = (isc__task_t *)task0;
-	isc_boolean_t priv;
+	bool priv;
 
 	LOCK(&task->lock);
-	priv = ISC_TF((task->flags & TASK_F_PRIVILEGED) != 0);
+	priv = (task->flags & TASK_F_PRIVILEGED);
 	UNLOCK(&task->lock);
 	return (priv);
 }
@@ -1807,7 +1632,7 @@ isc__task_register(void) {
 	return (isc_task_register(isc__taskmgr_create));
 }
 
-isc_boolean_t
+bool
 isc_task_exiting(isc_task_t *t) {
 	isc__task_t *task = (isc__task_t *)t;
 
@@ -1831,7 +1656,6 @@ isc_taskmgr_renderxml(isc_taskmgr_t *mgr0, xmlTextWriterPtr writer) {
 	 * on which type is enabled.
 	 */
 	TRY0(xmlTextWriterStartElement(writer, ISC_XMLCHAR "thread-model"));
-#ifdef ISC_PLATFORM_USETHREADS
 	TRY0(xmlTextWriterStartElement(writer, ISC_XMLCHAR "type"));
 	TRY0(xmlTextWriterWriteString(writer, ISC_XMLCHAR "threaded"));
 	TRY0(xmlTextWriterEndElement(writer)); /* type */
@@ -1839,15 +1663,6 @@ isc_taskmgr_renderxml(isc_taskmgr_t *mgr0, xmlTextWriterPtr writer) {
 	TRY0(xmlTextWriterStartElement(writer, ISC_XMLCHAR "worker-threads"));
 	TRY0(xmlTextWriterWriteFormatString(writer, "%d", mgr->workers));
 	TRY0(xmlTextWriterEndElement(writer)); /* worker-threads */
-#else /* ISC_PLATFORM_USETHREADS */
-	TRY0(xmlTextWriterStartElement(writer, ISC_XMLCHAR "type"));
-	TRY0(xmlTextWriterWriteString(writer, ISC_XMLCHAR "non-threaded"));
-	TRY0(xmlTextWriterEndElement(writer)); /* type */
-
-	TRY0(xmlTextWriterStartElement(writer, ISC_XMLCHAR "references"));
-	TRY0(xmlTextWriterWriteFormatString(writer, "%d", mgr->refs));
-	TRY0(xmlTextWriterEndElement(writer)); /* references */
-#endif /* ISC_PLATFORM_USETHREADS */
 
 	TRY0(xmlTextWriterStartElement(writer, ISC_XMLCHAR "default-quantum"));
 	TRY0(xmlTextWriterWriteFormatString(writer, "%d",
@@ -1940,7 +1755,6 @@ isc_taskmgr_renderjson(isc_taskmgr_t *mgr0, json_object *tasks) {
 	 * Write out the thread-model, and some details about each depending
 	 * on which type is enabled.
 	 */
-#ifdef ISC_PLATFORM_USETHREADS
 	obj = json_object_new_string("threaded");
 	CHECKMEM(obj);
 	json_object_object_add(tasks, "thread-model", obj);
@@ -1948,15 +1762,6 @@ isc_taskmgr_renderjson(isc_taskmgr_t *mgr0, json_object *tasks) {
 	obj = json_object_new_int(mgr->workers);
 	CHECKMEM(obj);
 	json_object_object_add(tasks, "worker-threads", obj);
-#else /* ISC_PLATFORM_USETHREADS */
-	obj = json_object_new_string("non-threaded");
-	CHECKMEM(obj);
-	json_object_object_add(tasks, "thread-model", obj);
-
-	obj = json_object_new_int(mgr->refs);
-	CHECKMEM(obj);
-	json_object_object_add(tasks, "references", obj);
-#endif /* ISC_PLATFORM_USETHREADS */
 
 	obj = json_object_new_int(mgr->default_quantum);
 	CHECKMEM(obj);
@@ -2279,7 +2084,7 @@ isc_task_endexclusive(isc_task_t *task) {
 }
 
 void
-isc_task_setprivilege(isc_task_t *task, isc_boolean_t priv) {
+isc_task_setprivilege(isc_task_t *task, bool priv) {
 	REQUIRE(ISCAPI_TASK_VALID(task));
 
 	if (isc_bind9)
@@ -2288,7 +2093,7 @@ isc_task_setprivilege(isc_task_t *task, isc_boolean_t priv) {
 		task->methods->setprivilege(task, priv);
 }
 
-isc_boolean_t
+bool
 isc_task_privilege(isc_task_t *task) {
 	REQUIRE(ISCAPI_TASK_VALID(task));
 
