@@ -13,6 +13,8 @@
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <time.h>
 
@@ -70,11 +72,7 @@ create_managers(unsigned int workers) {
 	char *p;
 
 	if (workers == 0) {
-#ifdef ISC_PLATFORM_USETHREADS
 		workers = isc_os_ncpus();
-#else
-		workers = 1;
-#endif
 	}
 
 	p = getenv("ISC_TASK_WORKERS");
@@ -96,7 +94,7 @@ create_managers(unsigned int workers) {
 }
 
 isc_result_t
-isc_test_begin(FILE *logfile, isc_boolean_t start_managers,
+isc_test_begin(FILE *logfile, bool start_managers,
 	       unsigned int workers)
 {
 	isc_result_t result;
@@ -123,11 +121,7 @@ isc_test_begin(FILE *logfile, isc_boolean_t start_managers,
 		CHECK(isc_log_usechannel(logconfig, "stderr", NULL, NULL));
 	}
 
-#ifdef ISC_PLATFORM_USETHREADS
 	ncpus = isc_os_ncpus();
-#else
-	ncpus = 1;
-#endif
 
 	if (start_managers) {
 		CHECK(create_managers(workers));
@@ -159,7 +153,7 @@ isc_test_end(void) {
  * Sleep for 'usec' microseconds.
  */
 void
-isc_test_nap(isc_uint32_t usec) {
+isc_test_nap(uint32_t usec) {
 #ifdef HAVE_NANOSLEEP
 	struct timespec ts;
 
