@@ -1,12 +1,14 @@
 /*
- * Copyright (C) 2013, 2015-2017  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id$ */
 
 /* ! \file */
 
@@ -37,24 +39,6 @@ ATF_TC_BODY(isc_safe_memequal, tc) {
 				     "\x00\x00\x00\x00", 4));
 }
 
-ATF_TC(isc_safe_memcompare);
-ATF_TC_HEAD(isc_safe_memcompare, tc) {
-	atf_tc_set_md_var(tc, "descr", "safe memcompare()");
-}
-ATF_TC_BODY(isc_safe_memcompare, tc) {
-	UNUSED(tc);
-
-	ATF_CHECK(isc_safe_memcompare("test", "test", 4) == 0);
-	ATF_CHECK(isc_safe_memcompare("test", "tesc", 4) > 0);
-	ATF_CHECK(isc_safe_memcompare("test", "tesy", 4) < 0);
-	ATF_CHECK(isc_safe_memcompare("\x00\x00\x00\x00",
-				      "\x00\x00\x00\x00", 4) == 0);
-	ATF_CHECK(isc_safe_memcompare("\x00\x00\x00\x00",
-				      "\x00\x00\x00\x01", 4) < 0);
-	ATF_CHECK(isc_safe_memcompare("\x00\x00\x00\x02",
-				      "\x00\x00\x00\x00", 4) > 0);
-}
-
 ATF_TC(isc_safe_memwipe);
 ATF_TC_HEAD(isc_safe_memwipe, tc) {
 	atf_tc_set_md_var(tc, "descr", "isc_safe_memwipe()");
@@ -65,7 +49,6 @@ ATF_TC_BODY(isc_safe_memwipe, tc) {
 	/* These should pass. */
 	isc_safe_memwipe(NULL, 0);
 	isc_safe_memwipe((void *) -1, 0);
-	isc_safe_memwipe(NULL, 42);
 
 	/*
 	 * isc_safe_memwipe(ptr, size) should function same as
@@ -104,7 +87,6 @@ ATF_TC_BODY(isc_safe_memwipe, tc) {
  */
 ATF_TP_ADD_TCS(tp) {
 	ATF_TP_ADD_TC(tp, isc_safe_memequal);
-	ATF_TP_ADD_TC(tp, isc_safe_memcompare);
 	ATF_TP_ADD_TC(tp, isc_safe_memwipe);
 	return (atf_no_error());
 }
