@@ -1,15 +1,18 @@
 /*
- * Copyright (C) 1999-2005, 2007, 2008, 2012-2017  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id$ */
 
 #include <config.h>
 
+#include <stdbool.h>
 #include <sys/types.h>
 
 #if defined(HAVE_SYS_SYSCTL_H)
@@ -29,7 +32,7 @@
 #include <isc/net.h>
 #include <isc/netdb.h>
 #include <isc/once.h>
-#include <isc/strerror.h>
+#include <isc/strerr.h>
 #include <isc/string.h>
 #include <isc/util.h>
 
@@ -90,23 +93,8 @@
 
 #endif /* HAVE_SYSCTLBYNAME */
 
-#if defined(ISC_PLATFORM_HAVEIPV6)
-# if defined(ISC_PLATFORM_NEEDIN6ADDRANY)
-const struct in6_addr isc_net_in6addrany = IN6ADDR_ANY_INIT;
-# endif
-
-# if defined(ISC_PLATFORM_NEEDIN6ADDRLOOPBACK)
-const struct in6_addr isc_net_in6addrloop = IN6ADDR_LOOPBACK_INIT;
-# endif
-
-# if defined(WANT_IPV6)
 static isc_once_t 	once_ipv6only = ISC_ONCE_INIT;
-
-#  if defined(ISC_PLATFORM_HAVEIN6PKTINFO)
 static isc_once_t 	once_ipv6pktinfo = ISC_ONCE_INIT;
-#  endif
-# endif /* WANT_IPV6 */
-#endif /* ISC_PLATFORM_HAVEIPV6 */
 
 #ifndef ISC_CMSG_IP_TOS
 #ifdef __APPLE__
@@ -149,7 +137,7 @@ try_proto(int domain) {
 #endif
 			return (ISC_R_NOTFOUND);
 		default:
-			isc__strerror(errno, strbuf, sizeof(strbuf));
+			strerror_r(errno, strbuf, sizeof(strbuf));
 			UNEXPECTED_ERROR(__FILE__, __LINE__,
 					 "socket() %s: %s",
 					 isc_msgcat_get(isc_msgcat,
@@ -161,9 +149,6 @@ try_proto(int domain) {
 		}
 	}
 
-#ifdef ISC_PLATFORM_HAVEIPV6
-#ifdef WANT_IPV6
-#ifdef ISC_PLATFORM_HAVEIN6PKTINFO
 	if (domain == PF_INET6) {
 		struct sockaddr_in6 sin6;
 		unsigned int len;
@@ -201,9 +186,6 @@ try_proto(int domain) {
 			}
 		}
 	}
-#endif
-#endif
-#endif
 
 	(void)close(s);
 
@@ -213,13 +195,7 @@ try_proto(int domain) {
 static void
 initialize_action(void) {
 	ipv4_result = try_proto(PF_INET);
-#ifdef ISC_PLATFORM_HAVEIPV6
-#ifdef WANT_IPV6
-#ifdef ISC_PLATFORM_HAVEIN6PKTINFO
 	ipv6_result = try_proto(PF_INET6);
-#endif
-#endif
-#endif
 #ifdef ISC_PLATFORM_HAVESYSUNH
 	unix_result = try_proto(PF_UNIX);
 #endif
@@ -248,8 +224,6 @@ isc_net_probeunix(void) {
 	return (unix_result);
 }
 
-#ifdef ISC_PLATFORM_HAVEIPV6
-#ifdef WANT_IPV6
 static void
 try_ipv6only(void) {
 #ifdef IPV6_V6ONLY
@@ -271,7 +245,7 @@ try_ipv6only(void) {
 	/* check for TCP sockets */
 	s = socket(PF_INET6, SOCK_STREAM, 0);
 	if (s == -1) {
-		isc__strerror(errno, strbuf, sizeof(strbuf));
+		strerror_r(errno, strbuf, sizeof(strbuf));
 		UNEXPECTED_ERROR(__FILE__, __LINE__,
 				 "socket() %s: %s",
 				 isc_msgcat_get(isc_msgcat,
@@ -294,7 +268,7 @@ try_ipv6only(void) {
 	/* check for UDP sockets */
 	s = socket(PF_INET6, SOCK_DGRAM, 0);
 	if (s == -1) {
-		isc__strerror(errno, strbuf, sizeof(strbuf));
+		strerror_r(errno, strbuf, sizeof(strbuf));
 		UNEXPECTED_ERROR(__FILE__, __LINE__,
 				 "socket() %s: %s",
 				 isc_msgcat_get(isc_msgcat,
@@ -325,10 +299,7 @@ initialize_ipv6only(void) {
 	RUNTIME_CHECK(isc_once_do(&once_ipv6only,
 				  try_ipv6only) == ISC_R_SUCCESS);
 }
-#endif /* WANT_IPV6 */
 
-#ifdef ISC_PLATFORM_HAVEIN6PKTINFO
-#ifdef WANT_IPV6
 static void
 try_ipv6pktinfo(void) {
 	int s, on;
@@ -345,7 +316,7 @@ try_ipv6pktinfo(void) {
 	/* we only use this for UDP sockets */
 	s = socket(PF_INET6, SOCK_DGRAM, IPPROTO_UDP);
 	if (s == -1) {
-		isc__strerror(errno, strbuf, sizeof(strbuf));
+		strerror_r(errno, strbuf, sizeof(strbuf));
 		UNEXPECTED_ERROR(__FILE__, __LINE__,
 				 "socket() %s: %s",
 				 isc_msgcat_get(isc_msgcat,
@@ -380,38 +351,20 @@ initialize_ipv6pktinfo(void) {
 	RUNTIME_CHECK(isc_once_do(&once_ipv6pktinfo,
 				  try_ipv6pktinfo) == ISC_R_SUCCESS);
 }
-#endif /* WANT_IPV6 */
-#endif /* ISC_PLATFORM_HAVEIN6PKTINFO */
-#endif /* ISC_PLATFORM_HAVEIPV6 */
 
 isc_result_t
 isc_net_probe_ipv6only(void) {
-#ifdef ISC_PLATFORM_HAVEIPV6
-#ifdef WANT_IPV6
 	initialize_ipv6only();
-#else
-	ipv6only_result = ISC_R_NOTFOUND;
-#endif
-#endif
 	return (ipv6only_result);
 }
 
 isc_result_t
 isc_net_probe_ipv6pktinfo(void) {
-#ifdef ISC_PLATFORM_HAVEIPV6
-#ifdef ISC_PLATFORM_HAVEIN6PKTINFO
-#ifdef WANT_IPV6
 	initialize_ipv6pktinfo();
-#else
-	ipv6pktinfo_result = ISC_R_NOTFOUND;
-#endif
-#endif
-#endif
 	return (ipv6pktinfo_result);
 }
 
-#if ISC_CMSG_IP_TOS || \
-    defined(ISC_NET_BSD44MSGHDR) && defined(IPV6_TCLASS) && defined(WANT_IPV6)
+#if ISC_CMSG_IP_TOS || defined(IPV6_TCLASS)
 
 static inline ISC_SOCKADDR_LEN_T
 cmsg_len(ISC_SOCKADDR_LEN_T len) {
@@ -457,7 +410,6 @@ cmsg_space(ISC_SOCKADDR_LEN_T len) {
 #endif
 }
 
-#ifdef ISC_NET_BSD44MSGHDR
 /*
  * Make a fd non-blocking.
  */
@@ -477,7 +429,7 @@ make_nonblock(int fd) {
 #endif
 
 	if (ret == -1) {
-		isc__strerror(errno, strbuf, sizeof(strbuf));
+		strerror_r(errno, strbuf, sizeof(strbuf));
 		UNEXPECTED_ERROR(__FILE__, __LINE__,
 #ifdef USE_FIONBIO_IOCTL
 				 "ioctl(%d, FIONBIO, &on): %s", fd,
@@ -492,7 +444,7 @@ make_nonblock(int fd) {
 	return (ISC_R_SUCCESS);
 }
 
-static isc_boolean_t
+static bool
 cmsgsend(int s, int level, int type, struct addrinfo *res) {
 	char strbuf[ISC_STRERRORSIZE];
 	struct sockaddr_storage ss;
@@ -509,19 +461,19 @@ cmsgsend(int s, int level, int type, struct addrinfo *res) {
 	isc_result_t result;
 
 	if (bind(s, res->ai_addr, res->ai_addrlen) < 0) {
-		isc__strerror(errno, strbuf, sizeof(strbuf));
+		strerror_r(errno, strbuf, sizeof(strbuf));
 		isc_log_write(isc_lctx, ISC_LOGCATEGORY_GENERAL,
 			      ISC_LOGMODULE_SOCKET, ISC_LOG_DEBUG(10),
 			      "bind: %s", strbuf);
-		return (ISC_FALSE);
+		return (false);
 	}
 
 	if (getsockname(s, (struct sockaddr *)&ss, &len) < 0) {
-		isc__strerror(errno, strbuf, sizeof(strbuf));
+		strerror_r(errno, strbuf, sizeof(strbuf));
 		isc_log_write(isc_lctx, ISC_LOGCATEGORY_GENERAL,
 			      ISC_LOGMODULE_SOCKET, ISC_LOG_DEBUG(10),
 			      "getsockname: %s", strbuf);
-		return (ISC_FALSE);
+		return (false);
 	}
 
 	iovec.iov_base = buf;
@@ -580,7 +532,7 @@ cmsgsend(int s, int level, int type, struct addrinfo *res) {
 		default:
 			debug = ISC_LOG_NOTICE;
 		}
-		isc__strerror(errno, strbuf, sizeof(strbuf));
+		strerror_r(errno, strbuf, sizeof(strbuf));
 		if (debug != ISC_LOG_NOTICE) {
 			isc_log_write(isc_lctx, ISC_LOGCATEGORY_GENERAL,
 				      ISC_LOGMODULE_SOCKET, ISC_LOG_DEBUG(10),
@@ -593,7 +545,7 @@ cmsgsend(int s, int level, int type, struct addrinfo *res) {
 					 "sendmsg() with %s=%02x %s: %s",
 					 typestr, dscp, msgstr, strbuf);
 		}
-		return (ISC_FALSE);
+		return (false);
 	}
 
 	/*
@@ -615,12 +567,11 @@ cmsgsend(int s, int level, int type, struct addrinfo *res) {
 	msg.msg_flags = 0;
 
 	if (recvmsg(s, &msg, 0) < 0)
-		return (ISC_FALSE);
+		return (false);
 
-	return (ISC_TRUE);
+	return (true);
 }
 #endif
-#endif
 
 static void
 try_dscp_v4(void) {
@@ -653,7 +604,7 @@ try_dscp_v4(void) {
 	s = socket(res0->ai_family, res0->ai_socktype, res0->ai_protocol);
 
 	if (s == -1) {
-		isc__strerror(errno, strbuf, sizeof(strbuf));
+		strerror_r(errno, strbuf, sizeof(strbuf));
 		isc_log_write(isc_lctx, ISC_LOGCATEGORY_GENERAL,
 			      ISC_LOGMODULE_SOCKET, ISC_LOG_DEBUG(10),
 			      "socket: %s", strbuf);
@@ -670,15 +621,11 @@ try_dscp_v4(void) {
 		dscp_result |= ISC_NET_DSCPRECVV4;
 #endif /* IP_RECVTOS */
 
-#ifdef ISC_NET_BSD44MSGHDR
-
 #if ISC_CMSG_IP_TOS
 	if (cmsgsend(s, IPPROTO_IP, IP_TOS, res0))
 		dscp_result |= ISC_NET_DSCPPKTV4;
 #endif /* ISC_CMSG_IP_TOS */
 
-#endif /* ISC_NET_BSD44MSGHDR */
-
 	freeaddrinfo(res0);
 	close(s);
 
@@ -687,8 +634,6 @@ try_dscp_v4(void) {
 
 static void
 try_dscp_v6(void) {
-#ifdef ISC_PLATFORM_HAVEIPV6
-#ifdef WANT_IPV6
 #ifdef IPV6_TCLASS
 	char strbuf[ISC_STRERRORSIZE];
 	struct addrinfo hints, *res0;
@@ -717,7 +662,7 @@ try_dscp_v6(void) {
 
 	s = socket(res0->ai_family, res0->ai_socktype, res0->ai_protocol);
 	if (s == -1) {
-		isc__strerror(errno, strbuf, sizeof(strbuf));
+		strerror_r(errno, strbuf, sizeof(strbuf));
 		isc_log_write(isc_lctx, ISC_LOGCATEGORY_GENERAL,
 			      ISC_LOGMODULE_SOCKET, ISC_LOG_DEBUG(10),
 			      "socket: %s", strbuf);
@@ -733,17 +678,13 @@ try_dscp_v6(void) {
 		dscp_result |= ISC_NET_DSCPRECVV6;
 #endif /* IPV6_RECVTCLASS */
 
-#ifdef ISC_NET_BSD44MSGHDR
 	if (cmsgsend(s, IPPROTO_IPV6, IPV6_TCLASS, res0))
 		dscp_result |= ISC_NET_DSCPPKTV6;
-#endif /* ISC_NET_BSD44MSGHDR */
 
 	freeaddrinfo(res0);
 	close(s);
 
 #endif /* IPV6_TCLASS */
-#endif /* WANT_IPV6 */
-#endif /* ISC_PLATFORM_HAVEIPV6 */
 }
 
 static void
