@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -28,10 +28,6 @@
 #include <linux/fs.h>	/* To get the large NR_OPEN. */
 #endif
 
-#if defined(__hpux) && defined(HAVE_SYS_DYNTUNE_H)
-#include <sys/dyntune.h>
-#endif
-
 #include "errno2result.h"
 
 static isc_result_t
@@ -100,7 +96,7 @@ resource2rlim(isc_resource_t resource, int *rlim_resource) {
 isc_result_t
 isc_resource_setlimit(isc_resource_t resource, isc_resourcevalue_t value) {
 	struct rlimit rl;
-	ISC_PLATFORM_RLIMITTYPE rlim_value;
+	rlim_t rlim_value;
 	int unixresult;
 	int unixresource;
 	isc_result_t result;
@@ -118,17 +114,17 @@ isc_resource_setlimit(isc_resource_t resource, isc_resourcevalue_t value) {
 		 * integer so that it could contain the maximum range of
 		 * reasonable values.  Unfortunately, this exceeds the typical
 		 * range on Unix systems.  Ensure the range of
-		 * ISC_PLATFORM_RLIMITTYPE is not overflowed.
+		 * rlim_t is not overflowed.
 		 */
 		isc_resourcevalue_t rlim_max;
 		bool rlim_t_is_signed =
-			(((double)(ISC_PLATFORM_RLIMITTYPE)-1) < 0);
+			(((double)(rlim_t)-1) < 0);
 
 		if (rlim_t_is_signed)
-			rlim_max = ~((ISC_PLATFORM_RLIMITTYPE)1 <<
-				     (sizeof(ISC_PLATFORM_RLIMITTYPE) * 8 - 1));
+			rlim_max = ~((rlim_t)1 <<
+				     (sizeof(rlim_t) * 8 - 1));
 		else
-			rlim_max = (ISC_PLATFORM_RLIMITTYPE)-1;
+			rlim_max = (rlim_t)-1;
 
 		if (value > rlim_max)
 			value = rlim_max;
@@ -170,16 +166,6 @@ isc_resource_setlimit(isc_resource_t resource, isc_resourcevalue_t value) {
 		if (unixresult == 0)
 			return (ISC_R_SUCCESS);
 	}
-#elif defined(__hpux) && defined(HAVE_SYS_DYNTUNE_H)
-	if (resource == isc_resource_openfiles && rlim_value == RLIM_INFINITY) {
-		uint64_t maxfiles;
-		if (gettune("maxfiles_lim", &maxfiles) == 0) {
-			rl.rlim_cur = rl.rlim_max = maxfiles;
-			unixresult = setrlimit(unixresource, &rl);
-			if (unixresult == 0)
-				return (ISC_R_SUCCESS);
-		}
-	}
 #endif
 	if (resource == isc_resource_openfiles && rlim_value == RLIM_INFINITY) {
 		if (getrlimit(unixresource, &rl) == 0) {
@@ -194,38 +180,34 @@ isc_resource_setlimit(isc_resource_t resource, isc_resourcevalue_t value) {
 
 isc_result_t
 isc_resource_getlimit(isc_resource_t resource, isc_resourcevalue_t *value) {
+	int unixresult;
 	int unixresource;
 	struct rlimit rl;
 	isc_result_t result;
 
 	result = resource2rlim(resource, &unixresource);
-	if (result != ISC_R_SUCCESS) {
-		return (result);
+	if (result == ISC_R_SUCCESS) {
+		unixresult = getrlimit(unixresource, &rl);
+		INSIST(unixresult == 0);
+		*value = rl.rlim_max;
 	}
 
-	if (getrlimit(unixresource, &rl) != 0) {
-		return (isc__errno2result(errno));
-	}
-
-	*value = rl.rlim_max;
-	return (ISC_R_SUCCESS);
+	return (result);
 }
 
 isc_result_t
 isc_resource_getcurlimit(isc_resource_t resource, isc_resourcevalue_t *value) {
+	int unixresult;
 	int unixresource;
 	struct rlimit rl;
 	isc_result_t result;
 
 	result = resource2rlim(resource, &unixresource);
-	if (result != ISC_R_SUCCESS) {
-		return (result);
+	if (result == ISC_R_SUCCESS) {
+		unixresult = getrlimit(unixresource, &rl);
+		INSIST(unixresult == 0);
+		*value = rl.rlim_cur;
 	}
 
-	if (getrlimit(unixresource, &rl) != 0) {
-		return (isc__errno2result(errno));
-	}
-
-	*value = rl.rlim_cur;
-	return (ISC_R_SUCCESS);
+	return (result);
 }
