@@ -13,6 +13,8 @@
 
 #include <config.h>
 
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdlib.h>
 
 #include <isc/buffer.h>
@@ -88,7 +90,7 @@ free_map(cfg_parser_t *pctx, cfg_obj_t *obj);
 static isc_result_t
 parse_symtab_elt(cfg_parser_t *pctx, const char *name,
 		 cfg_type_t *elttype, isc_symtab_t *symtab,
-		 isc_boolean_t callback);
+		 bool callback);
 
 static void
 free_noop(cfg_parser_t *pctx, cfg_obj_t *obj);
@@ -97,7 +99,7 @@ static isc_result_t
 cfg_getstringtoken(cfg_parser_t *pctx);
 
 static void
-parser_complain(cfg_parser_t *pctx, isc_boolean_t is_warning,
+parser_complain(cfg_parser_t *pctx, bool is_warning,
 		unsigned int flags, const char *format, va_list args);
 
 /*
@@ -291,7 +293,7 @@ cfg_print_tuple(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	unsigned int i;
 	const cfg_tuplefielddef_t *fields;
 	const cfg_tuplefielddef_t *f;
-	isc_boolean_t need_space = ISC_FALSE;
+	bool need_space = false;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(obj != NULL);
@@ -303,8 +305,8 @@ cfg_print_tuple(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 		if (need_space && fieldobj->type->rep != &cfg_rep_void)
 			cfg_print_cstr(pctx, " ");
 		cfg_print_obj(pctx, fieldobj);
-		need_space = ISC_TF(need_space ||
-				    fieldobj->type->print != cfg_print_void);
+		need_space = (need_space ||
+			      fieldobj->type->print != cfg_print_void);
 	}
 }
 
@@ -312,7 +314,7 @@ void
 cfg_doc_tuple(cfg_printer_t *pctx, const cfg_type_t *type) {
 	const cfg_tuplefielddef_t *fields;
 	const cfg_tuplefielddef_t *f;
-	isc_boolean_t need_space = ISC_FALSE;
+	bool need_space = false;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(type != NULL);
@@ -323,7 +325,7 @@ cfg_doc_tuple(cfg_printer_t *pctx, const cfg_type_t *type) {
 		if (need_space)
 			cfg_print_cstr(pctx, " ");
 		cfg_doc_obj(pctx, f->type);
-		need_space = ISC_TF(f->type->print != cfg_print_void);
+		need_space = (f->type->print != cfg_print_void);
 	}
 }
 
@@ -345,10 +347,10 @@ free_tuple(cfg_parser_t *pctx, cfg_obj_t *obj) {
 		    nfields * sizeof(cfg_obj_t *));
 }
 
-isc_boolean_t
+bool
 cfg_obj_istuple(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_tuple));
+	return (obj->type->rep == &cfg_rep_tuple);
 }
 
 const cfg_obj_t *
@@ -449,16 +451,12 @@ cfg_parser_create(isc_mem_t *mctx, isc_log_t *lctx, cfg_parser_t **ret) {
 	pctx->mctx = NULL;
 	isc_mem_attach(mctx, &pctx->mctx);
 
-	result = isc_refcount_init(&pctx->references, 1);
-	if (result != ISC_R_SUCCESS) {
-		isc_mem_putanddetach(&pctx->mctx, pctx, sizeof(*pctx));
-		return (result);
-	}
+	isc_refcount_init(&pctx->references, 1);
 
 	pctx->lctx = lctx;
 	pctx->lexer = NULL;
-	pctx->seen_eof = ISC_FALSE;
-	pctx->ungotten = ISC_FALSE;
+	pctx->seen_eof = false;
+	pctx->ungotten = false;
 	pctx->errors = 0;
 	pctx->warnings = 0;
 	pctx->open_files = NULL;
@@ -542,8 +540,8 @@ cfg_parser_reset(cfg_parser_t *pctx) {
 	if (pctx->lexer != NULL)
 		isc_lex_close(pctx->lexer);
 
-	pctx->seen_eof = ISC_FALSE;
-	pctx->ungotten = ISC_FALSE;
+	pctx->seen_eof = false;
+	pctx->ungotten = false;
 	pctx->errors = 0;
 	pctx->warnings = 0;
 	pctx->line = 0;
@@ -668,22 +666,19 @@ cfg_parser_attach(cfg_parser_t *src, cfg_parser_t **dest) {
 	REQUIRE(src != NULL);
 	REQUIRE(dest != NULL && *dest == NULL);
 
-	isc_refcount_increment(&src->references, NULL);
+	isc_refcount_increment(&src->references);
 	*dest = src;
 }
 
 void
 cfg_parser_destroy(cfg_parser_t **pctxp) {
 	cfg_parser_t *pctx;
-	unsigned int refs;
 
 	REQUIRE(pctxp != NULL && *pctxp != NULL);
-
 	pctx = *pctxp;
 	*pctxp = NULL;
 
-	isc_refcount_decrement(&pctx->references, &refs);
-	if (refs == 0) {
+	if (isc_refcount_decrement(&pctx->references) == 1) {
 		isc_lex_destroy(&pctx->lexer);
 		/*
 		 * Cleaning up open_files does not
@@ -729,10 +724,10 @@ cfg_doc_void(cfg_printer_t *pctx, const cfg_type_t *type) {
 	UNUSED(type);
 }
 
-isc_boolean_t
+bool
 cfg_obj_isvoid(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_void));
+	return (obj->type->rep == &cfg_rep_void);
 }
 
 LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_void = {
@@ -749,7 +744,7 @@ cfg_parse_percentage(cfg_parser_t *pctx, const cfg_type_t *type,
 	char *endp;
 	isc_result_t result;
 	cfg_obj_t *obj = NULL;
-	isc_uint64_t percent;
+	uint64_t percent;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
@@ -771,7 +766,7 @@ cfg_parse_percentage(cfg_parser_t *pctx, const cfg_type_t *type,
 	}
 
 	CHECK(cfg_create_obj(pctx, &cfg_type_percentage, &obj));
-	obj->value.uint32 = (isc_uint32_t)percent;
+	obj->value.uint32 = (uint32_t)percent;
 	*ret = obj;
 
  cleanup:
@@ -791,7 +786,7 @@ cfg_print_percentage(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	cfg_print_chars(pctx, buf, strlen(buf));
 }
 
-isc_uint32_t
+uint32_t
 cfg_obj_aspercentage(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_percentage);
 	return (obj->value.uint32);
@@ -802,10 +797,10 @@ LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_percentage = {
 	cfg_doc_terminal, &cfg_rep_percentage, NULL
 };
 
-isc_boolean_t
+bool
 cfg_obj_ispercentage(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_percentage));
+	return (obj->type->rep == &cfg_rep_percentage);
 }
 
 /*
@@ -877,7 +872,7 @@ cfg_print_fixedpoint(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	cfg_print_chars(pctx, buf, strlen(buf));
 }
 
-isc_uint32_t
+uint32_t
 cfg_obj_asfixedpoint(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_fixedpoint);
 	return (obj->value.uint32);
@@ -888,10 +883,10 @@ LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_fixedpoint = {
 	cfg_doc_terminal, &cfg_rep_fixedpoint, NULL
 };
 
-isc_boolean_t
+bool
 cfg_obj_isfixedpoint(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_fixedpoint));
+	return (obj->type->rep == &cfg_rep_fixedpoint);
 }
 
 /*
@@ -939,13 +934,13 @@ cfg_print_uint32(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	cfg_print_rawuint(pctx, obj->value.uint32);
 }
 
-isc_boolean_t
+bool
 cfg_obj_isuint32(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_uint32));
+	return (obj->type->rep == &cfg_rep_uint32);
 }
 
-isc_uint32_t
+uint32_t
 cfg_obj_asuint32(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_uint32);
 	return (obj->value.uint32);
@@ -960,13 +955,13 @@ LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_uint32 = {
 /*
  * uint64
  */
-isc_boolean_t
+bool
 cfg_obj_isuint64(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_uint64));
+	return (obj->type->rep == &cfg_rep_uint64);
 }
 
-isc_uint64_t
+uint64_t
 cfg_obj_asuint64(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_uint64);
 	return (obj->value.uint64);
@@ -976,7 +971,7 @@ void
 cfg_print_uint64(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	char buf[32];
 
-	snprintf(buf, sizeof(buf), "%" ISC_PRINT_QUADFORMAT "u",
+	snprintf(buf, sizeof(buf), "%" PRIu64,
 		 obj->value.uint64);
 	cfg_print_cstr(pctx, buf);
 }
@@ -1140,7 +1135,7 @@ doc_btext(cfg_printer_t *pctx, const cfg_type_t *type) {
 }
 
 
-isc_boolean_t
+bool
 cfg_is_enum(const char *s, const char *const *enums) {
 	const char * const *p;
 
@@ -1149,9 +1144,9 @@ cfg_is_enum(const char *s, const char *const *enums) {
 
 	for (p = enums; *p != NULL; p++) {
 		if (strcasecmp(*p, s) == 0)
-			return (ISC_TRUE);
+			return (true);
 	}
-	return (ISC_FALSE);
+	return (false);
 }
 
 static isc_result_t
@@ -1231,10 +1226,10 @@ free_string(cfg_parser_t *pctx, cfg_obj_t *obj) {
 		    obj->value.string.length + 1);
 }
 
-isc_boolean_t
+bool
 cfg_obj_isstring(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_string));
+	return (obj->type->rep == &cfg_rep_string);
 }
 
 const char *
@@ -1284,13 +1279,13 @@ LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_bracketed_text = {
  * Booleans
  */
 
-isc_boolean_t
+bool
 cfg_obj_isboolean(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_boolean));
+	return (obj->type->rep == &cfg_rep_boolean);
 }
 
-isc_boolean_t
+bool
 cfg_obj_asboolean(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_boolean);
 	return (obj->value.boolean);
@@ -1300,7 +1295,7 @@ isc_result_t
 cfg_parse_boolean(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 {
 	isc_result_t result;
-	isc_boolean_t value;
+	bool value;
 	cfg_obj_t *obj = NULL;
 
 	REQUIRE(pctx != NULL);
@@ -1318,11 +1313,11 @@ cfg_parse_boolean(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 	if ((strcasecmp(TOKEN_STRING(pctx), "true") == 0) ||
 	    (strcasecmp(TOKEN_STRING(pctx), "yes") == 0) ||
 	    (strcmp(TOKEN_STRING(pctx), "1") == 0)) {
-		value = ISC_TRUE;
+		value = true;
 	} else if ((strcasecmp(TOKEN_STRING(pctx), "false") == 0) ||
 		   (strcasecmp(TOKEN_STRING(pctx), "no") == 0) ||
 		   (strcmp(TOKEN_STRING(pctx), "0") == 0)) {
-		value = ISC_FALSE;
+		value = false;
 	} else {
 		goto bad_boolean;
 	}
@@ -1579,10 +1574,10 @@ cfg_print_spacelist(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	}
 }
 
-isc_boolean_t
+bool
 cfg_obj_islist(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_list));
+	return (obj->type->rep == &cfg_rep_list);
 }
 
 const cfg_listelt_t *
@@ -1604,7 +1599,7 @@ cfg_list_next(const cfg_listelt_t *elt) {
  * a list, return 0.
  */
 unsigned int
-cfg_list_length(const cfg_obj_t *obj, isc_boolean_t recurse) {
+cfg_list_length(const cfg_obj_t *obj, bool recurse) {
 	const cfg_listelt_t *elt;
 	unsigned int count = 0;
 
@@ -1800,9 +1795,8 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 		} else {
 			/* Single-valued clause */
 			if (result == ISC_R_NOTFOUND) {
-				isc_boolean_t callback =
-					ISC_TF((clause->flags &
-						CFG_CLAUSEFLAG_CALLBACK) != 0);
+				bool callback =
+					(clause->flags & CFG_CLAUSEFLAG_CALLBACK);
 				CHECK(parse_symtab_elt(pctx, clause->name,
 						       clause->type,
 						       obj->value.map.symtab,
@@ -1836,7 +1830,7 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 static isc_result_t
 parse_symtab_elt(cfg_parser_t *pctx, const char *name,
 		 cfg_type_t *elttype, isc_symtab_t *symtab,
-		 isc_boolean_t callback)
+		 bool callback)
 {
 	isc_result_t result;
 	cfg_obj_t *obj = NULL;
@@ -2011,7 +2005,7 @@ static struct flagtext {
 void
 cfg_print_clauseflags(cfg_printer_t *pctx, unsigned int flags) {
 	struct flagtext *p;
-	isc_boolean_t first = ISC_TRUE;
+	bool first = true;
 	for (p = flagtexts; p->flag != 0; p++) {
 		if ((flags & p->flag) != 0) {
 			if (first)
@@ -2019,7 +2013,7 @@ cfg_print_clauseflags(cfg_printer_t *pctx, unsigned int flags) {
 			else
 				cfg_print_cstr(pctx, ", ");
 			cfg_print_cstr(pctx, p->text);
-			first = ISC_FALSE;
+			first = false;
 		}
 	}
 }
@@ -2094,10 +2088,10 @@ cfg_doc_map(cfg_printer_t *pctx, const cfg_type_t *type) {
 	print_close(pctx);
 }
 
-isc_boolean_t
+bool
 cfg_obj_ismap(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_map));
+	return (obj->type->rep == &cfg_rep_map);
 }
 
 isc_result_t
@@ -2326,7 +2320,7 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 		if ((flags & CFG_ADDR_V6OK) != 0 && strlen(s) <= 127U) {
 			char buf[128]; /* see lib/bind9/getaddresses.c */
 			char *d; /* zone delimiter */
-			isc_uint32_t zone = 0; /* scope zone ID */
+			uint32_t zone = 0; /* scope zone ID */
 
 			strlcpy(buf, s, sizeof(buf));
 			d = strchr(buf, '%');
@@ -2335,7 +2329,6 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 
 			if (inet_pton(AF_INET6, buf, &in6a) == 1) {
 				if (d != NULL) {
-#ifdef ISC_PLATFORM_HAVESCOPEID
 					isc_result_t result;
 
 					result = isc_netscope_pton(AF_INET6,
@@ -2344,9 +2337,6 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 								   &zone);
 					if (result != ISC_R_SUCCESS)
 						return (result);
-#else
-				return (ISC_R_BADADDRESSFORM);
-#endif
 				}
 
 				isc_netaddr_fromin6(na, &in6a);
@@ -2391,7 +2381,7 @@ cfg_parse_rawaddr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 	return (result);
 }
 
-isc_boolean_t
+bool
 cfg_lookingat_netaddr(cfg_parser_t *pctx, unsigned int flags) {
 	isc_result_t result;
 	isc_netaddr_t na_dummy;
@@ -2399,7 +2389,7 @@ cfg_lookingat_netaddr(cfg_parser_t *pctx, unsigned int flags) {
 	REQUIRE(pctx != NULL);
 
 	result = token_addr(pctx, flags, &na_dummy);
-	return (ISC_TF(result == ISC_R_SUCCESS));
+	return (result == ISC_R_SUCCESS);
 }
 
 isc_result_t
@@ -2618,10 +2608,10 @@ print_netprefix(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	cfg_print_rawuint(pctx, p->prefixlen);
 }
 
-isc_boolean_t
+bool
 cfg_obj_isnetprefix(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_netprefix));
+	return (obj->type->rep == &cfg_rep_netprefix);
 }
 
 void
@@ -2779,10 +2769,10 @@ cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 	}
 }
 
-isc_boolean_t
+bool
 cfg_obj_issockaddr(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (ISC_TF(obj->type->rep == &cfg_rep_sockaddr));
+	return (obj->type->rep == &cfg_rep_sockaddr);
 }
 
 const isc_sockaddr_t *
@@ -2811,7 +2801,7 @@ cfg_gettoken(cfg_parser_t *pctx, int options) {
  redo:
 	pctx->token.type = isc_tokentype_unknown;
 	result = isc_lex_gettoken(pctx->lexer, options, &pctx->token);
-	pctx->ungotten = ISC_FALSE;
+	pctx->ungotten = false;
 	pctx->line = isc_lex_getsourceline(pctx->lexer);
 
 	switch (result) {
@@ -2835,7 +2825,7 @@ cfg_gettoken(cfg_parser_t *pctx, int options) {
 						value.list, elt, link);
 				goto redo;
 			}
-			pctx->seen_eof = ISC_TRUE;
+			pctx->seen_eof = true;
 		}
 		break;
 
@@ -2864,7 +2854,7 @@ cfg_ungettoken(cfg_parser_t *pctx) {
 	if (pctx->seen_eof)
 		return;
 	isc_lex_ungettoken(pctx->lexer, &pctx->token);
-	pctx->ungotten = ISC_TRUE;
+	pctx->ungotten = true;
 }
 
 isc_result_t
@@ -2907,7 +2897,7 @@ cfg_parser_error(cfg_parser_t *pctx, unsigned int flags, const char *fmt, ...) {
 	REQUIRE(fmt != NULL);
 
 	va_start(args, fmt);
-	parser_complain(pctx, ISC_FALSE, flags, fmt, args);
+	parser_complain(pctx, false, flags, fmt, args);
 	va_end(args);
 	pctx->errors++;
 }
@@ -2920,24 +2910,24 @@ cfg_parser_warning(cfg_parser_t *pctx, unsigned int flags, const char *fmt, ...)
 	REQUIRE(fmt != NULL);
 
 	va_start(args, fmt);
-	parser_complain(pctx, ISC_TRUE, flags, fmt, args);
+	parser_complain(pctx, true, flags, fmt, args);
 	va_end(args);
 	pctx->warnings++;
 }
 
 #define MAX_LOG_TOKEN 30 /* How much of a token to quote in log messages. */
 
-static isc_boolean_t
+static bool
 have_current_file(cfg_parser_t *pctx) {
 	cfg_listelt_t *elt;
 	if (pctx->open_files == NULL)
-		return (ISC_FALSE);
+		return (false);
 
 	elt = ISC_LIST_TAIL(pctx->open_files->value.list);
 	if (elt == NULL)
-	      return (ISC_FALSE);
+	      return (false);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 static char *
@@ -2959,12 +2949,12 @@ current_file(cfg_parser_t *pctx) {
 }
 
 static void
-parser_complain(cfg_parser_t *pctx, isc_boolean_t is_warning,
+parser_complain(cfg_parser_t *pctx, bool is_warning,
 		unsigned int flags, const char *format,
 		va_list args)
 {
 	char tokenbuf[MAX_LOG_TOKEN + 10];
-	static char where[ISC_DIR_PATHMAX + 100];
+	static char where[PATH_MAX + 100];
 	static char message[2048];
 	int level = ISC_LOG_ERROR;
 	const char *prep = "";
@@ -3063,7 +3053,6 @@ cfg_obj_line(const cfg_obj_t *obj) {
 
 isc_result_t
 cfg_create_obj(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
-	isc_result_t result;
 	cfg_obj_t *obj;
 
 	REQUIRE(pctx != NULL);
@@ -3079,11 +3068,8 @@ cfg_create_obj(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	obj->line = pctx->line;
 	obj->pctx = pctx;
 
-	result = isc_refcount_init(&obj->references, 1);
-	if (result != ISC_R_SUCCESS) {
-		isc_mem_put(pctx->mctx, obj, sizeof(cfg_obj_t));
-		return (result);
-	}
+	isc_refcount_init(&obj->references, 1);
+
 	*ret = obj;
 
 	return (ISC_R_SUCCESS);
@@ -3112,7 +3098,7 @@ create_map(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_create_obj(pctx, type, &obj));
 	CHECK(isc_symtab_create(pctx->mctx, 5, /* XXX */
 				map_symtabitem_destroy,
-				pctx, ISC_FALSE, &symtab));
+				pctx, false, &symtab));
 	obj->value.map.symtab = symtab;
 	obj->value.map.id = NULL;
 
@@ -3131,13 +3117,13 @@ free_map(cfg_parser_t *pctx, cfg_obj_t *obj) {
 	isc_symtab_destroy(&obj->value.map.symtab);
 }
 
-isc_boolean_t
+bool
 cfg_obj_istype(const cfg_obj_t *obj, const cfg_type_t *type) {
 
 	REQUIRE(obj != NULL);
 	REQUIRE(type != NULL);
 
-	return (ISC_TF(obj->type == type));
+	return (obj->type == type);
 }
 
 /*
@@ -3145,21 +3131,17 @@ cfg_obj_istype(const cfg_obj_t *obj, const cfg_type_t *type) {
  */
 void
 cfg_obj_destroy(cfg_parser_t *pctx, cfg_obj_t **objp) {
-	cfg_obj_t *obj;
-	unsigned int refs;
-
 	REQUIRE(objp != NULL && *objp != NULL);
 	REQUIRE(pctx != NULL);
 
-	obj = *objp;
+	cfg_obj_t *obj = *objp;
+	*objp = NULL;
 
-	isc_refcount_decrement(&obj->references, &refs);
-	if (refs == 0) {
+	if (isc_refcount_decrement(&obj->references) == 1) {
 		obj->type->rep->free(pctx, obj);
 		isc_refcount_destroy(&obj->references);
 		isc_mem_put(pctx->mctx, obj, sizeof(cfg_obj_t));
 	}
-	*objp = NULL;
 }
 
 void
@@ -3167,7 +3149,7 @@ cfg_obj_attach(cfg_obj_t *src, cfg_obj_t **dest) {
     REQUIRE(src != NULL);
     REQUIRE(dest != NULL && *dest == NULL);
 
-    isc_refcount_increment(&src->references, NULL);
+    isc_refcount_increment(&src->references);
     *dest = src;
 }
 
